!-->  program to get potential energy for a given geometry after NN fitting
!-->  global variables are declared in this module
       module nnparam
       implicit none
       real*8,parameter::alpha=1.0d0,PI=3.1415926d0,radian=PI/180.0d0
       integer,parameter::nbasis=1105,ndim=21,natom=7
       real*8,parameter::vpesmin=-215.234262652419d0
       integer, parameter :: ninput=1104
       integer noutput,nhid,nlayer,ifunc,nwe,nodemax
       integer nscale
       integer, allocatable::nodes(:)
       real*8, allocatable::weighta(:,:,:),biasa(:,:)
       real*8, allocatable::pdela(:),pavga(:)

       end module nnparam

      subroutine pes(x,igrad,path,p,g,d)

      use nnparam
      implicit none
      ! number of electronic state
      integer, parameter :: nstates=1
      integer, parameter :: natoms=7
      integer, intent(in) :: igrad
      character(len=1024), intent(in) :: path
      double precision, intent(in) :: x(natoms,3)
      double precision, intent(out) :: p(nstates), g(nstates,natoms,3)
      double precision, intent(out) :: d(nstates,nstates,natoms,3)

      double precision :: v
      double precision :: tx(3,natoms)
      integer :: iatom, idir, j, istate
      !initialize 
      v=0.d0
      g=0.d0
      d=0.d0

      do iatom=1,natoms
        do idir=1,3
          tx(idir,iatom)=x(iatom, idir)
        enddo
      enddo

      if (igrad==0) then
        call pes_init(path)
        call fch3ohpipNN(tx, v)
        deallocate(nodes)
        deallocate(weighta)
        deallocate(biasa)
        deallocate(pdela)
        deallocate(pavga)
      else
        write (*,*) 'Only energy and gradient are available'
      endif

      do istate=1,nstates
        p(istate)=v
      enddo

      g=0.d0
      d=0.d0

      endsubroutine


       subroutine fch3ohpipNN(ct,vpes)
       use nnparam
       implicit none
       integer i,j,k,lpes
       real*8 rb(ndim),xbond(ndim),basis(nbasis),tmp1,txinput(nbasis-1)
       real*8 ct(3,natom),xvec(3,ndim),cx(3,natom),cy(3,natom)
       real*8 vpes,vpesa,vpesb,vpesc,vpesH,vnn
       basis=0.d0

       cx=ct

       k=0
       do i=1,natom-1
        do j=i+1,natom
         k=k+1
!        write(*,*)k,i,j
         xvec(:,k)=cx(:,i)-cx(:,j)
        enddo
       enddo
       if(k.ne.ndim)stop 'error in bond dimension'
       do i=1,ndim
        rb(i)=dsqrt(dot_product(xvec(:,i),xvec(:,i)))
       enddo

       xbond(:)=dexp(-rb(:)/alpha)
       call bemsav(xbond,basis)

       do j=1,nbasis-1
        txinput(j)=basis(j+1)
       enddo
!        write(987,'(2000E16.8)')txinput(:)

       call getpota(txinput,vpes)
!       vnn=vpes
!       vpes=vnn

       return

       end subroutine fch3ohpipNN

!-->  read NN weights and biases from matlab output
!-->  weights saved in 'weights.txt'
!-->  biases saved in 'biases.txt'
!-->  one has to call this subroutine one and only one before calling the getpot() subroutine
      subroutine pes_init(path)
      use nnparam
      implicit none
      character(len=1024), intent(in) :: path
      integer i,ihid,iwe,inode1,inode2,ilay1,ilay2
      integer ibasis,npd,iterm,ib,nfile
      character f1*80,line*80
      character(len=1024) :: file_path1, file_path2

      file_path1 = trim(path)//"/CH4OF/weights.txt"
      file_path2 = trim(path)//"/CH4OF/biases.txt"

      open(4,file=file_path2,status='old')

        nfile=7
        open(nfile,file=file_path1)
        read(nfile,*)nhid,noutput
        nscale=ninput+noutput
        nlayer=nhid+2 !additional one for input layer and one for output 
        allocate(nodes(nlayer),pdela(nscale),pavga(nscale))
        nodes(1)=ninput
        nodes(nlayer)=noutput
        read(nfile,*)(nodes(ihid),ihid=2,nhid+1)
        nodemax=0
        do i=1,nlayer
         nodemax=max(nodemax,nodes(i))
        enddo
        allocate(weighta(nodemax,nodemax,2:nlayer),&
     &   biasa(nodemax,2:nlayer))
        read(nfile,*)ifunc,nwe
!-->....ifunc hence controls the type of transfer function used for hidden layers
!-->....At this time, only an equivalent transfer function can be used for all hidden layers
!-->....and the pure linear function is always applid to the output layer.
!-->....see function tranfun() for details
        read(nfile,*)(pdela(i),i=1,nscale)
        read(nfile,*)(pavga(i),i=1,nscale)
        iwe=0
        do ilay1=2,nlayer
        ilay2=ilay1-1
        do inode1=1,nodes(ilay1)
        do inode2=1,nodes(ilay2) !
        read(nfile,*)weighta(inode2,inode1,ilay1)
        iwe=iwe+1
        enddo
        read(4,*)biasa(inode1,ilay1)
        iwe=iwe+1
        enddo
        enddo
        
        if (iwe.ne.nwe) then
           write(*,*)'provided number of parameters ',nwe
           write(*,*)'actual number of parameters ',iwe
           write(*,*)'nwe not equal to iwe, check input files or code'
           stop
        endif

        close(nfile)
        close(4)

        return
        end subroutine pes_init 

        subroutine getpota(x,vpot)
        use nnparam
        implicit none
        integer i,inode1,inode2,ilay1,ilay2
        integer j,k,neu1,neu2,ndriv
        real*8 x(ninput),y(nodemax,nlayer),vpot
        real*8, external :: tranfun
!-->....set up the normalized input layer
        do i=1,ninput
          y(i,1)=(x(i)-pavga(i))/pdela(i)
        enddo

!-->....evaluate the hidden layer
        do ilay1=2,nlayer-1
        ilay2=ilay1-1
        do inode1=1,nodes(ilay1)
        y(inode1,ilay1)=biasa(inode1,ilay1)
        do inode2=1,nodes(ilay2)
        y(inode1,ilay1)=y(inode1,ilay1)+y(inode2,ilay2)&
     &*weighta(inode2,inode1,ilay1)
        enddo
        y(inode1,ilay1)=tranfun(y(inode1,ilay1),ifunc)
        enddo
        enddo

!-->....now evaluate the output
        ilay1=nlayer
        ilay2=ilay1-1
        do inode1=1,nodes(ilay1)
        y(inode1,ilay1)=biasa(inode1,ilay1)
        do inode2=1,nodes(ilay2)
        y(inode1,ilay1)=y(inode1,ilay1)+y(inode2,ilay2)&
     &*weighta(inode2,inode1,ilay1)
        enddo
!-->....the transfer function is linear y=x for output layer
!-->....so no operation is needed here
        enddo

!-->....the value of output layer is the fitted potntial 
        vpot=y(nodes(nlayer),nlayer)*pdela(nscale)+pavga(nscale)

        return
        end subroutine getpota


        function tranfun(x,ifunc)
        implicit none
        integer ifunc
        real*8 tranfun,x
        if (ifunc.eq.1) then
        tranfun=dtanh(x)
        else if (ifunc.eq.2) then
        tranfun=1d0/(1d0+dexp(-x))
        else if (ifunc.eq.3) then
        tranfun=x
        endif
        return
        end

      subroutine bemsav(xmorse,p)
      implicit none
      real*8,dimension(1:21),intent(in)::xmorse
      real*8,dimension(0:1104),intent(out)::p
      ! ::::::::::::::::::::
      real*8,dimension(0:2000)::m
      call evmono(xmorse,m)
      call evpoly(m,p)
      return
      end subroutine bemsav
 
 
      subroutine evmono(x,m)
      implicit none
      real*8,dimension(1:21),intent(in)::x
      real*8,dimension(0:2000),intent(out)::m
 
      m(0)=1.D0
      m(1)=x(21)
      m(2)=x(20)
      m(3)=x(19)
      m(4)=x(18)
      m(5)=x(15)
      m(6)=x(11)
      m(7)=x(6)
      m(8)=x(17)
      m(9)=x(14)
      m(10)=x(10)
      m(11)=x(5)
      m(12)=x(16)
      m(13)=x(13)
      m(14)=x(9)
      m(15)=x(4)
      m(16)=x(12)
      m(17)=x(8)
      m(18)=x(7)
      m(19)=x(3)
      m(20)=x(2)
      m(21)=x(1)
      m(22)=m(4)*m(5)
      m(23)=m(4)*m(6)
      m(24)=m(5)*m(6)
      m(25)=m(4)*m(7)
      m(26)=m(5)*m(7)
      m(27)=m(6)*m(7)
      m(28)=m(5)*m(8)
      m(29)=m(4)*m(9)
      m(30)=m(6)*m(8)
      m(31)=m(6)*m(9)
      m(32)=m(4)*m(10)
      m(33)=m(5)*m(10)
      m(34)=m(7)*m(8)
      m(35)=m(7)*m(9)
      m(36)=m(7)*m(10)
      m(37)=m(4)*m(11)
      m(38)=m(5)*m(11)
      m(39)=m(6)*m(11)
      m(40)=m(8)*m(9)
      m(41)=m(8)*m(10)
      m(42)=m(9)*m(10)
      m(43)=m(8)*m(11)
      m(44)=m(9)*m(11)
      m(45)=m(10)*m(11)
      m(46)=m(5)*m(12)
      m(47)=m(4)*m(13)
      m(48)=m(6)*m(12)
      m(49)=m(6)*m(13)
      m(50)=m(4)*m(14)
      m(51)=m(5)*m(14)
      m(52)=m(7)*m(12)
      m(53)=m(7)*m(13)
      m(54)=m(7)*m(14)
      m(55)=m(4)*m(15)
      m(56)=m(5)*m(15)
      m(57)=m(6)*m(15)
      m(58)=m(9)*m(12)
      m(59)=m(8)*m(13)
      m(60)=m(10)*m(12)
      m(61)=m(10)*m(13)
      m(62)=m(8)*m(14)
      m(63)=m(9)*m(14)
      m(64)=m(11)*m(12)
      m(65)=m(11)*m(13)
      m(66)=m(11)*m(14)
      m(67)=m(8)*m(15)
      m(68)=m(9)*m(15)
      m(69)=m(10)*m(15)
      m(70)=m(12)*m(13)
      m(71)=m(12)*m(14)
      m(72)=m(13)*m(14)
      m(73)=m(12)*m(15)
      m(74)=m(13)*m(15)
      m(75)=m(14)*m(15)
      m(76)=m(6)*m(16)
      m(77)=m(5)*m(17)
      m(78)=m(4)*m(18)
      m(79)=m(7)*m(16)
      m(80)=m(7)*m(17)
      m(81)=m(7)*m(18)
      m(82)=m(5)*m(19)
      m(83)=m(6)*m(19)
      m(84)=m(4)*m(20)
      m(85)=m(6)*m(20)
      m(86)=m(4)*m(21)
      m(87)=m(5)*m(21)
      m(88)=m(10)*m(16)
      m(89)=m(9)*m(17)
      m(90)=m(8)*m(18)
      m(91)=m(11)*m(16)
      m(92)=m(11)*m(17)
      m(93)=m(11)*m(18)
      m(94)=m(9)*m(19)
      m(95)=m(10)*m(19)
      m(96)=m(8)*m(20)
      m(97)=m(10)*m(20)
      m(98)=m(8)*m(21)
      m(99)=m(9)*m(21)
      m(100)=m(14)*m(16)
      m(101)=m(13)*m(17)
      m(102)=m(12)*m(18)
      m(103)=m(15)*m(16)
      m(104)=m(15)*m(17)
      m(105)=m(15)*m(18)
      m(106)=m(13)*m(19)
      m(107)=m(14)*m(19)
      m(108)=m(12)*m(20)
      m(109)=m(14)*m(20)
      m(110)=m(12)*m(21)
      m(111)=m(13)*m(21)
      m(112)=m(18)*m(19)
      m(113)=m(17)*m(20)
      m(114)=m(16)*m(21)
      m(115)=m(16)*m(17)
      m(116)=m(16)*m(18)
      m(117)=m(17)*m(18)
      m(118)=m(16)*m(19)
      m(119)=m(17)*m(19)
      m(120)=m(16)*m(20)
      m(121)=m(18)*m(20)
      m(122)=m(19)*m(20)
      m(123)=m(17)*m(21)
      m(124)=m(18)*m(21)
      m(125)=m(19)*m(21)
      m(126)=m(20)*m(21)
      m(127)=m(4)*m(24)
      m(128)=m(4)*m(26)
      m(129)=m(4)*m(27)
      m(130)=m(5)*m(27)
      m(131)=m(5)*m(30)
      m(132)=m(4)*m(31)
      m(133)=m(4)*m(33)
      m(134)=m(5)*m(34)
      m(135)=m(4)*m(35)
      m(136)=m(6)*m(34)
      m(137)=m(6)*m(35)
      m(138)=m(4)*m(36)
      m(139)=m(5)*m(36)
      m(140)=m(4)*m(38)
      m(141)=m(4)*m(39)
      m(142)=m(5)*m(39)
      m(143)=m(6)*m(40)
      m(144)=m(5)*m(41)
      m(145)=m(4)*m(42)
      m(146)=m(7)*m(40)
      m(147)=m(7)*m(41)
      m(148)=m(7)*m(42)
      m(149)=m(5)*m(43)
      m(150)=m(4)*m(44)
      m(151)=m(6)*m(43)
      m(152)=m(6)*m(44)
      m(153)=m(4)*m(45)
      m(154)=m(5)*m(45)
      m(155)=m(8)*m(42)
      m(156)=m(8)*m(44)
      m(157)=m(8)*m(45)
      m(158)=m(9)*m(45)
      m(159)=m(5)*m(48)
      m(160)=m(4)*m(49)
      m(161)=m(4)*m(51)
      m(162)=m(5)*m(52)
      m(163)=m(4)*m(53)
      m(164)=m(6)*m(52)
      m(165)=m(6)*m(53)
      m(166)=m(4)*m(54)
      m(167)=m(5)*m(54)
      m(168)=m(4)*m(56)
      m(169)=m(4)*m(57)
      m(170)=m(5)*m(57)
      m(171)=m(6)*m(58)
      m(172)=m(6)*m(59)
      m(173)=m(5)*m(60)
      m(174)=m(4)*m(61)
      m(175)=m(5)*m(62)
      m(176)=m(4)*m(63)
      m(177)=m(7)*m(58)
      m(178)=m(7)*m(59)
      m(179)=m(7)*m(60)
      m(180)=m(7)*m(61)
      m(181)=m(7)*m(62)
      m(182)=m(7)*m(63)
      m(183)=m(5)*m(64)
      m(184)=m(4)*m(65)
      m(185)=m(6)*m(64)
      m(186)=m(6)*m(65)
      m(187)=m(4)*m(66)
      m(188)=m(5)*m(66)
      m(189)=m(5)*m(67)
      m(190)=m(4)*m(68)
      m(191)=m(6)*m(67)
      m(192)=m(6)*m(68)
      m(193)=m(4)*m(69)
      m(194)=m(5)*m(69)
      m(195)=m(9)*m(60)
      m(196)=m(8)*m(61)
      m(197)=m(8)*m(63)
      m(198)=m(9)*m(64)
      m(199)=m(8)*m(65)
      m(200)=m(10)*m(64)
      m(201)=m(10)*m(65)
      m(202)=m(8)*m(66)
      m(203)=m(9)*m(66)
      m(204)=m(8)*m(68)
      m(205)=m(8)*m(69)
      m(206)=m(9)*m(69)
      m(207)=m(5)*m(58)
      m(208)=m(4)*m(59)
      m(209)=m(6)*m(60)
      m(210)=m(6)*m(61)
      m(211)=m(4)*m(62)
      m(212)=m(5)*m(63)
      m(213)=m(7)*m(64)
      m(214)=m(7)*m(65)
      m(215)=m(7)*m(66)
      m(216)=m(4)*m(67)
      m(217)=m(5)*m(68)
      m(218)=m(6)*m(69)
      m(219)=m(6)*m(70)
      m(220)=m(5)*m(71)
      m(221)=m(4)*m(72)
      m(222)=m(7)*m(70)
      m(223)=m(7)*m(71)
      m(224)=m(7)*m(72)
      m(225)=m(5)*m(73)
      m(226)=m(4)*m(74)
      m(227)=m(6)*m(73)
      m(228)=m(6)*m(74)
      m(229)=m(4)*m(75)
      m(230)=m(5)*m(75)
      m(231)=m(10)*m(70)
      m(232)=m(9)*m(71)
      m(233)=m(8)*m(72)
      m(234)=m(11)*m(70)
      m(235)=m(11)*m(71)
      m(236)=m(11)*m(72)
      m(237)=m(9)*m(73)
      m(238)=m(8)*m(74)
      m(239)=m(10)*m(73)
      m(240)=m(10)*m(74)
      m(241)=m(8)*m(75)
      m(242)=m(9)*m(75)
      m(243)=m(12)*m(72)
      m(244)=m(12)*m(74)
      m(245)=m(12)*m(75)
      m(246)=m(13)*m(75)
      m(247)=m(6)*m(79)
      m(248)=m(5)*m(80)
      m(249)=m(4)*m(81)
      m(250)=m(5)*m(83)
      m(251)=m(4)*m(85)
      m(252)=m(4)*m(87)
      m(253)=m(7)*m(88)
      m(254)=m(7)*m(89)
      m(255)=m(7)*m(90)
      m(256)=m(6)*m(91)
      m(257)=m(5)*m(92)
      m(258)=m(4)*m(93)
      m(259)=m(6)*m(94)
      m(260)=m(5)*m(95)
      m(261)=m(6)*m(96)
      m(262)=m(4)*m(97)
      m(263)=m(5)*m(98)
      m(264)=m(4)*m(99)
      m(265)=m(10)*m(91)
      m(266)=m(9)*m(92)
      m(267)=m(8)*m(93)
      m(268)=m(9)*m(95)
      m(269)=m(8)*m(97)
      m(270)=m(8)*m(99)
      m(271)=m(6)*m(88)
      m(272)=m(5)*m(89)
      m(273)=m(4)*m(90)
      m(274)=m(7)*m(91)
      m(275)=m(7)*m(92)
      m(276)=m(7)*m(93)
      m(277)=m(5)*m(94)
      m(278)=m(6)*m(95)
      m(279)=m(4)*m(96)
      m(280)=m(6)*m(97)
      m(281)=m(4)*m(98)
      m(282)=m(5)*m(99)
      m(283)=m(7)*m(100)
      m(284)=m(7)*m(101)
      m(285)=m(7)*m(102)
      m(286)=m(6)*m(103)
      m(287)=m(5)*m(104)
      m(288)=m(4)*m(105)
      m(289)=m(6)*m(106)
      m(290)=m(5)*m(107)
      m(291)=m(6)*m(108)
      m(292)=m(4)*m(109)
      m(293)=m(5)*m(110)
      m(294)=m(4)*m(111)
      m(295)=m(11)*m(100)
      m(296)=m(11)*m(101)
      m(297)=m(11)*m(102)
      m(298)=m(10)*m(103)
      m(299)=m(9)*m(104)
      m(300)=m(8)*m(105)
      m(301)=m(10)*m(106)
      m(302)=m(9)*m(107)
      m(303)=m(10)*m(108)
      m(304)=m(8)*m(109)
      m(305)=m(9)*m(110)
      m(306)=m(8)*m(111)
      m(307)=m(14)*m(103)
      m(308)=m(13)*m(104)
      m(309)=m(12)*m(105)
      m(310)=m(13)*m(107)
      m(311)=m(12)*m(109)
      m(312)=m(12)*m(111)
      m(313)=m(6)*m(100)
      m(314)=m(5)*m(101)
      m(315)=m(4)*m(102)
      m(316)=m(7)*m(103)
      m(317)=m(7)*m(104)
      m(318)=m(7)*m(105)
      m(319)=m(5)*m(106)
      m(320)=m(6)*m(107)
      m(321)=m(4)*m(108)
      m(322)=m(6)*m(109)
      m(323)=m(4)*m(110)
      m(324)=m(5)*m(111)
      m(325)=m(10)*m(100)
      m(326)=m(9)*m(101)
      m(327)=m(8)*m(102)
      m(328)=m(11)*m(103)
      m(329)=m(11)*m(104)
      m(330)=m(11)*m(105)
      m(331)=m(9)*m(106)
      m(332)=m(10)*m(107)
      m(333)=m(8)*m(108)
      m(334)=m(10)*m(109)
      m(335)=m(8)*m(110)
      m(336)=m(9)*m(111)
      m(337)=m(4)*m(76)
      m(338)=m(5)*m(76)
      m(339)=m(4)*m(77)
      m(340)=m(6)*m(77)
      m(341)=m(5)*m(78)
      m(342)=m(6)*m(78)
      m(343)=m(4)*m(79)
      m(344)=m(5)*m(79)
      m(345)=m(4)*m(80)
      m(346)=m(6)*m(80)
      m(347)=m(5)*m(81)
      m(348)=m(6)*m(81)
      m(349)=m(4)*m(82)
      m(350)=m(4)*m(83)
      m(351)=m(7)*m(82)
      m(352)=m(7)*m(83)
      m(353)=m(5)*m(84)
      m(354)=m(5)*m(85)
      m(355)=m(7)*m(84)
      m(356)=m(7)*m(85)
      m(357)=m(6)*m(86)
      m(358)=m(6)*m(87)
      m(359)=m(7)*m(86)
      m(360)=m(7)*m(87)
      m(361)=m(8)*m(88)
      m(362)=m(9)*m(88)
      m(363)=m(8)*m(89)
      m(364)=m(10)*m(89)
      m(365)=m(9)*m(90)
      m(366)=m(10)*m(90)
      m(367)=m(8)*m(91)
      m(368)=m(9)*m(91)
      m(369)=m(8)*m(92)
      m(370)=m(10)*m(92)
      m(371)=m(9)*m(93)
      m(372)=m(10)*m(93)
      m(373)=m(8)*m(94)
      m(374)=m(8)*m(95)
      m(375)=m(11)*m(94)
      m(376)=m(11)*m(95)
      m(377)=m(9)*m(96)
      m(378)=m(9)*m(97)
      m(379)=m(11)*m(96)
      m(380)=m(11)*m(97)
      m(381)=m(10)*m(98)
      m(382)=m(10)*m(99)
      m(383)=m(11)*m(98)
      m(384)=m(11)*m(99)
      m(385)=m(12)*m(100)
      m(386)=m(13)*m(100)
      m(387)=m(12)*m(101)
      m(388)=m(14)*m(101)
      m(389)=m(13)*m(102)
      m(390)=m(14)*m(102)
      m(391)=m(12)*m(103)
      m(392)=m(13)*m(103)
      m(393)=m(12)*m(104)
      m(394)=m(14)*m(104)
      m(395)=m(13)*m(105)
      m(396)=m(14)*m(105)
      m(397)=m(12)*m(106)
      m(398)=m(12)*m(107)
      m(399)=m(15)*m(106)
      m(400)=m(15)*m(107)
      m(401)=m(13)*m(108)
      m(402)=m(13)*m(109)
      m(403)=m(15)*m(108)
      m(404)=m(15)*m(109)
      m(405)=m(14)*m(110)
      m(406)=m(14)*m(111)
      m(407)=m(15)*m(110)
      m(408)=m(15)*m(111)
      m(409)=m(7)*m(115)
      m(410)=m(7)*m(116)
      m(411)=m(7)*m(117)
      m(412)=m(6)*m(118)
      m(413)=m(5)*m(119)
      m(414)=m(6)*m(120)
      m(415)=m(4)*m(121)
      m(416)=m(6)*m(122)
      m(417)=m(5)*m(123)
      m(418)=m(4)*m(124)
      m(419)=m(5)*m(125)
      m(420)=m(4)*m(126)
      m(421)=m(11)*m(115)
      m(422)=m(11)*m(116)
      m(423)=m(11)*m(117)
      m(424)=m(10)*m(118)
      m(425)=m(9)*m(119)
      m(426)=m(10)*m(120)
      m(427)=m(8)*m(121)
      m(428)=m(10)*m(122)
      m(429)=m(9)*m(123)
      m(430)=m(8)*m(124)
      m(431)=m(9)*m(125)
      m(432)=m(8)*m(126)
      m(433)=m(15)*m(115)
      m(434)=m(15)*m(116)
      m(435)=m(15)*m(117)
      m(436)=m(14)*m(118)
      m(437)=m(13)*m(119)
      m(438)=m(14)*m(120)
      m(439)=m(12)*m(121)
      m(440)=m(14)*m(122)
      m(441)=m(13)*m(123)
      m(442)=m(12)*m(124)
      m(443)=m(13)*m(125)
      m(444)=m(12)*m(126)
      m(445)=m(5)*m(115)
      m(446)=m(6)*m(115)
      m(447)=m(4)*m(116)
      m(448)=m(6)*m(116)
      m(449)=m(4)*m(117)
      m(450)=m(5)*m(117)
      m(451)=m(5)*m(118)
      m(452)=m(6)*m(119)
      m(453)=m(7)*m(118)
      m(454)=m(7)*m(119)
      m(455)=m(4)*m(120)
      m(456)=m(6)*m(121)
      m(457)=m(7)*m(120)
      m(458)=m(7)*m(121)
      m(459)=m(4)*m(122)
      m(460)=m(5)*m(122)
      m(461)=m(4)*m(123)
      m(462)=m(5)*m(124)
      m(463)=m(7)*m(123)
      m(464)=m(7)*m(124)
      m(465)=m(4)*m(125)
      m(466)=m(6)*m(125)
      m(467)=m(5)*m(126)
      m(468)=m(6)*m(126)
      m(469)=m(9)*m(115)
      m(470)=m(10)*m(115)
      m(471)=m(8)*m(116)
      m(472)=m(10)*m(116)
      m(473)=m(8)*m(117)
      m(474)=m(9)*m(117)
      m(475)=m(9)*m(118)
      m(476)=m(10)*m(119)
      m(477)=m(11)*m(118)
      m(478)=m(11)*m(119)
      m(479)=m(8)*m(120)
      m(480)=m(10)*m(121)
      m(481)=m(11)*m(120)
      m(482)=m(11)*m(121)
      m(483)=m(8)*m(122)
      m(484)=m(9)*m(122)
      m(485)=m(8)*m(123)
      m(486)=m(9)*m(124)
      m(487)=m(11)*m(123)
      m(488)=m(11)*m(124)
      m(489)=m(8)*m(125)
      m(490)=m(10)*m(125)
      m(491)=m(9)*m(126)
      m(492)=m(10)*m(126)
      m(493)=m(13)*m(115)
      m(494)=m(14)*m(115)
      m(495)=m(12)*m(116)
      m(496)=m(14)*m(116)
      m(497)=m(12)*m(117)
      m(498)=m(13)*m(117)
      m(499)=m(13)*m(118)
      m(500)=m(14)*m(119)
      m(501)=m(15)*m(118)
      m(502)=m(15)*m(119)
      m(503)=m(12)*m(120)
      m(504)=m(14)*m(121)
      m(505)=m(15)*m(120)
      m(506)=m(15)*m(121)
      m(507)=m(12)*m(122)
      m(508)=m(13)*m(122)
      m(509)=m(12)*m(123)
      m(510)=m(13)*m(124)
      m(511)=m(15)*m(123)
      m(512)=m(15)*m(124)
      m(513)=m(12)*m(125)
      m(514)=m(14)*m(125)
      m(515)=m(13)*m(126)
      m(516)=m(14)*m(126)
      m(517)=m(16)*m(112)
      m(518)=m(17)*m(112)
      m(519)=m(16)*m(113)
      m(520)=m(17)*m(121)
      m(521)=m(17)*m(122)
      m(522)=m(18)*m(122)
      m(523)=m(16)*m(123)
      m(524)=m(16)*m(124)
      m(525)=m(16)*m(125)
      m(526)=m(18)*m(125)
      m(527)=m(16)*m(126)
      m(528)=m(17)*m(126)
      m(529)=m(16)*m(117)
      m(530)=m(16)*m(122)
      m(531)=m(17)*m(125)
      m(532)=m(18)*m(126)
      m(533)=m(16)*m(119)
      m(534)=m(16)*m(121)
      m(535)=m(17)*m(124)
      m(536)=m(19)*m(126)
      m(537)=m(4)*m(130)
      m(538)=m(5)*m(136)
      m(539)=m(4)*m(137)
      m(540)=m(4)*m(139)
      m(541)=m(4)*m(142)
      m(542)=m(6)*m(146)
      m(543)=m(5)*m(147)
      m(544)=m(4)*m(148)
      m(545)=m(5)*m(151)
      m(546)=m(4)*m(152)
      m(547)=m(4)*m(154)
      m(548)=m(7)*m(155)
      m(549)=m(6)*m(156)
      m(550)=m(5)*m(157)
      m(551)=m(4)*m(158)
      m(552)=m(8)*m(158)
      m(553)=m(4)*m(143)
      m(554)=m(5)*m(143)
      m(555)=m(4)*m(144)
      m(556)=m(5)*m(145)
      m(557)=m(6)*m(144)
      m(558)=m(6)*m(145)
      m(559)=m(4)*m(146)
      m(560)=m(5)*m(146)
      m(561)=m(4)*m(147)
      m(562)=m(5)*m(148)
      m(563)=m(6)*m(147)
      m(564)=m(6)*m(148)
      m(565)=m(4)*m(149)
      m(566)=m(5)*m(150)
      m(567)=m(4)*m(151)
      m(568)=m(5)*m(152)
      m(569)=m(6)*m(153)
      m(570)=m(6)*m(154)
      m(571)=m(7)*m(149)
      m(572)=m(7)*m(150)
      m(573)=m(7)*m(151)
      m(574)=m(7)*m(152)
      m(575)=m(7)*m(153)
      m(576)=m(7)*m(154)
      m(577)=m(5)*m(164)
      m(578)=m(4)*m(165)
      m(579)=m(4)*m(167)
      m(580)=m(4)*m(170)
      m(581)=m(6)*m(177)
      m(582)=m(6)*m(178)
      m(583)=m(5)*m(179)
      m(584)=m(4)*m(180)
      m(585)=m(5)*m(181)
      m(586)=m(4)*m(182)
      m(587)=m(5)*m(185)
      m(588)=m(4)*m(186)
      m(589)=m(4)*m(188)
      m(590)=m(5)*m(191)
      m(591)=m(4)*m(192)
      m(592)=m(4)*m(194)
      m(593)=m(7)*m(195)
      m(594)=m(7)*m(196)
      m(595)=m(7)*m(197)
      m(596)=m(6)*m(198)
      m(597)=m(6)*m(199)
      m(598)=m(5)*m(200)
      m(599)=m(4)*m(201)
      m(600)=m(5)*m(202)
      m(601)=m(4)*m(203)
      m(602)=m(6)*m(204)
      m(603)=m(5)*m(205)
      m(604)=m(4)*m(206)
      m(605)=m(9)*m(200)
      m(606)=m(8)*m(201)
      m(607)=m(8)*m(203)
      m(608)=m(8)*m(206)
      m(609)=m(5)*m(171)
      m(610)=m(4)*m(172)
      m(611)=m(5)*m(209)
      m(612)=m(4)*m(210)
      m(613)=m(4)*m(175)
      m(614)=m(4)*m(212)
      m(615)=m(5)*m(177)
      m(616)=m(4)*m(178)
      m(617)=m(6)*m(179)
      m(618)=m(6)*m(180)
      m(619)=m(4)*m(181)
      m(620)=m(5)*m(182)
      m(621)=m(5)*m(213)
      m(622)=m(4)*m(214)
      m(623)=m(6)*m(213)
      m(624)=m(6)*m(214)
      m(625)=m(4)*m(215)
      m(626)=m(5)*m(215)
      m(627)=m(4)*m(189)
      m(628)=m(4)*m(217)
      m(629)=m(4)*m(191)
      m(630)=m(5)*m(192)
      m(631)=m(4)*m(218)
      m(632)=m(5)*m(218)
      m(633)=m(5)*m(195)
      m(634)=m(4)*m(196)
      m(635)=m(6)*m(195)
      m(636)=m(6)*m(196)
      m(637)=m(4)*m(197)
      m(638)=m(5)*m(197)
      m(639)=m(5)*m(198)
      m(640)=m(4)*m(199)
      m(641)=m(6)*m(200)
      m(642)=m(6)*m(201)
      m(643)=m(4)*m(202)
      m(644)=m(5)*m(203)
      m(645)=m(7)*m(198)
      m(646)=m(7)*m(199)
      m(647)=m(7)*m(200)
      m(648)=m(7)*m(201)
      m(649)=m(7)*m(202)
      m(650)=m(7)*m(203)
      m(651)=m(4)*m(204)
      m(652)=m(5)*m(204)
      m(653)=m(4)*m(205)
      m(654)=m(5)*m(206)
      m(655)=m(6)*m(205)
      m(656)=m(6)*m(206)
      m(657)=m(6)*m(222)
      m(658)=m(5)*m(223)
      m(659)=m(4)*m(224)
      m(660)=m(5)*m(227)
      m(661)=m(4)*m(228)
      m(662)=m(4)*m(230)
      m(663)=m(7)*m(231)
      m(664)=m(7)*m(232)
      m(665)=m(7)*m(233)
      m(666)=m(6)*m(234)
      m(667)=m(5)*m(235)
      m(668)=m(4)*m(236)
      m(669)=m(6)*m(237)
      m(670)=m(6)*m(238)
      m(671)=m(5)*m(239)
      m(672)=m(4)*m(240)
      m(673)=m(5)*m(241)
      m(674)=m(4)*m(242)
      m(675)=m(10)*m(234)
      m(676)=m(9)*m(235)
      m(677)=m(8)*m(236)
      m(678)=m(9)*m(239)
      m(679)=m(8)*m(240)
      m(680)=m(8)*m(242)
      m(681)=m(6)*m(231)
      m(682)=m(5)*m(232)
      m(683)=m(4)*m(233)
      m(684)=m(7)*m(234)
      m(685)=m(7)*m(235)
      m(686)=m(7)*m(236)
      m(687)=m(5)*m(237)
      m(688)=m(4)*m(238)
      m(689)=m(6)*m(239)
      m(690)=m(6)*m(240)
      m(691)=m(4)*m(241)
      m(692)=m(5)*m(242)
      m(693)=m(7)*m(243)
      m(694)=m(6)*m(244)
      m(695)=m(5)*m(245)
      m(696)=m(4)*m(246)
      m(697)=m(11)*m(243)
      m(698)=m(10)*m(244)
      m(699)=m(9)*m(245)
      m(700)=m(8)*m(246)
      m(701)=m(12)*m(246)
      m(702)=m(4)*m(171)
      m(703)=m(5)*m(172)
      m(704)=m(4)*m(173)
      m(705)=m(5)*m(174)
      m(706)=m(6)*m(175)
      m(707)=m(6)*m(176)
      m(708)=m(4)*m(177)
      m(709)=m(5)*m(178)
      m(710)=m(4)*m(179)
      m(711)=m(5)*m(180)
      m(712)=m(6)*m(181)
      m(713)=m(6)*m(182)
      m(714)=m(4)*m(183)
      m(715)=m(5)*m(184)
      m(716)=m(4)*m(185)
      m(717)=m(5)*m(186)
      m(718)=m(6)*m(187)
      m(719)=m(6)*m(188)
      m(720)=m(7)*m(189)
      m(721)=m(7)*m(190)
      m(722)=m(7)*m(191)
      m(723)=m(7)*m(192)
      m(724)=m(7)*m(193)
      m(725)=m(7)*m(194)
      m(726)=m(4)*m(219)
      m(727)=m(5)*m(219)
      m(728)=m(4)*m(220)
      m(729)=m(5)*m(221)
      m(730)=m(6)*m(220)
      m(731)=m(6)*m(221)
      m(732)=m(4)*m(222)
      m(733)=m(5)*m(222)
      m(734)=m(4)*m(223)
      m(735)=m(5)*m(224)
      m(736)=m(6)*m(223)
      m(737)=m(6)*m(224)
      m(738)=m(4)*m(225)
      m(739)=m(5)*m(226)
      m(740)=m(4)*m(227)
      m(741)=m(5)*m(228)
      m(742)=m(6)*m(229)
      m(743)=m(6)*m(230)
      m(744)=m(7)*m(225)
      m(745)=m(7)*m(226)
      m(746)=m(7)*m(227)
      m(747)=m(7)*m(228)
      m(748)=m(7)*m(229)
      m(749)=m(7)*m(230)
      m(750)=m(8)*m(231)
      m(751)=m(9)*m(231)
      m(752)=m(8)*m(232)
      m(753)=m(9)*m(233)
      m(754)=m(10)*m(232)
      m(755)=m(10)*m(233)
      m(756)=m(8)*m(234)
      m(757)=m(9)*m(234)
      m(758)=m(8)*m(235)
      m(759)=m(9)*m(236)
      m(760)=m(10)*m(235)
      m(761)=m(10)*m(236)
      m(762)=m(8)*m(237)
      m(763)=m(9)*m(238)
      m(764)=m(8)*m(239)
      m(765)=m(9)*m(240)
      m(766)=m(10)*m(241)
      m(767)=m(10)*m(242)
      m(768)=m(11)*m(237)
      m(769)=m(11)*m(238)
      m(770)=m(11)*m(239)
      m(771)=m(11)*m(240)
      m(772)=m(11)*m(241)
      m(773)=m(11)*m(242)
      m(774)=m(6)*m(253)
      m(775)=m(5)*m(254)
      m(776)=m(4)*m(255)
      m(777)=m(6)*m(274)
      m(778)=m(5)*m(275)
      m(779)=m(4)*m(276)
      m(780)=m(5)*m(259)
      m(781)=m(5)*m(278)
      m(782)=m(4)*m(261)
      m(783)=m(4)*m(280)
      m(784)=m(4)*m(263)
      m(785)=m(4)*m(282)
      m(786)=m(6)*m(265)
      m(787)=m(5)*m(266)
      m(788)=m(4)*m(267)
      m(789)=m(7)*m(265)
      m(790)=m(7)*m(266)
      m(791)=m(7)*m(267)
      m(792)=m(5)*m(268)
      m(793)=m(6)*m(268)
      m(794)=m(4)*m(269)
      m(795)=m(6)*m(269)
      m(796)=m(4)*m(270)
      m(797)=m(5)*m(270)
      m(798)=m(7)*m(295)
      m(799)=m(7)*m(296)
      m(800)=m(7)*m(297)
      m(801)=m(6)*m(298)
      m(802)=m(5)*m(299)
      m(803)=m(4)*m(300)
      m(804)=m(6)*m(301)
      m(805)=m(5)*m(302)
      m(806)=m(6)*m(303)
      m(807)=m(4)*m(304)
      m(808)=m(5)*m(305)
      m(809)=m(4)*m(306)
      m(810)=m(6)*m(283)
      m(811)=m(5)*m(284)
      m(812)=m(4)*m(285)
      m(813)=m(6)*m(316)
      m(814)=m(5)*m(317)
      m(815)=m(4)*m(318)
      m(816)=m(5)*m(289)
      m(817)=m(5)*m(320)
      m(818)=m(4)*m(291)
      m(819)=m(4)*m(322)
      m(820)=m(4)*m(293)
      m(821)=m(4)*m(324)
      m(822)=m(6)*m(295)
      m(823)=m(5)*m(296)
      m(824)=m(4)*m(297)
      m(825)=m(7)*m(298)
      m(826)=m(7)*m(299)
      m(827)=m(7)*m(300)
      m(828)=m(5)*m(301)
      m(829)=m(6)*m(302)
      m(830)=m(4)*m(303)
      m(831)=m(6)*m(304)
      m(832)=m(4)*m(305)
      m(833)=m(5)*m(306)
      m(834)=m(6)*m(307)
      m(835)=m(5)*m(308)
      m(836)=m(4)*m(309)
      m(837)=m(7)*m(307)
      m(838)=m(7)*m(308)
      m(839)=m(7)*m(309)
      m(840)=m(5)*m(310)
      m(841)=m(6)*m(310)
      m(842)=m(4)*m(311)
      m(843)=m(6)*m(311)
      m(844)=m(4)*m(312)
      m(845)=m(5)*m(312)
      m(846)=m(7)*m(325)
      m(847)=m(7)*m(326)
      m(848)=m(7)*m(327)
      m(849)=m(6)*m(328)
      m(850)=m(5)*m(329)
      m(851)=m(4)*m(330)
      m(852)=m(6)*m(331)
      m(853)=m(5)*m(332)
      m(854)=m(6)*m(333)
      m(855)=m(4)*m(334)
      m(856)=m(5)*m(335)
      m(857)=m(4)*m(336)
      m(858)=m(10)*m(295)
      m(859)=m(9)*m(296)
      m(860)=m(8)*m(297)
      m(861)=m(10)*m(328)
      m(862)=m(9)*m(329)
      m(863)=m(8)*m(330)
      m(864)=m(9)*m(301)
      m(865)=m(9)*m(332)
      m(866)=m(8)*m(303)
      m(867)=m(8)*m(334)
      m(868)=m(8)*m(305)
      m(869)=m(8)*m(336)
      m(870)=m(10)*m(307)
      m(871)=m(9)*m(308)
      m(872)=m(8)*m(309)
      m(873)=m(11)*m(307)
      m(874)=m(11)*m(308)
      m(875)=m(11)*m(309)
      m(876)=m(9)*m(310)
      m(877)=m(10)*m(310)
      m(878)=m(8)*m(311)
      m(879)=m(10)*m(311)
      m(880)=m(8)*m(312)
      m(881)=m(9)*m(312)
      m(882)=m(6)*m(325)
      m(883)=m(5)*m(326)
      m(884)=m(4)*m(327)
      m(885)=m(7)*m(328)
      m(886)=m(7)*m(329)
      m(887)=m(7)*m(330)
      m(888)=m(5)*m(331)
      m(889)=m(6)*m(332)
      m(890)=m(4)*m(333)
      m(891)=m(6)*m(334)
      m(892)=m(4)*m(335)
      m(893)=m(5)*m(336)
      m(894)=m(4)*m(247)
      m(895)=m(5)*m(247)
      m(896)=m(4)*m(248)
      m(897)=m(5)*m(346)
      m(898)=m(4)*m(347)
      m(899)=m(4)*m(348)
      m(900)=m(4)*m(250)
      m(901)=m(5)*m(352)
      m(902)=m(4)*m(354)
      m(903)=m(4)*m(356)
      m(904)=m(4)*m(358)
      m(905)=m(4)*m(360)
      m(906)=m(4)*m(253)
      m(907)=m(5)*m(253)
      m(908)=m(4)*m(254)
      m(909)=m(6)*m(254)
      m(910)=m(5)*m(255)
      m(911)=m(6)*m(255)
      m(912)=m(4)*m(256)
      m(913)=m(5)*m(256)
      m(914)=m(4)*m(257)
      m(915)=m(6)*m(257)
      m(916)=m(5)*m(258)
      m(917)=m(6)*m(258)
      m(918)=m(4)*m(259)
      m(919)=m(4)*m(260)
      m(920)=m(7)*m(259)
      m(921)=m(7)*m(260)
      m(922)=m(5)*m(261)
      m(923)=m(5)*m(262)
      m(924)=m(7)*m(261)
      m(925)=m(7)*m(262)
      m(926)=m(6)*m(263)
      m(927)=m(6)*m(264)
      m(928)=m(7)*m(263)
      m(929)=m(7)*m(264)
      m(930)=m(4)*m(271)
      m(931)=m(5)*m(271)
      m(932)=m(4)*m(272)
      m(933)=m(6)*m(272)
      m(934)=m(5)*m(273)
      m(935)=m(6)*m(273)
      m(936)=m(4)*m(274)
      m(937)=m(5)*m(274)
      m(938)=m(4)*m(275)
      m(939)=m(6)*m(275)
      m(940)=m(5)*m(276)
      m(941)=m(6)*m(276)
      m(942)=m(4)*m(277)
      m(943)=m(4)*m(278)
      m(944)=m(7)*m(277)
      m(945)=m(7)*m(278)
      m(946)=m(5)*m(279)
      m(947)=m(5)*m(280)
      m(948)=m(7)*m(279)
      m(949)=m(7)*m(280)
      m(950)=m(6)*m(281)
      m(951)=m(6)*m(282)
      m(952)=m(7)*m(281)
      m(953)=m(7)*m(282)
      m(954)=m(4)*m(283)
      m(955)=m(5)*m(283)
      m(956)=m(4)*m(284)
      m(957)=m(6)*m(284)
      m(958)=m(5)*m(285)
      m(959)=m(6)*m(285)
      m(960)=m(4)*m(286)
      m(961)=m(5)*m(286)
      m(962)=m(4)*m(287)
      m(963)=m(6)*m(287)
      m(964)=m(5)*m(288)
      m(965)=m(6)*m(288)
      m(966)=m(4)*m(289)
      m(967)=m(4)*m(290)
      m(968)=m(7)*m(289)
      m(969)=m(7)*m(290)
      m(970)=m(5)*m(291)
      m(971)=m(5)*m(292)
      m(972)=m(7)*m(291)
      m(973)=m(7)*m(292)
      m(974)=m(6)*m(293)
      m(975)=m(6)*m(294)
      m(976)=m(7)*m(293)
      m(977)=m(7)*m(294)
      m(978)=m(4)*m(313)
      m(979)=m(5)*m(313)
      m(980)=m(4)*m(314)
      m(981)=m(6)*m(314)
      m(982)=m(5)*m(315)
      m(983)=m(6)*m(315)
      m(984)=m(4)*m(316)
      m(985)=m(5)*m(316)
      m(986)=m(4)*m(317)
      m(987)=m(6)*m(317)
      m(988)=m(5)*m(318)
      m(989)=m(6)*m(318)
      m(990)=m(4)*m(319)
      m(991)=m(4)*m(320)
      m(992)=m(7)*m(319)
      m(993)=m(7)*m(320)
      m(994)=m(5)*m(321)
      m(995)=m(5)*m(322)
      m(996)=m(7)*m(321)
      m(997)=m(7)*m(322)
      m(998)=m(6)*m(323)
      m(999)=m(6)*m(324)
      m(1000)=m(7)*m(323)
      m(1001)=m(7)*m(324)
      m(1002)=m(18)*m(349)
      m(1003)=m(18)*m(350)
      m(1004)=m(18)*m(351)
      m(1005)=m(18)*m(352)
      m(1006)=m(17)*m(353)
      m(1007)=m(17)*m(354)
      m(1008)=m(17)*m(355)
      m(1009)=m(17)*m(356)
      m(1010)=m(16)*m(357)
      m(1011)=m(16)*m(358)
      m(1012)=m(16)*m(359)
      m(1013)=m(16)*m(360)
      m(1014)=m(7)*m(361)
      m(1015)=m(7)*m(362)
      m(1016)=m(7)*m(363)
      m(1017)=m(7)*m(364)
      m(1018)=m(7)*m(365)
      m(1019)=m(7)*m(366)
      m(1020)=m(6)*m(367)
      m(1021)=m(6)*m(368)
      m(1022)=m(5)*m(369)
      m(1023)=m(5)*m(370)
      m(1024)=m(4)*m(371)
      m(1025)=m(4)*m(372)
      m(1026)=m(6)*m(373)
      m(1027)=m(5)*m(374)
      m(1028)=m(6)*m(375)
      m(1029)=m(5)*m(376)
      m(1030)=m(6)*m(377)
      m(1031)=m(4)*m(378)
      m(1032)=m(6)*m(379)
      m(1033)=m(4)*m(380)
      m(1034)=m(5)*m(381)
      m(1035)=m(4)*m(382)
      m(1036)=m(5)*m(383)
      m(1037)=m(4)*m(384)
      m(1038)=m(8)*m(265)
      m(1039)=m(9)*m(265)
      m(1040)=m(8)*m(266)
      m(1041)=m(9)*m(370)
      m(1042)=m(8)*m(371)
      m(1043)=m(8)*m(372)
      m(1044)=m(8)*m(268)
      m(1045)=m(9)*m(376)
      m(1046)=m(8)*m(378)
      m(1047)=m(8)*m(380)
      m(1048)=m(8)*m(382)
      m(1049)=m(8)*m(384)
      m(1050)=m(6)*m(361)
      m(1051)=m(6)*m(362)
      m(1052)=m(5)*m(363)
      m(1053)=m(5)*m(364)
      m(1054)=m(4)*m(365)
      m(1055)=m(4)*m(366)
      m(1056)=m(7)*m(367)
      m(1057)=m(7)*m(368)
      m(1058)=m(7)*m(369)
      m(1059)=m(7)*m(370)
      m(1060)=m(7)*m(371)
      m(1061)=m(7)*m(372)
      m(1062)=m(5)*m(373)
      m(1063)=m(6)*m(374)
      m(1064)=m(5)*m(375)
      m(1065)=m(6)*m(376)
      m(1066)=m(4)*m(377)
      m(1067)=m(6)*m(378)
      m(1068)=m(4)*m(379)
      m(1069)=m(6)*m(380)
      m(1070)=m(4)*m(381)
      m(1071)=m(5)*m(382)
      m(1072)=m(4)*m(383)
      m(1073)=m(5)*m(384)
      m(1074)=m(8)*m(295)
      m(1075)=m(9)*m(295)
      m(1076)=m(8)*m(296)
      m(1077)=m(10)*m(296)
      m(1078)=m(9)*m(297)
      m(1079)=m(10)*m(297)
      m(1080)=m(8)*m(298)
      m(1081)=m(9)*m(298)
      m(1082)=m(8)*m(299)
      m(1083)=m(10)*m(299)
      m(1084)=m(9)*m(300)
      m(1085)=m(10)*m(300)
      m(1086)=m(8)*m(301)
      m(1087)=m(8)*m(302)
      m(1088)=m(11)*m(301)
      m(1089)=m(11)*m(302)
      m(1090)=m(9)*m(303)
      m(1091)=m(9)*m(304)
      m(1092)=m(11)*m(303)
      m(1093)=m(11)*m(304)
      m(1094)=m(10)*m(305)
      m(1095)=m(10)*m(306)
      m(1096)=m(11)*m(305)
      m(1097)=m(11)*m(306)
      m(1098)=m(8)*m(325)
      m(1099)=m(9)*m(325)
      m(1100)=m(8)*m(326)
      m(1101)=m(10)*m(326)
      m(1102)=m(9)*m(327)
      m(1103)=m(10)*m(327)
      m(1104)=m(8)*m(328)
      m(1105)=m(9)*m(328)
      m(1106)=m(8)*m(329)
      m(1107)=m(10)*m(329)
      m(1108)=m(9)*m(330)
      m(1109)=m(10)*m(330)
      m(1110)=m(8)*m(331)
      m(1111)=m(8)*m(332)
      m(1112)=m(11)*m(331)
      m(1113)=m(11)*m(332)
      m(1114)=m(9)*m(333)
      m(1115)=m(9)*m(334)
      m(1116)=m(11)*m(333)
      m(1117)=m(11)*m(334)
      m(1118)=m(10)*m(335)
      m(1119)=m(10)*m(336)
      m(1120)=m(11)*m(335)
      m(1121)=m(11)*m(336)
      m(1122)=m(28)*m(112)
      m(1123)=m(29)*m(112)
      m(1124)=m(30)*m(112)
      m(1125)=m(32)*m(112)
      m(1126)=m(35)*m(112)
      m(1127)=m(36)*m(112)
      m(1128)=m(38)*m(112)
      m(1129)=m(39)*m(112)
      m(1130)=m(28)*m(113)
      m(1131)=m(29)*m(113)
      m(1132)=m(31)*m(113)
      m(1133)=m(33)*m(113)
      m(1134)=m(34)*m(113)
      m(1135)=m(36)*m(113)
      m(1136)=m(37)*m(113)
      m(1137)=m(39)*m(113)
      m(1138)=m(30)*m(114)
      m(1139)=m(31)*m(114)
      m(1140)=m(32)*m(114)
      m(1141)=m(33)*m(114)
      m(1142)=m(34)*m(114)
      m(1143)=m(35)*m(114)
      m(1144)=m(37)*m(114)
      m(1145)=m(38)*m(114)
      m(1146)=m(18)*m(373)
      m(1147)=m(18)*m(374)
      m(1148)=m(18)*m(375)
      m(1149)=m(18)*m(376)
      m(1150)=m(17)*m(377)
      m(1151)=m(17)*m(378)
      m(1152)=m(17)*m(379)
      m(1153)=m(17)*m(380)
      m(1154)=m(16)*m(381)
      m(1155)=m(16)*m(382)
      m(1156)=m(16)*m(383)
      m(1157)=m(16)*m(384)
      m(1158)=m(5)*m(361)
      m(1159)=m(4)*m(362)
      m(1160)=m(6)*m(363)
      m(1161)=m(4)*m(364)
      m(1162)=m(6)*m(365)
      m(1163)=m(5)*m(366)
      m(1164)=m(5)*m(367)
      m(1165)=m(4)*m(368)
      m(1166)=m(6)*m(369)
      m(1167)=m(4)*m(370)
      m(1168)=m(6)*m(371)
      m(1169)=m(5)*m(372)
      m(1170)=m(7)*m(373)
      m(1171)=m(7)*m(374)
      m(1172)=m(4)*m(375)
      m(1173)=m(4)*m(376)
      m(1174)=m(7)*m(377)
      m(1175)=m(7)*m(378)
      m(1176)=m(5)*m(379)
      m(1177)=m(5)*m(380)
      m(1178)=m(7)*m(381)
      m(1179)=m(7)*m(382)
      m(1180)=m(6)*m(383)
      m(1181)=m(6)*m(384)
      m(1182)=m(7)*m(385)
      m(1183)=m(7)*m(386)
      m(1184)=m(7)*m(387)
      m(1185)=m(7)*m(388)
      m(1186)=m(7)*m(389)
      m(1187)=m(7)*m(390)
      m(1188)=m(6)*m(391)
      m(1189)=m(6)*m(392)
      m(1190)=m(5)*m(393)
      m(1191)=m(5)*m(394)
      m(1192)=m(4)*m(395)
      m(1193)=m(4)*m(396)
      m(1194)=m(6)*m(397)
      m(1195)=m(5)*m(398)
      m(1196)=m(6)*m(399)
      m(1197)=m(5)*m(400)
      m(1198)=m(6)*m(401)
      m(1199)=m(4)*m(402)
      m(1200)=m(6)*m(403)
      m(1201)=m(4)*m(404)
      m(1202)=m(5)*m(405)
      m(1203)=m(4)*m(406)
      m(1204)=m(5)*m(407)
      m(1205)=m(4)*m(408)
      m(1206)=m(11)*m(385)
      m(1207)=m(11)*m(386)
      m(1208)=m(11)*m(387)
      m(1209)=m(11)*m(388)
      m(1210)=m(11)*m(389)
      m(1211)=m(11)*m(390)
      m(1212)=m(10)*m(391)
      m(1213)=m(10)*m(392)
      m(1214)=m(9)*m(393)
      m(1215)=m(9)*m(394)
      m(1216)=m(8)*m(395)
      m(1217)=m(8)*m(396)
      m(1218)=m(10)*m(397)
      m(1219)=m(9)*m(398)
      m(1220)=m(10)*m(399)
      m(1221)=m(9)*m(400)
      m(1222)=m(10)*m(401)
      m(1223)=m(8)*m(402)
      m(1224)=m(10)*m(403)
      m(1225)=m(8)*m(404)
      m(1226)=m(9)*m(405)
      m(1227)=m(8)*m(406)
      m(1228)=m(9)*m(407)
      m(1229)=m(8)*m(408)
      m(1230)=m(12)*m(307)
      m(1231)=m(13)*m(307)
      m(1232)=m(12)*m(308)
      m(1233)=m(13)*m(394)
      m(1234)=m(12)*m(395)
      m(1235)=m(12)*m(396)
      m(1236)=m(12)*m(310)
      m(1237)=m(13)*m(400)
      m(1238)=m(12)*m(402)
      m(1239)=m(12)*m(404)
      m(1240)=m(12)*m(406)
      m(1241)=m(12)*m(408)
      m(1242)=m(6)*m(385)
      m(1243)=m(6)*m(386)
      m(1244)=m(5)*m(387)
      m(1245)=m(5)*m(388)
      m(1246)=m(4)*m(389)
      m(1247)=m(4)*m(390)
      m(1248)=m(7)*m(391)
      m(1249)=m(7)*m(392)
      m(1250)=m(7)*m(393)
      m(1251)=m(7)*m(394)
      m(1252)=m(7)*m(395)
      m(1253)=m(7)*m(396)
      m(1254)=m(5)*m(397)
      m(1255)=m(6)*m(398)
      m(1256)=m(5)*m(399)
      m(1257)=m(6)*m(400)
      m(1258)=m(4)*m(401)
      m(1259)=m(6)*m(402)
      m(1260)=m(4)*m(403)
      m(1261)=m(6)*m(404)
      m(1262)=m(4)*m(405)
      m(1263)=m(5)*m(406)
      m(1264)=m(4)*m(407)
      m(1265)=m(5)*m(408)
      m(1266)=m(10)*m(385)
      m(1267)=m(10)*m(386)
      m(1268)=m(9)*m(387)
      m(1269)=m(9)*m(388)
      m(1270)=m(8)*m(389)
      m(1271)=m(8)*m(390)
      m(1272)=m(11)*m(391)
      m(1273)=m(11)*m(392)
      m(1274)=m(11)*m(393)
      m(1275)=m(11)*m(394)
      m(1276)=m(11)*m(395)
      m(1277)=m(11)*m(396)
      m(1278)=m(9)*m(397)
      m(1279)=m(10)*m(398)
      m(1280)=m(9)*m(399)
      m(1281)=m(10)*m(400)
      m(1282)=m(8)*m(401)
      m(1283)=m(10)*m(402)
      m(1284)=m(8)*m(403)
      m(1285)=m(10)*m(404)
      m(1286)=m(8)*m(405)
      m(1287)=m(9)*m(406)
      m(1288)=m(8)*m(407)
      m(1289)=m(9)*m(408)
      m(1290)=m(46)*m(112)
      m(1291)=m(47)*m(112)
      m(1292)=m(48)*m(112)
      m(1293)=m(50)*m(112)
      m(1294)=m(53)*m(112)
      m(1295)=m(54)*m(112)
      m(1296)=m(56)*m(112)
      m(1297)=m(57)*m(112)
      m(1298)=m(46)*m(113)
      m(1299)=m(47)*m(113)
      m(1300)=m(49)*m(113)
      m(1301)=m(51)*m(113)
      m(1302)=m(52)*m(113)
      m(1303)=m(54)*m(113)
      m(1304)=m(55)*m(113)
      m(1305)=m(57)*m(113)
      m(1306)=m(48)*m(114)
      m(1307)=m(49)*m(114)
      m(1308)=m(50)*m(114)
      m(1309)=m(51)*m(114)
      m(1310)=m(52)*m(114)
      m(1311)=m(53)*m(114)
      m(1312)=m(55)*m(114)
      m(1313)=m(56)*m(114)
      m(1314)=m(58)*m(112)
      m(1315)=m(59)*m(112)
      m(1316)=m(60)*m(112)
      m(1317)=m(62)*m(112)
      m(1318)=m(65)*m(112)
      m(1319)=m(66)*m(112)
      m(1320)=m(68)*m(112)
      m(1321)=m(69)*m(112)
      m(1322)=m(58)*m(113)
      m(1323)=m(59)*m(113)
      m(1324)=m(61)*m(113)
      m(1325)=m(63)*m(113)
      m(1326)=m(64)*m(113)
      m(1327)=m(66)*m(113)
      m(1328)=m(67)*m(113)
      m(1329)=m(69)*m(113)
      m(1330)=m(60)*m(114)
      m(1331)=m(61)*m(114)
      m(1332)=m(62)*m(114)
      m(1333)=m(63)*m(114)
      m(1334)=m(64)*m(114)
      m(1335)=m(65)*m(114)
      m(1336)=m(67)*m(114)
      m(1337)=m(68)*m(114)
      m(1338)=m(18)*m(397)
      m(1339)=m(18)*m(398)
      m(1340)=m(18)*m(399)
      m(1341)=m(18)*m(400)
      m(1342)=m(17)*m(401)
      m(1343)=m(17)*m(402)
      m(1344)=m(17)*m(403)
      m(1345)=m(17)*m(404)
      m(1346)=m(16)*m(405)
      m(1347)=m(16)*m(406)
      m(1348)=m(16)*m(407)
      m(1349)=m(16)*m(408)
      m(1350)=m(5)*m(385)
      m(1351)=m(4)*m(386)
      m(1352)=m(6)*m(387)
      m(1353)=m(4)*m(388)
      m(1354)=m(6)*m(389)
      m(1355)=m(5)*m(390)
      m(1356)=m(5)*m(391)
      m(1357)=m(4)*m(392)
      m(1358)=m(6)*m(393)
      m(1359)=m(4)*m(394)
      m(1360)=m(6)*m(395)
      m(1361)=m(5)*m(396)
      m(1362)=m(7)*m(397)
      m(1363)=m(7)*m(398)
      m(1364)=m(4)*m(399)
      m(1365)=m(4)*m(400)
      m(1366)=m(7)*m(401)
      m(1367)=m(7)*m(402)
      m(1368)=m(5)*m(403)
      m(1369)=m(5)*m(404)
      m(1370)=m(7)*m(405)
      m(1371)=m(7)*m(406)
      m(1372)=m(6)*m(407)
      m(1373)=m(6)*m(408)
      m(1374)=m(9)*m(385)
      m(1375)=m(8)*m(386)
      m(1376)=m(10)*m(387)
      m(1377)=m(8)*m(388)
      m(1378)=m(10)*m(389)
      m(1379)=m(9)*m(390)
      m(1380)=m(9)*m(391)
      m(1381)=m(8)*m(392)
      m(1382)=m(10)*m(393)
      m(1383)=m(8)*m(394)
      m(1384)=m(10)*m(395)
      m(1385)=m(9)*m(396)
      m(1386)=m(11)*m(397)
      m(1387)=m(11)*m(398)
      m(1388)=m(8)*m(399)
      m(1389)=m(8)*m(400)
      m(1390)=m(11)*m(401)
      m(1391)=m(11)*m(402)
      m(1392)=m(9)*m(403)
      m(1393)=m(9)*m(404)
      m(1394)=m(11)*m(405)
      m(1395)=m(11)*m(406)
      m(1396)=m(10)*m(407)
      m(1397)=m(10)*m(408)
      m(1398)=m(7)*m(421)
      m(1399)=m(7)*m(422)
      m(1400)=m(7)*m(423)
      m(1401)=m(6)*m(424)
      m(1402)=m(5)*m(425)
      m(1403)=m(6)*m(426)
      m(1404)=m(4)*m(427)
      m(1405)=m(6)*m(428)
      m(1406)=m(5)*m(429)
      m(1407)=m(4)*m(430)
      m(1408)=m(5)*m(431)
      m(1409)=m(4)*m(432)
      m(1410)=m(7)*m(433)
      m(1411)=m(7)*m(434)
      m(1412)=m(7)*m(435)
      m(1413)=m(6)*m(436)
      m(1414)=m(5)*m(437)
      m(1415)=m(6)*m(438)
      m(1416)=m(4)*m(439)
      m(1417)=m(6)*m(440)
      m(1418)=m(5)*m(441)
      m(1419)=m(4)*m(442)
      m(1420)=m(5)*m(443)
      m(1421)=m(4)*m(444)
      m(1422)=m(11)*m(433)
      m(1423)=m(11)*m(434)
      m(1424)=m(11)*m(435)
      m(1425)=m(10)*m(436)
      m(1426)=m(9)*m(437)
      m(1427)=m(10)*m(438)
      m(1428)=m(8)*m(439)
      m(1429)=m(10)*m(440)
      m(1430)=m(9)*m(441)
      m(1431)=m(8)*m(442)
      m(1432)=m(9)*m(443)
      m(1433)=m(8)*m(444)
      m(1434)=m(5)*m(409)
      m(1435)=m(6)*m(409)
      m(1436)=m(4)*m(410)
      m(1437)=m(6)*m(410)
      m(1438)=m(4)*m(411)
      m(1439)=m(5)*m(411)
      m(1440)=m(5)*m(412)
      m(1441)=m(5)*m(452)
      m(1442)=m(6)*m(453)
      m(1443)=m(5)*m(454)
      m(1444)=m(4)*m(414)
      m(1445)=m(4)*m(456)
      m(1446)=m(6)*m(457)
      m(1447)=m(4)*m(458)
      m(1448)=m(4)*m(416)
      m(1449)=m(5)*m(416)
      m(1450)=m(4)*m(417)
      m(1451)=m(4)*m(462)
      m(1452)=m(5)*m(463)
      m(1453)=m(4)*m(464)
      m(1454)=m(4)*m(419)
      m(1455)=m(5)*m(466)
      m(1456)=m(4)*m(467)
      m(1457)=m(4)*m(468)
      m(1458)=m(5)*m(421)
      m(1459)=m(6)*m(421)
      m(1460)=m(4)*m(422)
      m(1461)=m(6)*m(422)
      m(1462)=m(4)*m(423)
      m(1463)=m(5)*m(423)
      m(1464)=m(5)*m(424)
      m(1465)=m(6)*m(425)
      m(1466)=m(7)*m(424)
      m(1467)=m(7)*m(425)
      m(1468)=m(4)*m(426)
      m(1469)=m(6)*m(427)
      m(1470)=m(7)*m(426)
      m(1471)=m(7)*m(427)
      m(1472)=m(4)*m(428)
      m(1473)=m(5)*m(428)
      m(1474)=m(4)*m(429)
      m(1475)=m(5)*m(430)
      m(1476)=m(7)*m(429)
      m(1477)=m(7)*m(430)
      m(1478)=m(4)*m(431)
      m(1479)=m(6)*m(431)
      m(1480)=m(5)*m(432)
      m(1481)=m(6)*m(432)
      m(1482)=m(5)*m(433)
      m(1483)=m(6)*m(433)
      m(1484)=m(4)*m(434)
      m(1485)=m(6)*m(434)
      m(1486)=m(4)*m(435)
      m(1487)=m(5)*m(435)
      m(1488)=m(5)*m(436)
      m(1489)=m(6)*m(437)
      m(1490)=m(7)*m(436)
      m(1491)=m(7)*m(437)
      m(1492)=m(4)*m(438)
      m(1493)=m(6)*m(439)
      m(1494)=m(7)*m(438)
      m(1495)=m(7)*m(439)
      m(1496)=m(4)*m(440)
      m(1497)=m(5)*m(440)
      m(1498)=m(4)*m(441)
      m(1499)=m(5)*m(442)
      m(1500)=m(7)*m(441)
      m(1501)=m(7)*m(442)
      m(1502)=m(4)*m(443)
      m(1503)=m(6)*m(443)
      m(1504)=m(5)*m(444)
      m(1505)=m(6)*m(444)
      m(1506)=m(5)*m(446)
      m(1507)=m(4)*m(448)
      m(1508)=m(4)*m(450)
      m(1509)=m(5)*m(453)
      m(1510)=m(6)*m(454)
      m(1511)=m(4)*m(457)
      m(1512)=m(6)*m(458)
      m(1513)=m(4)*m(460)
      m(1514)=m(4)*m(463)
      m(1515)=m(5)*m(464)
      m(1516)=m(4)*m(466)
      m(1517)=m(5)*m(468)
      m(1518)=m(7)*m(469)
      m(1519)=m(7)*m(470)
      m(1520)=m(7)*m(471)
      m(1521)=m(7)*m(472)
      m(1522)=m(7)*m(473)
      m(1523)=m(7)*m(474)
      m(1524)=m(6)*m(475)
      m(1525)=m(5)*m(476)
      m(1526)=m(6)*m(477)
      m(1527)=m(5)*m(478)
      m(1528)=m(6)*m(479)
      m(1529)=m(4)*m(480)
      m(1530)=m(6)*m(481)
      m(1531)=m(4)*m(482)
      m(1532)=m(6)*m(483)
      m(1533)=m(6)*m(484)
      m(1534)=m(5)*m(485)
      m(1535)=m(4)*m(486)
      m(1536)=m(5)*m(487)
      m(1537)=m(4)*m(488)
      m(1538)=m(5)*m(489)
      m(1539)=m(5)*m(490)
      m(1540)=m(4)*m(491)
      m(1541)=m(4)*m(492)
      m(1542)=m(9)*m(421)
      m(1543)=m(10)*m(421)
      m(1544)=m(8)*m(422)
      m(1545)=m(10)*m(422)
      m(1546)=m(8)*m(423)
      m(1547)=m(9)*m(423)
      m(1548)=m(9)*m(424)
      m(1549)=m(9)*m(476)
      m(1550)=m(10)*m(477)
      m(1551)=m(9)*m(478)
      m(1552)=m(8)*m(426)
      m(1553)=m(8)*m(480)
      m(1554)=m(10)*m(481)
      m(1555)=m(8)*m(482)
      m(1556)=m(8)*m(428)
      m(1557)=m(9)*m(428)
      m(1558)=m(8)*m(429)
      m(1559)=m(8)*m(486)
      m(1560)=m(9)*m(487)
      m(1561)=m(8)*m(488)
      m(1562)=m(8)*m(431)
      m(1563)=m(9)*m(490)
      m(1564)=m(8)*m(491)
      m(1565)=m(8)*m(492)
      m(1566)=m(9)*m(433)
      m(1567)=m(10)*m(433)
      m(1568)=m(8)*m(434)
      m(1569)=m(10)*m(434)
      m(1570)=m(8)*m(435)
      m(1571)=m(9)*m(435)
      m(1572)=m(9)*m(436)
      m(1573)=m(10)*m(437)
      m(1574)=m(11)*m(436)
      m(1575)=m(11)*m(437)
      m(1576)=m(8)*m(438)
      m(1577)=m(10)*m(439)
      m(1578)=m(11)*m(438)
      m(1579)=m(11)*m(439)
      m(1580)=m(8)*m(440)
      m(1581)=m(9)*m(440)
      m(1582)=m(8)*m(441)
      m(1583)=m(9)*m(442)
      m(1584)=m(11)*m(441)
      m(1585)=m(11)*m(442)
      m(1586)=m(8)*m(443)
      m(1587)=m(10)*m(443)
      m(1588)=m(9)*m(444)
      m(1589)=m(10)*m(444)
      m(1590)=m(6)*m(469)
      m(1591)=m(5)*m(470)
      m(1592)=m(6)*m(471)
      m(1593)=m(4)*m(472)
      m(1594)=m(5)*m(473)
      m(1595)=m(4)*m(474)
      m(1596)=m(7)*m(475)
      m(1597)=m(7)*m(476)
      m(1598)=m(5)*m(477)
      m(1599)=m(6)*m(478)
      m(1600)=m(7)*m(479)
      m(1601)=m(7)*m(480)
      m(1602)=m(4)*m(481)
      m(1603)=m(6)*m(482)
      m(1604)=m(5)*m(483)
      m(1605)=m(4)*m(484)
      m(1606)=m(7)*m(485)
      m(1607)=m(7)*m(486)
      m(1608)=m(4)*m(487)
      m(1609)=m(5)*m(488)
      m(1610)=m(6)*m(489)
      m(1611)=m(4)*m(490)
      m(1612)=m(6)*m(491)
      m(1613)=m(5)*m(492)
      m(1614)=m(9)*m(470)
      m(1615)=m(8)*m(472)
      m(1616)=m(8)*m(474)
      m(1617)=m(9)*m(477)
      m(1618)=m(10)*m(478)
      m(1619)=m(8)*m(481)
      m(1620)=m(10)*m(482)
      m(1621)=m(8)*m(484)
      m(1622)=m(8)*m(487)
      m(1623)=m(9)*m(488)
      m(1624)=m(8)*m(490)
      m(1625)=m(9)*m(492)
      m(1626)=m(5)*m(469)
      m(1627)=m(6)*m(470)
      m(1628)=m(4)*m(471)
      m(1629)=m(6)*m(472)
      m(1630)=m(4)*m(473)
      m(1631)=m(5)*m(474)
      m(1632)=m(5)*m(475)
      m(1633)=m(6)*m(476)
      m(1634)=m(7)*m(477)
      m(1635)=m(7)*m(478)
      m(1636)=m(4)*m(479)
      m(1637)=m(6)*m(480)
      m(1638)=m(7)*m(481)
      m(1639)=m(7)*m(482)
      m(1640)=m(4)*m(483)
      m(1641)=m(5)*m(484)
      m(1642)=m(4)*m(485)
      m(1643)=m(5)*m(486)
      m(1644)=m(7)*m(487)
      m(1645)=m(7)*m(488)
      m(1646)=m(4)*m(489)
      m(1647)=m(6)*m(490)
      m(1648)=m(5)*m(491)
      m(1649)=m(6)*m(492)
      m(1650)=m(7)*m(493)
      m(1651)=m(7)*m(494)
      m(1652)=m(7)*m(495)
      m(1653)=m(7)*m(496)
      m(1654)=m(7)*m(497)
      m(1655)=m(7)*m(498)
      m(1656)=m(6)*m(499)
      m(1657)=m(5)*m(500)
      m(1658)=m(6)*m(501)
      m(1659)=m(5)*m(502)
      m(1660)=m(6)*m(503)
      m(1661)=m(4)*m(504)
      m(1662)=m(6)*m(505)
      m(1663)=m(4)*m(506)
      m(1664)=m(6)*m(507)
      m(1665)=m(6)*m(508)
      m(1666)=m(5)*m(509)
      m(1667)=m(4)*m(510)
      m(1668)=m(5)*m(511)
      m(1669)=m(4)*m(512)
      m(1670)=m(5)*m(513)
      m(1671)=m(5)*m(514)
      m(1672)=m(4)*m(515)
      m(1673)=m(4)*m(516)
      m(1674)=m(11)*m(493)
      m(1675)=m(11)*m(494)
      m(1676)=m(11)*m(495)
      m(1677)=m(11)*m(496)
      m(1678)=m(11)*m(497)
      m(1679)=m(11)*m(498)
      m(1680)=m(10)*m(499)
      m(1681)=m(9)*m(500)
      m(1682)=m(10)*m(501)
      m(1683)=m(9)*m(502)
      m(1684)=m(10)*m(503)
      m(1685)=m(8)*m(504)
      m(1686)=m(10)*m(505)
      m(1687)=m(8)*m(506)
      m(1688)=m(10)*m(507)
      m(1689)=m(10)*m(508)
      m(1690)=m(9)*m(509)
      m(1691)=m(8)*m(510)
      m(1692)=m(9)*m(511)
      m(1693)=m(8)*m(512)
      m(1694)=m(9)*m(513)
      m(1695)=m(9)*m(514)
      m(1696)=m(8)*m(515)
      m(1697)=m(8)*m(516)
      m(1698)=m(13)*m(433)
      m(1699)=m(14)*m(433)
      m(1700)=m(12)*m(434)
      m(1701)=m(14)*m(434)
      m(1702)=m(12)*m(435)
      m(1703)=m(13)*m(435)
      m(1704)=m(13)*m(436)
      m(1705)=m(13)*m(500)
      m(1706)=m(14)*m(501)
      m(1707)=m(13)*m(502)
      m(1708)=m(12)*m(438)
      m(1709)=m(12)*m(504)
      m(1710)=m(14)*m(505)
      m(1711)=m(12)*m(506)
      m(1712)=m(12)*m(440)
      m(1713)=m(13)*m(440)
      m(1714)=m(12)*m(441)
      m(1715)=m(12)*m(510)
      m(1716)=m(13)*m(511)
      m(1717)=m(12)*m(512)
      m(1718)=m(12)*m(443)
      m(1719)=m(13)*m(514)
      m(1720)=m(12)*m(515)
      m(1721)=m(12)*m(516)
      m(1722)=m(6)*m(493)
      m(1723)=m(5)*m(494)
      m(1724)=m(6)*m(495)
      m(1725)=m(4)*m(496)
      m(1726)=m(5)*m(497)
      m(1727)=m(4)*m(498)
      m(1728)=m(7)*m(499)
      m(1729)=m(7)*m(500)
      m(1730)=m(5)*m(501)
      m(1731)=m(6)*m(502)
      m(1732)=m(7)*m(503)
      m(1733)=m(7)*m(504)
      m(1734)=m(4)*m(505)
      m(1735)=m(6)*m(506)
      m(1736)=m(5)*m(507)
      m(1737)=m(4)*m(508)
      m(1738)=m(7)*m(509)
      m(1739)=m(7)*m(510)
      m(1740)=m(4)*m(511)
      m(1741)=m(5)*m(512)
      m(1742)=m(6)*m(513)
      m(1743)=m(4)*m(514)
      m(1744)=m(6)*m(515)
      m(1745)=m(5)*m(516)
      m(1746)=m(10)*m(493)
      m(1747)=m(9)*m(494)
      m(1748)=m(10)*m(495)
      m(1749)=m(8)*m(496)
      m(1750)=m(9)*m(497)
      m(1751)=m(8)*m(498)
      m(1752)=m(11)*m(499)
      m(1753)=m(11)*m(500)
      m(1754)=m(9)*m(501)
      m(1755)=m(10)*m(502)
      m(1756)=m(11)*m(503)
      m(1757)=m(11)*m(504)
      m(1758)=m(8)*m(505)
      m(1759)=m(10)*m(506)
      m(1760)=m(9)*m(507)
      m(1761)=m(8)*m(508)
      m(1762)=m(11)*m(509)
      m(1763)=m(11)*m(510)
      m(1764)=m(8)*m(511)
      m(1765)=m(9)*m(512)
      m(1766)=m(10)*m(513)
      m(1767)=m(8)*m(514)
      m(1768)=m(10)*m(515)
      m(1769)=m(9)*m(516)
      m(1770)=m(13)*m(494)
      m(1771)=m(12)*m(496)
      m(1772)=m(12)*m(498)
      m(1773)=m(13)*m(501)
      m(1774)=m(14)*m(502)
      m(1775)=m(12)*m(505)
      m(1776)=m(14)*m(506)
      m(1777)=m(12)*m(508)
      m(1778)=m(12)*m(511)
      m(1779)=m(13)*m(512)
      m(1780)=m(12)*m(514)
      m(1781)=m(13)*m(516)
      m(1782)=m(5)*m(493)
      m(1783)=m(6)*m(494)
      m(1784)=m(4)*m(495)
      m(1785)=m(6)*m(496)
      m(1786)=m(4)*m(497)
      m(1787)=m(5)*m(498)
      m(1788)=m(5)*m(499)
      m(1789)=m(6)*m(500)
      m(1790)=m(7)*m(501)
      m(1791)=m(7)*m(502)
      m(1792)=m(4)*m(503)
      m(1793)=m(6)*m(504)
      m(1794)=m(7)*m(505)
      m(1795)=m(7)*m(506)
      m(1796)=m(4)*m(507)
      m(1797)=m(5)*m(508)
      m(1798)=m(4)*m(509)
      m(1799)=m(5)*m(510)
      m(1800)=m(7)*m(511)
      m(1801)=m(7)*m(512)
      m(1802)=m(4)*m(513)
      m(1803)=m(6)*m(514)
      m(1804)=m(5)*m(515)
      m(1805)=m(6)*m(516)
      m(1806)=m(9)*m(493)
      m(1807)=m(10)*m(494)
      m(1808)=m(8)*m(495)
      m(1809)=m(10)*m(496)
      m(1810)=m(8)*m(497)
      m(1811)=m(9)*m(498)
      m(1812)=m(9)*m(499)
      m(1813)=m(10)*m(500)
      m(1814)=m(11)*m(501)
      m(1815)=m(11)*m(502)
      m(1816)=m(8)*m(503)
      m(1817)=m(10)*m(504)
      m(1818)=m(11)*m(505)
      m(1819)=m(11)*m(506)
      m(1820)=m(8)*m(507)
      m(1821)=m(9)*m(508)
      m(1822)=m(8)*m(509)
      m(1823)=m(9)*m(510)
      m(1824)=m(11)*m(511)
      m(1825)=m(11)*m(512)
      m(1826)=m(8)*m(513)
      m(1827)=m(10)*m(514)
      m(1828)=m(9)*m(515)
      m(1829)=m(10)*m(516)
      m(1830)=m(6)*m(517)
      m(1831)=m(5)*m(518)
      m(1832)=m(7)*m(517)
      m(1833)=m(7)*m(518)
      m(1834)=m(6)*m(519)
      m(1835)=m(4)*m(520)
      m(1836)=m(7)*m(519)
      m(1837)=m(7)*m(520)
      m(1838)=m(5)*m(521)
      m(1839)=m(6)*m(521)
      m(1840)=m(4)*m(522)
      m(1841)=m(6)*m(522)
      m(1842)=m(5)*m(523)
      m(1843)=m(4)*m(524)
      m(1844)=m(7)*m(523)
      m(1845)=m(7)*m(524)
      m(1846)=m(5)*m(525)
      m(1847)=m(6)*m(525)
      m(1848)=m(4)*m(526)
      m(1849)=m(5)*m(526)
      m(1850)=m(4)*m(527)
      m(1851)=m(6)*m(527)
      m(1852)=m(4)*m(528)
      m(1853)=m(5)*m(528)
      m(1854)=m(10)*m(517)
      m(1855)=m(9)*m(518)
      m(1856)=m(11)*m(517)
      m(1857)=m(11)*m(518)
      m(1858)=m(10)*m(519)
      m(1859)=m(8)*m(520)
      m(1860)=m(11)*m(519)
      m(1861)=m(11)*m(520)
      m(1862)=m(9)*m(521)
      m(1863)=m(10)*m(521)
      m(1864)=m(8)*m(522)
      m(1865)=m(10)*m(522)
      m(1866)=m(9)*m(523)
      m(1867)=m(8)*m(524)
      m(1868)=m(11)*m(523)
      m(1869)=m(11)*m(524)
      m(1870)=m(9)*m(525)
      m(1871)=m(10)*m(525)
      m(1872)=m(8)*m(526)
      m(1873)=m(9)*m(526)
      m(1874)=m(8)*m(527)
      m(1875)=m(10)*m(527)
      m(1876)=m(8)*m(528)
      m(1877)=m(9)*m(528)
      m(1878)=m(14)*m(517)
      m(1879)=m(13)*m(518)
      m(1880)=m(15)*m(517)
      m(1881)=m(15)*m(518)
      m(1882)=m(14)*m(519)
      m(1883)=m(12)*m(520)
      m(1884)=m(15)*m(519)
      m(1885)=m(15)*m(520)
      m(1886)=m(13)*m(521)
      m(1887)=m(14)*m(521)
      m(1888)=m(12)*m(522)
      m(1889)=m(14)*m(522)
      m(1890)=m(13)*m(523)
      m(1891)=m(12)*m(524)
      m(1892)=m(15)*m(523)
      m(1893)=m(15)*m(524)
      m(1894)=m(13)*m(525)
      m(1895)=m(14)*m(525)
      m(1896)=m(12)*m(526)
      m(1897)=m(13)*m(526)
      m(1898)=m(12)*m(527)
      m(1899)=m(14)*m(527)
      m(1900)=m(12)*m(528)
      m(1901)=m(13)*m(528)
      m(1902)=m(17)*m(522)
      m(1903)=m(16)*m(526)
      m(1904)=m(16)*m(528)
      m(1905)=m(7)*m(529)
      m(1906)=m(6)*m(530)
      m(1907)=m(5)*m(531)
      m(1908)=m(4)*m(532)
      m(1909)=m(11)*m(529)
      m(1910)=m(10)*m(530)
      m(1911)=m(9)*m(531)
      m(1912)=m(8)*m(532)
      m(1913)=m(15)*m(529)
      m(1914)=m(14)*m(530)
      m(1915)=m(13)*m(531)
      m(1916)=m(12)*m(532)
      m(1917)=m(4)*m(409)
      m(1918)=m(5)*m(410)
      m(1919)=m(6)*m(411)
      m(1920)=m(4)*m(412)
      m(1921)=m(4)*m(413)
      m(1922)=m(5)*m(414)
      m(1923)=m(5)*m(415)
      m(1924)=m(7)*m(416)
      m(1925)=m(6)*m(417)
      m(1926)=m(6)*m(418)
      m(1927)=m(7)*m(419)
      m(1928)=m(7)*m(420)
      m(1929)=m(8)*m(421)
      m(1930)=m(9)*m(422)
      m(1931)=m(10)*m(423)
      m(1932)=m(8)*m(424)
      m(1933)=m(8)*m(425)
      m(1934)=m(9)*m(426)
      m(1935)=m(9)*m(427)
      m(1936)=m(11)*m(428)
      m(1937)=m(10)*m(429)
      m(1938)=m(10)*m(430)
      m(1939)=m(11)*m(431)
      m(1940)=m(11)*m(432)
      m(1941)=m(12)*m(433)
      m(1942)=m(13)*m(434)
      m(1943)=m(14)*m(435)
      m(1944)=m(12)*m(436)
      m(1945)=m(12)*m(437)
      m(1946)=m(13)*m(438)
      m(1947)=m(13)*m(439)
      m(1948)=m(15)*m(440)
      m(1949)=m(14)*m(441)
      m(1950)=m(14)*m(442)
      m(1951)=m(15)*m(443)
      m(1952)=m(15)*m(444)
      m(1953)=m(5)*m(533)
      m(1954)=m(6)*m(533)
      m(1955)=m(7)*m(533)
      m(1956)=m(4)*m(534)
      m(1957)=m(6)*m(534)
      m(1958)=m(7)*m(534)
      m(1959)=m(4)*m(535)
      m(1960)=m(5)*m(535)
      m(1961)=m(7)*m(535)
      m(1962)=m(4)*m(536)
      m(1963)=m(5)*m(536)
      m(1964)=m(6)*m(536)
      m(1965)=m(9)*m(533)
      m(1966)=m(10)*m(533)
      m(1967)=m(11)*m(533)
      m(1968)=m(8)*m(534)
      m(1969)=m(10)*m(534)
      m(1970)=m(11)*m(534)
      m(1971)=m(8)*m(535)
      m(1972)=m(9)*m(535)
      m(1973)=m(11)*m(535)
      m(1974)=m(8)*m(536)
      m(1975)=m(9)*m(536)
      m(1976)=m(10)*m(536)
      m(1977)=m(13)*m(533)
      m(1978)=m(14)*m(533)
      m(1979)=m(15)*m(533)
      m(1980)=m(12)*m(534)
      m(1981)=m(14)*m(534)
      m(1982)=m(15)*m(534)
      m(1983)=m(12)*m(535)
      m(1984)=m(13)*m(535)
      m(1985)=m(15)*m(535)
      m(1986)=m(12)*m(536)
      m(1987)=m(13)*m(536)
      m(1988)=m(14)*m(536)
      m(1989)=m(16)*m(518)
      m(1990)=m(16)*m(520)
      m(1991)=m(16)*m(521)
      m(1992)=m(16)*m(522)
      m(1993)=m(16)*m(535)
      m(1994)=m(16)*m(531)
      m(1995)=m(17)*m(526)
      m(1996)=m(16)*m(532)
      m(1997)=m(17)*m(532)
      m(1998)=m(16)*m(536)
      m(1999)=m(17)*m(536)
      m(2000)=m(18)*m(536)
 
      return
      end subroutine evmono
 
      subroutine evpoly(m,p)
      implicit none
      real*8,dimension(0:2000),intent(in)::m
      real*8,dimension(0:1104),intent(out)::p
 
       p(0)=m(0)
       p(1)=m(1)
       p(2)=m(2)
       p(3)=m(3)
       p(4)=m(4)+m(5)+m(6)+m(7)
       p(5)=m(8)+m(9)+m(10)+m(11)
       p(6)=m(12)+m(13)+m(14)+m(15)
       p(7)=m(16)+m(17)+m(18)+m(19)+m(20)+m(21)
       p(8)=p(1)*p(2)
       p(9)=p(1)*p(3)
       p(10)=p(2)*p(3)
       p(11)=p(1)*p(4)
       p(12)=p(2)*p(4)
       p(13)=p(3)*p(4)
       p(14)=m(22)+m(23)+m(24)+m(25)+m(26)+m(27)
       p(15)=p(1)*p(5)
       p(16)=p(2)*p(5)
       p(17)=p(3)*p(5)
       p(18)=m(28)+m(29)+m(30)+m(31)+m(32)+m(33)+m(34)+m(35)+m(36)+m(37)&
     &+m(38)+m(39)
       p(19)=m(40)+m(41)+m(42)+m(43)+m(44)+m(45)
       p(20)=p(4)*p(5)-p(18)
       p(21)=p(1)*p(6)
       p(22)=p(2)*p(6)
       p(23)=p(3)*p(6)
       p(24)=m(46)+m(47)+m(48)+m(49)+m(50)+m(51)+m(52)+m(53)+m(54)+m(55)&
     &+m(56)+m(57)
       p(25)=m(58)+m(59)+m(60)+m(61)+m(62)+m(63)+m(64)+m(65)+m(66)+m(67)&
     &+m(68)+m(69)
       p(26)=m(70)+m(71)+m(72)+m(73)+m(74)+m(75)
       p(27)=p(4)*p(6)-p(24)
       p(28)=p(5)*p(6)-p(25)
       p(29)=p(1)*p(7)
       p(30)=p(2)*p(7)
       p(31)=p(3)*p(7)
       p(32)=m(76)+m(77)+m(78)+m(79)+m(80)+m(81)+m(82)+m(83)+m(84)+m(85)&
     &+m(86)+m(87)
       p(33)=m(88)+m(89)+m(90)+m(91)+m(92)+m(93)+m(94)+m(95)+m(96)+m(97)&
     &+m(98)+m(99)
       p(34)=m(100)+m(101)+m(102)+m(103)+m(104)+m(105)+m(106)+m(107)+m(1&
     &08)+m(109)+m(110)+m(111)
       p(35)=m(112)+m(113)+m(114)
       p(36)=p(4)*p(7)-p(32)
       p(37)=p(5)*p(7)-p(33)
       p(38)=p(6)*p(7)-p(34)
       p(39)=m(115)+m(116)+m(117)+m(118)+m(119)+m(120)+m(121)+m(122)+m(1&
     &23)+m(124)+m(125)+m(126)
       p(40)=p(1)*p(1)
       p(41)=p(2)*p(2)
       p(42)=p(3)*p(3)
       p(43)=p(4)*p(4)-p(14)-p(14)
       p(44)=p(5)*p(5)-p(19)-p(19)
       p(45)=p(6)*p(6)-p(26)-p(26)
       p(46)=p(7)*p(7)-p(39)-p(35)-p(39)-p(35)
       p(47)=p(1)*p(10)
       p(48)=p(1)*p(12)
       p(49)=p(1)*p(13)
       p(50)=p(2)*p(13)
       p(51)=p(1)*p(14)
       p(52)=p(2)*p(14)
       p(53)=p(3)*p(14)
       p(54)=m(127)+m(128)+m(129)+m(130)
       p(55)=p(1)*p(16)
       p(56)=p(1)*p(17)
       p(57)=p(2)*p(17)
       p(58)=p(1)*p(18)
       p(59)=p(2)*p(18)
       p(60)=p(3)*p(18)
       p(61)=m(131)+m(132)+m(133)+m(134)+m(135)+m(136)+m(137)+m(138)+m(1&
     &39)+m(140)+m(141)+m(142)
       p(62)=p(1)*p(19)
       p(63)=p(2)*p(19)
       p(64)=p(3)*p(19)
       p(65)=m(143)+m(144)+m(145)+m(146)+m(147)+m(148)+m(149)+m(150)+m(1&
     &51)+m(152)+m(153)+m(154)
       p(66)=m(155)+m(156)+m(157)+m(158)
       p(67)=p(1)*p(20)
       p(68)=p(2)*p(20)
       p(69)=p(3)*p(20)
       p(70)=p(5)*p(14)-p(61)
       p(71)=p(4)*p(19)-p(65)
       p(72)=p(1)*p(22)
       p(73)=p(1)*p(23)
       p(74)=p(2)*p(23)
       p(75)=p(1)*p(24)
       p(76)=p(2)*p(24)
       p(77)=p(3)*p(24)
       p(78)=m(159)+m(160)+m(161)+m(162)+m(163)+m(164)+m(165)+m(166)+m(1&
     &67)+m(168)+m(169)+m(170)
       p(79)=p(1)*p(25)
       p(80)=p(2)*p(25)
       p(81)=p(3)*p(25)
       p(82)=m(171)+m(172)+m(173)+m(174)+m(175)+m(176)+m(177)+m(178)+m(1&
     &79)+m(180)+m(181)+m(182)+m(183)+m(184)+m(185)+m(186)+m(187)+m(188)&
     &+m(189)+m(190)+m(191)+m(192)+m(193)+m(194)
       p(83)=m(195)+m(196)+m(197)+m(198)+m(199)+m(200)+m(201)+m(202)+m(2&
     &03)+m(204)+m(205)+m(206)
       p(84)=m(207)+m(208)+m(209)+m(210)+m(211)+m(212)+m(213)+m(214)+m(2&
     &15)+m(216)+m(217)+m(218)
       p(85)=p(1)*p(26)
       p(86)=p(2)*p(26)
       p(87)=p(3)*p(26)
       p(88)=m(219)+m(220)+m(221)+m(222)+m(223)+m(224)+m(225)+m(226)+m(2&
     &27)+m(228)+m(229)+m(230)
       p(89)=m(231)+m(232)+m(233)+m(234)+m(235)+m(236)+m(237)+m(238)+m(2&
     &39)+m(240)+m(241)+m(242)
       p(90)=m(243)+m(244)+m(245)+m(246)
       p(91)=p(1)*p(27)
       p(92)=p(2)*p(27)
       p(93)=p(3)*p(27)
       p(94)=p(6)*p(14)-p(78)
       p(95)=p(4)*p(25)-p(84)-p(82)
       p(96)=p(4)*p(26)-p(88)
       p(97)=p(1)*p(28)
       p(98)=p(2)*p(28)
       p(99)=p(3)*p(28)
       p(100)=p(5)*p(24)-p(84)-p(82)
       p(101)=p(6)*p(19)-p(83)
       p(102)=p(5)*p(26)-p(89)
       p(103)=p(4)*p(28)-p(100)
       p(104)=p(1)*p(30)
       p(105)=p(1)*p(31)
       p(106)=p(2)*p(31)
       p(107)=p(1)*p(32)
       p(108)=p(2)*p(32)
       p(109)=p(3)*p(32)
       p(110)=m(247)+m(248)+m(249)+m(250)+m(251)+m(252)
       p(111)=p(1)*p(33)
       p(112)=p(2)*p(33)
       p(113)=p(3)*p(33)
       p(114)=m(253)+m(254)+m(255)+m(256)+m(257)+m(258)+m(259)+m(260)+m(&
     &261)+m(262)+m(263)+m(264)
       p(115)=m(265)+m(266)+m(267)+m(268)+m(269)+m(270)
       p(116)=m(271)+m(272)+m(273)+m(274)+m(275)+m(276)+m(277)+m(278)+m(&
     &279)+m(280)+m(281)+m(282)
       p(117)=p(1)*p(34)
       p(118)=p(2)*p(34)
       p(119)=p(3)*p(34)
       p(120)=m(283)+m(284)+m(285)+m(286)+m(287)+m(288)+m(289)+m(290)+m(&
     &291)+m(292)+m(293)+m(294)
       p(121)=m(295)+m(296)+m(297)+m(298)+m(299)+m(300)+m(301)+m(302)+m(&
     &303)+m(304)+m(305)+m(306)
       p(122)=m(307)+m(308)+m(309)+m(310)+m(311)+m(312)
       p(123)=m(313)+m(314)+m(315)+m(316)+m(317)+m(318)+m(319)+m(320)+m(&
     &321)+m(322)+m(323)+m(324)
       p(124)=m(325)+m(326)+m(327)+m(328)+m(329)+m(330)+m(331)+m(332)+m(&
     &333)+m(334)+m(335)+m(336)
       p(125)=p(1)*p(35)
       p(126)=p(2)*p(35)
       p(127)=p(3)*p(35)
       p(128)=p(1)*p(36)
       p(129)=p(2)*p(36)
       p(130)=p(3)*p(36)
       p(131)=m(337)+m(338)+m(339)+m(340)+m(341)+m(342)+m(343)+m(344)+m(&
     &345)+m(346)+m(347)+m(348)+m(349)+m(350)+m(351)+m(352)+m(353)+m(354&
     &)+m(355)+m(356)+m(357)+m(358)+m(359)+m(360)
       p(132)=p(4)*p(33)-p(116)-p(114)
       p(133)=p(4)*p(34)-p(123)-p(120)
       p(134)=p(4)*p(35)
       p(135)=p(7)*p(14)-p(131)-p(110)
       p(136)=p(1)*p(37)
       p(137)=p(2)*p(37)
       p(138)=p(3)*p(37)
       p(139)=p(5)*p(32)-p(116)-p(114)
       p(140)=m(361)+m(362)+m(363)+m(364)+m(365)+m(366)+m(367)+m(368)+m(&
     &369)+m(370)+m(371)+m(372)+m(373)+m(374)+m(375)+m(376)+m(377)+m(378&
     &)+m(379)+m(380)+m(381)+m(382)+m(383)+m(384)
       p(141)=p(5)*p(34)-p(124)-p(121)
       p(142)=p(5)*p(35)
       p(143)=p(7)*p(18)-p(139)-p(132)-p(114)
       p(144)=p(7)*p(19)-p(140)-p(115)
       p(145)=p(7)*p(20)-p(116)
       p(146)=p(1)*p(38)
       p(147)=p(2)*p(38)
       p(148)=p(3)*p(38)
       p(149)=p(6)*p(32)-p(123)-p(120)
       p(150)=p(6)*p(33)-p(124)-p(121)
       p(151)=m(385)+m(386)+m(387)+m(388)+m(389)+m(390)+m(391)+m(392)+m(&
     &393)+m(394)+m(395)+m(396)+m(397)+m(398)+m(399)+m(400)+m(401)+m(402&
     &)+m(403)+m(404)+m(405)+m(406)+m(407)+m(408)
       p(152)=p(6)*p(35)
       p(153)=p(7)*p(24)-p(149)-p(133)-p(120)
       p(154)=p(7)*p(25)-p(150)-p(141)-p(121)
       p(155)=p(7)*p(26)-p(151)-p(122)
       p(156)=p(7)*p(27)-p(123)
       p(157)=p(7)*p(28)-p(124)
       p(158)=p(1)*p(39)
       p(159)=p(2)*p(39)
       p(160)=p(3)*p(39)
       p(161)=m(409)+m(410)+m(411)+m(412)+m(413)+m(414)+m(415)+m(416)+m(&
     &417)+m(418)+m(419)+m(420)
       p(162)=m(421)+m(422)+m(423)+m(424)+m(425)+m(426)+m(427)+m(428)+m(&
     &429)+m(430)+m(431)+m(432)
       p(163)=m(433)+m(434)+m(435)+m(436)+m(437)+m(438)+m(439)+m(440)+m(&
     &441)+m(442)+m(443)+m(444)
       p(164)=m(445)+m(446)+m(447)+m(448)+m(449)+m(450)+m(451)+m(452)+m(&
     &453)+m(454)+m(455)+m(456)+m(457)+m(458)+m(459)+m(460)+m(461)+m(462&
     &)+m(463)+m(464)+m(465)+m(466)+m(467)+m(468)
       p(165)=m(469)+m(470)+m(471)+m(472)+m(473)+m(474)+m(475)+m(476)+m(&
     &477)+m(478)+m(479)+m(480)+m(481)+m(482)+m(483)+m(484)+m(485)+m(486&
     &)+m(487)+m(488)+m(489)+m(490)+m(491)+m(492)
       p(166)=m(493)+m(494)+m(495)+m(496)+m(497)+m(498)+m(499)+m(500)+m(&
     &501)+m(502)+m(503)+m(504)+m(505)+m(506)+m(507)+m(508)+m(509)+m(510&
     &)+m(511)+m(512)+m(513)+m(514)+m(515)+m(516)
       p(167)=m(517)+m(518)+m(519)+m(520)+m(521)+m(522)+m(523)+m(524)+m(&
     &525)+m(526)+m(527)+m(528)
       p(168)=m(529)+m(530)+m(531)+m(532)
       p(169)=p(4)*p(39)-p(164)-p(161)
       p(170)=p(5)*p(39)-p(165)-p(162)
       p(171)=p(6)*p(39)-p(166)-p(163)
       p(172)=m(533)+m(534)+m(535)+m(536)
       p(173)=p(1)*p(8)
       p(174)=p(1)*p(41)
       p(175)=p(1)*p(9)
       p(176)=p(2)*p(10)
       p(177)=p(1)*p(42)
       p(178)=p(2)*p(42)
       p(179)=p(1)*p(11)
       p(180)=p(2)*p(12)
       p(181)=p(3)*p(13)
       p(182)=p(1)*p(43)
       p(183)=p(2)*p(43)
       p(184)=p(3)*p(43)
       p(185)=p(4)*p(14)-p(54)-p(54)-p(54)
       p(186)=p(1)*p(15)
       p(187)=p(2)*p(16)
       p(188)=p(3)*p(17)
       p(189)=p(4)*p(18)-p(70)-p(61)-p(61)
       p(190)=p(4)*p(20)-p(70)
       p(191)=p(1)*p(44)
       p(192)=p(2)*p(44)
       p(193)=p(3)*p(44)
       p(194)=p(5)*p(18)-p(71)-p(65)-p(65)
       p(195)=p(5)*p(19)-p(66)-p(66)-p(66)
       p(196)=p(4)*p(44)-p(194)
       p(197)=p(1)*p(21)
       p(198)=p(2)*p(22)
       p(199)=p(3)*p(23)
       p(200)=p(4)*p(24)-p(94)-p(78)-p(78)
       p(201)=p(5)*p(25)-p(101)-p(83)-p(83)
       p(202)=p(4)*p(27)-p(94)
       p(203)=p(5)*p(28)-p(101)
       p(204)=p(1)*p(45)
       p(205)=p(2)*p(45)
       p(206)=p(3)*p(45)
       p(207)=p(6)*p(24)-p(96)-p(88)-p(88)
       p(208)=p(6)*p(25)-p(102)-p(89)-p(89)
       p(209)=p(6)*p(26)-p(90)-p(90)-p(90)
       p(210)=p(4)*p(45)-p(207)
       p(211)=p(5)*p(45)-p(208)
       p(212)=p(1)*p(29)
       p(213)=p(2)*p(30)
       p(214)=p(3)*p(31)
       p(215)=p(4)*p(32)-p(131)-p(110)-p(110)
       p(216)=p(5)*p(33)-p(140)-p(115)-p(115)
       p(217)=p(6)*p(34)-p(151)-p(122)-p(122)
       p(218)=p(7)*p(43)-p(215)
       p(219)=p(7)*p(44)-p(216)
       p(220)=p(7)*p(45)-p(217)
       p(221)=p(1)*p(46)
       p(222)=p(2)*p(46)
       p(223)=p(3)*p(46)
       p(224)=p(7)*p(32)-p(164)-p(161)-p(134)-p(161)
       p(225)=p(7)*p(33)-p(165)-p(162)-p(142)-p(162)
       p(226)=p(7)*p(34)-p(166)-p(163)-p(152)-p(163)
       p(227)=p(7)*p(35)-p(167)
       p(228)=p(4)*p(46)-p(224)
       p(229)=p(5)*p(46)-p(225)
       p(230)=p(6)*p(46)-p(226)
       p(231)=p(7)*p(39)-p(168)-p(172)-p(167)-p(168)-p(172)-p(167)-p(168&
     &)-p(172)
       p(232)=p(1)*p(40)
       p(233)=p(2)*p(41)
       p(234)=p(3)*p(42)
       p(235)=p(4)*p(43)-p(185)
       p(236)=p(5)*p(44)-p(195)
       p(237)=p(6)*p(45)-p(209)
       p(238)=p(7)*p(46)-p(231)-p(227)
       p(239)=p(1)*p(50)
       p(240)=p(1)*p(52)
       p(241)=p(1)*p(53)
       p(242)=p(2)*p(53)
       p(243)=p(1)*p(54)
       p(244)=p(2)*p(54)
       p(245)=p(3)*p(54)
       p(246)=m(537)
       p(247)=p(1)*p(57)
       p(248)=p(1)*p(59)
       p(249)=p(1)*p(60)
       p(250)=p(2)*p(60)
       p(251)=p(1)*p(61)
       p(252)=p(2)*p(61)
       p(253)=p(3)*p(61)
       p(254)=m(538)+m(539)+m(540)+m(541)
       p(255)=p(1)*p(63)
       p(256)=p(1)*p(64)
       p(257)=p(2)*p(64)
       p(258)=p(1)*p(65)
       p(259)=p(2)*p(65)
       p(260)=p(3)*p(65)
       p(261)=m(542)+m(543)+m(544)+m(545)+m(546)+m(547)
       p(262)=p(1)*p(66)
       p(263)=p(2)*p(66)
       p(264)=p(3)*p(66)
       p(265)=m(548)+m(549)+m(550)+m(551)
       p(266)=m(552)
       p(267)=p(1)*p(68)
       p(268)=p(1)*p(69)
       p(269)=p(2)*p(69)
       p(270)=p(1)*p(70)
       p(271)=p(2)*p(70)
       p(272)=p(3)*p(70)
       p(273)=p(5)*p(54)-p(254)
       p(274)=p(1)*p(71)
       p(275)=p(2)*p(71)
       p(276)=p(3)*p(71)
       p(277)=m(553)+m(554)+m(555)+m(556)+m(557)+m(558)+m(559)+m(560)+m(&
     &561)+m(562)+m(563)+m(564)+m(565)+m(566)+m(567)+m(568)+m(569)+m(570&
     &)+m(571)+m(572)+m(573)+m(574)+m(575)+m(576)
       p(278)=p(4)*p(66)-p(265)
       p(279)=p(14)*p(19)-p(277)-p(261)
       p(280)=p(1)*p(74)
       p(281)=p(1)*p(76)
       p(282)=p(1)*p(77)
       p(283)=p(2)*p(77)
       p(284)=p(1)*p(78)
       p(285)=p(2)*p(78)
       p(286)=p(3)*p(78)
       p(287)=m(577)+m(578)+m(579)+m(580)
       p(288)=p(1)*p(80)
       p(289)=p(1)*p(81)
       p(290)=p(2)*p(81)
       p(291)=p(1)*p(82)
       p(292)=p(2)*p(82)
       p(293)=p(3)*p(82)
       p(294)=m(581)+m(582)+m(583)+m(584)+m(585)+m(586)+m(587)+m(588)+m(&
     &589)+m(590)+m(591)+m(592)
       p(295)=p(1)*p(83)
       p(296)=p(2)*p(83)
       p(297)=p(3)*p(83)
       p(298)=m(593)+m(594)+m(595)+m(596)+m(597)+m(598)+m(599)+m(600)+m(&
     &601)+m(602)+m(603)+m(604)
       p(299)=m(605)+m(606)+m(607)+m(608)
       p(300)=p(1)*p(84)
       p(301)=p(2)*p(84)
       p(302)=p(3)*p(84)
       p(303)=m(609)+m(610)+m(611)+m(612)+m(613)+m(614)+m(615)+m(616)+m(&
     &617)+m(618)+m(619)+m(620)+m(621)+m(622)+m(623)+m(624)+m(625)+m(626&
     &)+m(627)+m(628)+m(629)+m(630)+m(631)+m(632)
       p(304)=m(633)+m(634)+m(635)+m(636)+m(637)+m(638)+m(639)+m(640)+m(&
     &641)+m(642)+m(643)+m(644)+m(645)+m(646)+m(647)+m(648)+m(649)+m(650&
     &)+m(651)+m(652)+m(653)+m(654)+m(655)+m(656)
       p(305)=p(1)*p(86)
       p(306)=p(1)*p(87)
       p(307)=p(2)*p(87)
       p(308)=p(1)*p(88)
       p(309)=p(2)*p(88)
       p(310)=p(3)*p(88)
       p(311)=m(657)+m(658)+m(659)+m(660)+m(661)+m(662)
       p(312)=p(1)*p(89)
       p(313)=p(2)*p(89)
       p(314)=p(3)*p(89)
       p(315)=m(663)+m(664)+m(665)+m(666)+m(667)+m(668)+m(669)+m(670)+m(&
     &671)+m(672)+m(673)+m(674)
       p(316)=m(675)+m(676)+m(677)+m(678)+m(679)+m(680)
       p(317)=m(681)+m(682)+m(683)+m(684)+m(685)+m(686)+m(687)+m(688)+m(&
     &689)+m(690)+m(691)+m(692)
       p(318)=p(1)*p(90)
       p(319)=p(2)*p(90)
       p(320)=p(3)*p(90)
       p(321)=m(693)+m(694)+m(695)+m(696)
       p(322)=m(697)+m(698)+m(699)+m(700)
       p(323)=m(701)
       p(324)=p(1)*p(92)
       p(325)=p(1)*p(93)
       p(326)=p(2)*p(93)
       p(327)=p(1)*p(94)
       p(328)=p(2)*p(94)
       p(329)=p(3)*p(94)
       p(330)=p(6)*p(54)-p(287)
       p(331)=p(1)*p(95)
       p(332)=p(2)*p(95)
       p(333)=p(3)*p(95)
       p(334)=m(702)+m(703)+m(704)+m(705)+m(706)+m(707)+m(708)+m(709)+m(&
     &710)+m(711)+m(712)+m(713)+m(714)+m(715)+m(716)+m(717)+m(718)+m(719&
     &)+m(720)+m(721)+m(722)+m(723)+m(724)+m(725)
       p(335)=p(4)*p(83)-p(304)-p(298)
       p(336)=p(14)*p(25)-p(334)-p(303)-p(294)
       p(337)=p(1)*p(96)
       p(338)=p(2)*p(96)
       p(339)=p(3)*p(96)
       p(340)=m(726)+m(727)+m(728)+m(729)+m(730)+m(731)+m(732)+m(733)+m(&
     &734)+m(735)+m(736)+m(737)+m(738)+m(739)+m(740)+m(741)+m(742)+m(743&
     &)+m(744)+m(745)+m(746)+m(747)+m(748)+m(749)
       p(341)=p(4)*p(89)-p(317)-p(315)
       p(342)=p(4)*p(90)-p(321)
       p(343)=p(14)*p(26)-p(340)-p(311)
       p(344)=p(1)*p(98)
       p(345)=p(1)*p(99)
       p(346)=p(2)*p(99)
       p(347)=p(1)*p(100)
       p(348)=p(2)*p(100)
       p(349)=p(3)*p(100)
       p(350)=p(5)*p(78)-p(303)-p(294)
       p(351)=p(1)*p(101)
       p(352)=p(2)*p(101)
       p(353)=p(3)*p(101)
       p(354)=p(6)*p(65)-p(335)-p(298)
       p(355)=p(6)*p(66)-p(299)
       p(356)=p(19)*p(24)-p(354)-p(304)-p(298)
       p(357)=p(1)*p(102)
       p(358)=p(2)*p(102)
       p(359)=p(3)*p(102)
       p(360)=p(5)*p(88)-p(317)-p(315)
       p(361)=m(750)+m(751)+m(752)+m(753)+m(754)+m(755)+m(756)+m(757)+m(&
     &758)+m(759)+m(760)+m(761)+m(762)+m(763)+m(764)+m(765)+m(766)+m(767&
     &)+m(768)+m(769)+m(770)+m(771)+m(772)+m(773)
       p(362)=p(5)*p(90)-p(322)
       p(363)=p(18)*p(26)-p(360)-p(341)-p(315)
       p(364)=p(19)*p(26)-p(361)-p(316)
       p(365)=p(1)*p(103)
       p(366)=p(2)*p(103)
       p(367)=p(3)*p(103)
       p(368)=p(14)*p(28)-p(350)
       p(369)=p(19)*p(27)-p(335)
       p(370)=p(20)*p(26)-p(317)
       p(371)=p(1)*p(106)
       p(372)=p(1)*p(108)
       p(373)=p(1)*p(109)
       p(374)=p(2)*p(109)
       p(375)=p(1)*p(110)
       p(376)=p(2)*p(110)
       p(377)=p(3)*p(110)
       p(378)=p(1)*p(112)
       p(379)=p(1)*p(113)
       p(380)=p(2)*p(113)
       p(381)=p(1)*p(114)
       p(382)=p(2)*p(114)
       p(383)=p(3)*p(114)
       p(384)=p(1)*p(115)
       p(385)=p(2)*p(115)
       p(386)=p(3)*p(115)
       p(387)=p(1)*p(116)
       p(388)=p(2)*p(116)
       p(389)=p(3)*p(116)
       p(390)=m(774)+m(775)+m(776)+m(777)+m(778)+m(779)+m(780)+m(781)+m(&
     &782)+m(783)+m(784)+m(785)
       p(391)=m(786)+m(787)+m(788)+m(789)+m(790)+m(791)+m(792)+m(793)+m(&
     &794)+m(795)+m(796)+m(797)
       p(392)=p(1)*p(118)
       p(393)=p(1)*p(119)
       p(394)=p(2)*p(119)
       p(395)=p(1)*p(120)
       p(396)=p(2)*p(120)
       p(397)=p(3)*p(120)
       p(398)=p(1)*p(121)
       p(399)=p(2)*p(121)
       p(400)=p(3)*p(121)
       p(401)=m(798)+m(799)+m(800)+m(801)+m(802)+m(803)+m(804)+m(805)+m(&
     &806)+m(807)+m(808)+m(809)
       p(402)=p(1)*p(122)
       p(403)=p(2)*p(122)
       p(404)=p(3)*p(122)
       p(405)=p(1)*p(123)
       p(406)=p(2)*p(123)
       p(407)=p(3)*p(123)
       p(408)=m(810)+m(811)+m(812)+m(813)+m(814)+m(815)+m(816)+m(817)+m(&
     &818)+m(819)+m(820)+m(821)
       p(409)=m(822)+m(823)+m(824)+m(825)+m(826)+m(827)+m(828)+m(829)+m(&
     &830)+m(831)+m(832)+m(833)
       p(410)=m(834)+m(835)+m(836)+m(837)+m(838)+m(839)+m(840)+m(841)+m(&
     &842)+m(843)+m(844)+m(845)
       p(411)=p(1)*p(124)
       p(412)=p(2)*p(124)
       p(413)=p(3)*p(124)
       p(414)=m(846)+m(847)+m(848)+m(849)+m(850)+m(851)+m(852)+m(853)+m(&
     &854)+m(855)+m(856)+m(857)
       p(415)=m(858)+m(859)+m(860)+m(861)+m(862)+m(863)+m(864)+m(865)+m(&
     &866)+m(867)+m(868)+m(869)
       p(416)=m(870)+m(871)+m(872)+m(873)+m(874)+m(875)+m(876)+m(877)+m(&
     &878)+m(879)+m(880)+m(881)
       p(417)=m(882)+m(883)+m(884)+m(885)+m(886)+m(887)+m(888)+m(889)+m(&
     &890)+m(891)+m(892)+m(893)
       p(418)=p(1)*p(126)
       p(419)=p(1)*p(127)
       p(420)=p(2)*p(127)
       p(421)=p(1)*p(129)
       p(422)=p(1)*p(130)
       p(423)=p(2)*p(130)
       p(424)=p(1)*p(131)
       p(425)=p(2)*p(131)
       p(426)=p(3)*p(131)
       p(427)=m(894)+m(895)+m(896)+m(897)+m(898)+m(899)+m(900)+m(901)+m(&
     &902)+m(903)+m(904)+m(905)
       p(428)=p(1)*p(132)
       p(429)=p(2)*p(132)
       p(430)=p(3)*p(132)
       p(431)=m(906)+m(907)+m(908)+m(909)+m(910)+m(911)+m(912)+m(913)+m(&
     &914)+m(915)+m(916)+m(917)+m(918)+m(919)+m(920)+m(921)+m(922)+m(923&
     &)+m(924)+m(925)+m(926)+m(927)+m(928)+m(929)
       p(432)=p(4)*p(115)-p(391)
       p(433)=m(930)+m(931)+m(932)+m(933)+m(934)+m(935)+m(936)+m(937)+m(&
     &938)+m(939)+m(940)+m(941)+m(942)+m(943)+m(944)+m(945)+m(946)+m(947&
     &)+m(948)+m(949)+m(950)+m(951)+m(952)+m(953)
       p(434)=p(1)*p(133)
       p(435)=p(2)*p(133)
       p(436)=p(3)*p(133)
       p(437)=m(954)+m(955)+m(956)+m(957)+m(958)+m(959)+m(960)+m(961)+m(&
     &962)+m(963)+m(964)+m(965)+m(966)+m(967)+m(968)+m(969)+m(970)+m(971&
     &)+m(972)+m(973)+m(974)+m(975)+m(976)+m(977)
       p(438)=p(4)*p(121)-p(409)-p(401)
       p(439)=p(4)*p(122)-p(410)
       p(440)=m(978)+m(979)+m(980)+m(981)+m(982)+m(983)+m(984)+m(985)+m(&
     &986)+m(987)+m(988)+m(989)+m(990)+m(991)+m(992)+m(993)+m(994)+m(995&
     &)+m(996)+m(997)+m(998)+m(999)+m(1000)+m(1001)
       p(441)=p(4)*p(124)-p(417)-p(414)
       p(442)=p(1)*p(134)
       p(443)=p(2)*p(134)
       p(444)=p(3)*p(134)
       p(445)=m(1002)+m(1003)+m(1004)+m(1005)+m(1006)+m(1007)+m(1008)+m(&
     &1009)+m(1010)+m(1011)+m(1012)+m(1013)
       p(446)=p(1)*p(135)
       p(447)=p(2)*p(135)
       p(448)=p(3)*p(135)
       p(449)=p(7)*p(54)-p(427)
       p(450)=p(14)*p(33)-p(433)-p(431)-p(390)
       p(451)=p(14)*p(34)-p(440)-p(437)-p(408)
       p(452)=p(14)*p(35)-p(445)
       p(453)=p(1)*p(137)
       p(454)=p(1)*p(138)
       p(455)=p(2)*p(138)
       p(456)=p(1)*p(139)
       p(457)=p(2)*p(139)
       p(458)=p(3)*p(139)
       p(459)=p(5)*p(110)-p(390)
       p(460)=p(1)*p(140)
       p(461)=p(2)*p(140)
       p(462)=p(3)*p(140)
       p(463)=m(1014)+m(1015)+m(1016)+m(1017)+m(1018)+m(1019)+m(1020)+m(&
     &1021)+m(1022)+m(1023)+m(1024)+m(1025)+m(1026)+m(1027)+m(1028)+m(10&
     &29)+m(1030)+m(1031)+m(1032)+m(1033)+m(1034)+m(1035)+m(1036)+m(1037&
     &)
       p(464)=m(1038)+m(1039)+m(1040)+m(1041)+m(1042)+m(1043)+m(1044)+m(&
     &1045)+m(1046)+m(1047)+m(1048)+m(1049)
       p(465)=m(1050)+m(1051)+m(1052)+m(1053)+m(1054)+m(1055)+m(1056)+m(&
     &1057)+m(1058)+m(1059)+m(1060)+m(1061)+m(1062)+m(1063)+m(1064)+m(10&
     &65)+m(1066)+m(1067)+m(1068)+m(1069)+m(1070)+m(1071)+m(1072)+m(1073&
     &)
       p(466)=p(1)*p(141)
       p(467)=p(2)*p(141)
       p(468)=p(3)*p(141)
       p(469)=p(5)*p(120)-p(414)-p(401)
       p(470)=m(1074)+m(1075)+m(1076)+m(1077)+m(1078)+m(1079)+m(1080)+m(&
     &1081)+m(1082)+m(1083)+m(1084)+m(1085)+m(1086)+m(1087)+m(1088)+m(10&
     &89)+m(1090)+m(1091)+m(1092)+m(1093)+m(1094)+m(1095)+m(1096)+m(1097&
     &)
       p(471)=p(5)*p(122)-p(416)
       p(472)=p(5)*p(123)-p(417)-p(409)
       p(473)=m(1098)+m(1099)+m(1100)+m(1101)+m(1102)+m(1103)+m(1104)+m(&
     &1105)+m(1106)+m(1107)+m(1108)+m(1109)+m(1110)+m(1111)+m(1112)+m(11&
     &13)+m(1114)+m(1115)+m(1116)+m(1117)+m(1118)+m(1119)+m(1120)+m(1121&
     &)
       p(474)=p(1)*p(142)
       p(475)=p(2)*p(142)
       p(476)=p(3)*p(142)
       p(477)=m(1122)+m(1123)+m(1124)+m(1125)+m(1126)+m(1127)+m(1128)+m(&
     &1129)+m(1130)+m(1131)+m(1132)+m(1133)+m(1134)+m(1135)+m(1136)+m(11&
     &37)+m(1138)+m(1139)+m(1140)+m(1141)+m(1142)+m(1143)+m(1144)+m(1145&
     &)
       p(478)=m(1146)+m(1147)+m(1148)+m(1149)+m(1150)+m(1151)+m(1152)+m(&
     &1153)+m(1154)+m(1155)+m(1156)+m(1157)
       p(479)=p(1)*p(143)
       p(480)=p(2)*p(143)
       p(481)=p(3)*p(143)
       p(482)=p(7)*p(61)-p(450)-p(459)-p(431)
       p(483)=m(1158)+m(1159)+m(1160)+m(1161)+m(1162)+m(1163)+m(1164)+m(&
     &1165)+m(1166)+m(1167)+m(1168)+m(1169)+m(1170)+m(1171)+m(1172)+m(11&
     &73)+m(1174)+m(1175)+m(1176)+m(1177)+m(1178)+m(1179)+m(1180)+m(1181&
     &)
       p(484)=p(18)*p(34)-p(472)-p(441)-p(469)-p(414)-p(438)-p(409)
       p(485)=p(18)*p(35)-p(477)
       p(486)=p(1)*p(144)
       p(487)=p(2)*p(144)
       p(488)=p(3)*p(144)
       p(489)=p(7)*p(65)-p(483)-p(463)-p(432)
       p(490)=p(7)*p(66)-p(464)
       p(491)=p(19)*p(34)-p(473)-p(470)-p(415)
       p(492)=p(19)*p(35)-p(478)
       p(493)=p(1)*p(145)
       p(494)=p(2)*p(145)
       p(495)=p(3)*p(145)
       p(496)=p(5)*p(131)-p(482)-p(433)-p(431)
       p(497)=p(4)*p(140)-p(483)-p(465)-p(463)
       p(498)=p(20)*p(34)-p(417)-p(401)
       p(499)=p(20)*p(35)
       p(500)=p(5)*p(135)-p(450)
       p(501)=p(4)*p(144)-p(489)
       p(502)=p(1)*p(147)
       p(503)=p(1)*p(148)
       p(504)=p(2)*p(148)
       p(505)=p(1)*p(149)
       p(506)=p(2)*p(149)
       p(507)=p(3)*p(149)
       p(508)=p(6)*p(110)-p(408)
       p(509)=p(1)*p(150)
       p(510)=p(2)*p(150)
       p(511)=p(3)*p(150)
       p(512)=p(6)*p(114)-p(414)-p(409)
       p(513)=p(6)*p(115)-p(415)
       p(514)=p(6)*p(116)-p(417)-p(401)
       p(515)=p(1)*p(151)
       p(516)=p(2)*p(151)
       p(517)=p(3)*p(151)
       p(518)=m(1182)+m(1183)+m(1184)+m(1185)+m(1186)+m(1187)+m(1188)+m(&
     &1189)+m(1190)+m(1191)+m(1192)+m(1193)+m(1194)+m(1195)+m(1196)+m(11&
     &97)+m(1198)+m(1199)+m(1200)+m(1201)+m(1202)+m(1203)+m(1204)+m(1205&
     &)
       p(519)=m(1206)+m(1207)+m(1208)+m(1209)+m(1210)+m(1211)+m(1212)+m(&
     &1213)+m(1214)+m(1215)+m(1216)+m(1217)+m(1218)+m(1219)+m(1220)+m(12&
     &21)+m(1222)+m(1223)+m(1224)+m(1225)+m(1226)+m(1227)+m(1228)+m(1229&
     &)
       p(520)=m(1230)+m(1231)+m(1232)+m(1233)+m(1234)+m(1235)+m(1236)+m(&
     &1237)+m(1238)+m(1239)+m(1240)+m(1241)
       p(521)=m(1242)+m(1243)+m(1244)+m(1245)+m(1246)+m(1247)+m(1248)+m(&
     &1249)+m(1250)+m(1251)+m(1252)+m(1253)+m(1254)+m(1255)+m(1256)+m(12&
     &57)+m(1258)+m(1259)+m(1260)+m(1261)+m(1262)+m(1263)+m(1264)+m(1265&
     &)
       p(522)=m(1266)+m(1267)+m(1268)+m(1269)+m(1270)+m(1271)+m(1272)+m(&
     &1273)+m(1274)+m(1275)+m(1276)+m(1277)+m(1278)+m(1279)+m(1280)+m(12&
     &81)+m(1282)+m(1283)+m(1284)+m(1285)+m(1286)+m(1287)+m(1288)+m(1289&
     &)
       p(523)=p(1)*p(152)
       p(524)=p(2)*p(152)
       p(525)=p(3)*p(152)
       p(526)=m(1290)+m(1291)+m(1292)+m(1293)+m(1294)+m(1295)+m(1296)+m(&
     &1297)+m(1298)+m(1299)+m(1300)+m(1301)+m(1302)+m(1303)+m(1304)+m(13&
     &05)+m(1306)+m(1307)+m(1308)+m(1309)+m(1310)+m(1311)+m(1312)+m(1313&
     &)
       p(527)=m(1314)+m(1315)+m(1316)+m(1317)+m(1318)+m(1319)+m(1320)+m(&
     &1321)+m(1322)+m(1323)+m(1324)+m(1325)+m(1326)+m(1327)+m(1328)+m(13&
     &29)+m(1330)+m(1331)+m(1332)+m(1333)+m(1334)+m(1335)+m(1336)+m(1337&
     &)
       p(528)=m(1338)+m(1339)+m(1340)+m(1341)+m(1342)+m(1343)+m(1344)+m(&
     &1345)+m(1346)+m(1347)+m(1348)+m(1349)
       p(529)=p(1)*p(153)
       p(530)=p(2)*p(153)
       p(531)=p(3)*p(153)
       p(532)=p(7)*p(78)-p(451)-p(508)-p(437)
       p(533)=p(24)*p(33)-p(514)-p(441)-p(512)-p(414)-p(438)-p(401)
       p(534)=m(1350)+m(1351)+m(1352)+m(1353)+m(1354)+m(1355)+m(1356)+m(&
     &1357)+m(1358)+m(1359)+m(1360)+m(1361)+m(1362)+m(1363)+m(1364)+m(13&
     &65)+m(1366)+m(1367)+m(1368)+m(1369)+m(1370)+m(1371)+m(1372)+m(1373&
     &)
       p(535)=p(24)*p(35)-p(526)
       p(536)=p(1)*p(154)
       p(537)=p(2)*p(154)
       p(538)=p(3)*p(154)
       p(539)=p(7)*p(82)-p(533)-p(484)-p(512)-p(469)-p(438)
       p(540)=p(7)*p(83)-p(491)-p(513)-p(470)
       p(541)=m(1374)+m(1375)+m(1376)+m(1377)+m(1378)+m(1379)+m(1380)+m(&
     &1381)+m(1382)+m(1383)+m(1384)+m(1385)+m(1386)+m(1387)+m(1388)+m(13&
     &89)+m(1390)+m(1391)+m(1392)+m(1393)+m(1394)+m(1395)+m(1396)+m(1397&
     &)
       p(542)=p(25)*p(35)-p(527)
       p(543)=p(7)*p(84)-p(514)-p(498)-p(401)
       p(544)=p(1)*p(155)
       p(545)=p(2)*p(155)
       p(546)=p(3)*p(155)
       p(547)=p(7)*p(88)-p(534)-p(518)-p(439)
       p(548)=p(7)*p(89)-p(541)-p(519)-p(471)
       p(549)=p(7)*p(90)-p(520)
       p(550)=p(26)*p(35)-p(528)
       p(551)=p(1)*p(156)
       p(552)=p(2)*p(156)
       p(553)=p(3)*p(156)
       p(554)=p(6)*p(131)-p(532)-p(440)-p(437)
       p(555)=p(27)*p(33)-p(417)-p(409)
       p(556)=p(4)*p(151)-p(534)-p(521)-p(518)
       p(557)=p(27)*p(35)
       p(558)=p(6)*p(135)-p(451)
       p(559)=p(4)*p(154)-p(543)-p(539)
       p(560)=p(4)*p(155)-p(547)
       p(561)=p(1)*p(157)
       p(562)=p(2)*p(157)
       p(563)=p(3)*p(157)
       p(564)=p(28)*p(32)-p(417)-p(414)
       p(565)=p(6)*p(140)-p(540)-p(473)-p(470)
       p(566)=p(5)*p(151)-p(541)-p(522)-p(519)
       p(567)=p(28)*p(35)
       p(568)=p(5)*p(153)-p(543)-p(533)
       p(569)=p(6)*p(144)-p(491)
       p(570)=p(5)*p(155)-p(548)
       p(571)=p(7)*p(103)-p(417)
       p(572)=p(1)*p(159)
       p(573)=p(1)*p(160)
       p(574)=p(2)*p(160)
       p(575)=p(1)*p(161)
       p(576)=p(2)*p(161)
       p(577)=p(3)*p(161)
       p(578)=p(1)*p(162)
       p(579)=p(2)*p(162)
       p(580)=p(3)*p(162)
       p(581)=m(1398)+m(1399)+m(1400)+m(1401)+m(1402)+m(1403)+m(1404)+m(&
     &1405)+m(1406)+m(1407)+m(1408)+m(1409)
       p(582)=p(1)*p(163)
       p(583)=p(2)*p(163)
       p(584)=p(3)*p(163)
       p(585)=m(1410)+m(1411)+m(1412)+m(1413)+m(1414)+m(1415)+m(1416)+m(&
     &1417)+m(1418)+m(1419)+m(1420)+m(1421)
       p(586)=m(1422)+m(1423)+m(1424)+m(1425)+m(1426)+m(1427)+m(1428)+m(&
     &1429)+m(1430)+m(1431)+m(1432)+m(1433)
       p(587)=p(1)*p(164)
       p(588)=p(2)*p(164)
       p(589)=p(3)*p(164)
       p(590)=m(1434)+m(1435)+m(1436)+m(1437)+m(1438)+m(1439)+m(1440)+m(&
     &1441)+m(1442)+m(1443)+m(1444)+m(1445)+m(1446)+m(1447)+m(1448)+m(14&
     &49)+m(1450)+m(1451)+m(1452)+m(1453)+m(1454)+m(1455)+m(1456)+m(1457&
     &)
       p(591)=m(1458)+m(1459)+m(1460)+m(1461)+m(1462)+m(1463)+m(1464)+m(&
     &1465)+m(1466)+m(1467)+m(1468)+m(1469)+m(1470)+m(1471)+m(1472)+m(14&
     &73)+m(1474)+m(1475)+m(1476)+m(1477)+m(1478)+m(1479)+m(1480)+m(1481&
     &)
       p(592)=m(1482)+m(1483)+m(1484)+m(1485)+m(1486)+m(1487)+m(1488)+m(&
     &1489)+m(1490)+m(1491)+m(1492)+m(1493)+m(1494)+m(1495)+m(1496)+m(14&
     &97)+m(1498)+m(1499)+m(1500)+m(1501)+m(1502)+m(1503)+m(1504)+m(1505&
     &)
       p(593)=m(1506)+m(1507)+m(1508)+m(1509)+m(1510)+m(1511)+m(1512)+m(&
     &1513)+m(1514)+m(1515)+m(1516)+m(1517)
       p(594)=p(1)*p(165)
       p(595)=p(2)*p(165)
       p(596)=p(3)*p(165)
       p(597)=m(1518)+m(1519)+m(1520)+m(1521)+m(1522)+m(1523)+m(1524)+m(&
     &1525)+m(1526)+m(1527)+m(1528)+m(1529)+m(1530)+m(1531)+m(1532)+m(15&
     &33)+m(1534)+m(1535)+m(1536)+m(1537)+m(1538)+m(1539)+m(1540)+m(1541&
     &)
       p(598)=m(1542)+m(1543)+m(1544)+m(1545)+m(1546)+m(1547)+m(1548)+m(&
     &1549)+m(1550)+m(1551)+m(1552)+m(1553)+m(1554)+m(1555)+m(1556)+m(15&
     &57)+m(1558)+m(1559)+m(1560)+m(1561)+m(1562)+m(1563)+m(1564)+m(1565&
     &)
       p(599)=m(1566)+m(1567)+m(1568)+m(1569)+m(1570)+m(1571)+m(1572)+m(&
     &1573)+m(1574)+m(1575)+m(1576)+m(1577)+m(1578)+m(1579)+m(1580)+m(15&
     &81)+m(1582)+m(1583)+m(1584)+m(1585)+m(1586)+m(1587)+m(1588)+m(1589&
     &)
       p(600)=m(1590)+m(1591)+m(1592)+m(1593)+m(1594)+m(1595)+m(1596)+m(&
     &1597)+m(1598)+m(1599)+m(1600)+m(1601)+m(1602)+m(1603)+m(1604)+m(16&
     &05)+m(1606)+m(1607)+m(1608)+m(1609)+m(1610)+m(1611)+m(1612)+m(1613&
     &)
       p(601)=m(1614)+m(1615)+m(1616)+m(1617)+m(1618)+m(1619)+m(1620)+m(&
     &1621)+m(1622)+m(1623)+m(1624)+m(1625)
       p(602)=m(1626)+m(1627)+m(1628)+m(1629)+m(1630)+m(1631)+m(1632)+m(&
     &1633)+m(1634)+m(1635)+m(1636)+m(1637)+m(1638)+m(1639)+m(1640)+m(16&
     &41)+m(1642)+m(1643)+m(1644)+m(1645)+m(1646)+m(1647)+m(1648)+m(1649&
     &)
       p(603)=p(1)*p(166)
       p(604)=p(2)*p(166)
       p(605)=p(3)*p(166)
       p(606)=m(1650)+m(1651)+m(1652)+m(1653)+m(1654)+m(1655)+m(1656)+m(&
     &1657)+m(1658)+m(1659)+m(1660)+m(1661)+m(1662)+m(1663)+m(1664)+m(16&
     &65)+m(1666)+m(1667)+m(1668)+m(1669)+m(1670)+m(1671)+m(1672)+m(1673&
     &)
       p(607)=m(1674)+m(1675)+m(1676)+m(1677)+m(1678)+m(1679)+m(1680)+m(&
     &1681)+m(1682)+m(1683)+m(1684)+m(1685)+m(1686)+m(1687)+m(1688)+m(16&
     &89)+m(1690)+m(1691)+m(1692)+m(1693)+m(1694)+m(1695)+m(1696)+m(1697&
     &)
       p(608)=m(1698)+m(1699)+m(1700)+m(1701)+m(1702)+m(1703)+m(1704)+m(&
     &1705)+m(1706)+m(1707)+m(1708)+m(1709)+m(1710)+m(1711)+m(1712)+m(17&
     &13)+m(1714)+m(1715)+m(1716)+m(1717)+m(1718)+m(1719)+m(1720)+m(1721&
     &)
       p(609)=m(1722)+m(1723)+m(1724)+m(1725)+m(1726)+m(1727)+m(1728)+m(&
     &1729)+m(1730)+m(1731)+m(1732)+m(1733)+m(1734)+m(1735)+m(1736)+m(17&
     &37)+m(1738)+m(1739)+m(1740)+m(1741)+m(1742)+m(1743)+m(1744)+m(1745&
     &)
       p(610)=m(1746)+m(1747)+m(1748)+m(1749)+m(1750)+m(1751)+m(1752)+m(&
     &1753)+m(1754)+m(1755)+m(1756)+m(1757)+m(1758)+m(1759)+m(1760)+m(17&
     &61)+m(1762)+m(1763)+m(1764)+m(1765)+m(1766)+m(1767)+m(1768)+m(1769&
     &)
       p(611)=m(1770)+m(1771)+m(1772)+m(1773)+m(1774)+m(1775)+m(1776)+m(&
     &1777)+m(1778)+m(1779)+m(1780)+m(1781)
       p(612)=m(1782)+m(1783)+m(1784)+m(1785)+m(1786)+m(1787)+m(1788)+m(&
     &1789)+m(1790)+m(1791)+m(1792)+m(1793)+m(1794)+m(1795)+m(1796)+m(17&
     &97)+m(1798)+m(1799)+m(1800)+m(1801)+m(1802)+m(1803)+m(1804)+m(1805&
     &)
       p(613)=m(1806)+m(1807)+m(1808)+m(1809)+m(1810)+m(1811)+m(1812)+m(&
     &1813)+m(1814)+m(1815)+m(1816)+m(1817)+m(1818)+m(1819)+m(1820)+m(18&
     &21)+m(1822)+m(1823)+m(1824)+m(1825)+m(1826)+m(1827)+m(1828)+m(1829&
     &)
       p(614)=p(1)*p(167)
       p(615)=p(2)*p(167)
       p(616)=p(3)*p(167)
       p(617)=m(1830)+m(1831)+m(1832)+m(1833)+m(1834)+m(1835)+m(1836)+m(&
     &1837)+m(1838)+m(1839)+m(1840)+m(1841)+m(1842)+m(1843)+m(1844)+m(18&
     &45)+m(1846)+m(1847)+m(1848)+m(1849)+m(1850)+m(1851)+m(1852)+m(1853&
     &)
       p(618)=m(1854)+m(1855)+m(1856)+m(1857)+m(1858)+m(1859)+m(1860)+m(&
     &1861)+m(1862)+m(1863)+m(1864)+m(1865)+m(1866)+m(1867)+m(1868)+m(18&
     &69)+m(1870)+m(1871)+m(1872)+m(1873)+m(1874)+m(1875)+m(1876)+m(1877&
     &)
       p(619)=m(1878)+m(1879)+m(1880)+m(1881)+m(1882)+m(1883)+m(1884)+m(&
     &1885)+m(1886)+m(1887)+m(1888)+m(1889)+m(1890)+m(1891)+m(1892)+m(18&
     &93)+m(1894)+m(1895)+m(1896)+m(1897)+m(1898)+m(1899)+m(1900)+m(1901&
     &)
       p(620)=m(1902)+m(1903)+m(1904)
       p(621)=p(1)*p(168)
       p(622)=p(2)*p(168)
       p(623)=p(3)*p(168)
       p(624)=m(1905)+m(1906)+m(1907)+m(1908)
       p(625)=m(1909)+m(1910)+m(1911)+m(1912)
       p(626)=m(1913)+m(1914)+m(1915)+m(1916)
       p(627)=p(1)*p(169)
       p(628)=p(2)*p(169)
       p(629)=p(3)*p(169)
       p(630)=m(1917)+m(1918)+m(1919)+m(1920)+m(1921)+m(1922)+m(1923)+m(&
     &1924)+m(1925)+m(1926)+m(1927)+m(1928)
       p(631)=p(4)*p(162)-p(591)-p(581)
       p(632)=p(4)*p(163)-p(592)-p(585)
       p(633)=p(14)*p(39)-p(593)-p(630)-p(590)
       p(634)=p(4)*p(165)-p(602)-p(600)-p(597)
       p(635)=p(4)*p(166)-p(612)-p(609)-p(606)
       p(636)=p(4)*p(167)-p(617)
       p(637)=p(4)*p(168)-p(624)
       p(638)=p(1)*p(170)
       p(639)=p(2)*p(170)
       p(640)=p(3)*p(170)
       p(641)=p(5)*p(161)-p(597)-p(581)
       p(642)=m(1929)+m(1930)+m(1931)+m(1932)+m(1933)+m(1934)+m(1935)+m(&
     &1936)+m(1937)+m(1938)+m(1939)+m(1940)
       p(643)=p(5)*p(163)-p(599)-p(586)
       p(644)=p(5)*p(164)-p(602)-p(600)-p(591)
       p(645)=p(19)*p(39)-p(601)-p(642)-p(598)
       p(646)=p(5)*p(166)-p(613)-p(610)-p(607)
       p(647)=p(5)*p(167)-p(618)
       p(648)=p(5)*p(168)-p(625)
       p(649)=p(4)*p(170)-p(644)-p(641)
       p(650)=p(1)*p(171)
       p(651)=p(2)*p(171)
       p(652)=p(3)*p(171)
       p(653)=p(6)*p(161)-p(606)-p(585)
       p(654)=p(6)*p(162)-p(607)-p(586)
       p(655)=m(1941)+m(1942)+m(1943)+m(1944)+m(1945)+m(1946)+m(1947)+m(&
     &1948)+m(1949)+m(1950)+m(1951)+m(1952)
       p(656)=p(6)*p(164)-p(612)-p(609)-p(592)
       p(657)=p(6)*p(165)-p(613)-p(610)-p(599)
       p(658)=p(26)*p(39)-p(611)-p(655)-p(608)
       p(659)=p(6)*p(167)-p(619)
       p(660)=p(6)*p(168)-p(626)
       p(661)=p(4)*p(171)-p(656)-p(653)
       p(662)=p(5)*p(171)-p(657)-p(654)
       p(663)=p(1)*p(172)
       p(664)=p(2)*p(172)
       p(665)=p(3)*p(172)
       p(666)=m(1953)+m(1954)+m(1955)+m(1956)+m(1957)+m(1958)+m(1959)+m(&
     &1960)+m(1961)+m(1962)+m(1963)+m(1964)
       p(667)=m(1965)+m(1966)+m(1967)+m(1968)+m(1969)+m(1970)+m(1971)+m(&
     &1972)+m(1973)+m(1974)+m(1975)+m(1976)
       p(668)=m(1977)+m(1978)+m(1979)+m(1980)+m(1981)+m(1982)+m(1983)+m(&
     &1984)+m(1985)+m(1986)+m(1987)+m(1988)
       p(669)=m(1989)+m(1990)+m(1991)+m(1992)+m(1993)+m(1994)+m(1995)+m(&
     &1996)+m(1997)+m(1998)+m(1999)+m(2000)
       p(670)=p(4)*p(172)-p(666)
       p(671)=p(5)*p(172)-p(667)
       p(672)=p(6)*p(172)-p(668)
       p(673)=p(1)*p(47)
       p(674)=p(1)*p(176)
       p(675)=p(1)*p(178)
       p(676)=p(1)*p(48)
       p(677)=p(1)*p(180)
       p(678)=p(1)*p(49)
       p(679)=p(2)*p(50)
       p(680)=p(1)*p(181)
       p(681)=p(2)*p(181)
       p(682)=p(1)*p(51)
       p(683)=p(2)*p(52)
       p(684)=p(3)*p(53)
       p(685)=p(1)*p(183)
       p(686)=p(1)*p(184)
       p(687)=p(2)*p(184)
       p(688)=p(1)*p(185)
       p(689)=p(2)*p(185)
       p(690)=p(3)*p(185)
       p(691)=p(4)*p(54)-p(246)-p(246)-p(246)-p(246)
       p(692)=p(1)*p(55)
       p(693)=p(1)*p(187)
       p(694)=p(1)*p(56)
       p(695)=p(2)*p(57)
       p(696)=p(1)*p(188)
       p(697)=p(2)*p(188)
       p(698)=p(1)*p(58)
       p(699)=p(2)*p(59)
       p(700)=p(3)*p(60)
       p(701)=p(1)*p(189)
       p(702)=p(2)*p(189)
       p(703)=p(3)*p(189)
       p(704)=p(4)*p(61)-p(273)-p(254)-p(254)-p(254)
       p(705)=p(1)*p(62)
       p(706)=p(2)*p(63)
       p(707)=p(3)*p(64)
       p(708)=p(4)*p(65)-p(277)-p(261)-p(261)
       p(709)=p(1)*p(67)
       p(710)=p(2)*p(68)
       p(711)=p(3)*p(69)
       p(712)=p(14)*p(18)-p(273)-p(254)-p(704)-p(273)-p(254)-p(254)
       p(713)=p(1)*p(190)
       p(714)=p(2)*p(190)
       p(715)=p(3)*p(190)
       p(716)=p(14)*p(20)-p(273)
       p(717)=p(19)*p(43)-p(708)
       p(718)=p(1)*p(192)
       p(719)=p(1)*p(193)
       p(720)=p(2)*p(193)
       p(721)=p(1)*p(194)
       p(722)=p(2)*p(194)
       p(723)=p(3)*p(194)
       p(724)=p(5)*p(61)-p(277)-p(261)-p(261)
       p(725)=p(1)*p(195)
       p(726)=p(2)*p(195)
       p(727)=p(3)*p(195)
       p(728)=p(5)*p(65)-p(278)-p(265)-p(265)-p(265)
       p(729)=p(5)*p(66)-p(266)-p(266)-p(266)-p(266)
       p(730)=p(18)*p(19)-p(278)-p(265)-p(728)-p(278)-p(265)-p(265)
       p(731)=p(1)*p(196)
       p(732)=p(2)*p(196)
       p(733)=p(3)*p(196)
       p(734)=p(14)*p(44)-p(724)
       p(735)=p(19)*p(20)-p(278)
       p(736)=p(1)*p(72)
       p(737)=p(1)*p(198)
       p(738)=p(1)*p(73)
       p(739)=p(2)*p(74)
       p(740)=p(1)*p(199)
       p(741)=p(2)*p(199)
       p(742)=p(1)*p(75)
       p(743)=p(2)*p(76)
       p(744)=p(3)*p(77)
       p(745)=p(1)*p(200)
       p(746)=p(2)*p(200)
       p(747)=p(3)*p(200)
       p(748)=p(4)*p(78)-p(330)-p(287)-p(287)-p(287)
       p(749)=p(1)*p(79)
       p(750)=p(2)*p(80)
       p(751)=p(3)*p(81)
       p(752)=p(4)*p(82)-p(334)-p(303)-p(294)-p(294)
       p(753)=p(4)*p(84)-p(336)-p(303)
       p(754)=p(1)*p(201)
       p(755)=p(2)*p(201)
       p(756)=p(3)*p(201)
       p(757)=p(5)*p(82)-p(354)-p(304)-p(298)-p(298)
       p(758)=p(5)*p(83)-p(355)-p(299)-p(299)-p(299)
       p(759)=p(5)*p(84)-p(356)-p(304)
       p(760)=p(1)*p(85)
       p(761)=p(2)*p(86)
       p(762)=p(3)*p(87)
       p(763)=p(4)*p(88)-p(340)-p(311)-p(311)
       p(764)=p(5)*p(89)-p(361)-p(316)-p(316)
       p(765)=p(1)*p(91)
       p(766)=p(2)*p(92)
       p(767)=p(3)*p(93)
       p(768)=p(14)*p(24)-p(330)-p(287)-p(748)-p(330)-p(287)-p(287)
       p(769)=p(4)*p(201)-p(759)-p(757)
       p(770)=p(1)*p(202)
       p(771)=p(2)*p(202)
       p(772)=p(3)*p(202)
       p(773)=p(14)*p(27)-p(330)
       p(774)=p(4)*p(95)-p(336)-p(334)
       p(775)=p(26)*p(43)-p(763)
       p(776)=p(1)*p(97)
       p(777)=p(2)*p(98)
       p(778)=p(3)*p(99)
       p(779)=p(5)*p(200)-p(753)-p(752)
       p(780)=p(19)*p(25)-p(355)-p(299)-p(758)-p(355)-p(299)-p(299)
       p(781)=p(4)*p(103)-p(368)
       p(782)=p(1)*p(203)
       p(783)=p(2)*p(203)
       p(784)=p(3)*p(203)
       p(785)=p(5)*p(100)-p(356)-p(354)
       p(786)=p(19)*p(28)-p(355)
       p(787)=p(26)*p(44)-p(764)
       p(788)=p(4)*p(203)-p(785)
       p(789)=p(1)*p(205)
       p(790)=p(1)*p(206)
       p(791)=p(2)*p(206)
       p(792)=p(1)*p(207)
       p(793)=p(2)*p(207)
       p(794)=p(3)*p(207)
       p(795)=p(6)*p(78)-p(340)-p(311)-p(311)
       p(796)=p(1)*p(208)
       p(797)=p(2)*p(208)
       p(798)=p(3)*p(208)
       p(799)=p(6)*p(82)-p(360)-p(341)-p(315)-p(315)
       p(800)=p(6)*p(83)-p(361)-p(316)-p(316)
       p(801)=p(6)*p(84)-p(370)-p(317)-p(317)
       p(802)=p(1)*p(209)
       p(803)=p(2)*p(209)
       p(804)=p(3)*p(209)
       p(805)=p(6)*p(88)-p(342)-p(321)-p(321)-p(321)
       p(806)=p(6)*p(89)-p(362)-p(322)-p(322)-p(322)
       p(807)=p(6)*p(90)-p(323)-p(323)-p(323)-p(323)
       p(808)=p(24)*p(26)-p(342)-p(321)-p(805)-p(342)-p(321)-p(321)
       p(809)=p(25)*p(26)-p(362)-p(322)-p(806)-p(362)-p(322)-p(322)
       p(810)=p(1)*p(210)
       p(811)=p(2)*p(210)
       p(812)=p(3)*p(210)
       p(813)=p(14)*p(45)-p(795)
       p(814)=p(4)*p(208)-p(801)-p(799)
       p(815)=p(26)*p(27)-p(342)
       p(816)=p(1)*p(211)
       p(817)=p(2)*p(211)
       p(818)=p(3)*p(211)
       p(819)=p(5)*p(207)-p(801)-p(799)
       p(820)=p(19)*p(45)-p(800)
       p(821)=p(26)*p(28)-p(362)
       p(822)=p(4)*p(211)-p(819)
       p(823)=p(1)*p(104)
       p(824)=p(1)*p(213)
       p(825)=p(1)*p(105)
       p(826)=p(2)*p(106)
       p(827)=p(1)*p(214)
       p(828)=p(2)*p(214)
       p(829)=p(1)*p(107)
       p(830)=p(2)*p(108)
       p(831)=p(3)*p(109)
       p(832)=p(1)*p(215)
       p(833)=p(2)*p(215)
       p(834)=p(3)*p(215)
       p(835)=p(4)*p(110)-p(427)
       p(836)=p(1)*p(111)
       p(837)=p(2)*p(112)
       p(838)=p(3)*p(113)
       p(839)=p(4)*p(114)-p(431)-p(390)
       p(840)=p(4)*p(116)-p(433)-p(390)
       p(841)=p(1)*p(216)
       p(842)=p(2)*p(216)
       p(843)=p(3)*p(216)
       p(844)=p(5)*p(114)-p(463)-p(391)
       p(845)=p(5)*p(115)-p(464)
       p(846)=p(5)*p(116)-p(465)-p(391)
       p(847)=p(1)*p(117)
       p(848)=p(2)*p(118)
       p(849)=p(3)*p(119)
       p(850)=p(4)*p(120)-p(437)-p(408)
       p(851)=p(5)*p(121)-p(470)-p(415)
       p(852)=p(4)*p(123)-p(440)-p(408)
       p(853)=p(5)*p(124)-p(473)-p(415)
       p(854)=p(1)*p(217)
       p(855)=p(2)*p(217)
       p(856)=p(3)*p(217)
       p(857)=p(6)*p(120)-p(518)-p(410)
       p(858)=p(6)*p(121)-p(519)-p(416)
       p(859)=p(6)*p(122)-p(520)
       p(860)=p(6)*p(123)-p(521)-p(410)
       p(861)=p(6)*p(124)-p(522)-p(416)
       p(862)=p(1)*p(125)
       p(863)=p(2)*p(126)
       p(864)=p(3)*p(127)
       p(865)=p(1)*p(128)
       p(866)=p(2)*p(129)
       p(867)=p(3)*p(130)
       p(868)=p(14)*p(32)-p(449)-p(427)-p(835)-p(427)
       p(869)=p(4)*p(216)-p(846)-p(844)
       p(870)=p(4)*p(217)-p(860)-p(857)
       p(871)=p(1)*p(218)
       p(872)=p(2)*p(218)
       p(873)=p(3)*p(218)
       p(874)=p(4)*p(131)-p(449)-p(427)-p(868)-p(449)-p(427)
       p(875)=p(33)*p(43)-p(840)-p(839)
       p(876)=p(34)*p(43)-p(852)-p(850)
       p(877)=p(35)*p(43)
       p(878)=p(4)*p(135)-p(449)
       p(879)=p(1)*p(136)
       p(880)=p(2)*p(137)
       p(881)=p(3)*p(138)
       p(882)=p(5)*p(215)-p(840)-p(839)
       p(883)=p(19)*p(33)-p(490)-p(464)-p(845)-p(464)
       p(884)=p(5)*p(217)-p(861)-p(858)
       p(885)=p(4)*p(143)-p(500)-p(482)
       p(886)=p(7)*p(190)-p(840)
       p(887)=p(1)*p(219)
       p(888)=p(2)*p(219)
       p(889)=p(3)*p(219)
       p(890)=p(32)*p(44)-p(846)-p(844)
       p(891)=p(5)*p(140)-p(490)-p(464)-p(883)-p(490)-p(464)
       p(892)=p(34)*p(44)-p(853)-p(851)
       p(893)=p(35)*p(44)
       p(894)=p(5)*p(143)-p(501)-p(483)
       p(895)=p(5)*p(144)-p(490)
       p(896)=p(7)*p(196)-p(846)
       p(897)=p(1)*p(146)
       p(898)=p(2)*p(147)
       p(899)=p(3)*p(148)
       p(900)=p(6)*p(215)-p(852)-p(850)
       p(901)=p(6)*p(216)-p(853)-p(851)
       p(902)=p(26)*p(34)-p(549)-p(520)-p(859)-p(520)
       p(903)=p(4)*p(153)-p(558)-p(532)
       p(904)=p(5)*p(154)-p(569)-p(540)
       p(905)=p(7)*p(202)-p(852)
       p(906)=p(7)*p(203)-p(853)
       p(907)=p(1)*p(220)
       p(908)=p(2)*p(220)
       p(909)=p(3)*p(220)
       p(910)=p(32)*p(45)-p(860)-p(857)
       p(911)=p(33)*p(45)-p(861)-p(858)
       p(912)=p(6)*p(151)-p(549)-p(520)-p(902)-p(549)-p(520)
       p(913)=p(35)*p(45)
       p(914)=p(6)*p(153)-p(560)-p(534)
       p(915)=p(6)*p(154)-p(570)-p(541)
       p(916)=p(6)*p(155)-p(549)
       p(917)=p(7)*p(210)-p(860)
       p(918)=p(7)*p(211)-p(861)
       p(919)=p(1)*p(158)
       p(920)=p(2)*p(159)
       p(921)=p(3)*p(160)
       p(922)=p(4)*p(161)-p(630)-p(590)
       p(923)=p(5)*p(162)-p(642)-p(598)
       p(924)=p(6)*p(163)-p(655)-p(608)
       p(925)=p(4)*p(164)-p(633)-p(593)-p(590)-p(593)
       p(926)=p(5)*p(165)-p(645)-p(601)-p(598)-p(601)
       p(927)=p(6)*p(166)-p(658)-p(611)-p(608)-p(611)
       p(928)=p(4)*p(169)-p(633)-p(630)
       p(929)=p(5)*p(170)-p(645)-p(642)
       p(930)=p(6)*p(171)-p(658)-p(655)
       p(931)=p(1)*p(222)
       p(932)=p(1)*p(223)
       p(933)=p(2)*p(223)
       p(934)=p(1)*p(224)
       p(935)=p(2)*p(224)
       p(936)=p(3)*p(224)
       p(937)=p(7)*p(110)-p(590)-p(452)
       p(938)=p(1)*p(225)
       p(939)=p(2)*p(225)
       p(940)=p(3)*p(225)
       p(941)=p(7)*p(114)-p(597)-p(591)-p(485)
       p(942)=p(7)*p(115)-p(598)-p(492)
       p(943)=p(7)*p(116)-p(602)-p(581)-p(499)-p(581)
       p(944)=p(1)*p(226)
       p(945)=p(2)*p(226)
       p(946)=p(3)*p(226)
       p(947)=p(7)*p(120)-p(606)-p(592)-p(535)
       p(948)=p(7)*p(121)-p(607)-p(599)-p(542)
       p(949)=p(7)*p(122)-p(608)-p(550)
       p(950)=p(7)*p(123)-p(612)-p(585)-p(557)-p(585)
       p(951)=p(7)*p(124)-p(613)-p(586)-p(567)-p(586)
       p(952)=p(1)*p(227)
       p(953)=p(2)*p(227)
       p(954)=p(3)*p(227)
       p(955)=p(32)*p(35)-p(617)
       p(956)=p(33)*p(35)-p(618)
       p(957)=p(34)*p(35)-p(619)
       p(958)=p(1)*p(228)
       p(959)=p(2)*p(228)
       p(960)=p(3)*p(228)
       p(961)=p(7)*p(131)-p(633)-p(593)-p(630)-p(590)-p(445)-p(593)-p(63&
     &0)-p(445)
       p(962)=p(4)*p(225)-p(943)-p(941)
       p(963)=p(4)*p(226)-p(950)-p(947)
       p(964)=p(4)*p(227)-p(955)
       p(965)=p(7)*p(135)-p(633)-p(452)
       p(966)=p(1)*p(229)
       p(967)=p(2)*p(229)
       p(968)=p(3)*p(229)
       p(969)=p(5)*p(224)-p(943)-p(941)
       p(970)=p(7)*p(140)-p(645)-p(601)-p(642)-p(598)-p(478)-p(601)-p(64&
     &2)-p(478)
       p(971)=p(5)*p(226)-p(951)-p(948)
       p(972)=p(5)*p(227)-p(956)
       p(973)=p(7)*p(143)-p(644)-p(634)-p(485)
       p(974)=p(7)*p(144)-p(645)-p(492)
       p(975)=p(20)*p(46)-p(943)
       p(976)=p(1)*p(230)
       p(977)=p(2)*p(230)
       p(978)=p(3)*p(230)
       p(979)=p(6)*p(224)-p(950)-p(947)
       p(980)=p(6)*p(225)-p(951)-p(948)
       p(981)=p(7)*p(151)-p(658)-p(611)-p(655)-p(608)-p(528)-p(611)-p(65&
     &5)-p(528)
       p(982)=p(6)*p(227)-p(957)
       p(983)=p(7)*p(153)-p(656)-p(635)-p(535)
       p(984)=p(7)*p(154)-p(657)-p(646)-p(542)
       p(985)=p(7)*p(155)-p(658)-p(550)
       p(986)=p(27)*p(46)-p(950)
       p(987)=p(28)*p(46)-p(951)
       p(988)=p(1)*p(231)
       p(989)=p(2)*p(231)
       p(990)=p(3)*p(231)
       p(991)=p(7)*p(161)-p(624)-p(666)-p(617)-p(624)-p(624)
       p(992)=p(7)*p(162)-p(625)-p(667)-p(618)-p(625)-p(625)
       p(993)=p(7)*p(163)-p(626)-p(668)-p(619)-p(626)-p(626)
       p(994)=p(32)*p(39)-p(637)-p(624)-p(666)-p(636)-p(617)-p(991)-p(62&
     &4)-p(666)-p(624)
       p(995)=p(33)*p(39)-p(648)-p(625)-p(667)-p(647)-p(618)-p(992)-p(62&
     &5)-p(667)-p(625)
       p(996)=p(34)*p(39)-p(660)-p(626)-p(668)-p(659)-p(619)-p(993)-p(62&
     &6)-p(668)-p(626)
       p(997)=p(35)*p(39)-p(669)
       p(998)=p(7)*p(164)-p(637)-p(666)-p(636)-p(617)-p(994)-p(637)-p(66&
     &6)
       p(999)=p(7)*p(165)-p(648)-p(667)-p(647)-p(618)-p(995)-p(648)-p(66&
     &7)
       p(1000)=p(7)*p(166)-p(660)-p(668)-p(659)-p(619)-p(996)-p(660)-p(6&
     &68)
       p(1001)=p(7)*p(167)-p(669)-p(620)-p(997)-p(669)-p(620)-p(620)-p(6&
     &20)
       p(1002)=p(7)*p(168)-p(669)
       p(1003)=p(4)*p(231)-p(998)-p(994)-p(991)
       p(1004)=p(5)*p(231)-p(999)-p(995)-p(992)
       p(1005)=p(6)*p(231)-p(1000)-p(996)-p(993)
       p(1006)=p(7)*p(172)-p(669)
       p(1007)=p(1)*p(173)
       p(1008)=p(1)*p(174)
       p(1009)=p(1)*p(233)
       p(1010)=p(1)*p(175)
       p(1011)=p(2)*p(176)
       p(1012)=p(1)*p(177)
       p(1013)=p(2)*p(178)
       p(1014)=p(1)*p(234)
       p(1015)=p(2)*p(234)
       p(1016)=p(1)*p(179)
       p(1017)=p(2)*p(180)
       p(1018)=p(3)*p(181)
       p(1019)=p(1)*p(182)
       p(1020)=p(2)*p(183)
       p(1021)=p(3)*p(184)
       p(1022)=p(14)*p(14)-p(246)-p(691)-p(246)-p(691)-p(246)-p(246)-p(2&
     &46)-p(246)
       p(1023)=p(1)*p(235)
       p(1024)=p(2)*p(235)
       p(1025)=p(3)*p(235)
       p(1026)=p(14)*p(43)-p(691)
       p(1027)=p(1)*p(186)
       p(1028)=p(2)*p(187)
       p(1029)=p(3)*p(188)
       p(1030)=p(4)*p(189)-p(712)-p(704)
       p(1031)=p(4)*p(190)-p(716)
       p(1032)=p(1)*p(191)
       p(1033)=p(2)*p(192)
       p(1034)=p(3)*p(193)
       p(1035)=p(4)*p(194)-p(734)-p(724)-p(724)
       p(1036)=p(19)*p(19)-p(266)-p(729)-p(266)-p(729)-p(266)-p(266)-p(2&
     &66)-p(266)
       p(1037)=p(4)*p(196)-p(734)
       p(1038)=p(1)*p(236)
       p(1039)=p(2)*p(236)
       p(1040)=p(3)*p(236)
       p(1041)=p(5)*p(194)-p(730)-p(728)
       p(1042)=p(19)*p(44)-p(729)
       p(1043)=p(4)*p(236)-p(1041)
       p(1044)=p(1)*p(197)
       p(1045)=p(2)*p(198)
       p(1046)=p(3)*p(199)
       p(1047)=p(4)*p(200)-p(768)-p(748)
       p(1048)=p(5)*p(201)-p(780)-p(758)
       p(1049)=p(4)*p(202)-p(773)
       p(1050)=p(5)*p(203)-p(786)
       p(1051)=p(1)*p(204)
       p(1052)=p(2)*p(205)
       p(1053)=p(3)*p(206)
       p(1054)=p(4)*p(207)-p(813)-p(795)-p(795)
       p(1055)=p(5)*p(208)-p(820)-p(800)-p(800)
       p(1056)=p(26)*p(26)-p(323)-p(807)-p(323)-p(807)-p(323)-p(323)-p(3&
     &23)-p(323)
       p(1057)=p(4)*p(210)-p(813)
       p(1058)=p(5)*p(211)-p(820)
       p(1059)=p(1)*p(237)
       p(1060)=p(2)*p(237)
       p(1061)=p(3)*p(237)
       p(1062)=p(6)*p(207)-p(808)-p(805)
       p(1063)=p(6)*p(208)-p(809)-p(806)
       p(1064)=p(26)*p(45)-p(807)
       p(1065)=p(4)*p(237)-p(1062)
       p(1066)=p(5)*p(237)-p(1063)
       p(1067)=p(1)*p(212)
       p(1068)=p(2)*p(213)
       p(1069)=p(3)*p(214)
       p(1070)=p(4)*p(215)-p(868)-p(835)
       p(1071)=p(5)*p(216)-p(883)-p(845)
       p(1072)=p(6)*p(217)-p(902)-p(859)
       p(1073)=p(7)*p(235)-p(1070)
       p(1074)=p(7)*p(236)-p(1071)
       p(1075)=p(7)*p(237)-p(1072)
       p(1076)=p(1)*p(221)
       p(1077)=p(2)*p(222)
       p(1078)=p(3)*p(223)
       p(1079)=p(4)*p(224)-p(961)-p(937)-p(937)
       p(1080)=p(5)*p(225)-p(970)-p(942)-p(942)
       p(1081)=p(6)*p(226)-p(981)-p(949)-p(949)
       p(1082)=p(35)*p(35)-p(620)-p(620)
       p(1083)=p(43)*p(46)-p(1079)
       p(1084)=p(44)*p(46)-p(1080)
       p(1085)=p(45)*p(46)-p(1081)
       p(1086)=p(39)*p(39)-p(669)-p(620)-p(1002)-p(1006)-p(1001)-p(669)-&
     &p(620)-p(1002)-p(1006)-p(1001)-p(669)-p(620)-p(669)-p(620)
       p(1087)=p(1)*p(238)
       p(1088)=p(2)*p(238)
       p(1089)=p(3)*p(238)
       p(1090)=p(7)*p(224)-p(994)-p(991)-p(955)
       p(1091)=p(7)*p(225)-p(995)-p(992)-p(956)
       p(1092)=p(7)*p(226)-p(996)-p(993)-p(957)
       p(1093)=p(35)*p(46)-p(1001)
       p(1094)=p(4)*p(238)-p(1090)
       p(1095)=p(5)*p(238)-p(1091)
       p(1096)=p(6)*p(238)-p(1092)
       p(1097)=p(39)*p(46)-p(1002)-p(1006)-p(997)
       p(1098)=p(1)*p(232)
       p(1099)=p(2)*p(233)
       p(1100)=p(3)*p(234)
       p(1101)=p(4)*p(235)-p(1026)
       p(1102)=p(5)*p(236)-p(1042)
       p(1103)=p(6)*p(237)-p(1064)
       p(1104)=p(7)*p(238)-p(1097)-p(1093)
 
      return
      end subroutine evpoly
