!-->  program to get potential energy for a given geometry after NN fitting
!-->  global variables are declared in this module
       module nnparam
       implicit none
       real*8,parameter::alpha=1.0d0,vpesmin=-536.01052952d0,&
       &vpescut=5.0d0,&
       &PI=3.141592653589793238d0,radian=PI/180.0d0,bohr=0.5291772d0
       integer,parameter::n0ho=20,n0hcl=18  !dipole
       integer,parameter::nxho=18,nxhcl=18  ! product energy
       integer,parameter::n2n=100
       real*8 DP0ho(n0ho),DP0hcl(n0hcl),R0ho(n0ho),R0hcl(n0hcl)
       real*8 Exhohcl(nxhcl,nxho),Rxho(nxho),Rxhcl(nxhcl)
       real*8 DP0ho2(n2n),DP0hcl2(n2n)
       real*8 Exhohcl2(nxhcl,nxho)
       integer,parameter::nbasis=18
       integer,parameter::ninput=17
       integer noutput,nhid,nlayer,ifunc,nwe,nodemax
       integer nterm(1:nbasis),nindex(1:nbasis,1:100,1:6)
       integer nscale
       integer, allocatable::nodes(:)

       real*8, allocatable::weighta(:,:,:),biasa(:,:)
       real*8, allocatable::pdela(:),pavga(:)
       real*8, allocatable::weightb(:,:,:),biasb(:,:)
       real*8, allocatable::pdelb(:),pavgb(:)
       real*8, allocatable::weightc(:,:,:),biasc(:,:)
       real*8, allocatable::pdelc(:),pavgc(:)

       end module nnparam

      subroutine pes(x,igrad,p,g,d)

      use nnparam
      implicit none
      ! number of electronic state
      integer, parameter :: nstates=1
      integer, parameter :: natoms=4
      integer, intent(in) :: igrad
      double precision, intent(in) :: x(natoms,3)
      double precision, intent(out) :: p(nstates), g(nstates,natoms,3)
      double precision, intent(out) :: d(nstates,nstates,natoms,3)

      double precision :: v, va, vb, vc
      double precision :: tx(3,natoms)
      integer :: iatom, idir, j, istate
      !initialize 
      v=0.d0
      g=0.d0
      d=0.d0

      do iatom=1,natoms
        do idir=1,3
          tx(idir,iatom)=x(iatom, idir)
        enddo
      enddo

      if (igrad==0) then
        call pes_init
        call HOHCl_pes_interface(tx,v)
        deallocate(nodes)
        deallocate(weighta)
        deallocate(biasa)
        deallocate(pdela)
        deallocate(pavga)
        deallocate(weightb)
        deallocate(biasb)
        deallocate(pdelb)
        deallocate(pavgb)
        deallocate(weightc)
        deallocate(biasc)
        deallocate(pdelc)
        deallocate(pavgc)
      else
        write (*,*) 'Only energy and gradient are available'
      endif

      do istate=1,nstates
        p(istate)=v
      enddo

      g=0.d0
      d=0.d0

      endsubroutine

       subroutine clh2oNN(ct,vpes,vpesa,vpesb,vpesc) !ct in HHClO order and angstrom
       use nnparam
       implicit none
       integer,parameter::ndim=6
       integer j,k
       real*8 rb(ndim),xbond(ndim),basis(0:nbasis-1),tmp1
       real*8 txinput(1:nbasis-1)
       real*8 ct(3,4),xvec(3,ndim),xct(3,4),vpes
       real*8 vpesa,vpesb,vpesc,r12,r13,r14,r23,r24,r34

       basis=0.d0
       xct=ct
       
       xvec(:,1)=xct(:,2)-xct(:,1) !  H2->H1
       xvec(:,2)=xct(:,3)-xct(:,1) !  x->H1
       xvec(:,3)=xct(:,4)-xct(:,1) !  O->H1
       xvec(:,4)=xct(:,3)-xct(:,2) !  H2->x
       xvec(:,5)=xct(:,4)-xct(:,2) !  H2->O
       xvec(:,6)=xct(:,4)-xct(:,3) !  x-O 
       rb(1)=dsqrt(dot_product(xvec(:,1),xvec(:,1)))
       rb(2)=dsqrt(dot_product(xvec(:,2),xvec(:,2)))
       rb(3)=dsqrt(dot_product(xvec(:,3),xvec(:,3)))
       rb(4)=dsqrt(dot_product(xvec(:,4),xvec(:,4)))
       rb(5)=dsqrt(dot_product(xvec(:,5),xvec(:,5)))
       rb(6)=dsqrt(dot_product(xvec(:,6),xvec(:,6))) 

       r12=rb(1);r13=rb(2);r14=rb(3);r23=rb(4);r24=rb(5);r34=rb(6)

       xbond(:)=dexp(-rb(:)/alpha)
       
       call bemsav(xbond,basis)
      
       do j=1,nbasis-1
        txinput(j)=basis(j)
       enddo

       call getpota(txinput,vpesa)
       call getpotb(txinput,vpesb)
       call getpotc(txinput,vpesc)
       vpes=(vpesa+vpesb+vpesc)/3.0d0

       if(vpes.lt.-1.5d0)vpes=5.0d0
       vpes=min(vpes,5.0d0)
       
       return
        
       end subroutine clh2oNN

!-->  read NN weights and biases from matlab output
!-->  weights saved in 'weights.txt'
!-->  biases saved in 'biases.txt'
!-->  one has to call this subroutine one and only one before calling the getpot() subroutine
      subroutine pes_init
      use nnparam
      implicit none
      real*8,parameter::dy1=1.0d30,dyn=1.0d30
      integer,parameter::nn=100
      integer ihid,iwe,inode1,inode2,ilay1,ilay2
      integer ibasis,npd,iterm,ib,nfile
      integer i,j,k,m,n
      real*8 Et1,r1t,r2t,r3t,Et2,xa,xb,xc,vpes
      real*8 x1a(nxhcl),x2a(nxho),ya(nxhcl,nxho)
      real*8 ytmp(nn),y2tmp(nn),y2a(nxhcl,nxho)
      real*8 E1ho(nxho),E2hcl(nxhcl)
      character*100 fho,fhcl,line,f1
      
      Rxhcl(   1)=      0.85000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(   1,   1)=   -535.49286818d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(   2,   1)=   -535.57670980d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(   3,   1)=   -535.63937868d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(   4,   1)=   -535.68281958d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(   5,   1)=   -535.71500464d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(   6,   1)=   -535.73683383d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(   7,   1)=   -535.75100139d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(   8,   1)=   -535.75926917d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(   9,   1)=   -535.76296967d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(  10,   1)=   -535.76343561d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(  11,   1)=   -535.76314593d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(  12,   1)=   -535.76067780d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(  13,   1)=   -535.75626809d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(  14,   1)=   -535.75044341d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(  15,   1)=   -535.74361442d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(  16,   1)=   -535.72624998d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(  17,   1)=   -535.70969746d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(   1)=      0.65000000d0
      Exhohcl(  18,   1)=   -535.69330138d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(   1,   2)=   -535.57784571d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(   2,   2)=   -535.66214663d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(   3,   2)=   -535.72307246d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(   4,   2)=   -535.76786926d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(   5,   2)=   -535.79967886d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(   6,   2)=   -535.82150656d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(   7,   2)=   -535.83567751d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(   8,   2)=   -535.84394567d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(   9,   2)=   -535.84764659d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(  10,   2)=   -535.84811275d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(  11,   2)=   -535.84782324d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(  12,   2)=   -535.84535531d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(  13,   2)=   -535.84094569d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(  14,   2)=   -535.83512120d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(  15,   2)=   -535.82850512d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(  16,   2)=   -535.81134001d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(  17,   2)=   -535.79478293d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(   2)=      0.70000000d0
      Exhohcl(  18,   2)=   -535.77838035d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(   1,   3)=   -535.63471622d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(   2,   3)=   -535.71825575d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(   3,   3)=   -535.77999911d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(   4,   3)=   -535.82474097d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(   5,   3)=   -535.85759532d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(   6,   3)=   -535.87838108d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(   7,   3)=   -535.89254909d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(   8,   3)=   -535.90081758d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(   9,   3)=   -535.90451893d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(  10,   3)=   -535.90498533d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(  11,   3)=   -535.90469599d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(  12,   3)=   -535.90222827d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(  13,   3)=   -535.89781876d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(  14,   3)=   -535.89199449d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(  15,   3)=   -535.88516865d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(  16,   3)=   -535.86851306d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(  17,   3)=   -535.85195370d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(   3)=      0.75000000d0
      Exhohcl(  18,   3)=   -535.83554776d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(   1,   4)=   -535.67162219d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(   2,   4)=   -535.75527451d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(   3,   4)=   -535.81757446d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(   4,   4)=   -535.86173357d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(   5,   4)=   -535.89354404d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(   6,   4)=   -535.91537400d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(   7,   4)=   -535.92954258d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(   8,   4)=   -535.93781114d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(   9,   4)=   -535.94151293d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(  10,   4)=   -535.94197956d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(  11,   4)=   -535.94169040d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(  12,   4)=   -535.93922291d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(  13,   4)=   -535.93481352d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(  14,   4)=   -535.92898947d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(  15,   4)=   -535.92237383d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(  16,   4)=   -535.90573575d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(  17,   4)=   -535.88917533d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(   4)=      0.80000000d0
      Exhohcl(  18,   4)=   -535.87276916d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(   1,   5)=   -535.69443684d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(   2,   5)=   -535.77800402d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(   3,   5)=   -535.83966595d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(   4,   5)=   -535.88510933d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(   5,   5)=   -535.91627430d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(   6,   5)=   -535.93810367d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(   7,   5)=   -535.95227320d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(   8,   5)=   -535.96054264d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(   9,   5)=   -535.96424428d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(  10,   5)=   -535.96471116d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(  11,   5)=   -535.96442218d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(  12,   5)=   -535.96195493d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(  13,   5)=   -535.95754667d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(  14,   5)=   -535.95172183d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(  15,   5)=   -535.94490891d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(  16,   5)=   -535.92956589d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(  17,   5)=   -535.91208872d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(   5)=      0.85000000d0
      Exhohcl(  18,   5)=   -535.89568023d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(   1,   6)=   -535.70692546d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(   2,   6)=   -535.79049257d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(   3,   6)=   -535.85215419d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(   4,   6)=   -535.89695181d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(   5,   6)=   -535.92876270d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(   6,   6)=   -535.95059310d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(   7,   6)=   -535.96532358d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(   8,   6)=   -535.97303214d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(   9,   6)=   -535.97673324d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(  10,   6)=   -535.97720147d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(  11,   6)=   -535.97691224d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(  12,   6)=   -535.97444565d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(  13,   6)=   -535.97003739d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(  14,   6)=   -535.96421284d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(  15,   6)=   -535.95741140d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(  16,   6)=   -535.94205819d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(  17,   6)=   -535.92472734d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(   6)=      0.90000000d0
      Exhohcl(  18,   6)=   -535.90831861d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(   1,   7)=   -535.71198673d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(   2,   7)=   -535.79561295d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(   3,   7)=   -535.85730242d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(   4,   7)=   -535.90248679d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(   5,   7)=   -535.93391152d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(   6,   7)=   -535.95633682d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(   7,   7)=   -535.96991147d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(   8,   7)=   -535.97818168d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(   9,   7)=   -535.98188320d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(  10,   7)=   -535.98235083d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(  11,   7)=   -535.98206271d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(  12,   7)=   -535.97973376d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(  13,   7)=   -535.97518828d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(  14,   7)=   -535.96936389d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(  15,   7)=   -535.96257747d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(  16,   7)=   -535.94704425d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(  17,   7)=   -535.93000172d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(   7)=      0.95000000d0
      Exhohcl(  18,   7)=   -535.91359319d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(   1,   8)=   -535.71254840d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(   2,   8)=   -535.79625009d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(   3,   8)=   -535.85780542d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(   4,   8)=   -535.90260268d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(   5,   8)=   -535.93441505d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(   6,   8)=   -535.95624519d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(   7,   8)=   -535.97041367d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(   8,   8)=   -535.97868523d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(   9,   8)=   -535.98238694d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(  10,   8)=   -535.98285559d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(  11,   8)=   -535.98256664d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(  12,   8)=   -535.98010027d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(  13,   8)=   -535.97569240d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(  14,   8)=   -535.96986810d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(  15,   8)=   -535.96308920d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(  16,   8)=   -535.94755658d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(  17,   8)=   -535.93055261d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(   8)=      0.97131000d0
      Exhohcl(  18,   8)=   -535.91414426d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(   1,   9)=   -535.70811432d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(   2,   9)=   -535.79174159d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(   3,   9)=   -535.85343064d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(   4,   9)=   -535.89822735d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(   5,   9)=   -535.93003966d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(   6,   9)=   -535.95187033d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(   7,   9)=   -535.96604347d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(   8,   9)=   -535.97431450d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(   9,   9)=   -535.97801704d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(  10,   9)=   -535.97851627d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(  11,   9)=   -535.97819755d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(  12,   9)=   -535.97573172d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(  13,   9)=   -535.97132344d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(  14,   9)=   -535.96549992d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(  15,   9)=   -535.95866036d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(  16,   9)=   -535.94096326d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(  17,   9)=   -535.92633179d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(   9)=      1.05000000d0
      Exhohcl(  18,   9)=   -535.90992441d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(   1,  10)=   -535.70176363d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(   2,  10)=   -535.78539095d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(   3,  10)=   -535.84708093d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(   4,  10)=   -535.89187702d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(   5,  10)=   -535.92368909d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(   6,  10)=   -535.94552260d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(   7,  10)=   -535.95970268d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(   8,  10)=   -535.96798734d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(   9,  10)=   -535.97167049d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(  10,  10)=   -535.97213744d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(  11,  10)=   -535.97191345d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(  12,  10)=   -535.96938486d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(  13,  10)=   -535.96497689d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(  14,  10)=   -535.95915351d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(  15,  10)=   -535.95231426d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(  16,  10)=   -535.93690057d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(  17,  10)=   -535.92044735d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(  10)=      1.10000000d0
      Exhohcl(  18,  10)=   -535.90365374d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(   1,  11)=   -535.69368536d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(   2,  11)=   -535.77731304d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(   3,  11)=   -535.83900382d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(   4,  11)=   -535.88380018d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(   5,  11)=   -535.91561246d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(   6,  11)=   -535.93744619d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(   7,  11)=   -535.95162647d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(   8,  11)=   -535.95993136d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(   9,  11)=   -535.96371221d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(  10,  11)=   -535.96415480d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(  11,  11)=   -535.96390159d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(  12,  11)=   -535.96144690d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(  13,  11)=   -535.95690408d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(  14,  11)=   -535.95108050d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(  15,  11)=   -535.94424167d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(  16,  11)=   -535.92885014d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(  17,  11)=   -535.91230477d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(  11)=      1.15000000d0
      Exhohcl(  18,  11)=   -535.89564234d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(   1,  12)=   -535.68450475d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(   2,  12)=   -535.76813292d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(   3,  12)=   -535.82982473d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(   4,  12)=   -535.87462135d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(   5,  12)=   -535.90643385d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(   6,  12)=   -535.92826775d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(   7,  12)=   -535.94185954d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(   8,  12)=   -535.95007151d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(   9,  12)=   -535.95453426d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(  10,  12)=   -535.95505969d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(  11,  12)=   -535.95483884d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(  12,  12)=   -535.95232472d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(  13,  12)=   -535.94792085d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(  14,  12)=   -535.94190828d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(  15,  12)=   -535.93506982d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(  16,  12)=   -535.91969750d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(  17,  12)=   -535.90315324d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(  12)=      1.20000000d0
      Exhohcl(  18,  12)=   -535.88651736d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(   1,  13)=   -535.67468734d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(   2,  13)=   -535.75831613d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(   3,  13)=   -535.81878755d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(   4,  13)=   -535.86480621d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(   5,  13)=   -535.89661892d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(   6,  13)=   -535.91845296d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(   7,  13)=   -535.93263344d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(   8,  13)=   -535.94093855d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(   9,  13)=   -535.94471980d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(  10,  13)=   -535.94524532d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(  11,  13)=   -535.94502458d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(  12,  13)=   -535.94268335d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(  13,  13)=   -535.93814785d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(  14,  13)=   -535.93232385d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(  15,  13)=   -535.92526913d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(  16,  13)=   -535.90990903d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(  17,  13)=   -535.89336578d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(  13)=      1.25000000d0
      Exhohcl(  18,  13)=   -535.87675110d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(   1,  14)=   -535.66457682d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(   2,  14)=   -535.74820642d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(   3,  14)=   -535.80990155d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(   4,  14)=   -535.85469870d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(   5,  14)=   -535.88651159d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(   6,  14)=   -535.90715746d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(   7,  14)=   -535.92132688d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(   8,  14)=   -535.93083132d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(   9,  14)=   -535.93319074d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(  10,  14)=   -535.93513824d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(  11,  14)=   -535.93491762d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(  12,  14)=   -535.93058428d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(  13,  14)=   -535.92825196d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(  14,  14)=   -535.92224566d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(  15,  14)=   -535.91541535d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(  16,  14)=   -535.89983793d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(  17,  14)=   -535.88309850d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(  14)=      1.30000000d0
      Exhohcl(  18,  14)=   -535.86669565d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(   1,  15)=   -535.65442972d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(   2,  15)=   -535.73809321d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(   3,  15)=   -535.79975797d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(   4,  15)=   -535.84455538d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(   5,  15)=   -535.87636843d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(   6,  15)=   -535.89820255d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(   7,  15)=   -535.91238293d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(   8,  15)=   -535.91906366d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(   9,  15)=   -535.92446928d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(  10,  15)=   -535.92314875d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(  11,  15)=   -535.92477559d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(  12,  15)=   -535.92011032d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(  13,  15)=   -535.91811055d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(  14,  15)=   -535.91232968d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(  15,  15)=   -535.90529313d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(  16,  15)=   -535.88974831d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(  17,  15)=   -535.87302032d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(  15)=      1.35000000d0
      Exhohcl(  18,  15)=   -535.85661836d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(   1,  16)=   -535.64445137d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(   2,  16)=   -535.72808228d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(   3,  16)=   -535.78754392d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(   4,  16)=   -535.83458036d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(   5,  16)=   -535.86639358d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(   6,  16)=   -535.88633720d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(   7,  16)=   -535.90240793d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(   8,  16)=   -535.91071282d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(   9,  16)=   -535.91449532d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(  10,  16)=   -535.91280678d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(  11,  16)=   -535.91480063d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(  12,  16)=   -535.91246022d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(  13,  16)=   -535.90813629d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(  14,  16)=   -535.90235581d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(  15,  16)=   -535.89553652d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(  16,  16)=   -535.87982825d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(  17,  16)=   -535.86329706d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(  16)=      1.40000000d0
      Exhohcl(  18,  16)=   -535.84671832d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(   1,  17)=   -535.63480136d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(   2,  17)=   -535.71847117d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(   3,  17)=   -535.78013665d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(   4,  17)=   -535.82493464d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(   5,  17)=   -535.85674801d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(   6,  17)=   -535.87858212d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(   7,  17)=   -535.89276222d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(   8,  17)=   -535.90106823d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(   9,  17)=   -535.90484952d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(  10,  17)=   -535.90273221d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(  11,  17)=   -535.90515502d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(  12,  17)=   -535.90281494d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(  13,  17)=   -535.89849144d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(  14,  17)=   -535.89271143d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(  15,  17)=   -535.88589260d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(  16,  17)=   -535.87019905d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(  17,  17)=   -535.85371232d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(  17)=      1.45000000d0
      Exhohcl(  18,  17)=   -535.83714272d0
      Rxhcl(   1)=      0.85000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(   1,  18)=   -535.62559698d0
      Rxhcl(   2)=      0.90000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(   2,  18)=   -535.70927160d0
      Rxhcl(   3)=      0.95000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(   3,  18)=   -535.77093737d0
      Rxhcl(   4)=      1.00000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(   4,  18)=   -535.81270763d0
      Rxhcl(   5)=      1.05000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(   5,  18)=   -535.84754909d0
      Rxhcl(   6)=      1.10000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(   6,  18)=   -535.86938315d0
      Rxhcl(   7)=      1.15000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(   7,  18)=   -535.88356311d0
      Rxhcl(   8)=      1.20000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(   8,  18)=   -535.89186774d0
      Rxhcl(   9)=      1.25000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(   9,  18)=   -535.89564910d0
      Rxhcl(  10)=      1.27413000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(  10,  18)=   -535.89652917d0
      Rxhcl(  11)=      1.30000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(  11,  18)=   -535.89595480d0
      Rxhcl(  12)=      1.35000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(  12,  18)=   -535.89361506d0
      Rxhcl(  13)=      1.40000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(  13,  18)=   -535.88929198d0
      Rxhcl(  14)=      1.45000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(  14,  18)=   -535.88351243d0
      Rxhcl(  15)=      1.50000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(  15,  18)=   -535.87669407d0
      Rxhcl(  16)=      1.60000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(  16,  18)=   -535.86119084d0
      Rxhcl(  17)=      1.70000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(  17,  18)=   -535.84456004d0
      Rxhcl(  18)=      1.80000000d0
      Rxho(  18)=      1.50000000d0
      Exhohcl(  18,  18)=   -535.82799974d0
      
! HO and HCl separated at 50.0 angstrom      

      E1ho(   1)=   -535.76343561d0
      E1ho(   2)=   -535.84811275d0
      E1ho(   3)=   -535.90498533d0
      E1ho(   4)=   -535.94197956d0
      E1ho(   5)=   -535.96471116d0
      E1ho(   6)=   -535.97720147d0
      E1ho(   7)=   -535.98235083d0
      E2hcl(   1)=   -535.71254840d0
      E2hcl(   2)=   -535.79625009d0
      E2hcl(   3)=   -535.85780542d0
      E2hcl(   4)=   -535.90260268d0
      E2hcl(   5)=   -535.93441505d0
      E2hcl(   6)=   -535.95624519d0
      E2hcl(   7)=   -535.97041367d0
      E2hcl(   8)=   -535.97868523d0
      E2hcl(   9)=   -535.98238694d0
      E1ho(   8)=   -535.98285559d0
      E2hcl(  10)=   -535.98285559d0
      E2hcl(  11)=   -535.98256664d0
      E2hcl(  12)=   -535.98010027d0
      E2hcl(  13)=   -535.97569240d0
      E2hcl(  14)=   -535.96986810d0
      E2hcl(  15)=   -535.96308920d0
      E2hcl(  16)=   -535.94755658d0
      E2hcl(  17)=   -535.93055261d0
      E2hcl(  18)=   -535.91414426d0
      E1ho(   9)=   -535.97851627d0
      E1ho(  10)=   -535.97213744d0
      E1ho(  11)=   -535.96415480d0
      E1ho(  12)=   -535.95505969d0
      E1ho(  13)=   -535.94524532d0
      E1ho(  14)=   -535.93513824d0
      E1ho(  15)=   -535.92314875d0
      E1ho(  16)=   -535.91280678d0
      E1ho(  17)=   -535.90273221d0
      E1ho(  18)=   -535.89652917d0
      
      m=nxhcl
      n=nxho
      x1a=Rxhcl
      x2a=Rxho
      ya=Exhohcl
    
      do j=1,m 
       do k=1,n
        ytmp(k)= ya(j,k)
       enddo
       call spline(x2a,ytmp,n,1.0d30,1.0d30,y2tmp)
       do k=1,n
        y2a(j,k)=y2tmp(k)
       enddo
      enddo

      Exhohcl2=y2a
      
!HCl dipole      
      
      DP0hcl(   1)=      0.29998559d0
      R0hcl(   1)=      3.03540523d0
      DP0hcl(   2)=      0.31240799d0
      R0hcl(   2)=      3.21395848d0
      DP0hcl(   3)=      0.32592469d0
      R0hcl(   3)=      3.39251172d0
      DP0hcl(   4)=      0.34049667d0
      R0hcl(   4)=      3.57106497d0
      DP0hcl(   5)=      0.35601186d0
      R0hcl(   5)=      3.74961822d0
      DP0hcl(   6)=      0.37230131d0
      R0hcl(   6)=      3.92817147d0
      DP0hcl(   7)=      0.38920632d0
      R0hcl(   7)=      4.10672472d0
      DP0hcl(   8)=      0.40645081d0
      R0hcl(   8)=      4.28527797d0
      DP0hcl(   9)=      0.42373476d0
      R0hcl(   9)=      4.46383122d0
      DP0hcl(  10)=      0.43203844d0
      R0hcl(  10)=      4.55000101d0
      DP0hcl(  11)=      0.44087383d0
      R0hcl(  11)=      4.64238447d0
      DP0hcl(  12)=      0.45769729d0
      R0hcl(  12)=      4.82093771d0
      DP0hcl(  13)=      0.47378445d0
      R0hcl(  13)=      4.99949096d0
      DP0hcl(  14)=      0.48908038d0
      R0hcl(  14)=      5.17804421d0
      DP0hcl(  15)=      0.50326909d0
      R0hcl(  15)=      5.35659746d0
      DP0hcl(  16)=      0.52731193d0
      R0hcl(  16)=      5.71370396d0
      DP0hcl(  17)=      0.54378078d0
      R0hcl(  17)=      6.07081045d0
      DP0hcl(  18)=      0.55069854d0
      R0hcl(  18)=      6.42791695d0

      call spline(R0hcl,DP0hcl,n0hcl,dy1,dyn,DP0hcl2)

!HO dipole      
     
      DP0ho(   1)=      0.56795497d0
      R0ho(   1)=      2.32119223d0
      DP0ho(   2)=      0.58170575d0
      R0ho(   2)=      2.49974548d0
      DP0ho(   3)=      0.59508262d0
      R0ho(   3)=      2.67829873d0
      DP0ho(   4)=      0.60793273d0
      R0ho(   4)=      2.85685198d0
      DP0ho(   5)=      0.62001012d0
      R0ho(   5)=      3.03540523d0
      DP0ho(   6)=      0.63108237d0
      R0ho(   6)=      3.21395848d0
      DP0ho(   7)=      0.63710861d0
      R0ho(   7)=      3.32109043d0
      DP0ho(   8)=      0.64258788d0
      R0ho(   8)=      3.42822237d0
      DP0ho(   9)=      0.64449723d0
      R0ho(   9)=      3.46861112d0
      DP0ho(  10)=      0.64892295d0
      R0ho(  10)=      3.57106497d0
      DP0ho(  11)=      0.65503496d0
      R0ho(  11)=      3.74961822d0
      DP0ho(  12)=      0.65878681d0
      R0ho(  12)=      3.92817147d0
      DP0ho(  13)=      0.65980958d0
      R0ho(  13)=      4.10672472d0
      DP0ho(  14)=      0.65759048d0
      R0ho(  14)=      4.28527797d0
      DP0ho(  15)=      0.65152781d0
      R0ho(  15)=      4.46383122d0
      DP0ho(  16)=      0.64098716d0
      R0ho(  16)=      4.64238447d0
      DP0ho(  17)=      0.62572365d0
      R0ho(  17)=      4.82093771d0
      DP0ho(  18)=      0.60629609d0
      R0ho(  18)=      4.99949096d0
      DP0ho(  19)=      0.58339655d0
      R0ho(  19)=      5.17804421d0
      DP0ho(  20)=      0.55745569d0
      R0ho(  20)=      5.35659746d0

      call spline(R0ho,DP0ho,n0ho,dy1,dyn,DP0ho2)

!******************************************************************************

      nhid=  2;noutput=  1
      nscale=ninput+noutput
      nlayer=nhid+2
      allocate(nodes(nlayer),pdela(nscale),pavga(nscale))
      nodes(1)=ninput
      nodes(nlayer)=noutput
      nodes( 2)=50
      nodes( 3)=80
      nodemax=0
      do i=1,nlayer
       nodemax=max(nodemax,nodes(i))
      enddo
      allocate(weighta(nodemax,nodemax,2:nlayer),&
     &biasa(nodemax,2:nlayer))
      ifunc=  1;nwe=  5061
      pdela(  1)=  0.1067562850000000d0
      pavga(  1)=  0.1067562850000000d0
      pdela(  2)=  0.3584514100000000d0
      pavga(  2)=  0.5815815700000000d0
      pdela(  3)=  0.2995175250000000d0
      pavga(  3)=  0.2995175250000000d0
      pdela(  4)=  0.2568390200000000d0
      pavga(  4)=  0.2568390200000000d0
      pdela(  5)=  0.0795311450000000d0
      pavga(  5)=  0.0795311450000000d0
      pdela(  6)=  0.1104549900000000d0
      pavga(  6)=  0.1104549900000000d0
      pdela(  7)=  0.0412553110000000d0
      pavga(  7)=  0.0412553110000000d0
      pdela(  8)=  0.1001943800000000d0
      pavga(  8)=  0.1001943800000000d0
      pdela(  9)=  0.0447088400000000d0
      pavga(  9)=  0.0447088400000000d0
      pdela( 10)=  0.0963427050000000d0
      pavga( 10)=  0.0963427050000000d0
      pdela( 11)=  0.0380176695000000d0
      pavga( 11)=  0.0380176695000000d0
      pdela( 12)=  0.1950274550000000d0
      pavga( 12)=  0.1950274550000000d0
      pdela( 13)=  0.1168573000000000d0
      pavga( 13)=  0.1168573000000000d0
      pdela( 14)=  0.0227938090000000d0
      pavga( 14)=  0.0227938090000000d0
      pdela( 15)=  0.1960274905000000d0
      pavga( 15)=  0.2458145595000000d0
      pdela( 16)=  0.0900038150000000d0
      pavga( 16)=  0.0900038150000000d0
      pdela( 17)=  0.1319325650000000d0
      pavga( 17)=  0.1319325650000000d0
      pdela( 18)=  2.5885233649999999d0
      pavga( 18)=  2.4110914349999999d0
      iwe=  0
      weighta(  1,  1,  2)=                 -0.54839787516564564296d0
      iwe=iwe+1
      weighta(  2,  1,  2)=                  0.12328853873602953206d0
      iwe=iwe+1
      weighta(  3,  1,  2)=                  0.54887635268439805003d0
      iwe=iwe+1
      weighta(  4,  1,  2)=                  0.55137627195191318830d0
      iwe=iwe+1
      weighta(  5,  1,  2)=                 -0.21116236498751403405d0
      iwe=iwe+1
      weighta(  6,  1,  2)=                  0.15055642743456232324d0
      iwe=iwe+1
      weighta(  7,  1,  2)=                 -0.14252589531403991874d0
      iwe=iwe+1
      weighta(  8,  1,  2)=                  0.27608439126777095662d0
      iwe=iwe+1
      weighta(  9,  1,  2)=                  1.37777229983682714121d0
      iwe=iwe+1
      weighta( 10,  1,  2)=                 -0.04172786899024796131d0
      iwe=iwe+1
      weighta( 11,  1,  2)=                  0.18829358832431999926d0
      iwe=iwe+1
      weighta( 12,  1,  2)=                 -0.52943461763761079375d0
      iwe=iwe+1
      weighta( 13,  1,  2)=                 -0.75425776044635894912d0
      iwe=iwe+1
      weighta( 14,  1,  2)=                 -0.46527490006243610310d0
      iwe=iwe+1
      weighta( 15,  1,  2)=                 -0.03634693429172042994d0
      iwe=iwe+1
      weighta( 16,  1,  2)=                  0.11763055257912292950d0
      iwe=iwe+1
      weighta( 17,  1,  2)=                  0.58331322131904461692d0
      iwe=iwe+1
      biasa(  1,  2)=                  1.87656707074313966466d0
      iwe=iwe+1
      weighta(  1,  2,  2)=                  0.43255969514833803036d0
      iwe=iwe+1
      weighta(  2,  2,  2)=                 -0.31148361513244066101d0
      iwe=iwe+1
      weighta(  3,  2,  2)=                  0.59809772388497661755d0
      iwe=iwe+1
      weighta(  4,  2,  2)=                 -0.11608581120167457690d0
      iwe=iwe+1
      weighta(  5,  2,  2)=                  0.86763107683485696242d0
      iwe=iwe+1
      weighta(  6,  2,  2)=                  0.09283216747049932716d0
      iwe=iwe+1
      weighta(  7,  2,  2)=                 -0.51596893565408152860d0
      iwe=iwe+1
      weighta(  8,  2,  2)=                  0.70699609268788488059d0
      iwe=iwe+1
      weighta(  9,  2,  2)=                  0.02691631985980206046d0
      iwe=iwe+1
      weighta( 10,  2,  2)=                 -0.22534163864055870019d0
      iwe=iwe+1
      weighta( 11,  2,  2)=                 -0.50555894802628797979d0
      iwe=iwe+1
      weighta( 12,  2,  2)=                  0.65240829074244721664d0
      iwe=iwe+1
      weighta( 13,  2,  2)=                 -0.18232244324978705285d0
      iwe=iwe+1
      weighta( 14,  2,  2)=                  0.40843793907818543021d0
      iwe=iwe+1
      weighta( 15,  2,  2)=                 -0.59130038316506339235d0
      iwe=iwe+1
      weighta( 16,  2,  2)=                  0.49163412120825117357d0
      iwe=iwe+1
      weighta( 17,  2,  2)=                 -0.52626174048152718488d0
      iwe=iwe+1
      biasa(  2,  2)=                 -1.76110796447809003773d0
      iwe=iwe+1
      weighta(  1,  3,  2)=                  0.22809712102627785479d0
      iwe=iwe+1
      weighta(  2,  3,  2)=                 -0.47642898833466823527d0
      iwe=iwe+1
      weighta(  3,  3,  2)=                 -0.21114954305957975289d0
      iwe=iwe+1
      weighta(  4,  3,  2)=                  0.39147440306612035776d0
      iwe=iwe+1
      weighta(  5,  3,  2)=                  0.49583690603117380746d0
      iwe=iwe+1
      weighta(  6,  3,  2)=                  0.45109998436422871215d0
      iwe=iwe+1
      weighta(  7,  3,  2)=                  0.11050612940297814546d0
      iwe=iwe+1
      weighta(  8,  3,  2)=                 -0.06880657340421308943d0
      iwe=iwe+1
      weighta(  9,  3,  2)=                  0.26981717619951745002d0
      iwe=iwe+1
      weighta( 10,  3,  2)=                  0.58080730956204218440d0
      iwe=iwe+1
      weighta( 11,  3,  2)=                  0.37121455915399942382d0
      iwe=iwe+1
      weighta( 12,  3,  2)=                 -0.67370321062452021010d0
      iwe=iwe+1
      weighta( 13,  3,  2)=                 -0.65358599737424083465d0
      iwe=iwe+1
      weighta( 14,  3,  2)=                 -0.01491941621297336595d0
      iwe=iwe+1
      weighta( 15,  3,  2)=                 -0.24776298441849739507d0
      iwe=iwe+1
      weighta( 16,  3,  2)=                  0.36107588653432098891d0
      iwe=iwe+1
      weighta( 17,  3,  2)=                  0.64860944069210191287d0
      iwe=iwe+1
      biasa(  3,  2)=                 -1.62766211387146464418d0
      iwe=iwe+1
      weighta(  1,  4,  2)=                  0.38749481608085828421d0
      iwe=iwe+1
      weighta(  2,  4,  2)=                 -0.44888182568000961625d0
      iwe=iwe+1
      weighta(  3,  4,  2)=                  0.39078416173195096306d0
      iwe=iwe+1
      weighta(  4,  4,  2)=                 -0.47418419912010667527d0
      iwe=iwe+1
      weighta(  5,  4,  2)=                 -0.08816416606700135106d0
      iwe=iwe+1
      weighta(  6,  4,  2)=                  0.47949278466737393911d0
      iwe=iwe+1
      weighta(  7,  4,  2)=                  0.47844522888674767547d0
      iwe=iwe+1
      weighta(  8,  4,  2)=                  0.03954269798976001171d0
      iwe=iwe+1
      weighta(  9,  4,  2)=                  0.21314058284981796110d0
      iwe=iwe+1
      weighta( 10,  4,  2)=                 -0.64473662524998975876d0
      iwe=iwe+1
      weighta( 11,  4,  2)=                  0.68206487223361933481d0
      iwe=iwe+1
      weighta( 12,  4,  2)=                  0.64562686218608644761d0
      iwe=iwe+1
      weighta( 13,  4,  2)=                 -0.29749288797321943312d0
      iwe=iwe+1
      weighta( 14,  4,  2)=                 -0.07852317372658440542d0
      iwe=iwe+1
      weighta( 15,  4,  2)=                  0.14950769996878859880d0
      iwe=iwe+1
      weighta( 16,  4,  2)=                  0.29068143446435090738d0
      iwe=iwe+1
      weighta( 17,  4,  2)=                 -0.15992797343930245657d0
      iwe=iwe+1
      biasa(  4,  2)=                 -1.73479860292437404468d0
      iwe=iwe+1
      weighta(  1,  5,  2)=                  0.51721568007012519441d0
      iwe=iwe+1
      weighta(  2,  5,  2)=                 -0.91756368179993608170d0
      iwe=iwe+1
      weighta(  3,  5,  2)=                  0.02365211355335733803d0
      iwe=iwe+1
      weighta(  4,  5,  2)=                 -0.30767489155543881196d0
      iwe=iwe+1
      weighta(  5,  5,  2)=                 -0.77179619698495105506d0
      iwe=iwe+1
      weighta(  6,  5,  2)=                 -1.23159728975573012910d0
      iwe=iwe+1
      weighta(  7,  5,  2)=                 -0.39402251517651232238d0
      iwe=iwe+1
      weighta(  8,  5,  2)=                  0.20757398753626496446d0
      iwe=iwe+1
      weighta(  9,  5,  2)=                  0.91915900799574001834d0
      iwe=iwe+1
      weighta( 10,  5,  2)=                 -0.53795700718151728825d0
      iwe=iwe+1
      weighta( 11,  5,  2)=                 -0.57135557783275214838d0
      iwe=iwe+1
      weighta( 12,  5,  2)=                 -0.09354036598412071579d0
      iwe=iwe+1
      weighta( 13,  5,  2)=                  0.36613161852986819689d0
      iwe=iwe+1
      weighta( 14,  5,  2)=                  0.16366194080204948813d0
      iwe=iwe+1
      weighta( 15,  5,  2)=                  0.68416411469844096160d0
      iwe=iwe+1
      weighta( 16,  5,  2)=                  0.76754695134916661736d0
      iwe=iwe+1
      weighta( 17,  5,  2)=                 -0.20701197717469457804d0
      iwe=iwe+1
      biasa(  5,  2)=                 -2.04736779502537036279d0
      iwe=iwe+1
      weighta(  1,  6,  2)=                  1.21824776920714050732d0
      iwe=iwe+1
      weighta(  2,  6,  2)=                  0.13706291803027476073d0
      iwe=iwe+1
      weighta(  3,  6,  2)=                 -0.50511213699616896999d0
      iwe=iwe+1
      weighta(  4,  6,  2)=                 -0.52608081876444212632d0
      iwe=iwe+1
      weighta(  5,  6,  2)=                  0.13449483544190130035d0
      iwe=iwe+1
      weighta(  6,  6,  2)=                  0.94526985903310656312d0
      iwe=iwe+1
      weighta(  7,  6,  2)=                  0.70977618787579244142d0
      iwe=iwe+1
      weighta(  8,  6,  2)=                  0.86747063324898965320d0
      iwe=iwe+1
      weighta(  9,  6,  2)=                 -1.48734571753758881840d0
      iwe=iwe+1
      weighta( 10,  6,  2)=                 -1.32665356937980782881d0
      iwe=iwe+1
      weighta( 11,  6,  2)=                 -0.39696140752847369759d0
      iwe=iwe+1
      weighta( 12,  6,  2)=                  0.29544754157606023526d0
      iwe=iwe+1
      weighta( 13,  6,  2)=                 -0.33296293554759009981d0
      iwe=iwe+1
      weighta( 14,  6,  2)=                 -0.07352239837120483346d0
      iwe=iwe+1
      weighta( 15,  6,  2)=                 -0.77129107596821522286d0
      iwe=iwe+1
      weighta( 16,  6,  2)=                  0.43312333050489221220d0
      iwe=iwe+1
      weighta( 17,  6,  2)=                  0.59415238427252003994d0
      iwe=iwe+1
      biasa(  6,  2)=                 -2.02384870960198082201d0
      iwe=iwe+1
      weighta(  1,  7,  2)=                  0.35788453168199474419d0
      iwe=iwe+1
      weighta(  2,  7,  2)=                 -0.46834797526999538686d0
      iwe=iwe+1
      weighta(  3,  7,  2)=                  0.02476586195434059973d0
      iwe=iwe+1
      weighta(  4,  7,  2)=                 -0.36093024642638060762d0
      iwe=iwe+1
      weighta(  5,  7,  2)=                 -0.17915776538088856729d0
      iwe=iwe+1
      weighta(  6,  7,  2)=                 -0.73874028111653378126d0
      iwe=iwe+1
      weighta(  7,  7,  2)=                 -0.62899029498291769702d0
      iwe=iwe+1
      weighta(  8,  7,  2)=                  0.72761313534784355372d0
      iwe=iwe+1
      weighta(  9,  7,  2)=                  0.89573288561768038551d0
      iwe=iwe+1
      weighta( 10,  7,  2)=                 -0.98082213863069245274d0
      iwe=iwe+1
      weighta( 11,  7,  2)=                  0.00862496118080255739d0
      iwe=iwe+1
      weighta( 12,  7,  2)=                 -0.71815553273190491090d0
      iwe=iwe+1
      weighta( 13,  7,  2)=                 -0.51241542088709879366d0
      iwe=iwe+1
      weighta( 14,  7,  2)=                  0.96068696299614275702d0
      iwe=iwe+1
      weighta( 15,  7,  2)=                  0.23706547571446007217d0
      iwe=iwe+1
      weighta( 16,  7,  2)=                 -0.78385870913075406108d0
      iwe=iwe+1
      weighta( 17,  7,  2)=                 -0.44450931586659625516d0
      iwe=iwe+1
      biasa(  7,  2)=                 -1.49184933734618052625d0
      iwe=iwe+1
      weighta(  1,  8,  2)=                 -0.56859090546052482029d0
      iwe=iwe+1
      weighta(  2,  8,  2)=                  0.10512146565482904936d0
      iwe=iwe+1
      weighta(  3,  8,  2)=                  0.61360154601531591290d0
      iwe=iwe+1
      weighta(  4,  8,  2)=                 -0.14327312824733126617d0
      iwe=iwe+1
      weighta(  5,  8,  2)=                 -0.51454241746114737222d0
      iwe=iwe+1
      weighta(  6,  8,  2)=                 -0.26320006321598149457d0
      iwe=iwe+1
      weighta(  7,  8,  2)=                  0.28848161461768750957d0
      iwe=iwe+1
      weighta(  8,  8,  2)=                  0.65201738312537815823d0
      iwe=iwe+1
      weighta(  9,  8,  2)=                  2.63230539283930919936d0
      iwe=iwe+1
      weighta( 10,  8,  2)=                  1.41301196099181836097d0
      iwe=iwe+1
      weighta( 11,  8,  2)=                  0.29270245421272744757d0
      iwe=iwe+1
      weighta( 12,  8,  2)=                 -0.12860523954346592124d0
      iwe=iwe+1
      weighta( 13,  8,  2)=                 -0.09408211717839334853d0
      iwe=iwe+1
      weighta( 14,  8,  2)=                  0.55111994320664547953d0
      iwe=iwe+1
      weighta( 15,  8,  2)=                 -0.86807295413528440253d0
      iwe=iwe+1
      weighta( 16,  8,  2)=                 -1.95175460416504131800d0
      iwe=iwe+1
      weighta( 17,  8,  2)=                 -0.09137689714775555638d0
      iwe=iwe+1
      biasa(  8,  2)=                  2.09380205238869443463d0
      iwe=iwe+1
      weighta(  1,  9,  2)=                  0.43065115968933315171d0
      iwe=iwe+1
      weighta(  2,  9,  2)=                  0.67112945353623387756d0
      iwe=iwe+1
      weighta(  3,  9,  2)=                  0.30192324445446533376d0
      iwe=iwe+1
      weighta(  4,  9,  2)=                  0.07901886592139574506d0
      iwe=iwe+1
      weighta(  5,  9,  2)=                  0.42812064193384719024d0
      iwe=iwe+1
      weighta(  6,  9,  2)=                 -0.43787372135526436701d0
      iwe=iwe+1
      weighta(  7,  9,  2)=                  0.62663272401745484519d0
      iwe=iwe+1
      weighta(  8,  9,  2)=                 -0.22072637441473302866d0
      iwe=iwe+1
      weighta(  9,  9,  2)=                  0.63393313298170461678d0
      iwe=iwe+1
      weighta( 10,  9,  2)=                 -0.33413379438554230427d0
      iwe=iwe+1
      weighta( 11,  9,  2)=                 -0.38017005668507519722d0
      iwe=iwe+1
      weighta( 12,  9,  2)=                  0.56413333343673310871d0
      iwe=iwe+1
      weighta( 13,  9,  2)=                 -0.51807758985070662128d0
      iwe=iwe+1
      weighta( 14,  9,  2)=                  0.48271709838546911220d0
      iwe=iwe+1
      weighta( 15,  9,  2)=                  0.26690068624861773561d0
      iwe=iwe+1
      weighta( 16,  9,  2)=                  0.54591895218383590382d0
      iwe=iwe+1
      weighta( 17,  9,  2)=                  0.17583859649195140995d0
      iwe=iwe+1
      biasa(  9,  2)=                 -1.14959610304440840167d0
      iwe=iwe+1
      weighta(  1, 10,  2)=                 -0.06279994841915216564d0
      iwe=iwe+1
      weighta(  2, 10,  2)=                 -0.76359545785199711698d0
      iwe=iwe+1
      weighta(  3, 10,  2)=                  0.01882776780315346954d0
      iwe=iwe+1
      weighta(  4, 10,  2)=                 -0.07539324579053299780d0
      iwe=iwe+1
      weighta(  5, 10,  2)=                 -0.26925752141384579064d0
      iwe=iwe+1
      weighta(  6, 10,  2)=                 -0.21990210495033302163d0
      iwe=iwe+1
      weighta(  7, 10,  2)=                  0.68263570934816886204d0
      iwe=iwe+1
      weighta(  8, 10,  2)=                  0.48338765661832644449d0
      iwe=iwe+1
      weighta(  9, 10,  2)=                  1.29341407967222332687d0
      iwe=iwe+1
      weighta( 10, 10,  2)=                 -0.39749079546159338250d0
      iwe=iwe+1
      weighta( 11, 10,  2)=                 -0.09842531629304819563d0
      iwe=iwe+1
      weighta( 12, 10,  2)=                 -0.41639204949415603574d0
      iwe=iwe+1
      weighta( 13, 10,  2)=                 -0.65998017780814755007d0
      iwe=iwe+1
      weighta( 14, 10,  2)=                  0.09657340872580714997d0
      iwe=iwe+1
      weighta( 15, 10,  2)=                  0.83331665596516879546d0
      iwe=iwe+1
      weighta( 16, 10,  2)=                 -0.24233857829665150785d0
      iwe=iwe+1
      weighta( 17, 10,  2)=                  0.30162830819038466412d0
      iwe=iwe+1
      biasa( 10,  2)=                  1.19156162311691637967d0
      iwe=iwe+1
      weighta(  1, 11,  2)=                  0.47309829745070608453d0
      iwe=iwe+1
      weighta(  2, 11,  2)=                  0.27761031507155847775d0
      iwe=iwe+1
      weighta(  3, 11,  2)=                 -0.60605805442197502320d0
      iwe=iwe+1
      weighta(  4, 11,  2)=                  0.30463966194337072091d0
      iwe=iwe+1
      weighta(  5, 11,  2)=                 -0.11887344021411130890d0
      iwe=iwe+1
      weighta(  6, 11,  2)=                  1.19942650228462621698d0
      iwe=iwe+1
      weighta(  7, 11,  2)=                  0.42050033867001579413d0
      iwe=iwe+1
      weighta(  8, 11,  2)=                  0.99914506966425253864d0
      iwe=iwe+1
      weighta(  9, 11,  2)=                 -0.50432558272491745388d0
      iwe=iwe+1
      weighta( 10, 11,  2)=                 -0.51306608999923886127d0
      iwe=iwe+1
      weighta( 11, 11,  2)=                 -0.47651035994348034386d0
      iwe=iwe+1
      weighta( 12, 11,  2)=                 -0.04830483884558779695d0
      iwe=iwe+1
      weighta( 13, 11,  2)=                 -0.10940163402252707503d0
      iwe=iwe+1
      weighta( 14, 11,  2)=                 -0.00513459915850198508d0
      iwe=iwe+1
      weighta( 15, 11,  2)=                 -0.06138904524860291229d0
      iwe=iwe+1
      weighta( 16, 11,  2)=                  0.27075598272058726268d0
      iwe=iwe+1
      weighta( 17, 11,  2)=                 -0.53054625542267475069d0
      iwe=iwe+1
      biasa( 11,  2)=                 -1.41449921775319698014d0
      iwe=iwe+1
      weighta(  1, 12,  2)=                 -0.58084616516580578338d0
      iwe=iwe+1
      weighta(  2, 12,  2)=                 -0.00228675676835877941d0
      iwe=iwe+1
      weighta(  3, 12,  2)=                  0.46366480194633585832d0
      iwe=iwe+1
      weighta(  4, 12,  2)=                 -0.54169677814959804607d0
      iwe=iwe+1
      weighta(  5, 12,  2)=                 -0.43996997205662652375d0
      iwe=iwe+1
      weighta(  6, 12,  2)=                 -0.40184117683677406108d0
      iwe=iwe+1
      weighta(  7, 12,  2)=                  0.07058529809063465721d0
      iwe=iwe+1
      weighta(  8, 12,  2)=                  0.17339873395501428921d0
      iwe=iwe+1
      weighta(  9, 12,  2)=                  0.92476748727352098278d0
      iwe=iwe+1
      weighta( 10, 12,  2)=                 -0.73460266100681859136d0
      iwe=iwe+1
      weighta( 11, 12,  2)=                  0.35406463849098523955d0
      iwe=iwe+1
      weighta( 12, 12,  2)=                  0.30163799261718599043d0
      iwe=iwe+1
      weighta( 13, 12,  2)=                  0.49015584115381172214d0
      iwe=iwe+1
      weighta( 14, 12,  2)=                  0.24752741270603714763d0
      iwe=iwe+1
      weighta( 15, 12,  2)=                  0.74232274946287279960d0
      iwe=iwe+1
      weighta( 16, 12,  2)=                 -0.05096344059313883540d0
      iwe=iwe+1
      weighta( 17, 12,  2)=                  0.75123277183561643078d0
      iwe=iwe+1
      biasa( 12,  2)=                  0.98877855601235831173d0
      iwe=iwe+1
      weighta(  1, 13,  2)=                 -0.57940287032538395628d0
      iwe=iwe+1
      weighta(  2, 13,  2)=                 -0.54338195689782775588d0
      iwe=iwe+1
      weighta(  3, 13,  2)=                 -0.40170800585485189060d0
      iwe=iwe+1
      weighta(  4, 13,  2)=                  0.22605254561377721712d0
      iwe=iwe+1
      weighta(  5, 13,  2)=                  0.61084012685598776393d0
      iwe=iwe+1
      weighta(  6, 13,  2)=                  0.06004838400833815981d0
      iwe=iwe+1
      weighta(  7, 13,  2)=                 -0.29934966350939418156d0
      iwe=iwe+1
      weighta(  8, 13,  2)=                 -0.15554860012456397933d0
      iwe=iwe+1
      weighta(  9, 13,  2)=                  0.81354227938712420087d0
      iwe=iwe+1
      weighta( 10, 13,  2)=                 -0.33208039171053521654d0
      iwe=iwe+1
      weighta( 11, 13,  2)=                 -0.41875251161777865549d0
      iwe=iwe+1
      weighta( 12, 13,  2)=                  0.46368453083182187280d0
      iwe=iwe+1
      weighta( 13, 13,  2)=                  0.09908627773720744825d0
      iwe=iwe+1
      weighta( 14, 13,  2)=                  0.29601355442195737000d0
      iwe=iwe+1
      weighta( 15, 13,  2)=                 -0.83757609539181832048d0
      iwe=iwe+1
      weighta( 16, 13,  2)=                 -0.05984014607017428683d0
      iwe=iwe+1
      weighta( 17, 13,  2)=                 -0.35976496717362949074d0
      iwe=iwe+1
      biasa( 13,  2)=                  1.05072873925323917454d0
      iwe=iwe+1
      weighta(  1, 14,  2)=                 -0.76914223878623888542d0
      iwe=iwe+1
      weighta(  2, 14,  2)=                  0.69908481308526571052d0
      iwe=iwe+1
      weighta(  3, 14,  2)=                  0.04984421546762620586d0
      iwe=iwe+1
      weighta(  4, 14,  2)=                 -0.52441869511314187502d0
      iwe=iwe+1
      weighta(  5, 14,  2)=                 -0.32651254061036255605d0
      iwe=iwe+1
      weighta(  6, 14,  2)=                  0.05700948273262649441d0
      iwe=iwe+1
      weighta(  7, 14,  2)=                 -0.42785785055238734209d0
      iwe=iwe+1
      weighta(  8, 14,  2)=                 -0.09663559197553843461d0
      iwe=iwe+1
      weighta(  9, 14,  2)=                  0.30173971038326802274d0
      iwe=iwe+1
      weighta( 10, 14,  2)=                  0.41636666757826279461d0
      iwe=iwe+1
      weighta( 11, 14,  2)=                  0.23535537208972892587d0
      iwe=iwe+1
      weighta( 12, 14,  2)=                 -0.37652720005326778541d0
      iwe=iwe+1
      weighta( 13, 14,  2)=                 -0.40143701540790216464d0
      iwe=iwe+1
      weighta( 14, 14,  2)=                  0.08510041766470596847d0
      iwe=iwe+1
      weighta( 15, 14,  2)=                  0.39502739075018289405d0
      iwe=iwe+1
      weighta( 16, 14,  2)=                 -0.41410837128490290970d0
      iwe=iwe+1
      weighta( 17, 14,  2)=                  0.41436954160160477389d0
      iwe=iwe+1
      biasa( 14,  2)=                  0.78584368374188628970d0
      iwe=iwe+1
      weighta(  1, 15,  2)=                  0.00568977053783369449d0
      iwe=iwe+1
      weighta(  2, 15,  2)=                  0.32585536897855826854d0
      iwe=iwe+1
      weighta(  3, 15,  2)=                 -0.15835333764753672936d0
      iwe=iwe+1
      weighta(  4, 15,  2)=                  0.29674786112779055758d0
      iwe=iwe+1
      weighta(  5, 15,  2)=                  0.18004067994459374558d0
      iwe=iwe+1
      weighta(  6, 15,  2)=                 -0.48124168598372657479d0
      iwe=iwe+1
      weighta(  7, 15,  2)=                  0.54877676614465153992d0
      iwe=iwe+1
      weighta(  8, 15,  2)=                 -0.15747985426340324611d0
      iwe=iwe+1
      weighta(  9, 15,  2)=                  0.48611552595209606142d0
      iwe=iwe+1
      weighta( 10, 15,  2)=                  0.22698457680922043411d0
      iwe=iwe+1
      weighta( 11, 15,  2)=                  0.30205822561701500817d0
      iwe=iwe+1
      weighta( 12, 15,  2)=                 -0.63172211362828711856d0
      iwe=iwe+1
      weighta( 13, 15,  2)=                  0.31949298724360664092d0
      iwe=iwe+1
      weighta( 14, 15,  2)=                 -0.16218182105732664722d0
      iwe=iwe+1
      weighta( 15, 15,  2)=                  0.15201557290668582523d0
      iwe=iwe+1
      weighta( 16, 15,  2)=                 -1.19523557435156679851d0
      iwe=iwe+1
      weighta( 17, 15,  2)=                 -0.44325110423500246881d0
      iwe=iwe+1
      biasa( 15,  2)=                 -1.00555751970549334118d0
      iwe=iwe+1
      weighta(  1, 16,  2)=                 -0.45022002998491095216d0
      iwe=iwe+1
      weighta(  2, 16,  2)=                  0.49227636659408652298d0
      iwe=iwe+1
      weighta(  3, 16,  2)=                 -0.11685158802163021774d0
      iwe=iwe+1
      weighta(  4, 16,  2)=                  1.07644983473316369071d0
      iwe=iwe+1
      weighta(  5, 16,  2)=                 -0.25982478976210920951d0
      iwe=iwe+1
      weighta(  6, 16,  2)=                 -0.64331881365080656465d0
      iwe=iwe+1
      weighta(  7, 16,  2)=                  0.10647130712527461127d0
      iwe=iwe+1
      weighta(  8, 16,  2)=                  0.65529638729771899630d0
      iwe=iwe+1
      weighta(  9, 16,  2)=                 -0.11709415559869411350d0
      iwe=iwe+1
      weighta( 10, 16,  2)=                  0.44863348942824032850d0
      iwe=iwe+1
      weighta( 11, 16,  2)=                  0.26898344338611046567d0
      iwe=iwe+1
      weighta( 12, 16,  2)=                  1.60375024262172471978d0
      iwe=iwe+1
      weighta( 13, 16,  2)=                  0.09604781745651772007d0
      iwe=iwe+1
      weighta( 14, 16,  2)=                 -0.46035607914235915361d0
      iwe=iwe+1
      weighta( 15, 16,  2)=                 -0.48400151795549944955d0
      iwe=iwe+1
      weighta( 16, 16,  2)=                 -0.57954645756722833472d0
      iwe=iwe+1
      weighta( 17, 16,  2)=                 -0.70706622268527452579d0
      iwe=iwe+1
      biasa( 16,  2)=                  1.03053568018179730892d0
      iwe=iwe+1
      weighta(  1, 17,  2)=                 -0.40558308379208157790d0
      iwe=iwe+1
      weighta(  2, 17,  2)=                  0.03247745356144210449d0
      iwe=iwe+1
      weighta(  3, 17,  2)=                 -0.06699647690013611767d0
      iwe=iwe+1
      weighta(  4, 17,  2)=                 -0.46324879125239265543d0
      iwe=iwe+1
      weighta(  5, 17,  2)=                  0.23474807187036658696d0
      iwe=iwe+1
      weighta(  6, 17,  2)=                  0.08463678559411197400d0
      iwe=iwe+1
      weighta(  7, 17,  2)=                  0.42983021821285527508d0
      iwe=iwe+1
      weighta(  8, 17,  2)=                  0.52983008940036324663d0
      iwe=iwe+1
      weighta(  9, 17,  2)=                 -0.64724510238456511857d0
      iwe=iwe+1
      weighta( 10, 17,  2)=                  0.38607475241228167429d0
      iwe=iwe+1
      weighta( 11, 17,  2)=                 -0.45300483418223586041d0
      iwe=iwe+1
      weighta( 12, 17,  2)=                 -0.63512412406951590516d0
      iwe=iwe+1
      weighta( 13, 17,  2)=                 -0.46266727570371241063d0
      iwe=iwe+1
      weighta( 14, 17,  2)=                 -0.47512062819348988008d0
      iwe=iwe+1
      weighta( 15, 17,  2)=                  0.40511958723232194268d0
      iwe=iwe+1
      weighta( 16, 17,  2)=                  0.46988166721696134065d0
      iwe=iwe+1
      weighta( 17, 17,  2)=                  0.54622631644460040157d0
      iwe=iwe+1
      biasa( 17,  2)=                  0.86901106594006904960d0
      iwe=iwe+1
      weighta(  1, 18,  2)=                  0.86561761859107932970d0
      iwe=iwe+1
      weighta(  2, 18,  2)=                  0.64715963713874036234d0
      iwe=iwe+1
      weighta(  3, 18,  2)=                  0.02615906478217742623d0
      iwe=iwe+1
      weighta(  4, 18,  2)=                 -0.24500001991975278726d0
      iwe=iwe+1
      weighta(  5, 18,  2)=                 -0.52090477144177549373d0
      iwe=iwe+1
      weighta(  6, 18,  2)=                  0.51477195397507335972d0
      iwe=iwe+1
      weighta(  7, 18,  2)=                 -0.02595880154420728697d0
      iwe=iwe+1
      weighta(  8, 18,  2)=                 -0.16523625907810263191d0
      iwe=iwe+1
      weighta(  9, 18,  2)=                  0.73987452960689736869d0
      iwe=iwe+1
      weighta( 10, 18,  2)=                  0.68086993257643357857d0
      iwe=iwe+1
      weighta( 11, 18,  2)=                 -0.40927366237717016650d0
      iwe=iwe+1
      weighta( 12, 18,  2)=                  0.87185365762222222230d0
      iwe=iwe+1
      weighta( 13, 18,  2)=                 -0.78405479310554515582d0
      iwe=iwe+1
      weighta( 14, 18,  2)=                 -0.57848062381064857540d0
      iwe=iwe+1
      weighta( 15, 18,  2)=                 -0.28182478289218865219d0
      iwe=iwe+1
      weighta( 16, 18,  2)=                 -1.12258584245394787970d0
      iwe=iwe+1
      weighta( 17, 18,  2)=                  0.44614284353839556152d0
      iwe=iwe+1
      biasa( 18,  2)=                 -0.30463032888413033028d0
      iwe=iwe+1
      weighta(  1, 19,  2)=                 -0.25410504700959396507d0
      iwe=iwe+1
      weighta(  2, 19,  2)=                  0.65969193409241722037d0
      iwe=iwe+1
      weighta(  3, 19,  2)=                 -0.24560377335151831191d0
      iwe=iwe+1
      weighta(  4, 19,  2)=                 -0.52548579628915548234d0
      iwe=iwe+1
      weighta(  5, 19,  2)=                 -0.97900296355923654978d0
      iwe=iwe+1
      weighta(  6, 19,  2)=                  0.62869159247833017456d0
      iwe=iwe+1
      weighta(  7, 19,  2)=                  0.54202288391051711702d0
      iwe=iwe+1
      weighta(  8, 19,  2)=                  0.22683828960182367274d0
      iwe=iwe+1
      weighta(  9, 19,  2)=                 -0.60935740907936086774d0
      iwe=iwe+1
      weighta( 10, 19,  2)=                  1.07994785593699793580d0
      iwe=iwe+1
      weighta( 11, 19,  2)=                 -0.14028863829840557131d0
      iwe=iwe+1
      weighta( 12, 19,  2)=                 -0.72276118280243917269d0
      iwe=iwe+1
      weighta( 13, 19,  2)=                 -0.12825355748088523855d0
      iwe=iwe+1
      weighta( 14, 19,  2)=                  0.53913255960796957478d0
      iwe=iwe+1
      weighta( 15, 19,  2)=                 -0.18611052106464481826d0
      iwe=iwe+1
      weighta( 16, 19,  2)=                  0.08868187464928803387d0
      iwe=iwe+1
      weighta( 17, 19,  2)=                 -0.24262200316167276126d0
      iwe=iwe+1
      biasa( 19,  2)=                 -0.68496296661205546830d0
      iwe=iwe+1
      weighta(  1, 20,  2)=                 -0.71323523206461092450d0
      iwe=iwe+1
      weighta(  2, 20,  2)=                 -0.48140205042219297304d0
      iwe=iwe+1
      weighta(  3, 20,  2)=                  0.18119825081308377213d0
      iwe=iwe+1
      weighta(  4, 20,  2)=                 -0.11641912735537227053d0
      iwe=iwe+1
      weighta(  5, 20,  2)=                 -0.67874165661991281429d0
      iwe=iwe+1
      weighta(  6, 20,  2)=                 -0.68125640226470574046d0
      iwe=iwe+1
      weighta(  7, 20,  2)=                 -0.10406660325956412771d0
      iwe=iwe+1
      weighta(  8, 20,  2)=                 -0.02210313954815085538d0
      iwe=iwe+1
      weighta(  9, 20,  2)=                  0.46052662227358437397d0
      iwe=iwe+1
      weighta( 10, 20,  2)=                 -0.75512357232533078299d0
      iwe=iwe+1
      weighta( 11, 20,  2)=                  0.07607585974540818918d0
      iwe=iwe+1
      weighta( 12, 20,  2)=                  0.24113053877124127067d0
      iwe=iwe+1
      weighta( 13, 20,  2)=                 -0.09707659622935847776d0
      iwe=iwe+1
      weighta( 14, 20,  2)=                  0.16729678290060195911d0
      iwe=iwe+1
      weighta( 15, 20,  2)=                  1.10786766735907860060d0
      iwe=iwe+1
      weighta( 16, 20,  2)=                 -0.10341873955675155716d0
      iwe=iwe+1
      weighta( 17, 20,  2)=                  0.13866448747093496063d0
      iwe=iwe+1
      biasa( 20,  2)=                  0.44062407392013258622d0
      iwe=iwe+1
      weighta(  1, 21,  2)=                  0.27223882515454178588d0
      iwe=iwe+1
      weighta(  2, 21,  2)=                  0.13120982168089664888d0
      iwe=iwe+1
      weighta(  3, 21,  2)=                 -0.82729573765823782860d0
      iwe=iwe+1
      weighta(  4, 21,  2)=                 -0.68839921413055304988d0
      iwe=iwe+1
      weighta(  5, 21,  2)=                 -0.27379980074795889911d0
      iwe=iwe+1
      weighta(  6, 21,  2)=                  0.54722085048974788979d0
      iwe=iwe+1
      weighta(  7, 21,  2)=                 -0.39007526150575644319d0
      iwe=iwe+1
      weighta(  8, 21,  2)=                 -0.56083666410787202938d0
      iwe=iwe+1
      weighta(  9, 21,  2)=                 -0.83212226423240354123d0
      iwe=iwe+1
      weighta( 10, 21,  2)=                 -0.30076106962198889683d0
      iwe=iwe+1
      weighta( 11, 21,  2)=                  0.63270183594453976994d0
      iwe=iwe+1
      weighta( 12, 21,  2)=                  0.18660364437995860531d0
      iwe=iwe+1
      weighta( 13, 21,  2)=                  0.51874012600008667651d0
      iwe=iwe+1
      weighta( 14, 21,  2)=                  0.41199868325632271748d0
      iwe=iwe+1
      weighta( 15, 21,  2)=                 -0.60731144916053481086d0
      iwe=iwe+1
      weighta( 16, 21,  2)=                 -0.23254744330677329378d0
      iwe=iwe+1
      weighta( 17, 21,  2)=                  0.65462300535524575729d0
      iwe=iwe+1
      biasa( 21,  2)=                 -0.63502697993369672247d0
      iwe=iwe+1
      weighta(  1, 22,  2)=                 -0.64435869482053842461d0
      iwe=iwe+1
      weighta(  2, 22,  2)=                 -0.09834302164070249375d0
      iwe=iwe+1
      weighta(  3, 22,  2)=                  0.76049785731805441547d0
      iwe=iwe+1
      weighta(  4, 22,  2)=                 -0.95516318145232359527d0
      iwe=iwe+1
      weighta(  5, 22,  2)=                  0.11514344925817084075d0
      iwe=iwe+1
      weighta(  6, 22,  2)=                  0.94506664754802649497d0
      iwe=iwe+1
      weighta(  7, 22,  2)=                 -0.07063744093082156839d0
      iwe=iwe+1
      weighta(  8, 22,  2)=                  0.22294819617154251756d0
      iwe=iwe+1
      weighta(  9, 22,  2)=                  0.96197838306166427724d0
      iwe=iwe+1
      weighta( 10, 22,  2)=                 -0.22021481187979849437d0
      iwe=iwe+1
      weighta( 11, 22,  2)=                  0.07310539425461184959d0
      iwe=iwe+1
      weighta( 12, 22,  2)=                 -0.58985434918753354427d0
      iwe=iwe+1
      weighta( 13, 22,  2)=                  0.09468879406407079702d0
      iwe=iwe+1
      weighta( 14, 22,  2)=                 -0.17885101586879426083d0
      iwe=iwe+1
      weighta( 15, 22,  2)=                 -0.32879442863983393552d0
      iwe=iwe+1
      weighta( 16, 22,  2)=                  0.62426094634198647793d0
      iwe=iwe+1
      weighta( 17, 22,  2)=                 -0.70985910771153215570d0
      iwe=iwe+1
      biasa( 22,  2)=                  0.33784699278479429774d0
      iwe=iwe+1
      weighta(  1, 23,  2)=                 -0.09153448687166210185d0
      iwe=iwe+1
      weighta(  2, 23,  2)=                 -0.82158504655814412754d0
      iwe=iwe+1
      weighta(  3, 23,  2)=                 -0.17274440465021428937d0
      iwe=iwe+1
      weighta(  4, 23,  2)=                  0.20728403211919246840d0
      iwe=iwe+1
      weighta(  5, 23,  2)=                  0.70103570020661998274d0
      iwe=iwe+1
      weighta(  6, 23,  2)=                 -0.71845883630475659842d0
      iwe=iwe+1
      weighta(  7, 23,  2)=                 -0.57536394511243749150d0
      iwe=iwe+1
      weighta(  8, 23,  2)=                 -0.25953665675932352519d0
      iwe=iwe+1
      weighta(  9, 23,  2)=                  0.52068076745794533711d0
      iwe=iwe+1
      weighta( 10, 23,  2)=                  0.68391575983998709187d0
      iwe=iwe+1
      weighta( 11, 23,  2)=                  0.51237170505972473578d0
      iwe=iwe+1
      weighta( 12, 23,  2)=                  0.33252192302593180928d0
      iwe=iwe+1
      weighta( 13, 23,  2)=                 -0.57519089562625602685d0
      iwe=iwe+1
      weighta( 14, 23,  2)=                  0.21385804872067512572d0
      iwe=iwe+1
      weighta( 15, 23,  2)=                  0.39308637868641138624d0
      iwe=iwe+1
      weighta( 16, 23,  2)=                  0.52427140225177004673d0
      iwe=iwe+1
      weighta( 17, 23,  2)=                 -0.22029295510546201275d0
      iwe=iwe+1
      biasa( 23,  2)=                 -0.13206999026303173350d0
      iwe=iwe+1
      weighta(  1, 24,  2)=                  0.23369896864678996184d0
      iwe=iwe+1
      weighta(  2, 24,  2)=                  0.66108044798810750020d0
      iwe=iwe+1
      weighta(  3, 24,  2)=                 -0.84892258758165872745d0
      iwe=iwe+1
      weighta(  4, 24,  2)=                  1.02349113515434120281d0
      iwe=iwe+1
      weighta(  5, 24,  2)=                 -0.42295921663890712061d0
      iwe=iwe+1
      weighta(  6, 24,  2)=                  0.58104522213396359032d0
      iwe=iwe+1
      weighta(  7, 24,  2)=                  0.23115128061814343985d0
      iwe=iwe+1
      weighta(  8, 24,  2)=                 -1.67917037470335084315d0
      iwe=iwe+1
      weighta(  9, 24,  2)=                  0.68158107079948926366d0
      iwe=iwe+1
      weighta( 10, 24,  2)=                 -0.07288271864201550931d0
      iwe=iwe+1
      weighta( 11, 24,  2)=                  0.29547516487542974106d0
      iwe=iwe+1
      weighta( 12, 24,  2)=                  0.44448910571801875102d0
      iwe=iwe+1
      weighta( 13, 24,  2)=                 -0.06060425950757242913d0
      iwe=iwe+1
      weighta( 14, 24,  2)=                  0.55468592980017816796d0
      iwe=iwe+1
      weighta( 15, 24,  2)=                  0.19695279658728562233d0
      iwe=iwe+1
      weighta( 16, 24,  2)=                 -0.89107702667279653497d0
      iwe=iwe+1
      weighta( 17, 24,  2)=                  0.33678079050120524052d0
      iwe=iwe+1
      biasa( 24,  2)=                  0.29848514467773618053d0
      iwe=iwe+1
      weighta(  1, 25,  2)=                 -0.45159179080878253387d0
      iwe=iwe+1
      weighta(  2, 25,  2)=                 -0.12381813518707748822d0
      iwe=iwe+1
      weighta(  3, 25,  2)=                 -0.02577530537181416462d0
      iwe=iwe+1
      weighta(  4, 25,  2)=                 -0.45166376118948375895d0
      iwe=iwe+1
      weighta(  5, 25,  2)=                 -0.17695854122341134196d0
      iwe=iwe+1
      weighta(  6, 25,  2)=                  0.84495150062349022591d0
      iwe=iwe+1
      weighta(  7, 25,  2)=                  0.34335311193903222948d0
      iwe=iwe+1
      weighta(  8, 25,  2)=                 -0.06440347649964271726d0
      iwe=iwe+1
      weighta(  9, 25,  2)=                  0.73091257629256456418d0
      iwe=iwe+1
      weighta( 10, 25,  2)=                 -0.32458919243918543662d0
      iwe=iwe+1
      weighta( 11, 25,  2)=                 -0.54432890923649146497d0
      iwe=iwe+1
      weighta( 12, 25,  2)=                 -0.57495954646666491694d0
      iwe=iwe+1
      weighta( 13, 25,  2)=                 -0.18846524079035203991d0
      iwe=iwe+1
      weighta( 14, 25,  2)=                 -0.31982039649404120363d0
      iwe=iwe+1
      weighta( 15, 25,  2)=                 -0.07602226622352133145d0
      iwe=iwe+1
      weighta( 16, 25,  2)=                 -0.84354488612644540346d0
      iwe=iwe+1
      weighta( 17, 25,  2)=                  0.50817719713347109245d0
      iwe=iwe+1
      biasa( 25,  2)=                  0.15821102986035040505d0
      iwe=iwe+1
      weighta(  1, 26,  2)=                 -0.03511975408539589477d0
      iwe=iwe+1
      weighta(  2, 26,  2)=                  0.12768291541267123845d0
      iwe=iwe+1
      weighta(  3, 26,  2)=                 -0.53586749252968868262d0
      iwe=iwe+1
      weighta(  4, 26,  2)=                 -0.45736516826247824996d0
      iwe=iwe+1
      weighta(  5, 26,  2)=                  0.66719799375226040983d0
      iwe=iwe+1
      weighta(  6, 26,  2)=                  0.94438138094628909514d0
      iwe=iwe+1
      weighta(  7, 26,  2)=                 -0.02490437907331354006d0
      iwe=iwe+1
      weighta(  8, 26,  2)=                  0.56644907939358402071d0
      iwe=iwe+1
      weighta(  9, 26,  2)=                 -0.42784378632958164346d0
      iwe=iwe+1
      weighta( 10, 26,  2)=                 -0.33952669362090598382d0
      iwe=iwe+1
      weighta( 11, 26,  2)=                 -0.24192189559339608018d0
      iwe=iwe+1
      weighta( 12, 26,  2)=                  0.36640013818861166817d0
      iwe=iwe+1
      weighta( 13, 26,  2)=                  0.61131771407241430882d0
      iwe=iwe+1
      weighta( 14, 26,  2)=                 -0.23016233246847003779d0
      iwe=iwe+1
      weighta( 15, 26,  2)=                  0.18599794350624360151d0
      iwe=iwe+1
      weighta( 16, 26,  2)=                  0.31903336064147430617d0
      iwe=iwe+1
      weighta( 17, 26,  2)=                  0.12919897119970910615d0
      iwe=iwe+1
      biasa( 26,  2)=                  0.28583719317597300336d0
      iwe=iwe+1
      weighta(  1, 27,  2)=                 -0.35226507180335364655d0
      iwe=iwe+1
      weighta(  2, 27,  2)=                  0.75949115876358763710d0
      iwe=iwe+1
      weighta(  3, 27,  2)=                 -0.55940986086985966530d0
      iwe=iwe+1
      weighta(  4, 27,  2)=                 -0.24353246206693404674d0
      iwe=iwe+1
      weighta(  5, 27,  2)=                  0.07399596690019173695d0
      iwe=iwe+1
      weighta(  6, 27,  2)=                 -0.75319298513883070623d0
      iwe=iwe+1
      weighta(  7, 27,  2)=                  0.09292469716932375001d0
      iwe=iwe+1
      weighta(  8, 27,  2)=                 -0.74781494065153419903d0
      iwe=iwe+1
      weighta(  9, 27,  2)=                 -0.39771232961824504182d0
      iwe=iwe+1
      weighta( 10, 27,  2)=                  0.52433037433039109132d0
      iwe=iwe+1
      weighta( 11, 27,  2)=                  0.31070397363771806720d0
      iwe=iwe+1
      weighta( 12, 27,  2)=                  0.90389602629247878252d0
      iwe=iwe+1
      weighta( 13, 27,  2)=                  0.15684579178507940256d0
      iwe=iwe+1
      weighta( 14, 27,  2)=                 -0.93138362420016085341d0
      iwe=iwe+1
      weighta( 15, 27,  2)=                  0.35875566338146586132d0
      iwe=iwe+1
      weighta( 16, 27,  2)=                  1.03943163036631536222d0
      iwe=iwe+1
      weighta( 17, 27,  2)=                  0.15335927636386487150d0
      iwe=iwe+1
      biasa( 27,  2)=                 -0.08059980608810257685d0
      iwe=iwe+1
      weighta(  1, 28,  2)=                 -0.90882127485089447827d0
      iwe=iwe+1
      weighta(  2, 28,  2)=                 -0.47243990658665835358d0
      iwe=iwe+1
      weighta(  3, 28,  2)=                 -0.33441009712573899204d0
      iwe=iwe+1
      weighta(  4, 28,  2)=                 -0.15863163976343819250d0
      iwe=iwe+1
      weighta(  5, 28,  2)=                 -0.12513704839796910284d0
      iwe=iwe+1
      weighta(  6, 28,  2)=                 -1.36262241913941761773d0
      iwe=iwe+1
      weighta(  7, 28,  2)=                 -0.45719960840772877475d0
      iwe=iwe+1
      weighta(  8, 28,  2)=                  1.19395167206341223931d0
      iwe=iwe+1
      weighta(  9, 28,  2)=                  0.07178829711577089379d0
      iwe=iwe+1
      weighta( 10, 28,  2)=                 -1.48502615327296316750d0
      iwe=iwe+1
      weighta( 11, 28,  2)=                 -0.50051465819728746531d0
      iwe=iwe+1
      weighta( 12, 28,  2)=                 -0.37721191984738000613d0
      iwe=iwe+1
      weighta( 13, 28,  2)=                 -0.14043028975438270889d0
      iwe=iwe+1
      weighta( 14, 28,  2)=                  1.33644766645339374556d0
      iwe=iwe+1
      weighta( 15, 28,  2)=                  0.60117954542257800998d0
      iwe=iwe+1
      weighta( 16, 28,  2)=                  0.35218772437745443638d0
      iwe=iwe+1
      weighta( 17, 28,  2)=                  0.65201266357010456698d0
      iwe=iwe+1
      biasa( 28,  2)=                 -0.19333894570424484116d0
      iwe=iwe+1
      weighta(  1, 29,  2)=                 -0.14181151798463365044d0
      iwe=iwe+1
      weighta(  2, 29,  2)=                  0.48730210176825022872d0
      iwe=iwe+1
      weighta(  3, 29,  2)=                  0.81295417124365498829d0
      iwe=iwe+1
      weighta(  4, 29,  2)=                 -0.60008426709139939259d0
      iwe=iwe+1
      weighta(  5, 29,  2)=                 -0.35886929121584765223d0
      iwe=iwe+1
      weighta(  6, 29,  2)=                 -0.10892190697999964977d0
      iwe=iwe+1
      weighta(  7, 29,  2)=                  0.57864037518924438253d0
      iwe=iwe+1
      weighta(  8, 29,  2)=                  0.73618581368017976807d0
      iwe=iwe+1
      weighta(  9, 29,  2)=                 -0.14229189894075378042d0
      iwe=iwe+1
      weighta( 10, 29,  2)=                 -0.59618151704827071491d0
      iwe=iwe+1
      weighta( 11, 29,  2)=                  0.51168926752703425276d0
      iwe=iwe+1
      weighta( 12, 29,  2)=                 -0.22351285745012078321d0
      iwe=iwe+1
      weighta( 13, 29,  2)=                 -0.79846220906873022205d0
      iwe=iwe+1
      weighta( 14, 29,  2)=                 -0.31766516679899037268d0
      iwe=iwe+1
      weighta( 15, 29,  2)=                 -0.50240309865726340277d0
      iwe=iwe+1
      weighta( 16, 29,  2)=                  0.42171518786666328804d0
      iwe=iwe+1
      weighta( 17, 29,  2)=                  0.51033553190333647009d0
      iwe=iwe+1
      biasa( 29,  2)=                 -0.10734907684070568723d0
      iwe=iwe+1
      weighta(  1, 30,  2)=                  0.50205157633815766793d0
      iwe=iwe+1
      weighta(  2, 30,  2)=                  0.53510506964965331989d0
      iwe=iwe+1
      weighta(  3, 30,  2)=                  0.13160380442031568982d0
      iwe=iwe+1
      weighta(  4, 30,  2)=                 -0.44428262428704595743d0
      iwe=iwe+1
      weighta(  5, 30,  2)=                  0.00543966485315864300d0
      iwe=iwe+1
      weighta(  6, 30,  2)=                  0.81684829609683407003d0
      iwe=iwe+1
      weighta(  7, 30,  2)=                  0.12097139430684630823d0
      iwe=iwe+1
      weighta(  8, 30,  2)=                 -0.14747382827107821668d0
      iwe=iwe+1
      weighta(  9, 30,  2)=                 -0.51167965422937833342d0
      iwe=iwe+1
      weighta( 10, 30,  2)=                 -0.67959582616183178416d0
      iwe=iwe+1
      weighta( 11, 30,  2)=                 -0.54640170130245513391d0
      iwe=iwe+1
      weighta( 12, 30,  2)=                 -0.90083398895016519869d0
      iwe=iwe+1
      weighta( 13, 30,  2)=                 -0.88206650221199800477d0
      iwe=iwe+1
      weighta( 14, 30,  2)=                  0.14956646834370443400d0
      iwe=iwe+1
      weighta( 15, 30,  2)=                 -0.08997893185717875664d0
      iwe=iwe+1
      weighta( 16, 30,  2)=                 -0.30240199366122605396d0
      iwe=iwe+1
      weighta( 17, 30,  2)=                  0.03715011209093528610d0
      iwe=iwe+1
      biasa( 30,  2)=                  0.35368866094957795987d0
      iwe=iwe+1
      weighta(  1, 31,  2)=                  0.11365487336213227210d0
      iwe=iwe+1
      weighta(  2, 31,  2)=                 -0.29742328413048074731d0
      iwe=iwe+1
      weighta(  3, 31,  2)=                  0.46923607915307657956d0
      iwe=iwe+1
      weighta(  4, 31,  2)=                  0.21204407133236952143d0
      iwe=iwe+1
      weighta(  5, 31,  2)=                 -0.24247776138981672056d0
      iwe=iwe+1
      weighta(  6, 31,  2)=                  0.21611381565418258388d0
      iwe=iwe+1
      weighta(  7, 31,  2)=                  0.21293054104859412967d0
      iwe=iwe+1
      weighta(  8, 31,  2)=                 -0.44191787250170516677d0
      iwe=iwe+1
      weighta(  9, 31,  2)=                  0.19224483127188399245d0
      iwe=iwe+1
      weighta( 10, 31,  2)=                 -0.31223001702223690534d0
      iwe=iwe+1
      weighta( 11, 31,  2)=                  0.55548074996778917800d0
      iwe=iwe+1
      weighta( 12, 31,  2)=                 -0.48018405751798132197d0
      iwe=iwe+1
      weighta( 13, 31,  2)=                  0.57951400376732298270d0
      iwe=iwe+1
      weighta( 14, 31,  2)=                 -0.49448683157155226553d0
      iwe=iwe+1
      weighta( 15, 31,  2)=                 -0.31694011964288282268d0
      iwe=iwe+1
      weighta( 16, 31,  2)=                 -0.47788280994264825674d0
      iwe=iwe+1
      weighta( 17, 31,  2)=                  0.62540402284441154457d0
      iwe=iwe+1
      biasa( 31,  2)=                  0.40249601133882939585d0
      iwe=iwe+1
      weighta(  1, 32,  2)=                  0.22183659673955913316d0
      iwe=iwe+1
      weighta(  2, 32,  2)=                 -0.42432269147012091626d0
      iwe=iwe+1
      weighta(  3, 32,  2)=                 -0.21524215991991782482d0
      iwe=iwe+1
      weighta(  4, 32,  2)=                  0.13595305379643185528d0
      iwe=iwe+1
      weighta(  5, 32,  2)=                 -0.28458380612849099034d0
      iwe=iwe+1
      weighta(  6, 32,  2)=                  0.58795984258055145055d0
      iwe=iwe+1
      weighta(  7, 32,  2)=                 -0.03625926556569610687d0
      iwe=iwe+1
      weighta(  8, 32,  2)=                 -0.18253262982846887863d0
      iwe=iwe+1
      weighta(  9, 32,  2)=                 -0.37094195209467462071d0
      iwe=iwe+1
      weighta( 10, 32,  2)=                  0.46068404109479299535d0
      iwe=iwe+1
      weighta( 11, 32,  2)=                 -0.32851585347647621616d0
      iwe=iwe+1
      weighta( 12, 32,  2)=                  0.11957665756322136130d0
      iwe=iwe+1
      weighta( 13, 32,  2)=                  0.27133144945476928012d0
      iwe=iwe+1
      weighta( 14, 32,  2)=                  0.33306998949597854676d0
      iwe=iwe+1
      weighta( 15, 32,  2)=                 -1.49599841146914513956d0
      iwe=iwe+1
      weighta( 16, 32,  2)=                  0.17591531270775581652d0
      iwe=iwe+1
      weighta( 17, 32,  2)=                 -0.43296614528109728104d0
      iwe=iwe+1
      biasa( 32,  2)=                  0.88133571571524882415d0
      iwe=iwe+1
      weighta(  1, 33,  2)=                  0.31579497731675176819d0
      iwe=iwe+1
      weighta(  2, 33,  2)=                 -0.01305259989739135026d0
      iwe=iwe+1
      weighta(  3, 33,  2)=                 -0.18635642242921809930d0
      iwe=iwe+1
      weighta(  4, 33,  2)=                 -1.20029381121417477729d0
      iwe=iwe+1
      weighta(  5, 33,  2)=                 -0.45061442559851644374d0
      iwe=iwe+1
      weighta(  6, 33,  2)=                  0.13830552945049598423d0
      iwe=iwe+1
      weighta(  7, 33,  2)=                  0.71686960763551488274d0
      iwe=iwe+1
      weighta(  8, 33,  2)=                  0.58139675355415376679d0
      iwe=iwe+1
      weighta(  9, 33,  2)=                  0.86254750190953133338d0
      iwe=iwe+1
      weighta( 10, 33,  2)=                  0.45939181979509874365d0
      iwe=iwe+1
      weighta( 11, 33,  2)=                 -0.58766006214617716452d0
      iwe=iwe+1
      weighta( 12, 33,  2)=                 -0.52945203986518041273d0
      iwe=iwe+1
      weighta( 13, 33,  2)=                 -0.13877611661357991402d0
      iwe=iwe+1
      weighta( 14, 33,  2)=                  0.66832497888925335161d0
      iwe=iwe+1
      weighta( 15, 33,  2)=                 -0.27906489699453762565d0
      iwe=iwe+1
      weighta( 16, 33,  2)=                 -0.20944603149135346265d0
      iwe=iwe+1
      weighta( 17, 33,  2)=                 -0.52527356340034569993d0
      iwe=iwe+1
      biasa( 33,  2)=                  0.16617336779664224067d0
      iwe=iwe+1
      weighta(  1, 34,  2)=                  0.05238373433328602502d0
      iwe=iwe+1
      weighta(  2, 34,  2)=                 -0.28924705680269940933d0
      iwe=iwe+1
      weighta(  3, 34,  2)=                  0.47282246266914401689d0
      iwe=iwe+1
      weighta(  4, 34,  2)=                  0.62516675517098752035d0
      iwe=iwe+1
      weighta(  5, 34,  2)=                 -0.72170027540326031623d0
      iwe=iwe+1
      weighta(  6, 34,  2)=                 -0.60211662624632245056d0
      iwe=iwe+1
      weighta(  7, 34,  2)=                  0.49007360457524284936d0
      iwe=iwe+1
      weighta(  8, 34,  2)=                  1.18220671334878413283d0
      iwe=iwe+1
      weighta(  9, 34,  2)=                 -0.97268235822193560569d0
      iwe=iwe+1
      weighta( 10, 34,  2)=                  1.44418309408430345364d0
      iwe=iwe+1
      weighta( 11, 34,  2)=                 -0.33987870873645759096d0
      iwe=iwe+1
      weighta( 12, 34,  2)=                  0.50982383314630386195d0
      iwe=iwe+1
      weighta( 13, 34,  2)=                  0.16115901727116763165d0
      iwe=iwe+1
      weighta( 14, 34,  2)=                  0.10394552469980852805d0
      iwe=iwe+1
      weighta( 15, 34,  2)=                 -0.51714270214940705195d0
      iwe=iwe+1
      weighta( 16, 34,  2)=                  0.59178538027386806686d0
      iwe=iwe+1
      weighta( 17, 34,  2)=                 -0.82185359584199635385d0
      iwe=iwe+1
      biasa( 34,  2)=                  1.24677349885459487489d0
      iwe=iwe+1
      weighta(  1, 35,  2)=                  0.55831546601675263730d0
      iwe=iwe+1
      weighta(  2, 35,  2)=                 -0.35365243696116932526d0
      iwe=iwe+1
      weighta(  3, 35,  2)=                 -0.57231265844613632421d0
      iwe=iwe+1
      weighta(  4, 35,  2)=                  0.68595039411751090874d0
      iwe=iwe+1
      weighta(  5, 35,  2)=                  0.60943160513986038840d0
      iwe=iwe+1
      weighta(  6, 35,  2)=                  0.49196929414252482671d0
      iwe=iwe+1
      weighta(  7, 35,  2)=                  0.63283781107706094105d0
      iwe=iwe+1
      weighta(  8, 35,  2)=                  0.07840077949092975895d0
      iwe=iwe+1
      weighta(  9, 35,  2)=                  0.83101638256697596407d0
      iwe=iwe+1
      weighta( 10, 35,  2)=                 -0.77410896451409749730d0
      iwe=iwe+1
      weighta( 11, 35,  2)=                 -0.47453306270873196748d0
      iwe=iwe+1
      weighta( 12, 35,  2)=                 -0.12567762295317047583d0
      iwe=iwe+1
      weighta( 13, 35,  2)=                 -0.13960890590045765824d0
      iwe=iwe+1
      weighta( 14, 35,  2)=                 -0.26572992467758876911d0
      iwe=iwe+1
      weighta( 15, 35,  2)=                  0.56808564748207268646d0
      iwe=iwe+1
      weighta( 16, 35,  2)=                 -0.83709197920486977385d0
      iwe=iwe+1
      weighta( 17, 35,  2)=                 -0.32014973649786493404d0
      iwe=iwe+1
      biasa( 35,  2)=                  0.54659349307222493408d0
      iwe=iwe+1
      weighta(  1, 36,  2)=                 -0.30041860241260959219d0
      iwe=iwe+1
      weighta(  2, 36,  2)=                 -0.49905890408151437621d0
      iwe=iwe+1
      weighta(  3, 36,  2)=                  0.41193808609661403120d0
      iwe=iwe+1
      weighta(  4, 36,  2)=                  0.46670865916242881832d0
      iwe=iwe+1
      weighta(  5, 36,  2)=                  0.79892285266508356045d0
      iwe=iwe+1
      weighta(  6, 36,  2)=                 -0.61767630807110229796d0
      iwe=iwe+1
      weighta(  7, 36,  2)=                 -0.51268517034771099450d0
      iwe=iwe+1
      weighta(  8, 36,  2)=                 -0.42235169088036894625d0
      iwe=iwe+1
      weighta(  9, 36,  2)=                 -0.70018579203942465927d0
      iwe=iwe+1
      weighta( 10, 36,  2)=                 -0.95718963047915384124d0
      iwe=iwe+1
      weighta( 11, 36,  2)=                  0.33737246329156028724d0
      iwe=iwe+1
      weighta( 12, 36,  2)=                  0.49633633903824803113d0
      iwe=iwe+1
      weighta( 13, 36,  2)=                 -0.30996990010436831220d0
      iwe=iwe+1
      weighta( 14, 36,  2)=                 -0.70121853970360636943d0
      iwe=iwe+1
      weighta( 15, 36,  2)=                  0.67344328306864176259d0
      iwe=iwe+1
      weighta( 16, 36,  2)=                  1.32979064625753262696d0
      iwe=iwe+1
      weighta( 17, 36,  2)=                 -0.68007382914253500239d0
      iwe=iwe+1
      biasa( 36,  2)=                 -0.99539255607887966448d0
      iwe=iwe+1
      weighta(  1, 37,  2)=                  0.37305235276349940632d0
      iwe=iwe+1
      weighta(  2, 37,  2)=                 -0.18032950435153144442d0
      iwe=iwe+1
      weighta(  3, 37,  2)=                  0.72834055369272321379d0
      iwe=iwe+1
      weighta(  4, 37,  2)=                  0.51588312924650536750d0
      iwe=iwe+1
      weighta(  5, 37,  2)=                 -0.04639915821705192095d0
      iwe=iwe+1
      weighta(  6, 37,  2)=                 -0.31922212679798478430d0
      iwe=iwe+1
      weighta(  7, 37,  2)=                 -0.44393472068364941974d0
      iwe=iwe+1
      weighta(  8, 37,  2)=                  1.00259013153613518732d0
      iwe=iwe+1
      weighta(  9, 37,  2)=                  0.27451274325553870481d0
      iwe=iwe+1
      weighta( 10, 37,  2)=                  0.43776389462029102750d0
      iwe=iwe+1
      weighta( 11, 37,  2)=                  0.03014127270235768957d0
      iwe=iwe+1
      weighta( 12, 37,  2)=                  0.46390100575182902087d0
      iwe=iwe+1
      weighta( 13, 37,  2)=                  0.97159930588658061090d0
      iwe=iwe+1
      weighta( 14, 37,  2)=                 -0.04366006948912894148d0
      iwe=iwe+1
      weighta( 15, 37,  2)=                 -0.22736493331470639112d0
      iwe=iwe+1
      weighta( 16, 37,  2)=                 -0.27832516364713233425d0
      iwe=iwe+1
      weighta( 17, 37,  2)=                 -0.52792834427072421466d0
      iwe=iwe+1
      biasa( 37,  2)=                  0.98740913606117231005d0
      iwe=iwe+1
      weighta(  1, 38,  2)=                 -0.10555624221696914555d0
      iwe=iwe+1
      weighta(  2, 38,  2)=                  0.53877252205740155944d0
      iwe=iwe+1
      weighta(  3, 38,  2)=                  0.55876473148358296594d0
      iwe=iwe+1
      weighta(  4, 38,  2)=                 -0.00818817879693450879d0
      iwe=iwe+1
      weighta(  5, 38,  2)=                  0.86043679426146757461d0
      iwe=iwe+1
      weighta(  6, 38,  2)=                  0.12985862733165734473d0
      iwe=iwe+1
      weighta(  7, 38,  2)=                  0.44923576200333026343d0
      iwe=iwe+1
      weighta(  8, 38,  2)=                 -0.04327022042717861700d0
      iwe=iwe+1
      weighta(  9, 38,  2)=                 -1.15087719409387201353d0
      iwe=iwe+1
      weighta( 10, 38,  2)=                 -0.79579480489392517839d0
      iwe=iwe+1
      weighta( 11, 38,  2)=                  0.60635677925987740977d0
      iwe=iwe+1
      weighta( 12, 38,  2)=                 -0.08688570849839187538d0
      iwe=iwe+1
      weighta( 13, 38,  2)=                 -0.26991630611411115970d0
      iwe=iwe+1
      weighta( 14, 38,  2)=                 -0.68120572750659147410d0
      iwe=iwe+1
      weighta( 15, 38,  2)=                 -0.10525183776753715970d0
      iwe=iwe+1
      weighta( 16, 38,  2)=                 -0.56296009965751026005d0
      iwe=iwe+1
      weighta( 17, 38,  2)=                  0.28846576437284565664d0
      iwe=iwe+1
      biasa( 38,  2)=                 -0.93113802192454475648d0
      iwe=iwe+1
      weighta(  1, 39,  2)=                  0.43558492557602934703d0
      iwe=iwe+1
      weighta(  2, 39,  2)=                 -0.55883356108430426445d0
      iwe=iwe+1
      weighta(  3, 39,  2)=                  0.78333129387009370337d0
      iwe=iwe+1
      weighta(  4, 39,  2)=                  0.53792670867224134934d0
      iwe=iwe+1
      weighta(  5, 39,  2)=                 -0.14395077346832640952d0
      iwe=iwe+1
      weighta(  6, 39,  2)=                 -1.25868783423847374614d0
      iwe=iwe+1
      weighta(  7, 39,  2)=                  0.35502979842485665740d0
      iwe=iwe+1
      weighta(  8, 39,  2)=                  0.65286382995629821391d0
      iwe=iwe+1
      weighta(  9, 39,  2)=                 -0.24797567400613423905d0
      iwe=iwe+1
      weighta( 10, 39,  2)=                 -0.64757275384493806492d0
      iwe=iwe+1
      weighta( 11, 39,  2)=                  0.64878721506062320135d0
      iwe=iwe+1
      weighta( 12, 39,  2)=                  0.05846149063413783736d0
      iwe=iwe+1
      weighta( 13, 39,  2)=                  0.58007320434583076185d0
      iwe=iwe+1
      weighta( 14, 39,  2)=                 -0.23794567494082008441d0
      iwe=iwe+1
      weighta( 15, 39,  2)=                  0.66709232770536042167d0
      iwe=iwe+1
      weighta( 16, 39,  2)=                  0.61695177544392310054d0
      iwe=iwe+1
      weighta( 17, 39,  2)=                 -0.74455618162545900152d0
      iwe=iwe+1
      biasa( 39,  2)=                  0.93193711151732994136d0
      iwe=iwe+1
      weighta(  1, 40,  2)=                 -0.55398974255981781045d0
      iwe=iwe+1
      weighta(  2, 40,  2)=                  0.53568764916790634345d0
      iwe=iwe+1
      weighta(  3, 40,  2)=                 -0.32961033597006378359d0
      iwe=iwe+1
      weighta(  4, 40,  2)=                 -1.13439281367689726032d0
      iwe=iwe+1
      weighta(  5, 40,  2)=                  0.47459588804250546490d0
      iwe=iwe+1
      weighta(  6, 40,  2)=                  0.59980497549457290063d0
      iwe=iwe+1
      weighta(  7, 40,  2)=                  0.73898923172048613939d0
      iwe=iwe+1
      weighta(  8, 40,  2)=                  0.50334105843104015587d0
      iwe=iwe+1
      weighta(  9, 40,  2)=                  0.35335211269725957939d0
      iwe=iwe+1
      weighta( 10, 40,  2)=                 -0.28159160663186622031d0
      iwe=iwe+1
      weighta( 11, 40,  2)=                  0.40758288683503107741d0
      iwe=iwe+1
      weighta( 12, 40,  2)=                 -0.41265138345522112129d0
      iwe=iwe+1
      weighta( 13, 40,  2)=                 -0.48073292237857734310d0
      iwe=iwe+1
      weighta( 14, 40,  2)=                  0.09678540808494716374d0
      iwe=iwe+1
      weighta( 15, 40,  2)=                  0.20478647021221654811d0
      iwe=iwe+1
      weighta( 16, 40,  2)=                 -0.17045134918961832304d0
      iwe=iwe+1
      weighta( 17, 40,  2)=                 -0.73025190625733327199d0
      iwe=iwe+1
      biasa( 40,  2)=                 -1.13705753603330972368d0
      iwe=iwe+1
      weighta(  1, 41,  2)=                  0.31593133674608697703d0
      iwe=iwe+1
      weighta(  2, 41,  2)=                  0.27652367377287317973d0
      iwe=iwe+1
      weighta(  3, 41,  2)=                 -0.50656480836288075853d0
      iwe=iwe+1
      weighta(  4, 41,  2)=                  0.23288763581933763502d0
      iwe=iwe+1
      weighta(  5, 41,  2)=                 -0.56835969676255027050d0
      iwe=iwe+1
      weighta(  6, 41,  2)=                 -1.03557083446319064812d0
      iwe=iwe+1
      weighta(  7, 41,  2)=                 -0.25757396252224240563d0
      iwe=iwe+1
      weighta(  8, 41,  2)=                  0.80511849082289621560d0
      iwe=iwe+1
      weighta(  9, 41,  2)=                 -0.52690831391549075580d0
      iwe=iwe+1
      weighta( 10, 41,  2)=                 -0.73171354365985474821d0
      iwe=iwe+1
      weighta( 11, 41,  2)=                  0.19530556196018059034d0
      iwe=iwe+1
      weighta( 12, 41,  2)=                 -0.31182556480082551653d0
      iwe=iwe+1
      weighta( 13, 41,  2)=                  0.30433877554025284828d0
      iwe=iwe+1
      weighta( 14, 41,  2)=                 -0.22791739665644047963d0
      iwe=iwe+1
      weighta( 15, 41,  2)=                  0.97370590591111960688d0
      iwe=iwe+1
      weighta( 16, 41,  2)=                  0.88152086618008473895d0
      iwe=iwe+1
      weighta( 17, 41,  2)=                 -0.07002791388343053425d0
      iwe=iwe+1
      biasa( 41,  2)=                  0.69867328057571764788d0
      iwe=iwe+1
      weighta(  1, 42,  2)=                 -0.59941759260633287187d0
      iwe=iwe+1
      weighta(  2, 42,  2)=                 -0.39456612165330040565d0
      iwe=iwe+1
      weighta(  3, 42,  2)=                  0.17472478500954669034d0
      iwe=iwe+1
      weighta(  4, 42,  2)=                 -0.08403875634055650579d0
      iwe=iwe+1
      weighta(  5, 42,  2)=                 -0.34234255168565064231d0
      iwe=iwe+1
      weighta(  6, 42,  2)=                  0.78359931650715286544d0
      iwe=iwe+1
      weighta(  7, 42,  2)=                 -0.56138672536077260933d0
      iwe=iwe+1
      weighta(  8, 42,  2)=                 -0.41401677807211362259d0
      iwe=iwe+1
      weighta(  9, 42,  2)=                 -0.95928723150553507626d0
      iwe=iwe+1
      weighta( 10, 42,  2)=                  0.05561108810863665125d0
      iwe=iwe+1
      weighta( 11, 42,  2)=                  0.24129317507851505420d0
      iwe=iwe+1
      weighta( 12, 42,  2)=                  0.98752504220877335150d0
      iwe=iwe+1
      weighta( 13, 42,  2)=                  0.08367299206595088523d0
      iwe=iwe+1
      weighta( 14, 42,  2)=                 -0.18158141450432596642d0
      iwe=iwe+1
      weighta( 15, 42,  2)=                 -0.10398102953554984318d0
      iwe=iwe+1
      weighta( 16, 42,  2)=                  0.59758662128983153217d0
      iwe=iwe+1
      weighta( 17, 42,  2)=                 -0.89254869347997167761d0
      iwe=iwe+1
      biasa( 42,  2)=                 -1.64850660666316506386d0
      iwe=iwe+1
      weighta(  1, 43,  2)=                 -0.61228730578235424087d0
      iwe=iwe+1
      weighta(  2, 43,  2)=                 -0.11749139317496305746d0
      iwe=iwe+1
      weighta(  3, 43,  2)=                  1.10061799087819478515d0
      iwe=iwe+1
      weighta(  4, 43,  2)=                 -0.03123678984976012429d0
      iwe=iwe+1
      weighta(  5, 43,  2)=                 -0.30009942083488405640d0
      iwe=iwe+1
      weighta(  6, 43,  2)=                  1.13129634854383476217d0
      iwe=iwe+1
      weighta(  7, 43,  2)=                 -0.46342001089669460079d0
      iwe=iwe+1
      weighta(  8, 43,  2)=                  0.88706722827281103694d0
      iwe=iwe+1
      weighta(  9, 43,  2)=                  0.69504922181723705066d0
      iwe=iwe+1
      weighta( 10, 43,  2)=                 -0.58736859804726904155d0
      iwe=iwe+1
      weighta( 11, 43,  2)=                  0.08636859716093882311d0
      iwe=iwe+1
      weighta( 12, 43,  2)=                  0.44329126604655721966d0
      iwe=iwe+1
      weighta( 13, 43,  2)=                 -0.57934470709941454647d0
      iwe=iwe+1
      weighta( 14, 43,  2)=                 -0.52534754304411379611d0
      iwe=iwe+1
      weighta( 15, 43,  2)=                 -0.09812516511817345743d0
      iwe=iwe+1
      weighta( 16, 43,  2)=                 -0.77179929634240573844d0
      iwe=iwe+1
      weighta( 17, 43,  2)=                 -0.13897600766494264124d0
      iwe=iwe+1
      biasa( 43,  2)=                 -1.26342638741709767380d0
      iwe=iwe+1
      weighta(  1, 44,  2)=                  0.37325927269747410930d0
      iwe=iwe+1
      weighta(  2, 44,  2)=                  0.01222773895378881891d0
      iwe=iwe+1
      weighta(  3, 44,  2)=                 -0.26886297692571009543d0
      iwe=iwe+1
      weighta(  4, 44,  2)=                  0.06350653035321521256d0
      iwe=iwe+1
      weighta(  5, 44,  2)=                  0.72180519027243394969d0
      iwe=iwe+1
      weighta(  6, 44,  2)=                  0.86291982548325485425d0
      iwe=iwe+1
      weighta(  7, 44,  2)=                  1.26149132592817658782d0
      iwe=iwe+1
      weighta(  8, 44,  2)=                  0.34083004412394662941d0
      iwe=iwe+1
      weighta(  9, 44,  2)=                  0.00962890165374729115d0
      iwe=iwe+1
      weighta( 10, 44,  2)=                  0.19337380179990368290d0
      iwe=iwe+1
      weighta( 11, 44,  2)=                  0.48521078473102874362d0
      iwe=iwe+1
      weighta( 12, 44,  2)=                  0.28388275902817616814d0
      iwe=iwe+1
      weighta( 13, 44,  2)=                 -0.99649725221505081052d0
      iwe=iwe+1
      weighta( 14, 44,  2)=                  0.16450162299655612941d0
      iwe=iwe+1
      weighta( 15, 44,  2)=                 -0.21501108906954080613d0
      iwe=iwe+1
      weighta( 16, 44,  2)=                 -0.01962081725982703362d0
      iwe=iwe+1
      weighta( 17, 44,  2)=                  0.12108204031238682663d0
      iwe=iwe+1
      biasa( 44,  2)=                  1.58329249778507419322d0
      iwe=iwe+1
      weighta(  1, 45,  2)=                 -0.99423622854461146670d0
      iwe=iwe+1
      weighta(  2, 45,  2)=                 -0.37324526179946942994d0
      iwe=iwe+1
      weighta(  3, 45,  2)=                  0.22918511379562855890d0
      iwe=iwe+1
      weighta(  4, 45,  2)=                 -1.07250980929884365267d0
      iwe=iwe+1
      weighta(  5, 45,  2)=                 -0.99193719772509736377d0
      iwe=iwe+1
      weighta(  6, 45,  2)=                  0.58635540238693462101d0
      iwe=iwe+1
      weighta(  7, 45,  2)=                  0.06238852840771194619d0
      iwe=iwe+1
      weighta(  8, 45,  2)=                  0.88795229531158026415d0
      iwe=iwe+1
      weighta(  9, 45,  2)=                 -0.16191864955998719333d0
      iwe=iwe+1
      weighta( 10, 45,  2)=                 -0.04295390983812648333d0
      iwe=iwe+1
      weighta( 11, 45,  2)=                 -0.93757755166230416499d0
      iwe=iwe+1
      weighta( 12, 45,  2)=                  0.20046486477347522093d0
      iwe=iwe+1
      weighta( 13, 45,  2)=                 -0.05981373912531560977d0
      iwe=iwe+1
      weighta( 14, 45,  2)=                  0.13582269012002171071d0
      iwe=iwe+1
      weighta( 15, 45,  2)=                  0.01866014988971887931d0
      iwe=iwe+1
      weighta( 16, 45,  2)=                  0.59571191959657032733d0
      iwe=iwe+1
      weighta( 17, 45,  2)=                  0.48269954585693736204d0
      iwe=iwe+1
      biasa( 45,  2)=                 -1.77937470301677946871d0
      iwe=iwe+1
      weighta(  1, 46,  2)=                 -0.32601535915239615582d0
      iwe=iwe+1
      weighta(  2, 46,  2)=                  0.26588845220176071660d0
      iwe=iwe+1
      weighta(  3, 46,  2)=                  0.23651123524112491192d0
      iwe=iwe+1
      weighta(  4, 46,  2)=                 -1.12849561218433525056d0
      iwe=iwe+1
      weighta(  5, 46,  2)=                  0.25013434659920452674d0
      iwe=iwe+1
      weighta(  6, 46,  2)=                 -0.04315377203357007724d0
      iwe=iwe+1
      weighta(  7, 46,  2)=                  0.25657105624990456105d0
      iwe=iwe+1
      weighta(  8, 46,  2)=                 -0.68218982670878702823d0
      iwe=iwe+1
      weighta(  9, 46,  2)=                  0.35895795614096920323d0
      iwe=iwe+1
      weighta( 10, 46,  2)=                 -0.71878187062786869088d0
      iwe=iwe+1
      weighta( 11, 46,  2)=                  0.56427834862427805884d0
      iwe=iwe+1
      weighta( 12, 46,  2)=                  0.08692515441929443698d0
      iwe=iwe+1
      weighta( 13, 46,  2)=                 -0.56759214782484956885d0
      iwe=iwe+1
      weighta( 14, 46,  2)=                 -0.27890549395531027965d0
      iwe=iwe+1
      weighta( 15, 46,  2)=                 -0.16899791907717698347d0
      iwe=iwe+1
      weighta( 16, 46,  2)=                 -0.57582815713953949821d0
      iwe=iwe+1
      weighta( 17, 46,  2)=                 -0.13879567198690784258d0
      iwe=iwe+1
      biasa( 46,  2)=                 -1.64728224875621243051d0
      iwe=iwe+1
      weighta(  1, 47,  2)=                 -0.27903303653770222814d0
      iwe=iwe+1
      weighta(  2, 47,  2)=                  0.94006073887825458701d0
      iwe=iwe+1
      weighta(  3, 47,  2)=                 -0.88402282460787495744d0
      iwe=iwe+1
      weighta(  4, 47,  2)=                  0.55398793201567853028d0
      iwe=iwe+1
      weighta(  5, 47,  2)=                  0.76132053323937698419d0
      iwe=iwe+1
      weighta(  6, 47,  2)=                  1.31878183321560338292d0
      iwe=iwe+1
      weighta(  7, 47,  2)=                  0.29451640838887638285d0
      iwe=iwe+1
      weighta(  8, 47,  2)=                 -0.22617963212156941277d0
      iwe=iwe+1
      weighta(  9, 47,  2)=                  0.58881031258902805092d0
      iwe=iwe+1
      weighta( 10, 47,  2)=                 -0.29566614118282008583d0
      iwe=iwe+1
      weighta( 11, 47,  2)=                 -0.05006312295533320300d0
      iwe=iwe+1
      weighta( 12, 47,  2)=                  0.27619831479175976918d0
      iwe=iwe+1
      weighta( 13, 47,  2)=                  0.58111893553899163223d0
      iwe=iwe+1
      weighta( 14, 47,  2)=                 -0.43565565902446456992d0
      iwe=iwe+1
      weighta( 15, 47,  2)=                 -0.81646523433097106803d0
      iwe=iwe+1
      weighta( 16, 47,  2)=                 -0.76575356217218459864d0
      iwe=iwe+1
      weighta( 17, 47,  2)=                 -0.37169924381696156646d0
      iwe=iwe+1
      biasa( 47,  2)=                 -1.73394146705576268630d0
      iwe=iwe+1
      weighta(  1, 48,  2)=                 -0.34601941277958120358d0
      iwe=iwe+1
      weighta(  2, 48,  2)=                 -0.96384365056639265124d0
      iwe=iwe+1
      weighta(  3, 48,  2)=                  1.08526814968030782538d0
      iwe=iwe+1
      weighta(  4, 48,  2)=                 -0.63164169014750159992d0
      iwe=iwe+1
      weighta(  5, 48,  2)=                 -0.38799291972348076696d0
      iwe=iwe+1
      weighta(  6, 48,  2)=                 -1.02334545878432869870d0
      iwe=iwe+1
      weighta(  7, 48,  2)=                 -0.53193858112232983437d0
      iwe=iwe+1
      weighta(  8, 48,  2)=                  1.17767485447623099226d0
      iwe=iwe+1
      weighta(  9, 48,  2)=                  0.52531786546186443054d0
      iwe=iwe+1
      weighta( 10, 48,  2)=                  0.16985509356609440612d0
      iwe=iwe+1
      weighta( 11, 48,  2)=                  0.98007051309880233170d0
      iwe=iwe+1
      weighta( 12, 48,  2)=                  0.08917116909159329696d0
      iwe=iwe+1
      weighta( 13, 48,  2)=                 -0.63528958076616148798d0
      iwe=iwe+1
      weighta( 14, 48,  2)=                 -0.82410509949981469724d0
      iwe=iwe+1
      weighta( 15, 48,  2)=                  0.10492629425562849388d0
      iwe=iwe+1
      weighta( 16, 48,  2)=                 -0.41335106556042511272d0
      iwe=iwe+1
      weighta( 17, 48,  2)=                 -0.33269710247491440791d0
      iwe=iwe+1
      biasa( 48,  2)=                 -1.71288542672277621648d0
      iwe=iwe+1
      weighta(  1, 49,  2)=                 -0.27183583680375927871d0
      iwe=iwe+1
      weighta(  2, 49,  2)=                 -0.12077587628768911288d0
      iwe=iwe+1
      weighta(  3, 49,  2)=                  0.01362767374869530181d0
      iwe=iwe+1
      weighta(  4, 49,  2)=                  0.87380326559257937014d0
      iwe=iwe+1
      weighta(  5, 49,  2)=                 -0.35736701799598491469d0
      iwe=iwe+1
      weighta(  6, 49,  2)=                 -0.74046644869632571861d0
      iwe=iwe+1
      weighta(  7, 49,  2)=                  0.35181504176944417006d0
      iwe=iwe+1
      weighta(  8, 49,  2)=                  0.00707106925364140403d0
      iwe=iwe+1
      weighta(  9, 49,  2)=                  0.07585860685115147772d0
      iwe=iwe+1
      weighta( 10, 49,  2)=                 -0.40562992050157409274d0
      iwe=iwe+1
      weighta( 11, 49,  2)=                  0.61053883984096146698d0
      iwe=iwe+1
      weighta( 12, 49,  2)=                 -0.18173387239631033641d0
      iwe=iwe+1
      weighta( 13, 49,  2)=                 -0.61790294993636485366d0
      iwe=iwe+1
      weighta( 14, 49,  2)=                 -0.25470340260598189897d0
      iwe=iwe+1
      weighta( 15, 49,  2)=                 -0.00192861902151938080d0
      iwe=iwe+1
      weighta( 16, 49,  2)=                 -0.73121426553680668459d0
      iwe=iwe+1
      weighta( 17, 49,  2)=                  0.58339713620604027877d0
      iwe=iwe+1
      biasa( 49,  2)=                 -1.45277576508602423999d0
      iwe=iwe+1
      weighta(  1, 50,  2)=                 -0.78570303378056638444d0
      iwe=iwe+1
      weighta(  2, 50,  2)=                  0.35560633293532967203d0
      iwe=iwe+1
      weighta(  3, 50,  2)=                  0.88220307393630881254d0
      iwe=iwe+1
      weighta(  4, 50,  2)=                 -0.62289949165048386082d0
      iwe=iwe+1
      weighta(  5, 50,  2)=                 -0.26812865573962446630d0
      iwe=iwe+1
      weighta(  6, 50,  2)=                  0.54210817666375776813d0
      iwe=iwe+1
      weighta(  7, 50,  2)=                  0.00746679981455582176d0
      iwe=iwe+1
      weighta(  8, 50,  2)=                 -0.42875658546251987913d0
      iwe=iwe+1
      weighta(  9, 50,  2)=                 -0.54813644181895604390d0
      iwe=iwe+1
      weighta( 10, 50,  2)=                  0.74225043648433375321d0
      iwe=iwe+1
      weighta( 11, 50,  2)=                 -0.18424575857054883987d0
      iwe=iwe+1
      weighta( 12, 50,  2)=                 -0.60039856701303206954d0
      iwe=iwe+1
      weighta( 13, 50,  2)=                 -0.93124112195480746035d0
      iwe=iwe+1
      weighta( 14, 50,  2)=                 -0.15794552567674077781d0
      iwe=iwe+1
      weighta( 15, 50,  2)=                  0.35270601068513918186d0
      iwe=iwe+1
      weighta( 16, 50,  2)=                  0.66561383593265099901d0
      iwe=iwe+1
      weighta( 17, 50,  2)=                  0.75931455674353498519d0
      iwe=iwe+1
      biasa( 50,  2)=                 -1.67349780838749206957d0
      iwe=iwe+1
      weighta(  1,  1,  3)=                 -0.15082789085284997732d0
      iwe=iwe+1
      weighta(  2,  1,  3)=                  0.00683890911272883300d0
      iwe=iwe+1
      weighta(  3,  1,  3)=                 -0.28727422274742642205d0
      iwe=iwe+1
      weighta(  4,  1,  3)=                 -0.34202366099049924530d0
      iwe=iwe+1
      weighta(  5,  1,  3)=                  0.05765992597436936373d0
      iwe=iwe+1
      weighta(  6,  1,  3)=                 -0.28970343914130070040d0
      iwe=iwe+1
      weighta(  7,  1,  3)=                 -0.12848435743482006233d0
      iwe=iwe+1
      weighta(  8,  1,  3)=                  0.28875850447498174756d0
      iwe=iwe+1
      weighta(  9,  1,  3)=                 -0.35710675685870019169d0
      iwe=iwe+1
      weighta( 10,  1,  3)=                  0.37998382176112410757d0
      iwe=iwe+1
      weighta( 11,  1,  3)=                 -0.28236031693030438916d0
      iwe=iwe+1
      weighta( 12,  1,  3)=                  0.27296179906284945282d0
      iwe=iwe+1
      weighta( 13,  1,  3)=                  0.31294507743297811375d0
      iwe=iwe+1
      weighta( 14,  1,  3)=                  0.19511210330363884524d0
      iwe=iwe+1
      weighta( 15,  1,  3)=                 -0.16247810811181351287d0
      iwe=iwe+1
      weighta( 16,  1,  3)=                  0.01008012725725973384d0
      iwe=iwe+1
      weighta( 17,  1,  3)=                  0.39556576296875317622d0
      iwe=iwe+1
      weighta( 18,  1,  3)=                 -0.24637039876152586060d0
      iwe=iwe+1
      weighta( 19,  1,  3)=                  0.09654624214910959012d0
      iwe=iwe+1
      weighta( 20,  1,  3)=                 -0.27108760435020878843d0
      iwe=iwe+1
      weighta( 21,  1,  3)=                 -0.14596792778760619980d0
      iwe=iwe+1
      weighta( 22,  1,  3)=                 -0.39827063103361615148d0
      iwe=iwe+1
      weighta( 23,  1,  3)=                  0.15646869027625112669d0
      iwe=iwe+1
      weighta( 24,  1,  3)=                 -0.03028228113328729557d0
      iwe=iwe+1
      weighta( 25,  1,  3)=                 -0.25421004384514989116d0
      iwe=iwe+1
      weighta( 26,  1,  3)=                 -0.13734722852201883270d0
      iwe=iwe+1
      weighta( 27,  1,  3)=                  0.08689379491577892134d0
      iwe=iwe+1
      weighta( 28,  1,  3)=                  0.15554793467908248350d0
      iwe=iwe+1
      weighta( 29,  1,  3)=                  0.29789765656646555181d0
      iwe=iwe+1
      weighta( 30,  1,  3)=                  0.24229781824331084183d0
      iwe=iwe+1
      weighta( 31,  1,  3)=                 -0.31025421851830398134d0
      iwe=iwe+1
      weighta( 32,  1,  3)=                  0.17229280657215442774d0
      iwe=iwe+1
      weighta( 33,  1,  3)=                 -0.17311247441257229807d0
      iwe=iwe+1
      weighta( 34,  1,  3)=                  0.06674996170549551966d0
      iwe=iwe+1
      weighta( 35,  1,  3)=                 -0.21078469889386380887d0
      iwe=iwe+1
      weighta( 36,  1,  3)=                  0.04044037419879918660d0
      iwe=iwe+1
      weighta( 37,  1,  3)=                 -0.15265842180018299179d0
      iwe=iwe+1
      weighta( 38,  1,  3)=                 -0.14795595475581266309d0
      iwe=iwe+1
      weighta( 39,  1,  3)=                 -0.28618601401995713562d0
      iwe=iwe+1
      weighta( 40,  1,  3)=                 -0.03020878849484136264d0
      iwe=iwe+1
      weighta( 41,  1,  3)=                  0.17536800606366484412d0
      iwe=iwe+1
      weighta( 42,  1,  3)=                  0.03059125936750637861d0
      iwe=iwe+1
      weighta( 43,  1,  3)=                 -0.02725447613182353096d0
      iwe=iwe+1
      weighta( 44,  1,  3)=                 -0.06821356742425206676d0
      iwe=iwe+1
      weighta( 45,  1,  3)=                 -0.00113388602883687318d0
      iwe=iwe+1
      weighta( 46,  1,  3)=                 -0.06733647973613139659d0
      iwe=iwe+1
      weighta( 47,  1,  3)=                  0.32837284861819115989d0
      iwe=iwe+1
      weighta( 48,  1,  3)=                  0.11797083503238206537d0
      iwe=iwe+1
      weighta( 49,  1,  3)=                 -0.25581530180278361231d0
      iwe=iwe+1
      weighta( 50,  1,  3)=                 -0.27298868776789159130d0
      iwe=iwe+1
      biasa(  1,  3)=                  1.56154688445583444967d0
      iwe=iwe+1
      weighta(  1,  2,  3)=                  0.53373079915130483553d0
      iwe=iwe+1
      weighta(  2,  2,  3)=                  0.21507761751267828743d0
      iwe=iwe+1
      weighta(  3,  2,  3)=                  0.31790178376787608938d0
      iwe=iwe+1
      weighta(  4,  2,  3)=                 -0.33285680584064208931d0
      iwe=iwe+1
      weighta(  5,  2,  3)=                 -0.11436711747390794491d0
      iwe=iwe+1
      weighta(  6,  2,  3)=                 -0.34554453831570047795d0
      iwe=iwe+1
      weighta(  7,  2,  3)=                  0.06022975271126924934d0
      iwe=iwe+1
      weighta(  8,  2,  3)=                 -0.23868325295067135960d0
      iwe=iwe+1
      weighta(  9,  2,  3)=                 -0.12916548724581297658d0
      iwe=iwe+1
      weighta( 10,  2,  3)=                  0.13158198586581107414d0
      iwe=iwe+1
      weighta( 11,  2,  3)=                 -0.12181317078922937469d0
      iwe=iwe+1
      weighta( 12,  2,  3)=                  0.49852002269291278980d0
      iwe=iwe+1
      weighta( 13,  2,  3)=                 -0.32654335349850099890d0
      iwe=iwe+1
      weighta( 14,  2,  3)=                 -0.06056105520086470934d0
      iwe=iwe+1
      weighta( 15,  2,  3)=                  0.16917428263823000578d0
      iwe=iwe+1
      weighta( 16,  2,  3)=                 -0.23405734104623687752d0
      iwe=iwe+1
      weighta( 17,  2,  3)=                  0.01340454423273915001d0
      iwe=iwe+1
      weighta( 18,  2,  3)=                 -0.12394531637444923533d0
      iwe=iwe+1
      weighta( 19,  2,  3)=                  0.04050656056749799006d0
      iwe=iwe+1
      weighta( 20,  2,  3)=                  0.25039763052997232595d0
      iwe=iwe+1
      weighta( 21,  2,  3)=                 -0.05148847386665635073d0
      iwe=iwe+1
      weighta( 22,  2,  3)=                  0.20965315310047225039d0
      iwe=iwe+1
      weighta( 23,  2,  3)=                  0.17189939813192484097d0
      iwe=iwe+1
      weighta( 24,  2,  3)=                 -0.01963560699338526630d0
      iwe=iwe+1
      weighta( 25,  2,  3)=                 -0.05371799367276530041d0
      iwe=iwe+1
      weighta( 26,  2,  3)=                  0.24851412457381116816d0
      iwe=iwe+1
      weighta( 27,  2,  3)=                 -0.00624140300497339363d0
      iwe=iwe+1
      weighta( 28,  2,  3)=                  0.66594387389229292573d0
      iwe=iwe+1
      weighta( 29,  2,  3)=                  0.68931898252830703377d0
      iwe=iwe+1
      weighta( 30,  2,  3)=                 -0.16647023722443587967d0
      iwe=iwe+1
      weighta( 31,  2,  3)=                  0.23614385640137444677d0
      iwe=iwe+1
      weighta( 32,  2,  3)=                 -0.18783749149750400553d0
      iwe=iwe+1
      weighta( 33,  2,  3)=                  0.05210320517879744873d0
      iwe=iwe+1
      weighta( 34,  2,  3)=                  0.28420272855951544955d0
      iwe=iwe+1
      weighta( 35,  2,  3)=                  0.18821494247508208097d0
      iwe=iwe+1
      weighta( 36,  2,  3)=                  0.49566776078339985778d0
      iwe=iwe+1
      weighta( 37,  2,  3)=                 -0.09717639971064254145d0
      iwe=iwe+1
      weighta( 38,  2,  3)=                  0.64926893876153235485d0
      iwe=iwe+1
      weighta( 39,  2,  3)=                  0.46050836388039129154d0
      iwe=iwe+1
      weighta( 40,  2,  3)=                  0.36837475261975449747d0
      iwe=iwe+1
      weighta( 41,  2,  3)=                  0.08843018902898772127d0
      iwe=iwe+1
      weighta( 42,  2,  3)=                  0.27913951825362443016d0
      iwe=iwe+1
      weighta( 43,  2,  3)=                 -0.49756945229135157716d0
      iwe=iwe+1
      weighta( 44,  2,  3)=                  0.21380688866816924265d0
      iwe=iwe+1
      weighta( 45,  2,  3)=                 -0.34137911712770957484d0
      iwe=iwe+1
      weighta( 46,  2,  3)=                 -0.45418710556606506357d0
      iwe=iwe+1
      weighta( 47,  2,  3)=                  0.26036514631494406258d0
      iwe=iwe+1
      weighta( 48,  2,  3)=                  0.42959656278365998539d0
      iwe=iwe+1
      weighta( 49,  2,  3)=                 -0.06380986351334631823d0
      iwe=iwe+1
      weighta( 50,  2,  3)=                 -0.09357671355736163488d0
      iwe=iwe+1
      biasa(  2,  3)=                  1.56155071637216491531d0
      iwe=iwe+1
      weighta(  1,  3,  3)=                 -0.25483306044918130340d0
      iwe=iwe+1
      weighta(  2,  3,  3)=                 -0.03049742155342200292d0
      iwe=iwe+1
      weighta(  3,  3,  3)=                 -0.10852327304666647967d0
      iwe=iwe+1
      weighta(  4,  3,  3)=                  0.05729383010390105835d0
      iwe=iwe+1
      weighta(  5,  3,  3)=                  0.19058807897593074698d0
      iwe=iwe+1
      weighta(  6,  3,  3)=                 -0.39245861634933132400d0
      iwe=iwe+1
      weighta(  7,  3,  3)=                  0.32830367940026411455d0
      iwe=iwe+1
      weighta(  8,  3,  3)=                  0.23373543473501803835d0
      iwe=iwe+1
      weighta(  9,  3,  3)=                 -0.23828482478731860539d0
      iwe=iwe+1
      weighta( 10,  3,  3)=                 -0.25637557111653980213d0
      iwe=iwe+1
      weighta( 11,  3,  3)=                  0.14882009328318618335d0
      iwe=iwe+1
      weighta( 12,  3,  3)=                  0.21004502009263278928d0
      iwe=iwe+1
      weighta( 13,  3,  3)=                  0.14729871916922127051d0
      iwe=iwe+1
      weighta( 14,  3,  3)=                  0.19008769246255544094d0
      iwe=iwe+1
      weighta( 15,  3,  3)=                 -0.05282861586094578232d0
      iwe=iwe+1
      weighta( 16,  3,  3)=                  0.28064403997527331835d0
      iwe=iwe+1
      weighta( 17,  3,  3)=                 -0.19430269888170442760d0
      iwe=iwe+1
      weighta( 18,  3,  3)=                  0.21846712700325995882d0
      iwe=iwe+1
      weighta( 19,  3,  3)=                 -0.14272757603202648746d0
      iwe=iwe+1
      weighta( 20,  3,  3)=                 -0.18609754234076680834d0
      iwe=iwe+1
      weighta( 21,  3,  3)=                  0.18930132821255676867d0
      iwe=iwe+1
      weighta( 22,  3,  3)=                 -0.12051068628122706128d0
      iwe=iwe+1
      weighta( 23,  3,  3)=                  0.15593206305583265370d0
      iwe=iwe+1
      weighta( 24,  3,  3)=                 -0.20024429720939307398d0
      iwe=iwe+1
      weighta( 25,  3,  3)=                  0.17465041315115056864d0
      iwe=iwe+1
      weighta( 26,  3,  3)=                 -0.05550677241252426758d0
      iwe=iwe+1
      weighta( 27,  3,  3)=                  0.40842668432656298316d0
      iwe=iwe+1
      weighta( 28,  3,  3)=                  0.21638533097595979982d0
      iwe=iwe+1
      weighta( 29,  3,  3)=                  0.30818046289397998949d0
      iwe=iwe+1
      weighta( 30,  3,  3)=                  0.17121285915225897822d0
      iwe=iwe+1
      weighta( 31,  3,  3)=                 -0.15779271204911840543d0
      iwe=iwe+1
      weighta( 32,  3,  3)=                 -0.01678425886993788196d0
      iwe=iwe+1
      weighta( 33,  3,  3)=                 -0.03447649634216871928d0
      iwe=iwe+1
      weighta( 34,  3,  3)=                  0.51829220416423937845d0
      iwe=iwe+1
      weighta( 35,  3,  3)=                  0.15074470345884410927d0
      iwe=iwe+1
      weighta( 36,  3,  3)=                 -0.10616902102687512943d0
      iwe=iwe+1
      weighta( 37,  3,  3)=                  0.44127658623935517301d0
      iwe=iwe+1
      weighta( 38,  3,  3)=                 -0.30199589691322031859d0
      iwe=iwe+1
      weighta( 39,  3,  3)=                  0.24161178600810284678d0
      iwe=iwe+1
      weighta( 40,  3,  3)=                 -0.19482042870443219695d0
      iwe=iwe+1
      weighta( 41,  3,  3)=                 -0.17748188662444777663d0
      iwe=iwe+1
      weighta( 42,  3,  3)=                 -0.39606399724938445850d0
      iwe=iwe+1
      weighta( 43,  3,  3)=                  0.08634379046795750967d0
      iwe=iwe+1
      weighta( 44,  3,  3)=                  0.35935637226609873363d0
      iwe=iwe+1
      weighta( 45,  3,  3)=                  0.16865647405496658751d0
      iwe=iwe+1
      weighta( 46,  3,  3)=                 -0.20319679282259892061d0
      iwe=iwe+1
      weighta( 47,  3,  3)=                 -0.23297651520665149660d0
      iwe=iwe+1
      weighta( 48,  3,  3)=                  0.12668754226722447886d0
      iwe=iwe+1
      weighta( 49,  3,  3)=                  0.17880328805648684765d0
      iwe=iwe+1
      weighta( 50,  3,  3)=                  0.25710899086402216884d0
      iwe=iwe+1
      biasa(  3,  3)=                  1.42265634502435189823d0
      iwe=iwe+1
      weighta(  1,  4,  3)=                 -0.43284080774705807615d0
      iwe=iwe+1
      weighta(  2,  4,  3)=                  0.09370431306726381693d0
      iwe=iwe+1
      weighta(  3,  4,  3)=                 -0.19613022745206454278d0
      iwe=iwe+1
      weighta(  4,  4,  3)=                  0.37600013447903007924d0
      iwe=iwe+1
      weighta(  5,  4,  3)=                  0.40026243810595146799d0
      iwe=iwe+1
      weighta(  6,  4,  3)=                  0.33316690208835020304d0
      iwe=iwe+1
      weighta(  7,  4,  3)=                  0.25717643923164412723d0
      iwe=iwe+1
      weighta(  8,  4,  3)=                 -0.57521047304202144179d0
      iwe=iwe+1
      weighta(  9,  4,  3)=                 -0.12628780660172428396d0
      iwe=iwe+1
      weighta( 10,  4,  3)=                 -0.01410324502029451643d0
      iwe=iwe+1
      weighta( 11,  4,  3)=                 -0.03097679958722486179d0
      iwe=iwe+1
      weighta( 12,  4,  3)=                  0.03179318224538814353d0
      iwe=iwe+1
      weighta( 13,  4,  3)=                  0.42737339421607395407d0
      iwe=iwe+1
      weighta( 14,  4,  3)=                 -0.00970365929869832985d0
      iwe=iwe+1
      weighta( 15,  4,  3)=                 -0.38660494775110970656d0
      iwe=iwe+1
      weighta( 16,  4,  3)=                  0.52977231371026656248d0
      iwe=iwe+1
      weighta( 17,  4,  3)=                  0.19270777323752061316d0
      iwe=iwe+1
      weighta( 18,  4,  3)=                  0.13494667557555753423d0
      iwe=iwe+1
      weighta( 19,  4,  3)=                 -0.52865135528168527568d0
      iwe=iwe+1
      weighta( 20,  4,  3)=                 -0.30062395074862757749d0
      iwe=iwe+1
      weighta( 21,  4,  3)=                 -0.60336753276904198096d0
      iwe=iwe+1
      weighta( 22,  4,  3)=                 -0.38887327608423200020d0
      iwe=iwe+1
      weighta( 23,  4,  3)=                  0.30187925847586860595d0
      iwe=iwe+1
      weighta( 24,  4,  3)=                  0.42783084078023886354d0
      iwe=iwe+1
      weighta( 25,  4,  3)=                  0.00920914733432089475d0
      iwe=iwe+1
      weighta( 26,  4,  3)=                 -0.21908502790136763494d0
      iwe=iwe+1
      weighta( 27,  4,  3)=                  0.45021243237277053240d0
      iwe=iwe+1
      weighta( 28,  4,  3)=                  0.39707053654420776390d0
      iwe=iwe+1
      weighta( 29,  4,  3)=                  0.01139261988521164670d0
      iwe=iwe+1
      weighta( 30,  4,  3)=                 -0.13979633116323894604d0
      iwe=iwe+1
      weighta( 31,  4,  3)=                 -0.06895842028951017222d0
      iwe=iwe+1
      weighta( 32,  4,  3)=                  0.17713777174175299178d0
      iwe=iwe+1
      weighta( 33,  4,  3)=                  0.12533587423919320680d0
      iwe=iwe+1
      weighta( 34,  4,  3)=                  0.41695708994597741048d0
      iwe=iwe+1
      weighta( 35,  4,  3)=                 -0.08227323766342521660d0
      iwe=iwe+1
      weighta( 36,  4,  3)=                  0.66726635252825206024d0
      iwe=iwe+1
      weighta( 37,  4,  3)=                  0.19803580026448056040d0
      iwe=iwe+1
      weighta( 38,  4,  3)=                  0.05704374191305752739d0
      iwe=iwe+1
      weighta( 39,  4,  3)=                  0.87601541064837717965d0
      iwe=iwe+1
      weighta( 40,  4,  3)=                 -0.21625828675271810408d0
      iwe=iwe+1
      weighta( 41,  4,  3)=                  0.10804768443292844804d0
      iwe=iwe+1
      weighta( 42,  4,  3)=                  0.23970801135889108213d0
      iwe=iwe+1
      weighta( 43,  4,  3)=                 -0.08167564844137954749d0
      iwe=iwe+1
      weighta( 44,  4,  3)=                 -0.05901854104123393369d0
      iwe=iwe+1
      weighta( 45,  4,  3)=                 -0.07983103083139846123d0
      iwe=iwe+1
      weighta( 46,  4,  3)=                 -0.52952944680369218311d0
      iwe=iwe+1
      weighta( 47,  4,  3)=                 -0.61961247073782432793d0
      iwe=iwe+1
      weighta( 48,  4,  3)=                  0.08925048978672708855d0
      iwe=iwe+1
      weighta( 49,  4,  3)=                  0.07901443611414181445d0
      iwe=iwe+1
      weighta( 50,  4,  3)=                 -0.38556143835276779352d0
      iwe=iwe+1
      biasa(  4,  3)=                  1.32263820148479349648d0
      iwe=iwe+1
      weighta(  1,  5,  3)=                 -0.22688188848573298539d0
      iwe=iwe+1
      weighta(  2,  5,  3)=                  0.12137720486854272628d0
      iwe=iwe+1
      weighta(  3,  5,  3)=                 -0.33914570109652780738d0
      iwe=iwe+1
      weighta(  4,  5,  3)=                  0.25417856702276886427d0
      iwe=iwe+1
      weighta(  5,  5,  3)=                  0.19021336746489858616d0
      iwe=iwe+1
      weighta(  6,  5,  3)=                  0.17741889125226037449d0
      iwe=iwe+1
      weighta(  7,  5,  3)=                 -0.06555358935697522260d0
      iwe=iwe+1
      weighta(  8,  5,  3)=                  0.31657700678117145499d0
      iwe=iwe+1
      weighta(  9,  5,  3)=                  0.07475680855741421993d0
      iwe=iwe+1
      weighta( 10,  5,  3)=                  0.25030584435085595496d0
      iwe=iwe+1
      weighta( 11,  5,  3)=                 -0.12339873692576062980d0
      iwe=iwe+1
      weighta( 12,  5,  3)=                  0.37381861506259816963d0
      iwe=iwe+1
      weighta( 13,  5,  3)=                 -0.00883189054523291113d0
      iwe=iwe+1
      weighta( 14,  5,  3)=                 -0.06714403860963999437d0
      iwe=iwe+1
      weighta( 15,  5,  3)=                 -0.32832678386462377240d0
      iwe=iwe+1
      weighta( 16,  5,  3)=                 -0.06832594782059699112d0
      iwe=iwe+1
      weighta( 17,  5,  3)=                  0.24844662501842490476d0
      iwe=iwe+1
      weighta( 18,  5,  3)=                  0.18780679969306623978d0
      iwe=iwe+1
      weighta( 19,  5,  3)=                 -0.00223972532345268014d0
      iwe=iwe+1
      weighta( 20,  5,  3)=                 -0.00373821178745042167d0
      iwe=iwe+1
      weighta( 21,  5,  3)=                 -0.39410151360144757282d0
      iwe=iwe+1
      weighta( 22,  5,  3)=                 -0.24089692944838153599d0
      iwe=iwe+1
      weighta( 23,  5,  3)=                 -0.20920340462838840634d0
      iwe=iwe+1
      weighta( 24,  5,  3)=                  0.29676850155657158448d0
      iwe=iwe+1
      weighta( 25,  5,  3)=                  0.08042663268613799155d0
      iwe=iwe+1
      weighta( 26,  5,  3)=                 -0.16371515822698010090d0
      iwe=iwe+1
      weighta( 27,  5,  3)=                  0.27010447958061639673d0
      iwe=iwe+1
      weighta( 28,  5,  3)=                 -0.32979046980312332060d0
      iwe=iwe+1
      weighta( 29,  5,  3)=                  0.04909556027127635891d0
      iwe=iwe+1
      weighta( 30,  5,  3)=                 -0.36882434464897689841d0
      iwe=iwe+1
      weighta( 31,  5,  3)=                 -0.34925219634160109550d0
      iwe=iwe+1
      weighta( 32,  5,  3)=                  0.15460769376072824866d0
      iwe=iwe+1
      weighta( 33,  5,  3)=                  0.06304983338950297111d0
      iwe=iwe+1
      weighta( 34,  5,  3)=                  0.05337427985159449995d0
      iwe=iwe+1
      weighta( 35,  5,  3)=                  0.04896501787223567909d0
      iwe=iwe+1
      weighta( 36,  5,  3)=                  0.03691479082937734746d0
      iwe=iwe+1
      weighta( 37,  5,  3)=                 -0.30022776207970552909d0
      iwe=iwe+1
      weighta( 38,  5,  3)=                 -0.29780436529938697499d0
      iwe=iwe+1
      weighta( 39,  5,  3)=                  0.42541235368747992718d0
      iwe=iwe+1
      weighta( 40,  5,  3)=                 -0.12470564469574471622d0
      iwe=iwe+1
      weighta( 41,  5,  3)=                  0.25209813375401401991d0
      iwe=iwe+1
      weighta( 42,  5,  3)=                 -0.34960952472801487545d0
      iwe=iwe+1
      weighta( 43,  5,  3)=                 -0.05414342030689798385d0
      iwe=iwe+1
      weighta( 44,  5,  3)=                  0.17293766124883991342d0
      iwe=iwe+1
      weighta( 45,  5,  3)=                  0.30331553331547039809d0
      iwe=iwe+1
      weighta( 46,  5,  3)=                  0.07553312792225461147d0
      iwe=iwe+1
      weighta( 47,  5,  3)=                 -0.04837328284781001325d0
      iwe=iwe+1
      weighta( 48,  5,  3)=                 -0.11526659201466719906d0
      iwe=iwe+1
      weighta( 49,  5,  3)=                 -0.17353352850242687033d0
      iwe=iwe+1
      weighta( 50,  5,  3)=                  0.18809730181245915004d0
      iwe=iwe+1
      biasa(  5,  3)=                  1.34723218925746168750d0
      iwe=iwe+1
      weighta(  1,  6,  3)=                  0.34364321878719361614d0
      iwe=iwe+1
      weighta(  2,  6,  3)=                 -0.06303951370818113020d0
      iwe=iwe+1
      weighta(  3,  6,  3)=                 -0.26765141709277384674d0
      iwe=iwe+1
      weighta(  4,  6,  3)=                 -0.62453756603103105505d0
      iwe=iwe+1
      weighta(  5,  6,  3)=                  0.79952586012178272767d0
      iwe=iwe+1
      weighta(  6,  6,  3)=                 -1.30226012832839477262d0
      iwe=iwe+1
      weighta(  7,  6,  3)=                 -0.67846924240277428630d0
      iwe=iwe+1
      weighta(  8,  6,  3)=                  1.81900059943596659195d0
      iwe=iwe+1
      weighta(  9,  6,  3)=                 -0.34020943048426860456d0
      iwe=iwe+1
      weighta( 10,  6,  3)=                  1.13394196550979575733d0
      iwe=iwe+1
      weighta( 11,  6,  3)=                 -0.66110726739980696376d0
      iwe=iwe+1
      weighta( 12,  6,  3)=                  0.34900805827041642138d0
      iwe=iwe+1
      weighta( 13,  6,  3)=                  0.16741150227288936758d0
      iwe=iwe+1
      weighta( 14,  6,  3)=                 -0.43726889250365896800d0
      iwe=iwe+1
      weighta( 15,  6,  3)=                 -0.48874411626223651650d0
      iwe=iwe+1
      weighta( 16,  6,  3)=                  0.15805650464980161574d0
      iwe=iwe+1
      weighta( 17,  6,  3)=                  0.34651656336977698647d0
      iwe=iwe+1
      weighta( 18,  6,  3)=                  0.94948408640907744349d0
      iwe=iwe+1
      weighta( 19,  6,  3)=                 -0.86215917091948024442d0
      iwe=iwe+1
      weighta( 20,  6,  3)=                 -0.19544634334788218988d0
      iwe=iwe+1
      weighta( 21,  6,  3)=                 -1.00640718566871600892d0
      iwe=iwe+1
      weighta( 22,  6,  3)=                 -0.05589180215776186345d0
      iwe=iwe+1
      weighta( 23,  6,  3)=                  0.53910004511106757175d0
      iwe=iwe+1
      weighta( 24,  6,  3)=                  1.52778338640231048373d0
      iwe=iwe+1
      weighta( 25,  6,  3)=                  0.30429800732785056150d0
      iwe=iwe+1
      weighta( 26,  6,  3)=                 -0.14393589337903683889d0
      iwe=iwe+1
      weighta( 27,  6,  3)=                 -0.69946752982954152333d0
      iwe=iwe+1
      weighta( 28,  6,  3)=                 -0.15057913155764135471d0
      iwe=iwe+1
      weighta( 29,  6,  3)=                  0.06275495818236517809d0
      iwe=iwe+1
      weighta( 30,  6,  3)=                  0.13880832468766624022d0
      iwe=iwe+1
      weighta( 31,  6,  3)=                  0.22027301327393314367d0
      iwe=iwe+1
      weighta( 32,  6,  3)=                  0.11783476665624868784d0
      iwe=iwe+1
      weighta( 33,  6,  3)=                  0.69094700482342008563d0
      iwe=iwe+1
      weighta( 34,  6,  3)=                 -1.25211189714556025976d0
      iwe=iwe+1
      weighta( 35,  6,  3)=                  0.36900020044373094130d0
      iwe=iwe+1
      weighta( 36,  6,  3)=                 -0.58116377789364970230d0
      iwe=iwe+1
      weighta( 37,  6,  3)=                  0.03572020035860024034d0
      iwe=iwe+1
      weighta( 38,  6,  3)=                 -0.89673459742997740918d0
      iwe=iwe+1
      weighta( 39,  6,  3)=                 -0.30395909249525532303d0
      iwe=iwe+1
      weighta( 40,  6,  3)=                 -0.05333309136821819119d0
      iwe=iwe+1
      weighta( 41,  6,  3)=                 -0.00097571284162329503d0
      iwe=iwe+1
      weighta( 42,  6,  3)=                 -0.95053974562957987970d0
      iwe=iwe+1
      weighta( 43,  6,  3)=                  1.11638317180088986191d0
      iwe=iwe+1
      weighta( 44,  6,  3)=                 -0.50182602902028017322d0
      iwe=iwe+1
      weighta( 45,  6,  3)=                  0.61397961705428316659d0
      iwe=iwe+1
      weighta( 46,  6,  3)=                 -0.36393548860788227373d0
      iwe=iwe+1
      weighta( 47,  6,  3)=                  0.66849012762629023143d0
      iwe=iwe+1
      weighta( 48,  6,  3)=                  1.20879843336071490789d0
      iwe=iwe+1
      weighta( 49,  6,  3)=                 -0.09006906265940299583d0
      iwe=iwe+1
      weighta( 50,  6,  3)=                  0.61474080252422647064d0
      iwe=iwe+1
      biasa(  6,  3)=                  1.69910760062094556844d0
      iwe=iwe+1
      weighta(  1,  7,  3)=                 -0.01655928299638427525d0
      iwe=iwe+1
      weighta(  2,  7,  3)=                 -0.30521645396263857863d0
      iwe=iwe+1
      weighta(  3,  7,  3)=                  0.20001659555689715875d0
      iwe=iwe+1
      weighta(  4,  7,  3)=                 -0.00691339407859805494d0
      iwe=iwe+1
      weighta(  5,  7,  3)=                  0.14415717630883290168d0
      iwe=iwe+1
      weighta(  6,  7,  3)=                  0.04350925979579484820d0
      iwe=iwe+1
      weighta(  7,  7,  3)=                 -0.07075990749594221474d0
      iwe=iwe+1
      weighta(  8,  7,  3)=                 -0.17271778282606017885d0
      iwe=iwe+1
      weighta(  9,  7,  3)=                 -0.06968428412293638241d0
      iwe=iwe+1
      weighta( 10,  7,  3)=                  0.25165419570605784827d0
      iwe=iwe+1
      weighta( 11,  7,  3)=                  0.15957434419277846671d0
      iwe=iwe+1
      weighta( 12,  7,  3)=                 -0.27162165005793492689d0
      iwe=iwe+1
      weighta( 13,  7,  3)=                  0.29187483059346625014d0
      iwe=iwe+1
      weighta( 14,  7,  3)=                  0.19082856733348399492d0
      iwe=iwe+1
      weighta( 15,  7,  3)=                 -0.27388340472050193286d0
      iwe=iwe+1
      weighta( 16,  7,  3)=                  0.05843416633514351977d0
      iwe=iwe+1
      weighta( 17,  7,  3)=                 -0.27182317409913236972d0
      iwe=iwe+1
      weighta( 18,  7,  3)=                 -0.79987995598533889741d0
      iwe=iwe+1
      weighta( 19,  7,  3)=                 -0.45513240411416905351d0
      iwe=iwe+1
      weighta( 20,  7,  3)=                  0.03271843343679570887d0
      iwe=iwe+1
      weighta( 21,  7,  3)=                  0.43327156454792553619d0
      iwe=iwe+1
      weighta( 22,  7,  3)=                  0.61961086697956635483d0
      iwe=iwe+1
      weighta( 23,  7,  3)=                 -0.14309324195028105819d0
      iwe=iwe+1
      weighta( 24,  7,  3)=                  0.24560965539122817103d0
      iwe=iwe+1
      weighta( 25,  7,  3)=                 -0.42148664349214748359d0
      iwe=iwe+1
      weighta( 26,  7,  3)=                 -0.26668019220459748819d0
      iwe=iwe+1
      weighta( 27,  7,  3)=                  0.17475953499240068356d0
      iwe=iwe+1
      weighta( 28,  7,  3)=                  0.12295241640390530691d0
      iwe=iwe+1
      weighta( 29,  7,  3)=                 -0.36168869298940081736d0
      iwe=iwe+1
      weighta( 30,  7,  3)=                  0.01640889404556174214d0
      iwe=iwe+1
      weighta( 31,  7,  3)=                 -0.15718613014019239271d0
      iwe=iwe+1
      weighta( 32,  7,  3)=                  0.04596766087294345410d0
      iwe=iwe+1
      weighta( 33,  7,  3)=                  0.49485521571125112850d0
      iwe=iwe+1
      weighta( 34,  7,  3)=                 -0.05513868264339590736d0
      iwe=iwe+1
      weighta( 35,  7,  3)=                  0.20013145984788530130d0
      iwe=iwe+1
      weighta( 36,  7,  3)=                 -0.18627521925251713797d0
      iwe=iwe+1
      weighta( 37,  7,  3)=                 -0.24473329766169918398d0
      iwe=iwe+1
      weighta( 38,  7,  3)=                 -0.01591949505414370220d0
      iwe=iwe+1
      weighta( 39,  7,  3)=                 -0.30687786534137800887d0
      iwe=iwe+1
      weighta( 40,  7,  3)=                 -0.41484022974875373047d0
      iwe=iwe+1
      weighta( 41,  7,  3)=                 -0.13752732370175055343d0
      iwe=iwe+1
      weighta( 42,  7,  3)=                  0.12595935126886728672d0
      iwe=iwe+1
      weighta( 43,  7,  3)=                  0.32180040759639894077d0
      iwe=iwe+1
      weighta( 44,  7,  3)=                 -0.08692962649603028225d0
      iwe=iwe+1
      weighta( 45,  7,  3)=                  0.13232826477277406796d0
      iwe=iwe+1
      weighta( 46,  7,  3)=                  0.12831389412446816967d0
      iwe=iwe+1
      weighta( 47,  7,  3)=                 -0.00830406778714913585d0
      iwe=iwe+1
      weighta( 48,  7,  3)=                  0.17424840829070378789d0
      iwe=iwe+1
      weighta( 49,  7,  3)=                  0.39200405306554642060d0
      iwe=iwe+1
      weighta( 50,  7,  3)=                  0.01442694053887496816d0
      iwe=iwe+1
      biasa(  7,  3)=                 -1.20267251644998984794d0
      iwe=iwe+1
      weighta(  1,  8,  3)=                 -0.09214838737616160014d0
      iwe=iwe+1
      weighta(  2,  8,  3)=                  0.01603326497081131174d0
      iwe=iwe+1
      weighta(  3,  8,  3)=                  0.05647626275209094437d0
      iwe=iwe+1
      weighta(  4,  8,  3)=                 -0.45374778458729775332d0
      iwe=iwe+1
      weighta(  5,  8,  3)=                  0.07370198523389483169d0
      iwe=iwe+1
      weighta(  6,  8,  3)=                  0.28933929730340690600d0
      iwe=iwe+1
      weighta(  7,  8,  3)=                 -0.18071382285986775651d0
      iwe=iwe+1
      weighta(  8,  8,  3)=                 -0.38014448149165808166d0
      iwe=iwe+1
      weighta(  9,  8,  3)=                  0.41124228157987041676d0
      iwe=iwe+1
      weighta( 10,  8,  3)=                 -0.09316220148569510917d0
      iwe=iwe+1
      weighta( 11,  8,  3)=                 -0.05570541132773177556d0
      iwe=iwe+1
      weighta( 12,  8,  3)=                  0.25112743570305845475d0
      iwe=iwe+1
      weighta( 13,  8,  3)=                 -0.29760629637364521827d0
      iwe=iwe+1
      weighta( 14,  8,  3)=                  0.15789302183056860840d0
      iwe=iwe+1
      weighta( 15,  8,  3)=                  0.37720987872245670403d0
      iwe=iwe+1
      weighta( 16,  8,  3)=                  0.12747599636496823039d0
      iwe=iwe+1
      weighta( 17,  8,  3)=                 -0.01787371518420828587d0
      iwe=iwe+1
      weighta( 18,  8,  3)=                 -0.37252718338471318971d0
      iwe=iwe+1
      weighta( 19,  8,  3)=                 -0.53604486051781863321d0
      iwe=iwe+1
      weighta( 20,  8,  3)=                 -0.25086612223697263291d0
      iwe=iwe+1
      weighta( 21,  8,  3)=                  0.22036907165316829693d0
      iwe=iwe+1
      weighta( 22,  8,  3)=                  0.07489687570470207612d0
      iwe=iwe+1
      weighta( 23,  8,  3)=                  0.22779436013016549079d0
      iwe=iwe+1
      weighta( 24,  8,  3)=                 -0.19573492507701253929d0
      iwe=iwe+1
      weighta( 25,  8,  3)=                  0.12779255215613408159d0
      iwe=iwe+1
      weighta( 26,  8,  3)=                  0.28960547839288397487d0
      iwe=iwe+1
      weighta( 27,  8,  3)=                 -0.09404620631596738445d0
      iwe=iwe+1
      weighta( 28,  8,  3)=                  0.13687662352616666861d0
      iwe=iwe+1
      weighta( 29,  8,  3)=                  0.44243781043261498631d0
      iwe=iwe+1
      weighta( 30,  8,  3)=                 -0.09804954569723764446d0
      iwe=iwe+1
      weighta( 31,  8,  3)=                 -0.09718018647918376385d0
      iwe=iwe+1
      weighta( 32,  8,  3)=                  0.30555160253371232981d0
      iwe=iwe+1
      weighta( 33,  8,  3)=                 -0.21039665937136653451d0
      iwe=iwe+1
      weighta( 34,  8,  3)=                 -0.17490607077027914285d0
      iwe=iwe+1
      weighta( 35,  8,  3)=                  0.28284831482268535385d0
      iwe=iwe+1
      weighta( 36,  8,  3)=                  0.62648963670393453818d0
      iwe=iwe+1
      weighta( 37,  8,  3)=                 -0.01302528697930256663d0
      iwe=iwe+1
      weighta( 38,  8,  3)=                  0.83228314718282470075d0
      iwe=iwe+1
      weighta( 39,  8,  3)=                  0.00545974610805115279d0
      iwe=iwe+1
      weighta( 40,  8,  3)=                  0.10151316288783612807d0
      iwe=iwe+1
      weighta( 41,  8,  3)=                 -0.02054134155658928623d0
      iwe=iwe+1
      weighta( 42,  8,  3)=                 -0.28542666299192637203d0
      iwe=iwe+1
      weighta( 43,  8,  3)=                 -0.20309981280815928018d0
      iwe=iwe+1
      weighta( 44,  8,  3)=                 -0.00867312163713569381d0
      iwe=iwe+1
      weighta( 45,  8,  3)=                 -0.48436052741138524436d0
      iwe=iwe+1
      weighta( 46,  8,  3)=                 -0.05416643626866497752d0
      iwe=iwe+1
      weighta( 47,  8,  3)=                 -0.05311488477786036749d0
      iwe=iwe+1
      weighta( 48,  8,  3)=                  0.10466002914015493097d0
      iwe=iwe+1
      weighta( 49,  8,  3)=                  0.01318295961246810158d0
      iwe=iwe+1
      weighta( 50,  8,  3)=                  0.22892339754916524175d0
      iwe=iwe+1
      biasa(  8,  3)=                  1.42570887362909570761d0
      iwe=iwe+1
      weighta(  1,  9,  3)=                 -0.11440207587235728948d0
      iwe=iwe+1
      weighta(  2,  9,  3)=                  0.24003883978470058613d0
      iwe=iwe+1
      weighta(  3,  9,  3)=                  0.13031328385277912707d0
      iwe=iwe+1
      weighta(  4,  9,  3)=                  0.02398411333068628179d0
      iwe=iwe+1
      weighta(  5,  9,  3)=                  0.23645955780790955947d0
      iwe=iwe+1
      weighta(  6,  9,  3)=                 -0.19649161638453041534d0
      iwe=iwe+1
      weighta(  7,  9,  3)=                  0.17171560778359964972d0
      iwe=iwe+1
      weighta(  8,  9,  3)=                 -0.17935503575791689190d0
      iwe=iwe+1
      weighta(  9,  9,  3)=                 -0.24282459860147206920d0
      iwe=iwe+1
      weighta( 10,  9,  3)=                 -0.10517984159249947618d0
      iwe=iwe+1
      weighta( 11,  9,  3)=                 -0.39405884635508275915d0
      iwe=iwe+1
      weighta( 12,  9,  3)=                  0.48588608526339172045d0
      iwe=iwe+1
      weighta( 13,  9,  3)=                 -0.31429070450461527031d0
      iwe=iwe+1
      weighta( 14,  9,  3)=                  0.16514469226343270192d0
      iwe=iwe+1
      weighta( 15,  9,  3)=                  0.37925843429367994686d0
      iwe=iwe+1
      weighta( 16,  9,  3)=                 -0.30210232630795652575d0
      iwe=iwe+1
      weighta( 17,  9,  3)=                 -0.02251742495796929186d0
      iwe=iwe+1
      weighta( 18,  9,  3)=                 -0.14226911870707686925d0
      iwe=iwe+1
      weighta( 19,  9,  3)=                 -0.19984788752430099334d0
      iwe=iwe+1
      weighta( 20,  9,  3)=                  0.19594834986929213216d0
      iwe=iwe+1
      weighta( 21,  9,  3)=                 -0.20948754490413709628d0
      iwe=iwe+1
      weighta( 22,  9,  3)=                 -0.40585922596646567539d0
      iwe=iwe+1
      weighta( 23,  9,  3)=                 -0.09118503023830797083d0
      iwe=iwe+1
      weighta( 24,  9,  3)=                  0.09830361651402405587d0
      iwe=iwe+1
      weighta( 25,  9,  3)=                 -0.14964507358913586854d0
      iwe=iwe+1
      weighta( 26,  9,  3)=                  0.07222773299899844235d0
      iwe=iwe+1
      weighta( 27,  9,  3)=                  0.04108213589412394035d0
      iwe=iwe+1
      weighta( 28,  9,  3)=                  0.33984706183311685912d0
      iwe=iwe+1
      weighta( 29,  9,  3)=                 -0.06947501082092069624d0
      iwe=iwe+1
      weighta( 30,  9,  3)=                  0.28191079017451037281d0
      iwe=iwe+1
      weighta( 31,  9,  3)=                  0.40702754376096783595d0
      iwe=iwe+1
      weighta( 32,  9,  3)=                  0.28858147124429339714d0
      iwe=iwe+1
      weighta( 33,  9,  3)=                 -0.21256730120278125029d0
      iwe=iwe+1
      weighta( 34,  9,  3)=                  0.24973172987094430231d0
      iwe=iwe+1
      weighta( 35,  9,  3)=                 -0.24133435261503816127d0
      iwe=iwe+1
      weighta( 36,  9,  3)=                  0.06657280380645866358d0
      iwe=iwe+1
      weighta( 37,  9,  3)=                  0.43896990821266684835d0
      iwe=iwe+1
      weighta( 38,  9,  3)=                 -0.48454173714938447715d0
      iwe=iwe+1
      weighta( 39,  9,  3)=                  0.02968154627481901092d0
      iwe=iwe+1
      weighta( 40,  9,  3)=                 -0.62332781814868054582d0
      iwe=iwe+1
      weighta( 41,  9,  3)=                  0.25507586975623003367d0
      iwe=iwe+1
      weighta( 42,  9,  3)=                  0.09985080766889944948d0
      iwe=iwe+1
      weighta( 43,  9,  3)=                 -0.33712364211826850724d0
      iwe=iwe+1
      weighta( 44,  9,  3)=                  0.18351462608247393060d0
      iwe=iwe+1
      weighta( 45,  9,  3)=                 -0.17449377530455650875d0
      iwe=iwe+1
      weighta( 46,  9,  3)=                 -0.18824658355204165749d0
      iwe=iwe+1
      weighta( 47,  9,  3)=                 -0.03979411789009863060d0
      iwe=iwe+1
      weighta( 48,  9,  3)=                  0.16192661210175099407d0
      iwe=iwe+1
      weighta( 49,  9,  3)=                 -0.38392851635523783660d0
      iwe=iwe+1
      weighta( 50,  9,  3)=                  0.31124619256129931744d0
      iwe=iwe+1
      biasa(  9,  3)=                  1.25321148850537045227d0
      iwe=iwe+1
      weighta(  1, 10,  3)=                 -0.46493255238207081836d0
      iwe=iwe+1
      weighta(  2, 10,  3)=                  0.18912801261952202903d0
      iwe=iwe+1
      weighta(  3, 10,  3)=                  0.43756655634447827463d0
      iwe=iwe+1
      weighta(  4, 10,  3)=                  0.28556893976162139870d0
      iwe=iwe+1
      weighta(  5, 10,  3)=                 -0.63143982656343533577d0
      iwe=iwe+1
      weighta(  6, 10,  3)=                  0.40259697295516444493d0
      iwe=iwe+1
      weighta(  7, 10,  3)=                  0.49875753511584891564d0
      iwe=iwe+1
      weighta(  8, 10,  3)=                  0.43016052302220303405d0
      iwe=iwe+1
      weighta(  9, 10,  3)=                 -0.06197564177238799876d0
      iwe=iwe+1
      weighta( 10, 10,  3)=                 -0.28122539606102586740d0
      iwe=iwe+1
      weighta( 11, 10,  3)=                  0.35834655226444817044d0
      iwe=iwe+1
      weighta( 12, 10,  3)=                  0.00795876798978826377d0
      iwe=iwe+1
      weighta( 13, 10,  3)=                  0.06458941776863272310d0
      iwe=iwe+1
      weighta( 14, 10,  3)=                  0.00277833389464365648d0
      iwe=iwe+1
      weighta( 15, 10,  3)=                  0.11960657319042623803d0
      iwe=iwe+1
      weighta( 16, 10,  3)=                 -0.10349585804710868808d0
      iwe=iwe+1
      weighta( 17, 10,  3)=                  0.14528071623560656622d0
      iwe=iwe+1
      weighta( 18, 10,  3)=                 -0.35098864891373077191d0
      iwe=iwe+1
      weighta( 19, 10,  3)=                  0.35390176081473939673d0
      iwe=iwe+1
      weighta( 20, 10,  3)=                  0.14402839724078958517d0
      iwe=iwe+1
      weighta( 21, 10,  3)=                  0.19452423849409142265d0
      iwe=iwe+1
      weighta( 22, 10,  3)=                  0.18389030411692677824d0
      iwe=iwe+1
      weighta( 23, 10,  3)=                 -0.00247159143267839179d0
      iwe=iwe+1
      weighta( 24, 10,  3)=                 -0.12807246280402406757d0
      iwe=iwe+1
      weighta( 25, 10,  3)=                 -0.10271071920746648043d0
      iwe=iwe+1
      weighta( 26, 10,  3)=                  0.26098045137946607186d0
      iwe=iwe+1
      weighta( 27, 10,  3)=                 -0.08377450274991747603d0
      iwe=iwe+1
      weighta( 28, 10,  3)=                 -0.46097074021942102684d0
      iwe=iwe+1
      weighta( 29, 10,  3)=                 -0.05323239150834038758d0
      iwe=iwe+1
      weighta( 30, 10,  3)=                 -0.34123343240461684323d0
      iwe=iwe+1
      weighta( 31, 10,  3)=                  0.05327258722348099385d0
      iwe=iwe+1
      weighta( 32, 10,  3)=                  0.26452904768654122991d0
      iwe=iwe+1
      weighta( 33, 10,  3)=                 -0.08793257525114918371d0
      iwe=iwe+1
      weighta( 34, 10,  3)=                 -0.08772976005443736125d0
      iwe=iwe+1
      weighta( 35, 10,  3)=                 -0.36256602777182372899d0
      iwe=iwe+1
      weighta( 36, 10,  3)=                 -0.54052017567821453170d0
      iwe=iwe+1
      weighta( 37, 10,  3)=                  0.29505731939418988752d0
      iwe=iwe+1
      weighta( 38, 10,  3)=                 -0.08400307728542023844d0
      iwe=iwe+1
      weighta( 39, 10,  3)=                 -0.29173515889320439376d0
      iwe=iwe+1
      weighta( 40, 10,  3)=                  0.08699722931903923484d0
      iwe=iwe+1
      weighta( 41, 10,  3)=                 -0.15442196208653696798d0
      iwe=iwe+1
      weighta( 42, 10,  3)=                  0.15953112261530749683d0
      iwe=iwe+1
      weighta( 43, 10,  3)=                 -0.40748711028029754866d0
      iwe=iwe+1
      weighta( 44, 10,  3)=                  0.16844514032873456055d0
      iwe=iwe+1
      weighta( 45, 10,  3)=                 -0.00338837601223814216d0
      iwe=iwe+1
      weighta( 46, 10,  3)=                  0.06776628656178285137d0
      iwe=iwe+1
      weighta( 47, 10,  3)=                 -0.32988656144773303991d0
      iwe=iwe+1
      weighta( 48, 10,  3)=                 -0.45053509085741755280d0
      iwe=iwe+1
      weighta( 49, 10,  3)=                  0.42216268077838442485d0
      iwe=iwe+1
      weighta( 50, 10,  3)=                  0.31723880624311706633d0
      iwe=iwe+1
      biasa( 10,  3)=                  1.13351684253527373869d0
      iwe=iwe+1
      weighta(  1, 11,  3)=                 -0.11820084128958119329d0
      iwe=iwe+1
      weighta(  2, 11,  3)=                 -0.01114433025408142520d0
      iwe=iwe+1
      weighta(  3, 11,  3)=                 -0.27347671294337760894d0
      iwe=iwe+1
      weighta(  4, 11,  3)=                 -0.27885982079743387718d0
      iwe=iwe+1
      weighta(  5, 11,  3)=                  0.39043111933641666544d0
      iwe=iwe+1
      weighta(  6, 11,  3)=                 -0.22162795637606022559d0
      iwe=iwe+1
      weighta(  7, 11,  3)=                  0.25615276860874441889d0
      iwe=iwe+1
      weighta(  8, 11,  3)=                  0.03770797160794275155d0
      iwe=iwe+1
      weighta(  9, 11,  3)=                 -0.25971757742264034441d0
      iwe=iwe+1
      weighta( 10, 11,  3)=                  0.22424805496789421144d0
      iwe=iwe+1
      weighta( 11, 11,  3)=                 -0.29942897308790167310d0
      iwe=iwe+1
      weighta( 12, 11,  3)=                  0.07785632355173352503d0
      iwe=iwe+1
      weighta( 13, 11,  3)=                  0.16978799915256093112d0
      iwe=iwe+1
      weighta( 14, 11,  3)=                 -0.09640083704210600235d0
      iwe=iwe+1
      weighta( 15, 11,  3)=                  0.13149290241191283202d0
      iwe=iwe+1
      weighta( 16, 11,  3)=                 -0.08170903197289466902d0
      iwe=iwe+1
      weighta( 17, 11,  3)=                 -0.53617627042060977960d0
      iwe=iwe+1
      weighta( 18, 11,  3)=                 -0.28656792485282767124d0
      iwe=iwe+1
      weighta( 19, 11,  3)=                  0.15658149456062842031d0
      iwe=iwe+1
      weighta( 20, 11,  3)=                 -0.42827858415895653232d0
      iwe=iwe+1
      weighta( 21, 11,  3)=                 -0.26495372606279893324d0
      iwe=iwe+1
      weighta( 22, 11,  3)=                 -0.04138471254378201653d0
      iwe=iwe+1
      weighta( 23, 11,  3)=                  0.04988092656308461964d0
      iwe=iwe+1
      weighta( 24, 11,  3)=                  0.13955403285153261672d0
      iwe=iwe+1
      weighta( 25, 11,  3)=                 -0.22391691735899130200d0
      iwe=iwe+1
      weighta( 26, 11,  3)=                  0.01714216069188484459d0
      iwe=iwe+1
      weighta( 27, 11,  3)=                 -0.01749837123222014457d0
      iwe=iwe+1
      weighta( 28, 11,  3)=                  0.07805696639148346216d0
      iwe=iwe+1
      weighta( 29, 11,  3)=                 -0.23617748537601765402d0
      iwe=iwe+1
      weighta( 30, 11,  3)=                  0.13019366287491315748d0
      iwe=iwe+1
      weighta( 31, 11,  3)=                  0.43571810826219375956d0
      iwe=iwe+1
      weighta( 32, 11,  3)=                 -0.27231333966454740469d0
      iwe=iwe+1
      weighta( 33, 11,  3)=                  0.31281283011973348707d0
      iwe=iwe+1
      weighta( 34, 11,  3)=                 -0.27525982620278693913d0
      iwe=iwe+1
      weighta( 35, 11,  3)=                  0.18289359459203188840d0
      iwe=iwe+1
      weighta( 36, 11,  3)=                  0.42815815009856800222d0
      iwe=iwe+1
      weighta( 37, 11,  3)=                  0.40525991261440064140d0
      iwe=iwe+1
      weighta( 38, 11,  3)=                 -0.21841592567392104085d0
      iwe=iwe+1
      weighta( 39, 11,  3)=                 -0.21752545827881428209d0
      iwe=iwe+1
      weighta( 40, 11,  3)=                 -0.09489577830476000897d0
      iwe=iwe+1
      weighta( 41, 11,  3)=                 -0.37316041481561251780d0
      iwe=iwe+1
      weighta( 42, 11,  3)=                 -0.40339387229611367580d0
      iwe=iwe+1
      weighta( 43, 11,  3)=                  0.01193771026159252437d0
      iwe=iwe+1
      weighta( 44, 11,  3)=                 -0.28290913700208797366d0
      iwe=iwe+1
      weighta( 45, 11,  3)=                 -0.15310653022085524144d0
      iwe=iwe+1
      weighta( 46, 11,  3)=                 -0.16070405402536169781d0
      iwe=iwe+1
      weighta( 47, 11,  3)=                  0.11759807659237529742d0
      iwe=iwe+1
      weighta( 48, 11,  3)=                  0.44414960661654290242d0
      iwe=iwe+1
      weighta( 49, 11,  3)=                 -0.01420177067045118313d0
      iwe=iwe+1
      weighta( 50, 11,  3)=                 -0.29491270918504636223d0
      iwe=iwe+1
      biasa( 11,  3)=                  1.17202448934495118138d0
      iwe=iwe+1
      weighta(  1, 12,  3)=                 -0.26179706900380644852d0
      iwe=iwe+1
      weighta(  2, 12,  3)=                  0.11909641096807842275d0
      iwe=iwe+1
      weighta(  3, 12,  3)=                  0.14835322382764012938d0
      iwe=iwe+1
      weighta(  4, 12,  3)=                  0.24625841632526684899d0
      iwe=iwe+1
      weighta(  5, 12,  3)=                  0.43335114499477234151d0
      iwe=iwe+1
      weighta(  6, 12,  3)=                 -0.29548645530192318986d0
      iwe=iwe+1
      weighta(  7, 12,  3)=                 -0.33417439632659606819d0
      iwe=iwe+1
      weighta(  8, 12,  3)=                  0.31919808288688233944d0
      iwe=iwe+1
      weighta(  9, 12,  3)=                  0.25076463240564378365d0
      iwe=iwe+1
      weighta( 10, 12,  3)=                  0.20795303732508613193d0
      iwe=iwe+1
      weighta( 11, 12,  3)=                 -0.09670199750323814347d0
      iwe=iwe+1
      weighta( 12, 12,  3)=                 -0.30516849242710214485d0
      iwe=iwe+1
      weighta( 13, 12,  3)=                  0.37363947554897430914d0
      iwe=iwe+1
      weighta( 14, 12,  3)=                 -0.31266047539506142128d0
      iwe=iwe+1
      weighta( 15, 12,  3)=                  0.07745580294063299231d0
      iwe=iwe+1
      weighta( 16, 12,  3)=                 -0.48013301904513794316d0
      iwe=iwe+1
      weighta( 17, 12,  3)=                 -0.04789324812222097577d0
      iwe=iwe+1
      weighta( 18, 12,  3)=                  0.00980525327356484948d0
      iwe=iwe+1
      weighta( 19, 12,  3)=                  0.09371958490644503870d0
      iwe=iwe+1
      weighta( 20, 12,  3)=                  0.58057262641223716937d0
      iwe=iwe+1
      weighta( 21, 12,  3)=                  0.05146144697191751965d0
      iwe=iwe+1
      weighta( 22, 12,  3)=                  0.18955558606091504892d0
      iwe=iwe+1
      weighta( 23, 12,  3)=                  0.12148896350974439096d0
      iwe=iwe+1
      weighta( 24, 12,  3)=                  0.23627498557187393002d0
      iwe=iwe+1
      weighta( 25, 12,  3)=                 -0.10210883509546078707d0
      iwe=iwe+1
      weighta( 26, 12,  3)=                 -0.29586444555438640158d0
      iwe=iwe+1
      weighta( 27, 12,  3)=                  0.33977954022059642103d0
      iwe=iwe+1
      weighta( 28, 12,  3)=                 -0.02868780650486929193d0
      iwe=iwe+1
      weighta( 29, 12,  3)=                  0.63000001867850641268d0
      iwe=iwe+1
      weighta( 30, 12,  3)=                  0.12585814768324601887d0
      iwe=iwe+1
      weighta( 31, 12,  3)=                 -0.10280285660910098988d0
      iwe=iwe+1
      weighta( 32, 12,  3)=                  0.39643818959268856128d0
      iwe=iwe+1
      weighta( 33, 12,  3)=                 -0.28426521684714833871d0
      iwe=iwe+1
      weighta( 34, 12,  3)=                 -0.20877844399939818332d0
      iwe=iwe+1
      weighta( 35, 12,  3)=                 -0.05731139179181916898d0
      iwe=iwe+1
      weighta( 36, 12,  3)=                  0.31963039836681361727d0
      iwe=iwe+1
      weighta( 37, 12,  3)=                 -0.46154257337205745193d0
      iwe=iwe+1
      weighta( 38, 12,  3)=                 -0.44457041198116964420d0
      iwe=iwe+1
      weighta( 39, 12,  3)=                 -0.10357251079767827717d0
      iwe=iwe+1
      weighta( 40, 12,  3)=                  0.40544828182687353557d0
      iwe=iwe+1
      weighta( 41, 12,  3)=                  0.25817590208332907853d0
      iwe=iwe+1
      weighta( 42, 12,  3)=                 -0.07530400923854217721d0
      iwe=iwe+1
      weighta( 43, 12,  3)=                  0.26697010766226969558d0
      iwe=iwe+1
      weighta( 44, 12,  3)=                  0.08862643278000327529d0
      iwe=iwe+1
      weighta( 45, 12,  3)=                 -0.05334296834374868679d0
      iwe=iwe+1
      weighta( 46, 12,  3)=                 -0.13641659950244006128d0
      iwe=iwe+1
      weighta( 47, 12,  3)=                  0.29539879555409631617d0
      iwe=iwe+1
      weighta( 48, 12,  3)=                 -0.26077064329788501862d0
      iwe=iwe+1
      weighta( 49, 12,  3)=                 -0.12172834914580177301d0
      iwe=iwe+1
      weighta( 50, 12,  3)=                  0.09227820992479215945d0
      iwe=iwe+1
      biasa( 12,  3)=                  1.05828633433333640923d0
      iwe=iwe+1
      weighta(  1, 13,  3)=                 -0.06917020755668151777d0
      iwe=iwe+1
      weighta(  2, 13,  3)=                 -0.03042340964566507197d0
      iwe=iwe+1
      weighta(  3, 13,  3)=                 -0.19375002402310134708d0
      iwe=iwe+1
      weighta(  4, 13,  3)=                 -0.34391109907621641995d0
      iwe=iwe+1
      weighta(  5, 13,  3)=                 -0.23901401173975878045d0
      iwe=iwe+1
      weighta(  6, 13,  3)=                 -0.04228100676183089990d0
      iwe=iwe+1
      weighta(  7, 13,  3)=                 -0.07787921149284929290d0
      iwe=iwe+1
      weighta(  8, 13,  3)=                  0.05758739024392733191d0
      iwe=iwe+1
      weighta(  9, 13,  3)=                  0.26006247337897936411d0
      iwe=iwe+1
      weighta( 10, 13,  3)=                  0.01844596334170893817d0
      iwe=iwe+1
      weighta( 11, 13,  3)=                 -0.67261632081482725098d0
      iwe=iwe+1
      weighta( 12, 13,  3)=                 -0.11709158945736114488d0
      iwe=iwe+1
      weighta( 13, 13,  3)=                 -0.37541288442426218319d0
      iwe=iwe+1
      weighta( 14, 13,  3)=                 -0.00706273065393345657d0
      iwe=iwe+1
      weighta( 15, 13,  3)=                  0.37669330349005714087d0
      iwe=iwe+1
      weighta( 16, 13,  3)=                  0.33347990522717413375d0
      iwe=iwe+1
      weighta( 17, 13,  3)=                  0.19333674634240041734d0
      iwe=iwe+1
      weighta( 18, 13,  3)=                 -0.37666793104635137857d0
      iwe=iwe+1
      weighta( 19, 13,  3)=                 -0.09312293414684094661d0
      iwe=iwe+1
      weighta( 20, 13,  3)=                  0.33313741162412302543d0
      iwe=iwe+1
      weighta( 21, 13,  3)=                 -0.28830237530637892185d0
      iwe=iwe+1
      weighta( 22, 13,  3)=                 -0.24534122896485466292d0
      iwe=iwe+1
      weighta( 23, 13,  3)=                  0.14251871205182001234d0
      iwe=iwe+1
      weighta( 24, 13,  3)=                  0.11156133889810267157d0
      iwe=iwe+1
      weighta( 25, 13,  3)=                 -0.27290909186705419875d0
      iwe=iwe+1
      weighta( 26, 13,  3)=                 -0.62019675271988883303d0
      iwe=iwe+1
      weighta( 27, 13,  3)=                  0.10414909232199980049d0
      iwe=iwe+1
      weighta( 28, 13,  3)=                  0.07471598259806272457d0
      iwe=iwe+1
      weighta( 29, 13,  3)=                 -0.35262867433586109200d0
      iwe=iwe+1
      weighta( 30, 13,  3)=                 -0.33947513539357798695d0
      iwe=iwe+1
      weighta( 31, 13,  3)=                  0.20017255914993767330d0
      iwe=iwe+1
      weighta( 32, 13,  3)=                 -0.20462693285249089481d0
      iwe=iwe+1
      weighta( 33, 13,  3)=                  0.26344887674932598864d0
      iwe=iwe+1
      weighta( 34, 13,  3)=                  0.05543530518188510836d0
      iwe=iwe+1
      weighta( 35, 13,  3)=                 -0.12248666726386997494d0
      iwe=iwe+1
      weighta( 36, 13,  3)=                  0.33144543805898390998d0
      iwe=iwe+1
      weighta( 37, 13,  3)=                  0.06571598914101550726d0
      iwe=iwe+1
      weighta( 38, 13,  3)=                  0.06828447655135964911d0
      iwe=iwe+1
      weighta( 39, 13,  3)=                 -0.26216237520745350187d0
      iwe=iwe+1
      weighta( 40, 13,  3)=                 -0.22176367920953202195d0
      iwe=iwe+1
      weighta( 41, 13,  3)=                  0.45146693398750936677d0
      iwe=iwe+1
      weighta( 42, 13,  3)=                 -0.34060438021851774382d0
      iwe=iwe+1
      weighta( 43, 13,  3)=                 -0.15606308084642295242d0
      iwe=iwe+1
      weighta( 44, 13,  3)=                 -0.26413144859846171553d0
      iwe=iwe+1
      weighta( 45, 13,  3)=                 -0.14915423245509304429d0
      iwe=iwe+1
      weighta( 46, 13,  3)=                  0.61116229885626394136d0
      iwe=iwe+1
      weighta( 47, 13,  3)=                 -0.92983027699693410195d0
      iwe=iwe+1
      weighta( 48, 13,  3)=                  0.14919060014051807594d0
      iwe=iwe+1
      weighta( 49, 13,  3)=                 -0.15547542541292005969d0
      iwe=iwe+1
      weighta( 50, 13,  3)=                 -0.02459819687658649709d0
      iwe=iwe+1
      biasa( 13,  3)=                  1.17283325653743730754d0
      iwe=iwe+1
      weighta(  1, 14,  3)=                  0.32576181963839861977d0
      iwe=iwe+1
      weighta(  2, 14,  3)=                  0.00159930484143136617d0
      iwe=iwe+1
      weighta(  3, 14,  3)=                 -0.26559183244999495788d0
      iwe=iwe+1
      weighta(  4, 14,  3)=                  0.01856828667362699775d0
      iwe=iwe+1
      weighta(  5, 14,  3)=                 -0.03066053809714388428d0
      iwe=iwe+1
      weighta(  6, 14,  3)=                  0.15022116096679166697d0
      iwe=iwe+1
      weighta(  7, 14,  3)=                 -0.47172507652761735963d0
      iwe=iwe+1
      weighta(  8, 14,  3)=                  0.05421518162176924838d0
      iwe=iwe+1
      weighta(  9, 14,  3)=                 -0.04919205514561109105d0
      iwe=iwe+1
      weighta( 10, 14,  3)=                  0.03376274911897682307d0
      iwe=iwe+1
      weighta( 11, 14,  3)=                  0.36700133338900392532d0
      iwe=iwe+1
      weighta( 12, 14,  3)=                 -0.26664745037264836469d0
      iwe=iwe+1
      weighta( 13, 14,  3)=                  0.23629022022763188082d0
      iwe=iwe+1
      weighta( 14, 14,  3)=                  0.27433955760076023100d0
      iwe=iwe+1
      weighta( 15, 14,  3)=                  0.31501324269088903929d0
      iwe=iwe+1
      weighta( 16, 14,  3)=                 -0.18923802575095716172d0
      iwe=iwe+1
      weighta( 17, 14,  3)=                 -0.22648064283493277160d0
      iwe=iwe+1
      weighta( 18, 14,  3)=                  0.09973369150821223550d0
      iwe=iwe+1
      weighta( 19, 14,  3)=                  0.12236298532478270817d0
      iwe=iwe+1
      weighta( 20, 14,  3)=                  0.08954648604029666337d0
      iwe=iwe+1
      weighta( 21, 14,  3)=                 -0.05488470043642350304d0
      iwe=iwe+1
      weighta( 22, 14,  3)=                 -0.17804275655470452877d0
      iwe=iwe+1
      weighta( 23, 14,  3)=                  0.01278665464026602222d0
      iwe=iwe+1
      weighta( 24, 14,  3)=                  0.49243420541542076707d0
      iwe=iwe+1
      weighta( 25, 14,  3)=                  0.22078345874769653157d0
      iwe=iwe+1
      weighta( 26, 14,  3)=                  0.22320217522897697893d0
      iwe=iwe+1
      weighta( 27, 14,  3)=                  0.05214269756928278932d0
      iwe=iwe+1
      weighta( 28, 14,  3)=                 -0.16749203612006638431d0
      iwe=iwe+1
      weighta( 29, 14,  3)=                 -0.22292269365274880455d0
      iwe=iwe+1
      weighta( 30, 14,  3)=                 -0.11660711038181552357d0
      iwe=iwe+1
      weighta( 31, 14,  3)=                  0.27331365425143505643d0
      iwe=iwe+1
      weighta( 32, 14,  3)=                 -0.15720082051273476242d0
      iwe=iwe+1
      weighta( 33, 14,  3)=                 -0.04506008631274115855d0
      iwe=iwe+1
      weighta( 34, 14,  3)=                  0.08851894504115148665d0
      iwe=iwe+1
      weighta( 35, 14,  3)=                  0.00042585953224289689d0
      iwe=iwe+1
      weighta( 36, 14,  3)=                 -0.10245066969711648375d0
      iwe=iwe+1
      weighta( 37, 14,  3)=                  0.04541263842871852419d0
      iwe=iwe+1
      weighta( 38, 14,  3)=                  0.13419197331345261714d0
      iwe=iwe+1
      weighta( 39, 14,  3)=                  0.17731839870907198375d0
      iwe=iwe+1
      weighta( 40, 14,  3)=                 -0.22024323360682923623d0
      iwe=iwe+1
      weighta( 41, 14,  3)=                 -0.19751063303623705991d0
      iwe=iwe+1
      weighta( 42, 14,  3)=                  0.12616987157766579308d0
      iwe=iwe+1
      weighta( 43, 14,  3)=                 -0.27928427968439584195d0
      iwe=iwe+1
      weighta( 44, 14,  3)=                  0.46183326158283749541d0
      iwe=iwe+1
      weighta( 45, 14,  3)=                  0.50467919658271387373d0
      iwe=iwe+1
      weighta( 46, 14,  3)=                  0.04469729724043328828d0
      iwe=iwe+1
      weighta( 47, 14,  3)=                 -0.20295237806853061446d0
      iwe=iwe+1
      weighta( 48, 14,  3)=                  0.15703109567328560336d0
      iwe=iwe+1
      weighta( 49, 14,  3)=                  0.17229761150892811128d0
      iwe=iwe+1
      weighta( 50, 14,  3)=                  0.14188568190314246320d0
      iwe=iwe+1
      biasa( 14,  3)=                 -1.05976738098475564698d0
      iwe=iwe+1
      weighta(  1, 15,  3)=                  0.63884206979592250697d0
      iwe=iwe+1
      weighta(  2, 15,  3)=                  0.33605172823388856918d0
      iwe=iwe+1
      weighta(  3, 15,  3)=                 -0.13389397397817662250d0
      iwe=iwe+1
      weighta(  4, 15,  3)=                 -0.37327663711638381372d0
      iwe=iwe+1
      weighta(  5, 15,  3)=                 -0.09359640953402860453d0
      iwe=iwe+1
      weighta(  6, 15,  3)=                 -0.24818607271781331636d0
      iwe=iwe+1
      weighta(  7, 15,  3)=                  0.00743644189634901608d0
      iwe=iwe+1
      weighta(  8, 15,  3)=                  0.78983249963083235201d0
      iwe=iwe+1
      weighta(  9, 15,  3)=                 -0.00507911122048873911d0
      iwe=iwe+1
      weighta( 10, 15,  3)=                  0.32826070578646276976d0
      iwe=iwe+1
      weighta( 11, 15,  3)=                  0.00830306200377748868d0
      iwe=iwe+1
      weighta( 12, 15,  3)=                 -0.38064759398200015417d0
      iwe=iwe+1
      weighta( 13, 15,  3)=                 -0.22516744189129511700d0
      iwe=iwe+1
      weighta( 14, 15,  3)=                 -0.45869840530499583764d0
      iwe=iwe+1
      weighta( 15, 15,  3)=                 -0.35898209282025322908d0
      iwe=iwe+1
      weighta( 16, 15,  3)=                 -0.66219856347891714599d0
      iwe=iwe+1
      weighta( 17, 15,  3)=                  0.32366485874788825106d0
      iwe=iwe+1
      weighta( 18, 15,  3)=                  0.29773315334523509090d0
      iwe=iwe+1
      weighta( 19, 15,  3)=                 -0.10587458417553508028d0
      iwe=iwe+1
      weighta( 20, 15,  3)=                  0.31188792435483514431d0
      iwe=iwe+1
      weighta( 21, 15,  3)=                  0.10959723842459888343d0
      iwe=iwe+1
      weighta( 22, 15,  3)=                 -0.36789467643608703140d0
      iwe=iwe+1
      weighta( 23, 15,  3)=                 -0.35940829047098188376d0
      iwe=iwe+1
      weighta( 24, 15,  3)=                 -0.06242364041976506545d0
      iwe=iwe+1
      weighta( 25, 15,  3)=                  0.05933386539065082371d0
      iwe=iwe+1
      weighta( 26, 15,  3)=                  0.05257174331556854763d0
      iwe=iwe+1
      weighta( 27, 15,  3)=                 -0.14439780398805812656d0
      iwe=iwe+1
      weighta( 28, 15,  3)=                 -0.37023596270300040967d0
      iwe=iwe+1
      weighta( 29, 15,  3)=                  0.45257069489627310688d0
      iwe=iwe+1
      weighta( 30, 15,  3)=                  0.11864108130101233551d0
      iwe=iwe+1
      weighta( 31, 15,  3)=                  0.15917960548321458125d0
      iwe=iwe+1
      weighta( 32, 15,  3)=                 -0.18922472852557312151d0
      iwe=iwe+1
      weighta( 33, 15,  3)=                 -0.10695782274136346468d0
      iwe=iwe+1
      weighta( 34, 15,  3)=                 -0.57311030288485342865d0
      iwe=iwe+1
      weighta( 35, 15,  3)=                 -0.14085263797939201469d0
      iwe=iwe+1
      weighta( 36, 15,  3)=                 -0.67783237186510891803d0
      iwe=iwe+1
      weighta( 37, 15,  3)=                 -0.29375045378930808582d0
      iwe=iwe+1
      weighta( 38, 15,  3)=                 -0.23506473233660882260d0
      iwe=iwe+1
      weighta( 39, 15,  3)=                 -0.72494035347503327227d0
      iwe=iwe+1
      weighta( 40, 15,  3)=                  0.29426661948639337707d0
      iwe=iwe+1
      weighta( 41, 15,  3)=                 -0.20276330922445881533d0
      iwe=iwe+1
      weighta( 42, 15,  3)=                 -0.09224693686004549475d0
      iwe=iwe+1
      weighta( 43, 15,  3)=                  0.22827902821283657664d0
      iwe=iwe+1
      weighta( 44, 15,  3)=                  0.06393453878055566086d0
      iwe=iwe+1
      weighta( 45, 15,  3)=                  0.67432295463662206281d0
      iwe=iwe+1
      weighta( 46, 15,  3)=                 -0.09146086785547527520d0
      iwe=iwe+1
      weighta( 47, 15,  3)=                 -0.19833813917134912597d0
      iwe=iwe+1
      weighta( 48, 15,  3)=                 -0.11013216155691157860d0
      iwe=iwe+1
      weighta( 49, 15,  3)=                 -0.24062728522613044402d0
      iwe=iwe+1
      weighta( 50, 15,  3)=                  0.20792077311967815945d0
      iwe=iwe+1
      biasa( 15,  3)=                 -0.84241643737507099221d0
      iwe=iwe+1
      weighta(  1, 16,  3)=                  0.48420790747962905165d0
      iwe=iwe+1
      weighta(  2, 16,  3)=                  0.03753158491127712992d0
      iwe=iwe+1
      weighta(  3, 16,  3)=                  0.22457580505627608436d0
      iwe=iwe+1
      weighta(  4, 16,  3)=                 -0.15697362363303474231d0
      iwe=iwe+1
      weighta(  5, 16,  3)=                 -0.05241261873158212237d0
      iwe=iwe+1
      weighta(  6, 16,  3)=                  0.38866642055860500804d0
      iwe=iwe+1
      weighta(  7, 16,  3)=                  0.13644256626222753259d0
      iwe=iwe+1
      weighta(  8, 16,  3)=                  0.05393614462144259714d0
      iwe=iwe+1
      weighta(  9, 16,  3)=                 -0.12768297903291292439d0
      iwe=iwe+1
      weighta( 10, 16,  3)=                  0.11953844831990965980d0
      iwe=iwe+1
      weighta( 11, 16,  3)=                 -0.18821174219883499146d0
      iwe=iwe+1
      weighta( 12, 16,  3)=                 -0.02265582385265435539d0
      iwe=iwe+1
      weighta( 13, 16,  3)=                 -0.08471118035687584535d0
      iwe=iwe+1
      weighta( 14, 16,  3)=                  0.10133998857214002176d0
      iwe=iwe+1
      weighta( 15, 16,  3)=                  0.01374474737798391313d0
      iwe=iwe+1
      weighta( 16, 16,  3)=                 -0.64678198364077299498d0
      iwe=iwe+1
      weighta( 17, 16,  3)=                  0.52393194268195819596d0
      iwe=iwe+1
      weighta( 18, 16,  3)=                  0.10589137094679232365d0
      iwe=iwe+1
      weighta( 19, 16,  3)=                 -0.09806842967044283876d0
      iwe=iwe+1
      weighta( 20, 16,  3)=                 -0.23423145566890396507d0
      iwe=iwe+1
      weighta( 21, 16,  3)=                  0.02056823789770478514d0
      iwe=iwe+1
      weighta( 22, 16,  3)=                  0.12531842239399695882d0
      iwe=iwe+1
      weighta( 23, 16,  3)=                  0.01073998604806854565d0
      iwe=iwe+1
      weighta( 24, 16,  3)=                  0.29355646872478641241d0
      iwe=iwe+1
      weighta( 25, 16,  3)=                 -0.15550932945687362396d0
      iwe=iwe+1
      weighta( 26, 16,  3)=                 -0.19092498183537406908d0
      iwe=iwe+1
      weighta( 27, 16,  3)=                  0.30754129169196769977d0
      iwe=iwe+1
      weighta( 28, 16,  3)=                  0.50107259312511476246d0
      iwe=iwe+1
      weighta( 29, 16,  3)=                  0.18852827436262123428d0
      iwe=iwe+1
      weighta( 30, 16,  3)=                  0.18758538034554136931d0
      iwe=iwe+1
      weighta( 31, 16,  3)=                  0.32841112437219366349d0
      iwe=iwe+1
      weighta( 32, 16,  3)=                 -0.42927494587470388376d0
      iwe=iwe+1
      weighta( 33, 16,  3)=                  0.49723531239231050227d0
      iwe=iwe+1
      weighta( 34, 16,  3)=                  0.46531781251961429335d0
      iwe=iwe+1
      weighta( 35, 16,  3)=                 -0.15147817386657366767d0
      iwe=iwe+1
      weighta( 36, 16,  3)=                 -0.07881353216206810064d0
      iwe=iwe+1
      weighta( 37, 16,  3)=                 -0.24990869190552539303d0
      iwe=iwe+1
      weighta( 38, 16,  3)=                  0.47820519227745800217d0
      iwe=iwe+1
      weighta( 39, 16,  3)=                  0.40356952750938746011d0
      iwe=iwe+1
      weighta( 40, 16,  3)=                  0.36293826308788446067d0
      iwe=iwe+1
      weighta( 41, 16,  3)=                  0.34476872504802225095d0
      iwe=iwe+1
      weighta( 42, 16,  3)=                  0.14884001112019826230d0
      iwe=iwe+1
      weighta( 43, 16,  3)=                  0.01738643210583679100d0
      iwe=iwe+1
      weighta( 44, 16,  3)=                  0.07057000418696607325d0
      iwe=iwe+1
      weighta( 45, 16,  3)=                 -0.10862864770885671817d0
      iwe=iwe+1
      weighta( 46, 16,  3)=                 -0.09506086091585548570d0
      iwe=iwe+1
      weighta( 47, 16,  3)=                 -0.41847647375036606254d0
      iwe=iwe+1
      weighta( 48, 16,  3)=                 -0.42325479707777313720d0
      iwe=iwe+1
      weighta( 49, 16,  3)=                  0.01271481871930920694d0
      iwe=iwe+1
      weighta( 50, 16,  3)=                  0.08453251176025949887d0
      iwe=iwe+1
      biasa( 16,  3)=                 -0.73535456997068848750d0
      iwe=iwe+1
      weighta(  1, 17,  3)=                  0.54615600098816075025d0
      iwe=iwe+1
      weighta(  2, 17,  3)=                  0.39143743907282191330d0
      iwe=iwe+1
      weighta(  3, 17,  3)=                 -0.21028517834695187316d0
      iwe=iwe+1
      weighta(  4, 17,  3)=                 -0.32552085872425023938d0
      iwe=iwe+1
      weighta(  5, 17,  3)=                 -0.43499173372011140648d0
      iwe=iwe+1
      weighta(  6, 17,  3)=                  0.24409673200551884609d0
      iwe=iwe+1
      weighta(  7, 17,  3)=                 -0.47204788748461962156d0
      iwe=iwe+1
      weighta(  8, 17,  3)=                 -0.24561649598501117397d0
      iwe=iwe+1
      weighta(  9, 17,  3)=                  0.28428911777840426556d0
      iwe=iwe+1
      weighta( 10, 17,  3)=                 -0.07790964070979516931d0
      iwe=iwe+1
      weighta( 11, 17,  3)=                  0.16319351652202940262d0
      iwe=iwe+1
      weighta( 12, 17,  3)=                  0.04256816005797574298d0
      iwe=iwe+1
      weighta( 13, 17,  3)=                 -0.16564606187848471275d0
      iwe=iwe+1
      weighta( 14, 17,  3)=                  0.34653669417990584645d0
      iwe=iwe+1
      weighta( 15, 17,  3)=                  0.08134805920160970150d0
      iwe=iwe+1
      weighta( 16, 17,  3)=                  0.43083828688888581304d0
      iwe=iwe+1
      weighta( 17, 17,  3)=                 -0.10760920748191499241d0
      iwe=iwe+1
      weighta( 18, 17,  3)=                  0.38638412540097616388d0
      iwe=iwe+1
      weighta( 19, 17,  3)=                  0.29288287424456460606d0
      iwe=iwe+1
      weighta( 20, 17,  3)=                 -0.04946120877000278332d0
      iwe=iwe+1
      weighta( 21, 17,  3)=                  0.28124973904698419291d0
      iwe=iwe+1
      weighta( 22, 17,  3)=                  0.55056960815986322189d0
      iwe=iwe+1
      weighta( 23, 17,  3)=                 -0.37745052235525505813d0
      iwe=iwe+1
      weighta( 24, 17,  3)=                  0.08592762744596636748d0
      iwe=iwe+1
      weighta( 25, 17,  3)=                  0.44649266866770681572d0
      iwe=iwe+1
      weighta( 26, 17,  3)=                  0.23429161640966747471d0
      iwe=iwe+1
      weighta( 27, 17,  3)=                 -0.32697557599048321375d0
      iwe=iwe+1
      weighta( 28, 17,  3)=                  0.08456030077122834998d0
      iwe=iwe+1
      weighta( 29, 17,  3)=                 -0.04511324935300553562d0
      iwe=iwe+1
      weighta( 30, 17,  3)=                 -0.09687385273794626994d0
      iwe=iwe+1
      weighta( 31, 17,  3)=                  0.07506253206500503039d0
      iwe=iwe+1
      weighta( 32, 17,  3)=                  0.18137843483387014465d0
      iwe=iwe+1
      weighta( 33, 17,  3)=                  0.09812764200454296426d0
      iwe=iwe+1
      weighta( 34, 17,  3)=                 -0.19161132614998122037d0
      iwe=iwe+1
      weighta( 35, 17,  3)=                  0.25512429873909070466d0
      iwe=iwe+1
      weighta( 36, 17,  3)=                 -0.11121370720107144614d0
      iwe=iwe+1
      weighta( 37, 17,  3)=                 -0.04529634494129949202d0
      iwe=iwe+1
      weighta( 38, 17,  3)=                  0.10765060934711287444d0
      iwe=iwe+1
      weighta( 39, 17,  3)=                 -0.24823402585331239001d0
      iwe=iwe+1
      weighta( 40, 17,  3)=                 -0.29491979535857054673d0
      iwe=iwe+1
      weighta( 41, 17,  3)=                 -0.27737120789759106554d0
      iwe=iwe+1
      weighta( 42, 17,  3)=                 -0.02439185424250533626d0
      iwe=iwe+1
      weighta( 43, 17,  3)=                 -0.03376618555603112110d0
      iwe=iwe+1
      weighta( 44, 17,  3)=                 -0.20390275694362267056d0
      iwe=iwe+1
      weighta( 45, 17,  3)=                  0.13099182860303518194d0
      iwe=iwe+1
      weighta( 46, 17,  3)=                  0.44076679414084762865d0
      iwe=iwe+1
      weighta( 47, 17,  3)=                  0.23166052396062419838d0
      iwe=iwe+1
      weighta( 48, 17,  3)=                  0.05726613589923711806d0
      iwe=iwe+1
      weighta( 49, 17,  3)=                 -0.17234149197775222584d0
      iwe=iwe+1
      weighta( 50, 17,  3)=                 -0.35917485858117781383d0
      iwe=iwe+1
      biasa( 17,  3)=                 -0.84881814681244471821d0
      iwe=iwe+1
      weighta(  1, 18,  3)=                 -0.39074315101338380485d0
      iwe=iwe+1
      weighta(  2, 18,  3)=                  0.40168271419534012923d0
      iwe=iwe+1
      weighta(  3, 18,  3)=                  0.44319972382401140454d0
      iwe=iwe+1
      weighta(  4, 18,  3)=                  0.30698133532143495605d0
      iwe=iwe+1
      weighta(  5, 18,  3)=                 -0.18722354624067846784d0
      iwe=iwe+1
      weighta(  6, 18,  3)=                 -0.03565309343464524022d0
      iwe=iwe+1
      weighta(  7, 18,  3)=                  0.51091818247434817035d0
      iwe=iwe+1
      weighta(  8, 18,  3)=                  0.52037629140473717904d0
      iwe=iwe+1
      weighta(  9, 18,  3)=                 -0.30907611283471264629d0
      iwe=iwe+1
      weighta( 10, 18,  3)=                  0.53457588393061972187d0
      iwe=iwe+1
      weighta( 11, 18,  3)=                  0.25276201186662405895d0
      iwe=iwe+1
      weighta( 12, 18,  3)=                 -0.23568893192557738292d0
      iwe=iwe+1
      weighta( 13, 18,  3)=                 -0.35498078381537895298d0
      iwe=iwe+1
      weighta( 14, 18,  3)=                 -0.46205196905584144940d0
      iwe=iwe+1
      weighta( 15, 18,  3)=                  0.20559646344525014938d0
      iwe=iwe+1
      weighta( 16, 18,  3)=                 -0.03895879241847547553d0
      iwe=iwe+1
      weighta( 17, 18,  3)=                 -0.01531780062958818314d0
      iwe=iwe+1
      weighta( 18, 18,  3)=                  0.26245125602715019264d0
      iwe=iwe+1
      weighta( 19, 18,  3)=                  0.21723463558836017540d0
      iwe=iwe+1
      weighta( 20, 18,  3)=                  0.05739370685562115298d0
      iwe=iwe+1
      weighta( 21, 18,  3)=                  0.18287280300263589194d0
      iwe=iwe+1
      weighta( 22, 18,  3)=                 -0.08052540582299815008d0
      iwe=iwe+1
      weighta( 23, 18,  3)=                 -0.50905782664774734680d0
      iwe=iwe+1
      weighta( 24, 18,  3)=                 -0.06849060453721589337d0
      iwe=iwe+1
      weighta( 25, 18,  3)=                  0.12151063693286363876d0
      iwe=iwe+1
      weighta( 26, 18,  3)=                 -0.18228768998085037589d0
      iwe=iwe+1
      weighta( 27, 18,  3)=                 -0.05361167985802586106d0
      iwe=iwe+1
      weighta( 28, 18,  3)=                 -0.23533137251561536685d0
      iwe=iwe+1
      weighta( 29, 18,  3)=                  0.61956922319314933212d0
      iwe=iwe+1
      weighta( 30, 18,  3)=                 -0.26776970685151457729d0
      iwe=iwe+1
      weighta( 31, 18,  3)=                  0.07428886021607106205d0
      iwe=iwe+1
      weighta( 32, 18,  3)=                  0.36338291194556410213d0
      iwe=iwe+1
      weighta( 33, 18,  3)=                 -0.22807558733879135238d0
      iwe=iwe+1
      weighta( 34, 18,  3)=                 -0.43141880912289959360d0
      iwe=iwe+1
      weighta( 35, 18,  3)=                 -0.12654472800989935433d0
      iwe=iwe+1
      weighta( 36, 18,  3)=                 -0.23895374475099356859d0
      iwe=iwe+1
      weighta( 37, 18,  3)=                  0.37200876998988730016d0
      iwe=iwe+1
      weighta( 38, 18,  3)=                 -0.16584912028937690009d0
      iwe=iwe+1
      weighta( 39, 18,  3)=                 -0.03524059786292548652d0
      iwe=iwe+1
      weighta( 40, 18,  3)=                  0.30660212491370536503d0
      iwe=iwe+1
      weighta( 41, 18,  3)=                 -0.42186196195348585336d0
      iwe=iwe+1
      weighta( 42, 18,  3)=                 -0.45738865267545814053d0
      iwe=iwe+1
      weighta( 43, 18,  3)=                  0.13735376560036208216d0
      iwe=iwe+1
      weighta( 44, 18,  3)=                 -0.00843390290035558009d0
      iwe=iwe+1
      weighta( 45, 18,  3)=                 -0.31937446344512132601d0
      iwe=iwe+1
      weighta( 46, 18,  3)=                  0.47758908624695461942d0
      iwe=iwe+1
      weighta( 47, 18,  3)=                 -0.54107962675640453032d0
      iwe=iwe+1
      weighta( 48, 18,  3)=                 -0.32065553933731660852d0
      iwe=iwe+1
      weighta( 49, 18,  3)=                  0.35850264500379996901d0
      iwe=iwe+1
      weighta( 50, 18,  3)=                 -0.09856023258663121345d0
      iwe=iwe+1
      biasa( 18,  3)=                  0.55670596286877049863d0
      iwe=iwe+1
      weighta(  1, 19,  3)=                  0.28598423257935623454d0
      iwe=iwe+1
      weighta(  2, 19,  3)=                  0.53684052087125611052d0
      iwe=iwe+1
      weighta(  3, 19,  3)=                 -0.14547601797300183102d0
      iwe=iwe+1
      weighta(  4, 19,  3)=                 -0.37139971626936302274d0
      iwe=iwe+1
      weighta(  5, 19,  3)=                 -0.30771046293098441859d0
      iwe=iwe+1
      weighta(  6, 19,  3)=                  0.41213857552736032908d0
      iwe=iwe+1
      weighta(  7, 19,  3)=                  0.18074504651339373673d0
      iwe=iwe+1
      weighta(  8, 19,  3)=                  0.07478091766731509438d0
      iwe=iwe+1
      weighta(  9, 19,  3)=                 -0.13134714638378941487d0
      iwe=iwe+1
      weighta( 10, 19,  3)=                 -0.14100828724014352611d0
      iwe=iwe+1
      weighta( 11, 19,  3)=                 -0.07956096725002059777d0
      iwe=iwe+1
      weighta( 12, 19,  3)=                 -0.25260400943420835418d0
      iwe=iwe+1
      weighta( 13, 19,  3)=                 -0.02367151663484659552d0
      iwe=iwe+1
      weighta( 14, 19,  3)=                 -0.40553280258810597836d0
      iwe=iwe+1
      weighta( 15, 19,  3)=                 -0.37317046161313727204d0
      iwe=iwe+1
      weighta( 16, 19,  3)=                 -0.10578894280571117525d0
      iwe=iwe+1
      weighta( 17, 19,  3)=                 -0.14563455933202379411d0
      iwe=iwe+1
      weighta( 18, 19,  3)=                  0.12250645015381102232d0
      iwe=iwe+1
      weighta( 19, 19,  3)=                  0.13199936425464178780d0
      iwe=iwe+1
      weighta( 20, 19,  3)=                 -0.67511020455699133347d0
      iwe=iwe+1
      weighta( 21, 19,  3)=                  0.03865862774335880603d0
      iwe=iwe+1
      weighta( 22, 19,  3)=                  0.05272082770515727768d0
      iwe=iwe+1
      weighta( 23, 19,  3)=                 -0.06217755509174767437d0
      iwe=iwe+1
      weighta( 24, 19,  3)=                 -0.26212907518355271774d0
      iwe=iwe+1
      weighta( 25, 19,  3)=                 -0.08773534199632060382d0
      iwe=iwe+1
      weighta( 26, 19,  3)=                 -0.26264118541261133322d0
      iwe=iwe+1
      weighta( 27, 19,  3)=                 -0.21733090646021188674d0
      iwe=iwe+1
      weighta( 28, 19,  3)=                  0.37845356722038653308d0
      iwe=iwe+1
      weighta( 29, 19,  3)=                  0.22088363016365955560d0
      iwe=iwe+1
      weighta( 30, 19,  3)=                 -0.07396067678075202156d0
      iwe=iwe+1
      weighta( 31, 19,  3)=                  0.51060096372107655061d0
      iwe=iwe+1
      weighta( 32, 19,  3)=                  0.10560394263231601131d0
      iwe=iwe+1
      weighta( 33, 19,  3)=                 -0.19224756856225355683d0
      iwe=iwe+1
      weighta( 34, 19,  3)=                  0.01058214473840645570d0
      iwe=iwe+1
      weighta( 35, 19,  3)=                 -0.25175969097470352054d0
      iwe=iwe+1
      weighta( 36, 19,  3)=                 -0.45572629092601940615d0
      iwe=iwe+1
      weighta( 37, 19,  3)=                  0.09267169581180095816d0
      iwe=iwe+1
      weighta( 38, 19,  3)=                  0.15587323480181519697d0
      iwe=iwe+1
      weighta( 39, 19,  3)=                  0.12274039238689561648d0
      iwe=iwe+1
      weighta( 40, 19,  3)=                 -0.10575539606060944953d0
      iwe=iwe+1
      weighta( 41, 19,  3)=                 -0.45049953234261902457d0
      iwe=iwe+1
      weighta( 42, 19,  3)=                 -0.27480657985351458761d0
      iwe=iwe+1
      weighta( 43, 19,  3)=                 -0.12063274818388952658d0
      iwe=iwe+1
      weighta( 44, 19,  3)=                 -0.33323172418236135517d0
      iwe=iwe+1
      weighta( 45, 19,  3)=                  0.17492019523734061992d0
      iwe=iwe+1
      weighta( 46, 19,  3)=                  0.08675964366829649888d0
      iwe=iwe+1
      weighta( 47, 19,  3)=                  0.10803739425847995459d0
      iwe=iwe+1
      weighta( 48, 19,  3)=                  0.21499202095827213421d0
      iwe=iwe+1
      weighta( 49, 19,  3)=                 -0.17339974196568674891d0
      iwe=iwe+1
      weighta( 50, 19,  3)=                 -0.14956545532098233786d0
      iwe=iwe+1
      biasa( 19,  3)=                 -0.77599055004843631167d0
      iwe=iwe+1
      weighta(  1, 20,  3)=                  0.29867505634823504623d0
      iwe=iwe+1
      weighta(  2, 20,  3)=                  0.12011234546156165925d0
      iwe=iwe+1
      weighta(  3, 20,  3)=                 -0.27211789423424848078d0
      iwe=iwe+1
      weighta(  4, 20,  3)=                 -0.36549155835021734928d0
      iwe=iwe+1
      weighta(  5, 20,  3)=                  0.05285145141980777256d0
      iwe=iwe+1
      weighta(  6, 20,  3)=                 -0.12222047485890449869d0
      iwe=iwe+1
      weighta(  7, 20,  3)=                 -0.26982765475685377421d0
      iwe=iwe+1
      weighta(  8, 20,  3)=                 -0.37019349338818935413d0
      iwe=iwe+1
      weighta(  9, 20,  3)=                  0.35683234427406784750d0
      iwe=iwe+1
      weighta( 10, 20,  3)=                 -0.09778374793720497060d0
      iwe=iwe+1
      weighta( 11, 20,  3)=                  0.14944058945795055116d0
      iwe=iwe+1
      weighta( 12, 20,  3)=                 -0.19193341519108964022d0
      iwe=iwe+1
      weighta( 13, 20,  3)=                  0.29913037448753704295d0
      iwe=iwe+1
      weighta( 14, 20,  3)=                  0.23115970610300562438d0
      iwe=iwe+1
      weighta( 15, 20,  3)=                  0.08162793275804954007d0
      iwe=iwe+1
      weighta( 16, 20,  3)=                  0.21055294084748865657d0
      iwe=iwe+1
      weighta( 17, 20,  3)=                 -0.11593600512676284497d0
      iwe=iwe+1
      weighta( 18, 20,  3)=                  0.01074279778237547008d0
      iwe=iwe+1
      weighta( 19, 20,  3)=                 -0.16727677071166016654d0
      iwe=iwe+1
      weighta( 20, 20,  3)=                  0.10676029261797477521d0
      iwe=iwe+1
      weighta( 21, 20,  3)=                 -0.51318959200438230006d0
      iwe=iwe+1
      weighta( 22, 20,  3)=                  0.34875134336946650437d0
      iwe=iwe+1
      weighta( 23, 20,  3)=                  0.26650284557600939506d0
      iwe=iwe+1
      weighta( 24, 20,  3)=                  0.09641188443593476376d0
      iwe=iwe+1
      weighta( 25, 20,  3)=                  0.14465436569093065300d0
      iwe=iwe+1
      weighta( 26, 20,  3)=                  0.05951507382994442041d0
      iwe=iwe+1
      weighta( 27, 20,  3)=                 -0.52215150865552650838d0
      iwe=iwe+1
      weighta( 28, 20,  3)=                  0.45845308823303548840d0
      iwe=iwe+1
      weighta( 29, 20,  3)=                  0.40995111583745813544d0
      iwe=iwe+1
      weighta( 30, 20,  3)=                 -0.13362041254917211841d0
      iwe=iwe+1
      weighta( 31, 20,  3)=                 -0.23517870462722520464d0
      iwe=iwe+1
      weighta( 32, 20,  3)=                  0.07209871860467603755d0
      iwe=iwe+1
      weighta( 33, 20,  3)=                 -0.12638298460318847516d0
      iwe=iwe+1
      weighta( 34, 20,  3)=                  0.03905195187463857825d0
      iwe=iwe+1
      weighta( 35, 20,  3)=                 -0.35515885004263642033d0
      iwe=iwe+1
      weighta( 36, 20,  3)=                 -0.22773077116385156971d0
      iwe=iwe+1
      weighta( 37, 20,  3)=                  0.28225290401255909156d0
      iwe=iwe+1
      weighta( 38, 20,  3)=                 -0.20858114625048074231d0
      iwe=iwe+1
      weighta( 39, 20,  3)=                 -0.24502114012319109460d0
      iwe=iwe+1
      weighta( 40, 20,  3)=                  0.54973107240301943843d0
      iwe=iwe+1
      weighta( 41, 20,  3)=                  0.10337244356502456322d0
      iwe=iwe+1
      weighta( 42, 20,  3)=                  0.12801045025523569154d0
      iwe=iwe+1
      weighta( 43, 20,  3)=                  0.18956994152591524760d0
      iwe=iwe+1
      weighta( 44, 20,  3)=                 -0.33507853345100474529d0
      iwe=iwe+1
      weighta( 45, 20,  3)=                 -0.00468850794785404413d0
      iwe=iwe+1
      weighta( 46, 20,  3)=                  0.17001699387203722535d0
      iwe=iwe+1
      weighta( 47, 20,  3)=                 -0.23775791427088463492d0
      iwe=iwe+1
      weighta( 48, 20,  3)=                  0.06230582238403185869d0
      iwe=iwe+1
      weighta( 49, 20,  3)=                  0.41023251543290384369d0
      iwe=iwe+1
      weighta( 50, 20,  3)=                 -0.38225678215388914083d0
      iwe=iwe+1
      biasa( 20,  3)=                 -0.77800027562574802786d0
      iwe=iwe+1
      weighta(  1, 21,  3)=                 -0.04735189661084736323d0
      iwe=iwe+1
      weighta(  2, 21,  3)=                 -0.33893151311621133592d0
      iwe=iwe+1
      weighta(  3, 21,  3)=                  0.24784440153513573324d0
      iwe=iwe+1
      weighta(  4, 21,  3)=                 -0.30930224365077702009d0
      iwe=iwe+1
      weighta(  5, 21,  3)=                 -0.00240029118365639102d0
      iwe=iwe+1
      weighta(  6, 21,  3)=                  0.11587036378510928714d0
      iwe=iwe+1
      weighta(  7, 21,  3)=                  0.02799331650262407503d0
      iwe=iwe+1
      weighta(  8, 21,  3)=                 -0.03394722796742283971d0
      iwe=iwe+1
      weighta(  9, 21,  3)=                 -0.17461630734389507746d0
      iwe=iwe+1
      weighta( 10, 21,  3)=                  0.05775733139186411264d0
      iwe=iwe+1
      weighta( 11, 21,  3)=                 -0.16687095881660096719d0
      iwe=iwe+1
      weighta( 12, 21,  3)=                  0.00849072442300105937d0
      iwe=iwe+1
      weighta( 13, 21,  3)=                 -0.33309007926369377239d0
      iwe=iwe+1
      weighta( 14, 21,  3)=                  0.12719971239169913790d0
      iwe=iwe+1
      weighta( 15, 21,  3)=                  0.29714816226262102949d0
      iwe=iwe+1
      weighta( 16, 21,  3)=                  0.21534791263308411535d0
      iwe=iwe+1
      weighta( 17, 21,  3)=                  0.11125551646554490692d0
      iwe=iwe+1
      weighta( 18, 21,  3)=                 -0.41780926373354443371d0
      iwe=iwe+1
      weighta( 19, 21,  3)=                  0.21634542640012444092d0
      iwe=iwe+1
      weighta( 20, 21,  3)=                  0.33517889915310011828d0
      iwe=iwe+1
      weighta( 21, 21,  3)=                 -0.17065616986183299031d0
      iwe=iwe+1
      weighta( 22, 21,  3)=                  0.33535804993900025783d0
      iwe=iwe+1
      weighta( 23, 21,  3)=                 -0.24828211893630591778d0
      iwe=iwe+1
      weighta( 24, 21,  3)=                 -0.35614663160770199113d0
      iwe=iwe+1
      weighta( 25, 21,  3)=                  0.31491289528603694237d0
      iwe=iwe+1
      weighta( 26, 21,  3)=                 -0.15357884411777039668d0
      iwe=iwe+1
      weighta( 27, 21,  3)=                  0.25069744872294141835d0
      iwe=iwe+1
      weighta( 28, 21,  3)=                 -0.09660469443825371594d0
      iwe=iwe+1
      weighta( 29, 21,  3)=                 -0.06289997730476232229d0
      iwe=iwe+1
      weighta( 30, 21,  3)=                  0.32290999684207616349d0
      iwe=iwe+1
      weighta( 31, 21,  3)=                 -0.06359277153483117173d0
      iwe=iwe+1
      weighta( 32, 21,  3)=                 -0.20548110249085504986d0
      iwe=iwe+1
      weighta( 33, 21,  3)=                 -0.24411332345016345524d0
      iwe=iwe+1
      weighta( 34, 21,  3)=                 -0.18560315181589190359d0
      iwe=iwe+1
      weighta( 35, 21,  3)=                 -0.43422091155762515546d0
      iwe=iwe+1
      weighta( 36, 21,  3)=                 -0.02364299963208370270d0
      iwe=iwe+1
      weighta( 37, 21,  3)=                  0.08215239597596586674d0
      iwe=iwe+1
      weighta( 38, 21,  3)=                  0.05258710137370384979d0
      iwe=iwe+1
      weighta( 39, 21,  3)=                 -0.18199370894400890286d0
      iwe=iwe+1
      weighta( 40, 21,  3)=                  0.00804348046383960777d0
      iwe=iwe+1
      weighta( 41, 21,  3)=                  0.09452778483076020033d0
      iwe=iwe+1
      weighta( 42, 21,  3)=                  0.15218838479053931056d0
      iwe=iwe+1
      weighta( 43, 21,  3)=                  0.31056355988488804076d0
      iwe=iwe+1
      weighta( 44, 21,  3)=                 -0.15083304501370273232d0
      iwe=iwe+1
      weighta( 45, 21,  3)=                  0.33510750019768004160d0
      iwe=iwe+1
      weighta( 46, 21,  3)=                  0.06454323400828380908d0
      iwe=iwe+1
      weighta( 47, 21,  3)=                 -0.26746411155116939229d0
      iwe=iwe+1
      weighta( 48, 21,  3)=                 -0.15908676866628804203d0
      iwe=iwe+1
      weighta( 49, 21,  3)=                  0.28220656543720085141d0
      iwe=iwe+1
      weighta( 50, 21,  3)=                  0.29417560495499939233d0
      iwe=iwe+1
      biasa( 21,  3)=                  0.77057983755765191436d0
      iwe=iwe+1
      weighta(  1, 22,  3)=                  0.24459204531145051220d0
      iwe=iwe+1
      weighta(  2, 22,  3)=                  0.12458800812960903193d0
      iwe=iwe+1
      weighta(  3, 22,  3)=                 -0.04912738076966985390d0
      iwe=iwe+1
      weighta(  4, 22,  3)=                 -0.36900932756866661189d0
      iwe=iwe+1
      weighta(  5, 22,  3)=                  0.18480893402636816569d0
      iwe=iwe+1
      weighta(  6, 22,  3)=                 -0.69220718646988066425d0
      iwe=iwe+1
      weighta(  7, 22,  3)=                  0.35337615830113672244d0
      iwe=iwe+1
      weighta(  8, 22,  3)=                  0.09955096110213737526d0
      iwe=iwe+1
      weighta(  9, 22,  3)=                 -0.04009970674605781854d0
      iwe=iwe+1
      weighta( 10, 22,  3)=                  0.06681012503442444739d0
      iwe=iwe+1
      weighta( 11, 22,  3)=                  0.06983905827353636964d0
      iwe=iwe+1
      weighta( 12, 22,  3)=                  0.22973195026488701931d0
      iwe=iwe+1
      weighta( 13, 22,  3)=                  0.28002635735974779063d0
      iwe=iwe+1
      weighta( 14, 22,  3)=                 -0.14781368544216380578d0
      iwe=iwe+1
      weighta( 15, 22,  3)=                 -0.08632054551164156098d0
      iwe=iwe+1
      weighta( 16, 22,  3)=                 -0.43213440824654147931d0
      iwe=iwe+1
      weighta( 17, 22,  3)=                 -0.05290814501061080755d0
      iwe=iwe+1
      weighta( 18, 22,  3)=                 -0.12624115830952492567d0
      iwe=iwe+1
      weighta( 19, 22,  3)=                  0.42369367575334704323d0
      iwe=iwe+1
      weighta( 20, 22,  3)=                  0.23428343629051665009d0
      iwe=iwe+1
      weighta( 21, 22,  3)=                 -0.31435424605713807589d0
      iwe=iwe+1
      weighta( 22, 22,  3)=                  0.27663152003681473756d0
      iwe=iwe+1
      weighta( 23, 22,  3)=                  0.08005294677031164763d0
      iwe=iwe+1
      weighta( 24, 22,  3)=                 -0.12135467586192294487d0
      iwe=iwe+1
      weighta( 25, 22,  3)=                  0.36421190815818982323d0
      iwe=iwe+1
      weighta( 26, 22,  3)=                  0.16198818763977096413d0
      iwe=iwe+1
      weighta( 27, 22,  3)=                 -0.08567038569626300726d0
      iwe=iwe+1
      weighta( 28, 22,  3)=                 -0.51191551547425628854d0
      iwe=iwe+1
      weighta( 29, 22,  3)=                 -0.02740297315771499445d0
      iwe=iwe+1
      weighta( 30, 22,  3)=                 -0.16016447973926167814d0
      iwe=iwe+1
      weighta( 31, 22,  3)=                 -0.10663915602943657701d0
      iwe=iwe+1
      weighta( 32, 22,  3)=                 -0.10113096290467778193d0
      iwe=iwe+1
      weighta( 33, 22,  3)=                 -0.01438405020832414331d0
      iwe=iwe+1
      weighta( 34, 22,  3)=                  0.06188534772086558278d0
      iwe=iwe+1
      weighta( 35, 22,  3)=                 -0.07204193659367530422d0
      iwe=iwe+1
      weighta( 36, 22,  3)=                 -0.37083622499043827903d0
      iwe=iwe+1
      weighta( 37, 22,  3)=                  0.00179425774499805853d0
      iwe=iwe+1
      weighta( 38, 22,  3)=                 -0.01575077697777304067d0
      iwe=iwe+1
      weighta( 39, 22,  3)=                  0.15413121125971973591d0
      iwe=iwe+1
      weighta( 40, 22,  3)=                  0.20500919563673550283d0
      iwe=iwe+1
      weighta( 41, 22,  3)=                 -0.49237769122875657546d0
      iwe=iwe+1
      weighta( 42, 22,  3)=                  0.00178049518267289959d0
      iwe=iwe+1
      weighta( 43, 22,  3)=                 -0.08436852954858364839d0
      iwe=iwe+1
      weighta( 44, 22,  3)=                  0.08055807681530675890d0
      iwe=iwe+1
      weighta( 45, 22,  3)=                  0.37188075967049760706d0
      iwe=iwe+1
      weighta( 46, 22,  3)=                  0.44185257165050867423d0
      iwe=iwe+1
      weighta( 47, 22,  3)=                 -0.44035072852846313118d0
      iwe=iwe+1
      weighta( 48, 22,  3)=                 -0.01464053653120226187d0
      iwe=iwe+1
      weighta( 49, 22,  3)=                  0.28385963146616199904d0
      iwe=iwe+1
      weighta( 50, 22,  3)=                 -0.32006817503827234006d0
      iwe=iwe+1
      biasa( 22,  3)=                 -0.61113105575218107379d0
      iwe=iwe+1
      weighta(  1, 23,  3)=                  0.21812536976323848581d0
      iwe=iwe+1
      weighta(  2, 23,  3)=                  0.24408239926419755816d0
      iwe=iwe+1
      weighta(  3, 23,  3)=                 -0.45462373185037735501d0
      iwe=iwe+1
      weighta(  4, 23,  3)=                 -0.36701881786434414900d0
      iwe=iwe+1
      weighta(  5, 23,  3)=                 -0.36984702433449750947d0
      iwe=iwe+1
      weighta(  6, 23,  3)=                 -0.43251099864907199821d0
      iwe=iwe+1
      weighta(  7, 23,  3)=                 -0.41557363327863255931d0
      iwe=iwe+1
      weighta(  8, 23,  3)=                 -0.17397681456064814642d0
      iwe=iwe+1
      weighta(  9, 23,  3)=                  0.23256458519366340898d0
      iwe=iwe+1
      weighta( 10, 23,  3)=                 -0.21038262573345370421d0
      iwe=iwe+1
      weighta( 11, 23,  3)=                 -0.01815690583617662543d0
      iwe=iwe+1
      weighta( 12, 23,  3)=                  0.02741942055755971011d0
      iwe=iwe+1
      weighta( 13, 23,  3)=                 -0.09631041918951506464d0
      iwe=iwe+1
      weighta( 14, 23,  3)=                  0.19669738125674224305d0
      iwe=iwe+1
      weighta( 15, 23,  3)=                 -0.05368594200625562141d0
      iwe=iwe+1
      weighta( 16, 23,  3)=                  0.34281880820886212469d0
      iwe=iwe+1
      weighta( 17, 23,  3)=                  0.30133255106933076739d0
      iwe=iwe+1
      weighta( 18, 23,  3)=                  0.15867691531633465463d0
      iwe=iwe+1
      weighta( 19, 23,  3)=                 -0.34826738848476113120d0
      iwe=iwe+1
      weighta( 20, 23,  3)=                  0.25382194538431224196d0
      iwe=iwe+1
      weighta( 21, 23,  3)=                  0.21255393614387380063d0
      iwe=iwe+1
      weighta( 22, 23,  3)=                  0.06972540370051964753d0
      iwe=iwe+1
      weighta( 23, 23,  3)=                 -0.30879448593147312829d0
      iwe=iwe+1
      weighta( 24, 23,  3)=                  0.18100962219555011279d0
      iwe=iwe+1
      weighta( 25, 23,  3)=                  0.16045725125649620835d0
      iwe=iwe+1
      weighta( 26, 23,  3)=                  0.12976571705320083527d0
      iwe=iwe+1
      weighta( 27, 23,  3)=                  0.03194740457114332577d0
      iwe=iwe+1
      weighta( 28, 23,  3)=                 -0.48155921042535504428d0
      iwe=iwe+1
      weighta( 29, 23,  3)=                 -0.42160227921631243664d0
      iwe=iwe+1
      weighta( 30, 23,  3)=                 -0.02150443699883089824d0
      iwe=iwe+1
      weighta( 31, 23,  3)=                 -0.16087893704268679818d0
      iwe=iwe+1
      weighta( 32, 23,  3)=                  0.44011091504633836902d0
      iwe=iwe+1
      weighta( 33, 23,  3)=                  0.13410061858796848422d0
      iwe=iwe+1
      weighta( 34, 23,  3)=                 -0.03021746040019305038d0
      iwe=iwe+1
      weighta( 35, 23,  3)=                 -0.21860265063341627334d0
      iwe=iwe+1
      weighta( 36, 23,  3)=                 -0.15933425731594008656d0
      iwe=iwe+1
      weighta( 37, 23,  3)=                  0.18663681151541258729d0
      iwe=iwe+1
      weighta( 38, 23,  3)=                  0.20424039095242796371d0
      iwe=iwe+1
      weighta( 39, 23,  3)=                 -0.10078215718559323244d0
      iwe=iwe+1
      weighta( 40, 23,  3)=                  0.00275905570689803994d0
      iwe=iwe+1
      weighta( 41, 23,  3)=                  0.25728031292991776491d0
      iwe=iwe+1
      weighta( 42, 23,  3)=                  0.06625650135658202322d0
      iwe=iwe+1
      weighta( 43, 23,  3)=                 -0.22019946414167379523d0
      iwe=iwe+1
      weighta( 44, 23,  3)=                  0.07989026728326537041d0
      iwe=iwe+1
      weighta( 45, 23,  3)=                  0.23949974032966170334d0
      iwe=iwe+1
      weighta( 46, 23,  3)=                  0.19521858994073928995d0
      iwe=iwe+1
      weighta( 47, 23,  3)=                 -0.09780871982992002389d0
      iwe=iwe+1
      weighta( 48, 23,  3)=                 -0.53655142899973318205d0
      iwe=iwe+1
      weighta( 49, 23,  3)=                  0.28959932294560764010d0
      iwe=iwe+1
      weighta( 50, 23,  3)=                  0.27733244778331483937d0
      iwe=iwe+1
      biasa( 23,  3)=                  0.80972806767633564995d0
      iwe=iwe+1
      weighta(  1, 24,  3)=                 -0.12944359544218322911d0
      iwe=iwe+1
      weighta(  2, 24,  3)=                  0.20294184015536939625d0
      iwe=iwe+1
      weighta(  3, 24,  3)=                 -0.39349092169905663940d0
      iwe=iwe+1
      weighta(  4, 24,  3)=                 -0.42774020965428705132d0
      iwe=iwe+1
      weighta(  5, 24,  3)=                  0.43227549083349858794d0
      iwe=iwe+1
      weighta(  6, 24,  3)=                  0.10650512314328113017d0
      iwe=iwe+1
      weighta(  7, 24,  3)=                  0.05138771469067109077d0
      iwe=iwe+1
      weighta(  8, 24,  3)=                  0.33513115334289650393d0
      iwe=iwe+1
      weighta(  9, 24,  3)=                  0.08057689415854692172d0
      iwe=iwe+1
      weighta( 10, 24,  3)=                  0.06411219949766060189d0
      iwe=iwe+1
      weighta( 11, 24,  3)=                  0.17621627230430572664d0
      iwe=iwe+1
      weighta( 12, 24,  3)=                 -0.13373039559352556394d0
      iwe=iwe+1
      weighta( 13, 24,  3)=                  0.30381641837088213531d0
      iwe=iwe+1
      weighta( 14, 24,  3)=                 -0.02785296676198617538d0
      iwe=iwe+1
      weighta( 15, 24,  3)=                 -0.04579998810383224817d0
      iwe=iwe+1
      weighta( 16, 24,  3)=                  0.17546668210827925938d0
      iwe=iwe+1
      weighta( 17, 24,  3)=                  0.02196894342517329360d0
      iwe=iwe+1
      weighta( 18, 24,  3)=                  0.29914421605328017639d0
      iwe=iwe+1
      weighta( 19, 24,  3)=                  0.27322475811440505300d0
      iwe=iwe+1
      weighta( 20, 24,  3)=                  0.03676978444428321419d0
      iwe=iwe+1
      weighta( 21, 24,  3)=                  0.14023487743576967812d0
      iwe=iwe+1
      weighta( 22, 24,  3)=                 -0.21977481216412025899d0
      iwe=iwe+1
      weighta( 23, 24,  3)=                 -0.17996848898284933949d0
      iwe=iwe+1
      weighta( 24, 24,  3)=                  0.30693597500745289919d0
      iwe=iwe+1
      weighta( 25, 24,  3)=                 -0.28436031767247083035d0
      iwe=iwe+1
      weighta( 26, 24,  3)=                 -0.07492064456289640462d0
      iwe=iwe+1
      weighta( 27, 24,  3)=                  0.11177126814264440324d0
      iwe=iwe+1
      weighta( 28, 24,  3)=                 -0.64255419285736525836d0
      iwe=iwe+1
      weighta( 29, 24,  3)=                  0.03543199024298020194d0
      iwe=iwe+1
      weighta( 30, 24,  3)=                  0.25674017070883781155d0
      iwe=iwe+1
      weighta( 31, 24,  3)=                 -0.13974748766613784290d0
      iwe=iwe+1
      weighta( 32, 24,  3)=                  0.06370556737637310396d0
      iwe=iwe+1
      weighta( 33, 24,  3)=                 -0.19104648507913379873d0
      iwe=iwe+1
      weighta( 34, 24,  3)=                  0.19425491960088761556d0
      iwe=iwe+1
      weighta( 35, 24,  3)=                  0.34735054380460750334d0
      iwe=iwe+1
      weighta( 36, 24,  3)=                 -0.17204341271742701336d0
      iwe=iwe+1
      weighta( 37, 24,  3)=                 -0.46332433248130783232d0
      iwe=iwe+1
      weighta( 38, 24,  3)=                 -0.42615266664420026199d0
      iwe=iwe+1
      weighta( 39, 24,  3)=                 -0.00332686862841555199d0
      iwe=iwe+1
      weighta( 40, 24,  3)=                  0.22136968439293683297d0
      iwe=iwe+1
      weighta( 41, 24,  3)=                 -0.45791832258792236621d0
      iwe=iwe+1
      weighta( 42, 24,  3)=                  0.45676226715680146029d0
      iwe=iwe+1
      weighta( 43, 24,  3)=                  0.06776880846248203860d0
      iwe=iwe+1
      weighta( 44, 24,  3)=                  0.13123632190928857799d0
      iwe=iwe+1
      weighta( 45, 24,  3)=                 -0.31653826157865044832d0
      iwe=iwe+1
      weighta( 46, 24,  3)=                  0.40575216940252428754d0
      iwe=iwe+1
      weighta( 47, 24,  3)=                  0.04146348824721628190d0
      iwe=iwe+1
      weighta( 48, 24,  3)=                 -0.03354985726995859258d0
      iwe=iwe+1
      weighta( 49, 24,  3)=                  0.36007998078868469483d0
      iwe=iwe+1
      weighta( 50, 24,  3)=                 -0.13471298310940946208d0
      iwe=iwe+1
      biasa( 24,  3)=                  0.78995862180141540598d0
      iwe=iwe+1
      weighta(  1, 25,  3)=                 -0.14499560629156987845d0
      iwe=iwe+1
      weighta(  2, 25,  3)=                 -0.26219901535686890304d0
      iwe=iwe+1
      weighta(  3, 25,  3)=                  0.03779717249136342605d0
      iwe=iwe+1
      weighta(  4, 25,  3)=                  0.38976254582173164298d0
      iwe=iwe+1
      weighta(  5, 25,  3)=                 -0.18327912099670931600d0
      iwe=iwe+1
      weighta(  6, 25,  3)=                  0.37270191019145831879d0
      iwe=iwe+1
      weighta(  7, 25,  3)=                 -0.09889751934327087324d0
      iwe=iwe+1
      weighta(  8, 25,  3)=                  0.44506324284480813791d0
      iwe=iwe+1
      weighta(  9, 25,  3)=                  0.51516375139399117611d0
      iwe=iwe+1
      weighta( 10, 25,  3)=                 -0.04790859464700457371d0
      iwe=iwe+1
      weighta( 11, 25,  3)=                 -0.22929147229564736388d0
      iwe=iwe+1
      weighta( 12, 25,  3)=                 -0.10663713462989922454d0
      iwe=iwe+1
      weighta( 13, 25,  3)=                  0.39760411054829769562d0
      iwe=iwe+1
      weighta( 14, 25,  3)=                  0.02040226100760710731d0
      iwe=iwe+1
      weighta( 15, 25,  3)=                 -0.17973372387036870568d0
      iwe=iwe+1
      weighta( 16, 25,  3)=                  0.03504992437095583169d0
      iwe=iwe+1
      weighta( 17, 25,  3)=                 -0.13713194616027671313d0
      iwe=iwe+1
      weighta( 18, 25,  3)=                 -0.20143955243092867557d0
      iwe=iwe+1
      weighta( 19, 25,  3)=                  0.08919984601778600808d0
      iwe=iwe+1
      weighta( 20, 25,  3)=                 -0.22146525865956609436d0
      iwe=iwe+1
      weighta( 21, 25,  3)=                  0.13253907154273678048d0
      iwe=iwe+1
      weighta( 22, 25,  3)=                  0.56669185223255058581d0
      iwe=iwe+1
      weighta( 23, 25,  3)=                  0.27710328234267050940d0
      iwe=iwe+1
      weighta( 24, 25,  3)=                  0.23141081292354626076d0
      iwe=iwe+1
      weighta( 25, 25,  3)=                  0.10470835645114377754d0
      iwe=iwe+1
      weighta( 26, 25,  3)=                  0.50367918154289859078d0
      iwe=iwe+1
      weighta( 27, 25,  3)=                  0.19067397702658608893d0
      iwe=iwe+1
      weighta( 28, 25,  3)=                 -0.01091804354319899674d0
      iwe=iwe+1
      weighta( 29, 25,  3)=                 -0.10895228963306420600d0
      iwe=iwe+1
      weighta( 30, 25,  3)=                 -0.09666440819666989592d0
      iwe=iwe+1
      weighta( 31, 25,  3)=                  0.23464062225062445877d0
      iwe=iwe+1
      weighta( 32, 25,  3)=                 -0.20496232603400965644d0
      iwe=iwe+1
      weighta( 33, 25,  3)=                  0.40088186603645165063d0
      iwe=iwe+1
      weighta( 34, 25,  3)=                 -0.45492650190016148404d0
      iwe=iwe+1
      weighta( 35, 25,  3)=                 -0.19505735022319078964d0
      iwe=iwe+1
      weighta( 36, 25,  3)=                 -0.20241740558285784002d0
      iwe=iwe+1
      weighta( 37, 25,  3)=                  0.23025373347227093279d0
      iwe=iwe+1
      weighta( 38, 25,  3)=                  0.44670099377169664168d0
      iwe=iwe+1
      weighta( 39, 25,  3)=                 -0.16071273753301401621d0
      iwe=iwe+1
      weighta( 40, 25,  3)=                  0.24635945201407938310d0
      iwe=iwe+1
      weighta( 41, 25,  3)=                  0.41689646213722031387d0
      iwe=iwe+1
      weighta( 42, 25,  3)=                 -0.05590117758785265872d0
      iwe=iwe+1
      weighta( 43, 25,  3)=                 -0.10504682777215831879d0
      iwe=iwe+1
      weighta( 44, 25,  3)=                  0.08277092839449098904d0
      iwe=iwe+1
      weighta( 45, 25,  3)=                 -0.26567782248423310598d0
      iwe=iwe+1
      weighta( 46, 25,  3)=                  0.10826332210406192091d0
      iwe=iwe+1
      weighta( 47, 25,  3)=                 -0.14013192004219826581d0
      iwe=iwe+1
      weighta( 48, 25,  3)=                  0.26340326863230040244d0
      iwe=iwe+1
      weighta( 49, 25,  3)=                 -0.26253964464501416964d0
      iwe=iwe+1
      weighta( 50, 25,  3)=                  0.20593241064545905750d0
      iwe=iwe+1
      biasa( 25,  3)=                  0.45412856209449464773d0
      iwe=iwe+1
      weighta(  1, 26,  3)=                 -0.05197476678124653832d0
      iwe=iwe+1
      weighta(  2, 26,  3)=                 -0.02103211779252925698d0
      iwe=iwe+1
      weighta(  3, 26,  3)=                 -0.13961947617645206754d0
      iwe=iwe+1
      weighta(  4, 26,  3)=                 -0.33428465748669161650d0
      iwe=iwe+1
      weighta(  5, 26,  3)=                 -0.32716369082730190065d0
      iwe=iwe+1
      weighta(  6, 26,  3)=                  0.07820972634288685110d0
      iwe=iwe+1
      weighta(  7, 26,  3)=                 -0.16433662772046880862d0
      iwe=iwe+1
      weighta(  8, 26,  3)=                 -0.29940379123986832210d0
      iwe=iwe+1
      weighta(  9, 26,  3)=                  0.02014794815793051475d0
      iwe=iwe+1
      weighta( 10, 26,  3)=                  0.30702661019943627840d0
      iwe=iwe+1
      weighta( 11, 26,  3)=                 -0.20139894717260350965d0
      iwe=iwe+1
      weighta( 12, 26,  3)=                 -0.16464155919881046097d0
      iwe=iwe+1
      weighta( 13, 26,  3)=                  0.03494999864465433287d0
      iwe=iwe+1
      weighta( 14, 26,  3)=                  0.10589941258644640365d0
      iwe=iwe+1
      weighta( 15, 26,  3)=                 -0.10793057624562031604d0
      iwe=iwe+1
      weighta( 16, 26,  3)=                 -0.28255746408907578271d0
      iwe=iwe+1
      weighta( 17, 26,  3)=                 -0.10627481669021277000d0
      iwe=iwe+1
      weighta( 18, 26,  3)=                  0.09012785077366217146d0
      iwe=iwe+1
      weighta( 19, 26,  3)=                  0.23534057080333870005d0
      iwe=iwe+1
      weighta( 20, 26,  3)=                  0.17912515805420159420d0
      iwe=iwe+1
      weighta( 21, 26,  3)=                  0.18934703834409746803d0
      iwe=iwe+1
      weighta( 22, 26,  3)=                  0.32195597309330781233d0
      iwe=iwe+1
      weighta( 23, 26,  3)=                  0.25985914185868974613d0
      iwe=iwe+1
      weighta( 24, 26,  3)=                 -0.03364264378166208214d0
      iwe=iwe+1
      weighta( 25, 26,  3)=                 -0.29275758558822212452d0
      iwe=iwe+1
      weighta( 26, 26,  3)=                  0.18704127092592218173d0
      iwe=iwe+1
      weighta( 27, 26,  3)=                  0.35199285862386542334d0
      iwe=iwe+1
      weighta( 28, 26,  3)=                  0.00586708790438633318d0
      iwe=iwe+1
      weighta( 29, 26,  3)=                  0.17089698983257686771d0
      iwe=iwe+1
      weighta( 30, 26,  3)=                  0.27671859555262373620d0
      iwe=iwe+1
      weighta( 31, 26,  3)=                  0.03068347301614291617d0
      iwe=iwe+1
      weighta( 32, 26,  3)=                  0.35085182166247946833d0
      iwe=iwe+1
      weighta( 33, 26,  3)=                  0.11621196398742675293d0
      iwe=iwe+1
      weighta( 34, 26,  3)=                  0.28439351235196425050d0
      iwe=iwe+1
      weighta( 35, 26,  3)=                  0.02940107104778073160d0
      iwe=iwe+1
      weighta( 36, 26,  3)=                 -0.32854382609473958832d0
      iwe=iwe+1
      weighta( 37, 26,  3)=                  0.07906595767536840624d0
      iwe=iwe+1
      weighta( 38, 26,  3)=                  0.10358290617950695334d0
      iwe=iwe+1
      weighta( 39, 26,  3)=                 -0.14590827690943328210d0
      iwe=iwe+1
      weighta( 40, 26,  3)=                 -0.31771278927684620808d0
      iwe=iwe+1
      weighta( 41, 26,  3)=                  0.35591971700147834179d0
      iwe=iwe+1
      weighta( 42, 26,  3)=                 -0.14154477993497024957d0
      iwe=iwe+1
      weighta( 43, 26,  3)=                  0.17087005128381035912d0
      iwe=iwe+1
      weighta( 44, 26,  3)=                  0.29676618112031416530d0
      iwe=iwe+1
      weighta( 45, 26,  3)=                  0.11952201120908501064d0
      iwe=iwe+1
      weighta( 46, 26,  3)=                 -0.25192958745461946357d0
      iwe=iwe+1
      weighta( 47, 26,  3)=                 -0.34331475990081300464d0
      iwe=iwe+1
      weighta( 48, 26,  3)=                 -0.16369365220148276996d0
      iwe=iwe+1
      weighta( 49, 26,  3)=                 -0.07923603700719648868d0
      iwe=iwe+1
      weighta( 50, 26,  3)=                  0.26956610711401085556d0
      iwe=iwe+1
      biasa( 26,  3)=                  0.56414049772970786822d0
      iwe=iwe+1
      weighta(  1, 27,  3)=                  0.31181854775227058063d0
      iwe=iwe+1
      weighta(  2, 27,  3)=                 -0.01793980295846763287d0
      iwe=iwe+1
      weighta(  3, 27,  3)=                 -0.07818337474412292987d0
      iwe=iwe+1
      weighta(  4, 27,  3)=                  0.03974557629505085649d0
      iwe=iwe+1
      weighta(  5, 27,  3)=                  0.00452212688300719558d0
      iwe=iwe+1
      weighta(  6, 27,  3)=                 -0.19878684782037170375d0
      iwe=iwe+1
      weighta(  7, 27,  3)=                 -0.61939460712333793690d0
      iwe=iwe+1
      weighta(  8, 27,  3)=                 -0.61684495527244842528d0
      iwe=iwe+1
      weighta(  9, 27,  3)=                 -0.24993952906937705327d0
      iwe=iwe+1
      weighta( 10, 27,  3)=                 -0.06036230097273968115d0
      iwe=iwe+1
      weighta( 11, 27,  3)=                  0.31081174500865466070d0
      iwe=iwe+1
      weighta( 12, 27,  3)=                 -0.27749914156931992926d0
      iwe=iwe+1
      weighta( 13, 27,  3)=                  0.12949211605299967842d0
      iwe=iwe+1
      weighta( 14, 27,  3)=                  0.14268783373630861133d0
      iwe=iwe+1
      weighta( 15, 27,  3)=                 -0.32148084548341437916d0
      iwe=iwe+1
      weighta( 16, 27,  3)=                  0.12963598493334796413d0
      iwe=iwe+1
      weighta( 17, 27,  3)=                  0.10943224442906163141d0
      iwe=iwe+1
      weighta( 18, 27,  3)=                  0.24895326148494467677d0
      iwe=iwe+1
      weighta( 19, 27,  3)=                 -0.12690880441820706626d0
      iwe=iwe+1
      weighta( 20, 27,  3)=                 -0.03411373850023253357d0
      iwe=iwe+1
      weighta( 21, 27,  3)=                  0.00373905498060205128d0
      iwe=iwe+1
      weighta( 22, 27,  3)=                  0.21399290969291531739d0
      iwe=iwe+1
      weighta( 23, 27,  3)=                  0.03235945258956188925d0
      iwe=iwe+1
      weighta( 24, 27,  3)=                  0.45145950925566097345d0
      iwe=iwe+1
      weighta( 25, 27,  3)=                  0.30594485026206591494d0
      iwe=iwe+1
      weighta( 26, 27,  3)=                  0.19695585198331808097d0
      iwe=iwe+1
      weighta( 27, 27,  3)=                  0.31084815212446820221d0
      iwe=iwe+1
      weighta( 28, 27,  3)=                 -0.18546301826458091999d0
      iwe=iwe+1
      weighta( 29, 27,  3)=                  0.28453094052463040464d0
      iwe=iwe+1
      weighta( 30, 27,  3)=                  0.43662598413771858130d0
      iwe=iwe+1
      weighta( 31, 27,  3)=                  0.01552576926346319053d0
      iwe=iwe+1
      weighta( 32, 27,  3)=                  0.21689382858459094194d0
      iwe=iwe+1
      weighta( 33, 27,  3)=                 -0.25666663064916223069d0
      iwe=iwe+1
      weighta( 34, 27,  3)=                 -0.57234641815999376391d0
      iwe=iwe+1
      weighta( 35, 27,  3)=                 -0.28113446247402357203d0
      iwe=iwe+1
      weighta( 36, 27,  3)=                  0.28828329075432784778d0
      iwe=iwe+1
      weighta( 37, 27,  3)=                 -0.22629916568536861954d0
      iwe=iwe+1
      weighta( 38, 27,  3)=                  0.13336652741939272748d0
      iwe=iwe+1
      weighta( 39, 27,  3)=                 -0.20982545653386153184d0
      iwe=iwe+1
      weighta( 40, 27,  3)=                 -0.25871186032589432724d0
      iwe=iwe+1
      weighta( 41, 27,  3)=                 -0.06574025165508706747d0
      iwe=iwe+1
      weighta( 42, 27,  3)=                 -0.06397588769015404020d0
      iwe=iwe+1
      weighta( 43, 27,  3)=                 -0.22808660369306651972d0
      iwe=iwe+1
      weighta( 44, 27,  3)=                  0.31476677965497912304d0
      iwe=iwe+1
      weighta( 45, 27,  3)=                 -0.02522127201677003272d0
      iwe=iwe+1
      weighta( 46, 27,  3)=                 -0.12115586820190686612d0
      iwe=iwe+1
      weighta( 47, 27,  3)=                  0.20451052531581720428d0
      iwe=iwe+1
      weighta( 48, 27,  3)=                 -0.46247451338071021709d0
      iwe=iwe+1
      weighta( 49, 27,  3)=                  0.40551330740559204946d0
      iwe=iwe+1
      weighta( 50, 27,  3)=                 -0.27189989837683781193d0
      iwe=iwe+1
      biasa( 27,  3)=                 -0.64456609416927890255d0
      iwe=iwe+1
      weighta(  1, 28,  3)=                 -0.41337076593614813236d0
      iwe=iwe+1
      weighta(  2, 28,  3)=                 -0.08153198925228764826d0
      iwe=iwe+1
      weighta(  3, 28,  3)=                  0.03900265541298665595d0
      iwe=iwe+1
      weighta(  4, 28,  3)=                 -0.55796895419886438638d0
      iwe=iwe+1
      weighta(  5, 28,  3)=                  0.26716953061591663943d0
      iwe=iwe+1
      weighta(  6, 28,  3)=                 -0.67129802347962597153d0
      iwe=iwe+1
      weighta(  7, 28,  3)=                  0.08547745162908261529d0
      iwe=iwe+1
      weighta(  8, 28,  3)=                  0.12740846055777674262d0
      iwe=iwe+1
      weighta(  9, 28,  3)=                 -0.01774455856338408646d0
      iwe=iwe+1
      weighta( 10, 28,  3)=                  0.20286361785780224198d0
      iwe=iwe+1
      weighta( 11, 28,  3)=                  0.27700442351029092025d0
      iwe=iwe+1
      weighta( 12, 28,  3)=                  0.33947899151866567369d0
      iwe=iwe+1
      weighta( 13, 28,  3)=                 -0.42660323396772581450d0
      iwe=iwe+1
      weighta( 14, 28,  3)=                  0.36512042998664218096d0
      iwe=iwe+1
      weighta( 15, 28,  3)=                 -0.15761931014204061396d0
      iwe=iwe+1
      weighta( 16, 28,  3)=                  0.12732291989132338283d0
      iwe=iwe+1
      weighta( 17, 28,  3)=                  0.48151626844506678626d0
      iwe=iwe+1
      weighta( 18, 28,  3)=                  0.25846079338693905836d0
      iwe=iwe+1
      weighta( 19, 28,  3)=                  0.49567875005236033958d0
      iwe=iwe+1
      weighta( 20, 28,  3)=                 -0.05443666967772564647d0
      iwe=iwe+1
      weighta( 21, 28,  3)=                 -0.19618326133915764409d0
      iwe=iwe+1
      weighta( 22, 28,  3)=                 -0.07583051664381763868d0
      iwe=iwe+1
      weighta( 23, 28,  3)=                 -0.12916633068674485130d0
      iwe=iwe+1
      weighta( 24, 28,  3)=                  0.38506330596167986924d0
      iwe=iwe+1
      weighta( 25, 28,  3)=                 -0.15263027927441685794d0
      iwe=iwe+1
      weighta( 26, 28,  3)=                  0.78377277711013770833d0
      iwe=iwe+1
      weighta( 27, 28,  3)=                  0.26116753881542487115d0
      iwe=iwe+1
      weighta( 28, 28,  3)=                 -0.26374950118213008610d0
      iwe=iwe+1
      weighta( 29, 28,  3)=                  0.24515353579650492333d0
      iwe=iwe+1
      weighta( 30, 28,  3)=                 -0.11974258991900327276d0
      iwe=iwe+1
      weighta( 31, 28,  3)=                 -0.39506251261931052410d0
      iwe=iwe+1
      weighta( 32, 28,  3)=                 -0.10611413031414254626d0
      iwe=iwe+1
      weighta( 33, 28,  3)=                 -0.04594215283459890387d0
      iwe=iwe+1
      weighta( 34, 28,  3)=                  0.26383074807413314788d0
      iwe=iwe+1
      weighta( 35, 28,  3)=                 -0.29791478681463373634d0
      iwe=iwe+1
      weighta( 36, 28,  3)=                  0.04702450323392212000d0
      iwe=iwe+1
      weighta( 37, 28,  3)=                  0.04075444973715731944d0
      iwe=iwe+1
      weighta( 38, 28,  3)=                  0.53908838989188390123d0
      iwe=iwe+1
      weighta( 39, 28,  3)=                  0.07407654813419221884d0
      iwe=iwe+1
      weighta( 40, 28,  3)=                  0.11191122862958993722d0
      iwe=iwe+1
      weighta( 41, 28,  3)=                  0.43926494312932323760d0
      iwe=iwe+1
      weighta( 42, 28,  3)=                  0.11249424732617453737d0
      iwe=iwe+1
      weighta( 43, 28,  3)=                  0.01796953469156303482d0
      iwe=iwe+1
      weighta( 44, 28,  3)=                 -0.09053444274178849838d0
      iwe=iwe+1
      weighta( 45, 28,  3)=                 -0.56392668506925414107d0
      iwe=iwe+1
      weighta( 46, 28,  3)=                 -0.08365179611690508332d0
      iwe=iwe+1
      weighta( 47, 28,  3)=                 -0.04339561694303498141d0
      iwe=iwe+1
      weighta( 48, 28,  3)=                 -0.20728115590749976449d0
      iwe=iwe+1
      weighta( 49, 28,  3)=                  0.02548118878529546938d0
      iwe=iwe+1
      weighta( 50, 28,  3)=                 -0.28285784795781843126d0
      iwe=iwe+1
      biasa( 28,  3)=                  0.58671912938928483250d0
      iwe=iwe+1
      weighta(  1, 29,  3)=                 -0.38324194999101468539d0
      iwe=iwe+1
      weighta(  2, 29,  3)=                 -0.27049262523455935847d0
      iwe=iwe+1
      weighta(  3, 29,  3)=                  0.13413900419062910196d0
      iwe=iwe+1
      weighta(  4, 29,  3)=                  0.09387094232206640021d0
      iwe=iwe+1
      weighta(  5, 29,  3)=                  0.38665610691466506532d0
      iwe=iwe+1
      weighta(  6, 29,  3)=                 -0.90915427570553464243d0
      iwe=iwe+1
      weighta(  7, 29,  3)=                  0.07171260675357640779d0
      iwe=iwe+1
      weighta(  8, 29,  3)=                  0.08970165259983679806d0
      iwe=iwe+1
      weighta(  9, 29,  3)=                 -0.04224438004331185909d0
      iwe=iwe+1
      weighta( 10, 29,  3)=                 -0.39378104451512824236d0
      iwe=iwe+1
      weighta( 11, 29,  3)=                 -0.30162869380637957750d0
      iwe=iwe+1
      weighta( 12, 29,  3)=                  0.23124459943884034807d0
      iwe=iwe+1
      weighta( 13, 29,  3)=                 -0.32851395665109384137d0
      iwe=iwe+1
      weighta( 14, 29,  3)=                 -0.38406386029533323700d0
      iwe=iwe+1
      weighta( 15, 29,  3)=                  0.16755524393663659422d0
      iwe=iwe+1
      weighta( 16, 29,  3)=                  0.16785327278016359820d0
      iwe=iwe+1
      weighta( 17, 29,  3)=                 -0.20662622488727050429d0
      iwe=iwe+1
      weighta( 18, 29,  3)=                 -0.20909125230499628345d0
      iwe=iwe+1
      weighta( 19, 29,  3)=                  0.05062697009754630467d0
      iwe=iwe+1
      weighta( 20, 29,  3)=                  0.10993095402859685839d0
      iwe=iwe+1
      weighta( 21, 29,  3)=                 -0.24752000081378536245d0
      iwe=iwe+1
      weighta( 22, 29,  3)=                  0.07160707472971040988d0
      iwe=iwe+1
      weighta( 23, 29,  3)=                  0.16625448425122543727d0
      iwe=iwe+1
      weighta( 24, 29,  3)=                  0.35065752726656179705d0
      iwe=iwe+1
      weighta( 25, 29,  3)=                 -0.14781689867678726724d0
      iwe=iwe+1
      weighta( 26, 29,  3)=                 -0.29220752891951362606d0
      iwe=iwe+1
      weighta( 27, 29,  3)=                 -0.23010842737392844803d0
      iwe=iwe+1
      weighta( 28, 29,  3)=                  0.29162585077006880629d0
      iwe=iwe+1
      weighta( 29, 29,  3)=                 -0.12157168355483358169d0
      iwe=iwe+1
      weighta( 30, 29,  3)=                 -0.15756973652873459968d0
      iwe=iwe+1
      weighta( 31, 29,  3)=                 -0.05120402507755150712d0
      iwe=iwe+1
      weighta( 32, 29,  3)=                  0.08178449000901616417d0
      iwe=iwe+1
      weighta( 33, 29,  3)=                 -0.19099897991613973280d0
      iwe=iwe+1
      weighta( 34, 29,  3)=                  0.34366108666714018094d0
      iwe=iwe+1
      weighta( 35, 29,  3)=                 -0.20993530325580073148d0
      iwe=iwe+1
      weighta( 36, 29,  3)=                  0.10861279234290693863d0
      iwe=iwe+1
      weighta( 37, 29,  3)=                  0.37579154216745469519d0
      iwe=iwe+1
      weighta( 38, 29,  3)=                 -0.27984610754003730326d0
      iwe=iwe+1
      weighta( 39, 29,  3)=                  0.30275607473657750734d0
      iwe=iwe+1
      weighta( 40, 29,  3)=                 -0.01705808508460021980d0
      iwe=iwe+1
      weighta( 41, 29,  3)=                 -0.30357466225381057878d0
      iwe=iwe+1
      weighta( 42, 29,  3)=                 -0.41212900686841252851d0
      iwe=iwe+1
      weighta( 43, 29,  3)=                 -0.17688127096028855023d0
      iwe=iwe+1
      weighta( 44, 29,  3)=                  0.07910792974901520447d0
      iwe=iwe+1
      weighta( 45, 29,  3)=                 -0.21279539204038641631d0
      iwe=iwe+1
      weighta( 46, 29,  3)=                 -0.37919825770138171350d0
      iwe=iwe+1
      weighta( 47, 29,  3)=                  0.01004312493292431815d0
      iwe=iwe+1
      weighta( 48, 29,  3)=                  0.34002665750354527097d0
      iwe=iwe+1
      weighta( 49, 29,  3)=                  0.08631309559557927280d0
      iwe=iwe+1
      weighta( 50, 29,  3)=                 -0.31953321023089853448d0
      iwe=iwe+1
      biasa( 29,  3)=                  0.27975792544119981731d0
      iwe=iwe+1
      weighta(  1, 30,  3)=                 -0.04369216762116875236d0
      iwe=iwe+1
      weighta(  2, 30,  3)=                  0.27629130760048897786d0
      iwe=iwe+1
      weighta(  3, 30,  3)=                  0.15447976316167738586d0
      iwe=iwe+1
      weighta(  4, 30,  3)=                 -0.27084296710226962723d0
      iwe=iwe+1
      weighta(  5, 30,  3)=                 -0.44996064136083818719d0
      iwe=iwe+1
      weighta(  6, 30,  3)=                 -0.14396391701758443071d0
      iwe=iwe+1
      weighta(  7, 30,  3)=                  0.16290534403803880181d0
      iwe=iwe+1
      weighta(  8, 30,  3)=                  0.36631633251821049679d0
      iwe=iwe+1
      weighta(  9, 30,  3)=                  0.26510877647101832588d0
      iwe=iwe+1
      weighta( 10, 30,  3)=                 -0.28045387302724406053d0
      iwe=iwe+1
      weighta( 11, 30,  3)=                  0.09108382615949368877d0
      iwe=iwe+1
      weighta( 12, 30,  3)=                 -0.05328365745282788446d0
      iwe=iwe+1
      weighta( 13, 30,  3)=                 -0.02857560711540083065d0
      iwe=iwe+1
      weighta( 14, 30,  3)=                 -0.23750730856825974513d0
      iwe=iwe+1
      weighta( 15, 30,  3)=                 -0.06003985955276289893d0
      iwe=iwe+1
      weighta( 16, 30,  3)=                 -0.08856111855913165187d0
      iwe=iwe+1
      weighta( 17, 30,  3)=                  0.27149254912369341630d0
      iwe=iwe+1
      weighta( 18, 30,  3)=                  0.23498664485458367612d0
      iwe=iwe+1
      weighta( 19, 30,  3)=                 -0.11709524876367258250d0
      iwe=iwe+1
      weighta( 20, 30,  3)=                 -0.19693120686887005677d0
      iwe=iwe+1
      weighta( 21, 30,  3)=                 -0.35827944482239632018d0
      iwe=iwe+1
      weighta( 22, 30,  3)=                 -0.18744189019912749217d0
      iwe=iwe+1
      weighta( 23, 30,  3)=                  0.22193485369732443568d0
      iwe=iwe+1
      weighta( 24, 30,  3)=                 -0.01761822081904615422d0
      iwe=iwe+1
      weighta( 25, 30,  3)=                 -0.10064648345949887831d0
      iwe=iwe+1
      weighta( 26, 30,  3)=                 -0.01371457642550678001d0
      iwe=iwe+1
      weighta( 27, 30,  3)=                  0.32789304201433544517d0
      iwe=iwe+1
      weighta( 28, 30,  3)=                 -0.05838087669503982252d0
      iwe=iwe+1
      weighta( 29, 30,  3)=                  0.13031581342085343800d0
      iwe=iwe+1
      weighta( 30, 30,  3)=                 -0.00539496072051889441d0
      iwe=iwe+1
      weighta( 31, 30,  3)=                 -0.08671309857784044450d0
      iwe=iwe+1
      weighta( 32, 30,  3)=                  0.02168392437142588336d0
      iwe=iwe+1
      weighta( 33, 30,  3)=                 -0.23525637093053874960d0
      iwe=iwe+1
      weighta( 34, 30,  3)=                  0.47879538961260315055d0
      iwe=iwe+1
      weighta( 35, 30,  3)=                 -0.14520899088693239865d0
      iwe=iwe+1
      weighta( 36, 30,  3)=                  0.13318367145435422438d0
      iwe=iwe+1
      weighta( 37, 30,  3)=                 -0.02729307815784210237d0
      iwe=iwe+1
      weighta( 38, 30,  3)=                 -0.06676491742954983322d0
      iwe=iwe+1
      weighta( 39, 30,  3)=                  0.31854595288047254931d0
      iwe=iwe+1
      weighta( 40, 30,  3)=                  0.23942938429015428459d0
      iwe=iwe+1
      weighta( 41, 30,  3)=                 -0.59237037463926833780d0
      iwe=iwe+1
      weighta( 42, 30,  3)=                 -0.56606851911307332070d0
      iwe=iwe+1
      weighta( 43, 30,  3)=                  0.23802417042332854602d0
      iwe=iwe+1
      weighta( 44, 30,  3)=                 -0.28578136111461155400d0
      iwe=iwe+1
      weighta( 45, 30,  3)=                 -0.02149845241761913148d0
      iwe=iwe+1
      weighta( 46, 30,  3)=                 -0.24977419103979972559d0
      iwe=iwe+1
      weighta( 47, 30,  3)=                  0.41423183731092239057d0
      iwe=iwe+1
      weighta( 48, 30,  3)=                 -0.10639392322070681529d0
      iwe=iwe+1
      weighta( 49, 30,  3)=                  0.12146840428998177674d0
      iwe=iwe+1
      weighta( 50, 30,  3)=                  0.31886888200530039139d0
      iwe=iwe+1
      biasa( 30,  3)=                  0.43996947288443316593d0
      iwe=iwe+1
      weighta(  1, 31,  3)=                  0.07641540220069435729d0
      iwe=iwe+1
      weighta(  2, 31,  3)=                 -0.06093018805299070528d0
      iwe=iwe+1
      weighta(  3, 31,  3)=                  0.03307444318553349333d0
      iwe=iwe+1
      weighta(  4, 31,  3)=                  0.01739637761961330617d0
      iwe=iwe+1
      weighta(  5, 31,  3)=                 -0.17563769606701673531d0
      iwe=iwe+1
      weighta(  6, 31,  3)=                 -0.36736919906077092346d0
      iwe=iwe+1
      weighta(  7, 31,  3)=                  0.06189752932623766857d0
      iwe=iwe+1
      weighta(  8, 31,  3)=                  0.47912038066797746350d0
      iwe=iwe+1
      weighta(  9, 31,  3)=                 -0.32046776437145463312d0
      iwe=iwe+1
      weighta( 10, 31,  3)=                  0.64260494937273338056d0
      iwe=iwe+1
      weighta( 11, 31,  3)=                  0.21697019831465935713d0
      iwe=iwe+1
      weighta( 12, 31,  3)=                  0.25648808760065422430d0
      iwe=iwe+1
      weighta( 13, 31,  3)=                  0.28739273817239641140d0
      iwe=iwe+1
      weighta( 14, 31,  3)=                 -0.33085485427243765955d0
      iwe=iwe+1
      weighta( 15, 31,  3)=                 -0.34702036451535034356d0
      iwe=iwe+1
      weighta( 16, 31,  3)=                 -0.39063106217698573275d0
      iwe=iwe+1
      weighta( 17, 31,  3)=                  0.07792129203025603690d0
      iwe=iwe+1
      weighta( 18, 31,  3)=                 -0.35881190284025182846d0
      iwe=iwe+1
      weighta( 19, 31,  3)=                  0.29858478702191937337d0
      iwe=iwe+1
      weighta( 20, 31,  3)=                 -0.10705790068005623106d0
      iwe=iwe+1
      weighta( 21, 31,  3)=                  0.13724269310462003379d0
      iwe=iwe+1
      weighta( 22, 31,  3)=                 -0.41606613330542741025d0
      iwe=iwe+1
      weighta( 23, 31,  3)=                 -0.16156409744399008455d0
      iwe=iwe+1
      weighta( 24, 31,  3)=                 -0.02778502569326146004d0
      iwe=iwe+1
      weighta( 25, 31,  3)=                 -0.07278057154121414518d0
      iwe=iwe+1
      weighta( 26, 31,  3)=                  0.16640468750186021563d0
      iwe=iwe+1
      weighta( 27, 31,  3)=                 -0.60036505823713171015d0
      iwe=iwe+1
      weighta( 28, 31,  3)=                 -0.55607363606582260740d0
      iwe=iwe+1
      weighta( 29, 31,  3)=                 -0.04992714939149454217d0
      iwe=iwe+1
      weighta( 30, 31,  3)=                 -0.14569236099602353440d0
      iwe=iwe+1
      weighta( 31, 31,  3)=                  0.51003563408545804503d0
      iwe=iwe+1
      weighta( 32, 31,  3)=                 -0.20167713637158396489d0
      iwe=iwe+1
      weighta( 33, 31,  3)=                  0.13775101242899648324d0
      iwe=iwe+1
      weighta( 34, 31,  3)=                 -0.63107010196566037941d0
      iwe=iwe+1
      weighta( 35, 31,  3)=                  0.21472534006544671814d0
      iwe=iwe+1
      weighta( 36, 31,  3)=                 -0.16279675722228850732d0
      iwe=iwe+1
      weighta( 37, 31,  3)=                 -0.22653843649157429097d0
      iwe=iwe+1
      weighta( 38, 31,  3)=                  0.21887323123849913853d0
      iwe=iwe+1
      weighta( 39, 31,  3)=                  0.02319659836649437881d0
      iwe=iwe+1
      weighta( 40, 31,  3)=                 -0.07781195433521106986d0
      iwe=iwe+1
      weighta( 41, 31,  3)=                  0.20345877251029481636d0
      iwe=iwe+1
      weighta( 42, 31,  3)=                 -0.31014334182983932520d0
      iwe=iwe+1
      weighta( 43, 31,  3)=                  0.26506143319384112278d0
      iwe=iwe+1
      weighta( 44, 31,  3)=                  0.30751879753505834136d0
      iwe=iwe+1
      weighta( 45, 31,  3)=                  0.02653308093699457970d0
      iwe=iwe+1
      weighta( 46, 31,  3)=                  0.26008110184291283185d0
      iwe=iwe+1
      weighta( 47, 31,  3)=                  0.30874820126084379091d0
      iwe=iwe+1
      weighta( 48, 31,  3)=                 -0.54292390990923811156d0
      iwe=iwe+1
      weighta( 49, 31,  3)=                  0.24322040145837048319d0
      iwe=iwe+1
      weighta( 50, 31,  3)=                 -0.38861512208848242311d0
      iwe=iwe+1
      biasa( 31,  3)=                 -0.26103743274665419660d0
      iwe=iwe+1
      weighta(  1, 32,  3)=                  0.03904091774129934966d0
      iwe=iwe+1
      weighta(  2, 32,  3)=                 -0.29613004093827799412d0
      iwe=iwe+1
      weighta(  3, 32,  3)=                 -0.29705652066689280932d0
      iwe=iwe+1
      weighta(  4, 32,  3)=                  0.12655114719747531660d0
      iwe=iwe+1
      weighta(  5, 32,  3)=                  0.04018977695765144076d0
      iwe=iwe+1
      weighta(  6, 32,  3)=                  0.18534208171139066046d0
      iwe=iwe+1
      weighta(  7, 32,  3)=                  0.14460981597206645777d0
      iwe=iwe+1
      weighta(  8, 32,  3)=                  0.26548179531994919866d0
      iwe=iwe+1
      weighta(  9, 32,  3)=                 -0.18902284945563987972d0
      iwe=iwe+1
      weighta( 10, 32,  3)=                  0.32202021741139019717d0
      iwe=iwe+1
      weighta( 11, 32,  3)=                 -0.17372844849743557250d0
      iwe=iwe+1
      weighta( 12, 32,  3)=                  0.13493705159414282058d0
      iwe=iwe+1
      weighta( 13, 32,  3)=                  0.31863936936677145217d0
      iwe=iwe+1
      weighta( 14, 32,  3)=                  0.39741209637253316345d0
      iwe=iwe+1
      weighta( 15, 32,  3)=                 -0.06327594234921660177d0
      iwe=iwe+1
      weighta( 16, 32,  3)=                 -0.30182289873414264170d0
      iwe=iwe+1
      weighta( 17, 32,  3)=                 -0.18711593003740351060d0
      iwe=iwe+1
      weighta( 18, 32,  3)=                 -0.12621228309821336255d0
      iwe=iwe+1
      weighta( 19, 32,  3)=                  0.10479466894582514791d0
      iwe=iwe+1
      weighta( 20, 32,  3)=                  0.33221315955198427172d0
      iwe=iwe+1
      weighta( 21, 32,  3)=                 -0.27860868453755410767d0
      iwe=iwe+1
      weighta( 22, 32,  3)=                  0.09985450811461893394d0
      iwe=iwe+1
      weighta( 23, 32,  3)=                  0.22953425281453956885d0
      iwe=iwe+1
      weighta( 24, 32,  3)=                 -0.33952964864893075969d0
      iwe=iwe+1
      weighta( 25, 32,  3)=                  0.07388284324704773309d0
      iwe=iwe+1
      weighta( 26, 32,  3)=                  0.50160251822819856837d0
      iwe=iwe+1
      weighta( 27, 32,  3)=                 -0.37266068333045243577d0
      iwe=iwe+1
      weighta( 28, 32,  3)=                  0.29481728941259355281d0
      iwe=iwe+1
      weighta( 29, 32,  3)=                  0.56390291381151158578d0
      iwe=iwe+1
      weighta( 30, 32,  3)=                 -0.09115084065144099523d0
      iwe=iwe+1
      weighta( 31, 32,  3)=                 -0.19217152326101680226d0
      iwe=iwe+1
      weighta( 32, 32,  3)=                  0.37221476503887157561d0
      iwe=iwe+1
      weighta( 33, 32,  3)=                 -0.62886297935677093474d0
      iwe=iwe+1
      weighta( 34, 32,  3)=                  0.38053026806014500494d0
      iwe=iwe+1
      weighta( 35, 32,  3)=                 -0.28160016058686743179d0
      iwe=iwe+1
      weighta( 36, 32,  3)=                  0.19470962003407496499d0
      iwe=iwe+1
      weighta( 37, 32,  3)=                  0.19293123321490276978d0
      iwe=iwe+1
      weighta( 38, 32,  3)=                  0.37294402013698518816d0
      iwe=iwe+1
      weighta( 39, 32,  3)=                  0.13404814678956633589d0
      iwe=iwe+1
      weighta( 40, 32,  3)=                  0.12735649504042792501d0
      iwe=iwe+1
      weighta( 41, 32,  3)=                 -0.16607648459215432202d0
      iwe=iwe+1
      weighta( 42, 32,  3)=                 -0.32452128486405884544d0
      iwe=iwe+1
      weighta( 43, 32,  3)=                  0.62517072976553533792d0
      iwe=iwe+1
      weighta( 44, 32,  3)=                 -0.24414342087792967328d0
      iwe=iwe+1
      weighta( 45, 32,  3)=                  0.46592942710540846685d0
      iwe=iwe+1
      weighta( 46, 32,  3)=                  0.01677086761727054898d0
      iwe=iwe+1
      weighta( 47, 32,  3)=                 -0.08026440588846954494d0
      iwe=iwe+1
      weighta( 48, 32,  3)=                  0.72711801880816806509d0
      iwe=iwe+1
      weighta( 49, 32,  3)=                 -0.17646005969758676857d0
      iwe=iwe+1
      weighta( 50, 32,  3)=                 -0.24628625507400958572d0
      iwe=iwe+1
      biasa( 32,  3)=                  0.36879727602418588273d0
      iwe=iwe+1
      weighta(  1, 33,  3)=                  0.08689759973646662972d0
      iwe=iwe+1
      weighta(  2, 33,  3)=                 -0.00585577523722426684d0
      iwe=iwe+1
      weighta(  3, 33,  3)=                 -0.01093050299290019775d0
      iwe=iwe+1
      weighta(  4, 33,  3)=                 -0.05746338574355703416d0
      iwe=iwe+1
      weighta(  5, 33,  3)=                 -0.45337998055012362908d0
      iwe=iwe+1
      weighta(  6, 33,  3)=                 -0.31677005388448492562d0
      iwe=iwe+1
      weighta(  7, 33,  3)=                 -0.01481862347603580057d0
      iwe=iwe+1
      weighta(  8, 33,  3)=                  0.13851062510547115791d0
      iwe=iwe+1
      weighta(  9, 33,  3)=                  0.01410366022004229218d0
      iwe=iwe+1
      weighta( 10, 33,  3)=                  0.30039447364010402053d0
      iwe=iwe+1
      weighta( 11, 33,  3)=                 -0.22096436228328275586d0
      iwe=iwe+1
      weighta( 12, 33,  3)=                  0.17985307146201690021d0
      iwe=iwe+1
      weighta( 13, 33,  3)=                 -0.26114194696180809130d0
      iwe=iwe+1
      weighta( 14, 33,  3)=                 -0.34568230056104176651d0
      iwe=iwe+1
      weighta( 15, 33,  3)=                  0.13704485039695896154d0
      iwe=iwe+1
      weighta( 16, 33,  3)=                 -0.08397232893513734142d0
      iwe=iwe+1
      weighta( 17, 33,  3)=                 -0.00766794717019631932d0
      iwe=iwe+1
      weighta( 18, 33,  3)=                  0.02480370790389017921d0
      iwe=iwe+1
      weighta( 19, 33,  3)=                 -0.38501983674619527642d0
      iwe=iwe+1
      weighta( 20, 33,  3)=                 -0.37678275898544938416d0
      iwe=iwe+1
      weighta( 21, 33,  3)=                  0.21800482959474354328d0
      iwe=iwe+1
      weighta( 22, 33,  3)=                 -0.17601710620170316068d0
      iwe=iwe+1
      weighta( 23, 33,  3)=                 -0.14455543105607138177d0
      iwe=iwe+1
      weighta( 24, 33,  3)=                 -0.15071510643591962131d0
      iwe=iwe+1
      weighta( 25, 33,  3)=                  0.21627650577985987890d0
      iwe=iwe+1
      weighta( 26, 33,  3)=                 -0.63805837063836357004d0
      iwe=iwe+1
      weighta( 27, 33,  3)=                  0.22161568991655508643d0
      iwe=iwe+1
      weighta( 28, 33,  3)=                 -0.08123665108955374636d0
      iwe=iwe+1
      weighta( 29, 33,  3)=                 -0.22142759484561760908d0
      iwe=iwe+1
      weighta( 30, 33,  3)=                 -0.32462767072590209549d0
      iwe=iwe+1
      weighta( 31, 33,  3)=                 -0.31410788461451832898d0
      iwe=iwe+1
      weighta( 32, 33,  3)=                 -0.70602454704257111562d0
      iwe=iwe+1
      weighta( 33, 33,  3)=                 -0.00227154925196156173d0
      iwe=iwe+1
      weighta( 34, 33,  3)=                  0.20033330853970943153d0
      iwe=iwe+1
      weighta( 35, 33,  3)=                 -0.40605781154941816835d0
      iwe=iwe+1
      weighta( 36, 33,  3)=                  0.19158999460823714078d0
      iwe=iwe+1
      weighta( 37, 33,  3)=                  0.34822980048426904753d0
      iwe=iwe+1
      weighta( 38, 33,  3)=                  0.25484015232914897231d0
      iwe=iwe+1
      weighta( 39, 33,  3)=                 -0.26411045903922003575d0
      iwe=iwe+1
      weighta( 40, 33,  3)=                  0.07091211582170736660d0
      iwe=iwe+1
      weighta( 41, 33,  3)=                  0.19505835434382404192d0
      iwe=iwe+1
      weighta( 42, 33,  3)=                  0.50448007225352375915d0
      iwe=iwe+1
      weighta( 43, 33,  3)=                  0.35264432250352911735d0
      iwe=iwe+1
      weighta( 44, 33,  3)=                  0.18852459178046523935d0
      iwe=iwe+1
      weighta( 45, 33,  3)=                 -0.33736497881226068518d0
      iwe=iwe+1
      weighta( 46, 33,  3)=                  0.29450377717987852311d0
      iwe=iwe+1
      weighta( 47, 33,  3)=                 -0.34872111749555384508d0
      iwe=iwe+1
      weighta( 48, 33,  3)=                  0.42310705261633729801d0
      iwe=iwe+1
      weighta( 49, 33,  3)=                 -0.05216374910456654523d0
      iwe=iwe+1
      weighta( 50, 33,  3)=                 -0.40346417390473243714d0
      iwe=iwe+1
      biasa( 33,  3)=                 -0.14864581117314862313d0
      iwe=iwe+1
      weighta(  1, 34,  3)=                 -0.21696802198208858803d0
      iwe=iwe+1
      weighta(  2, 34,  3)=                 -0.12309567256026551774d0
      iwe=iwe+1
      weighta(  3, 34,  3)=                  0.13307936118181107332d0
      iwe=iwe+1
      weighta(  4, 34,  3)=                  0.08513253920397206853d0
      iwe=iwe+1
      weighta(  5, 34,  3)=                 -0.05391420353009106908d0
      iwe=iwe+1
      weighta(  6, 34,  3)=                 -0.06448589678224830868d0
      iwe=iwe+1
      weighta(  7, 34,  3)=                  0.19299872708900839280d0
      iwe=iwe+1
      weighta(  8, 34,  3)=                  0.07810829674390491750d0
      iwe=iwe+1
      weighta(  9, 34,  3)=                 -0.14848931917082655585d0
      iwe=iwe+1
      weighta( 10, 34,  3)=                  0.29101172488503157521d0
      iwe=iwe+1
      weighta( 11, 34,  3)=                  0.13071756822700891787d0
      iwe=iwe+1
      weighta( 12, 34,  3)=                 -0.20052374564683905778d0
      iwe=iwe+1
      weighta( 13, 34,  3)=                 -0.44650977101502636879d0
      iwe=iwe+1
      weighta( 14, 34,  3)=                  0.21900735955973479885d0
      iwe=iwe+1
      weighta( 15, 34,  3)=                 -0.23382102436742158158d0
      iwe=iwe+1
      weighta( 16, 34,  3)=                 -0.59776738462877299085d0
      iwe=iwe+1
      weighta( 17, 34,  3)=                 -0.23737194966287458731d0
      iwe=iwe+1
      weighta( 18, 34,  3)=                 -0.45966249441592549330d0
      iwe=iwe+1
      weighta( 19, 34,  3)=                 -0.13309782759046492884d0
      iwe=iwe+1
      weighta( 20, 34,  3)=                  0.13006244274934572469d0
      iwe=iwe+1
      weighta( 21, 34,  3)=                 -0.27400199111930639839d0
      iwe=iwe+1
      weighta( 22, 34,  3)=                  0.25485440106500190094d0
      iwe=iwe+1
      weighta( 23, 34,  3)=                  0.11343796636619028761d0
      iwe=iwe+1
      weighta( 24, 34,  3)=                 -0.04362459187468908928d0
      iwe=iwe+1
      weighta( 25, 34,  3)=                  0.55123441028366837457d0
      iwe=iwe+1
      weighta( 26, 34,  3)=                 -0.18064499389411131647d0
      iwe=iwe+1
      weighta( 27, 34,  3)=                 -0.27980928549216221857d0
      iwe=iwe+1
      weighta( 28, 34,  3)=                  0.09542123952229461525d0
      iwe=iwe+1
      weighta( 29, 34,  3)=                 -0.12244342500383165184d0
      iwe=iwe+1
      weighta( 30, 34,  3)=                 -0.06529598806621644824d0
      iwe=iwe+1
      weighta( 31, 34,  3)=                  0.28533391678847541684d0
      iwe=iwe+1
      weighta( 32, 34,  3)=                 -0.13887431586578402598d0
      iwe=iwe+1
      weighta( 33, 34,  3)=                  0.08400631803596503300d0
      iwe=iwe+1
      weighta( 34, 34,  3)=                  0.10188744860438178619d0
      iwe=iwe+1
      weighta( 35, 34,  3)=                 -0.41439324404245136968d0
      iwe=iwe+1
      weighta( 36, 34,  3)=                  0.17823658483056062374d0
      iwe=iwe+1
      weighta( 37, 34,  3)=                 -0.09723132403748920016d0
      iwe=iwe+1
      weighta( 38, 34,  3)=                 -0.11659893650685988764d0
      iwe=iwe+1
      weighta( 39, 34,  3)=                  0.07380063838420466982d0
      iwe=iwe+1
      weighta( 40, 34,  3)=                  0.31333041183360510473d0
      iwe=iwe+1
      weighta( 41, 34,  3)=                 -0.04860887585504326813d0
      iwe=iwe+1
      weighta( 42, 34,  3)=                 -0.63313040159905986659d0
      iwe=iwe+1
      weighta( 43, 34,  3)=                 -0.07074491525146220372d0
      iwe=iwe+1
      weighta( 44, 34,  3)=                  0.30865591800748876095d0
      iwe=iwe+1
      weighta( 45, 34,  3)=                 -0.00109317403485702865d0
      iwe=iwe+1
      weighta( 46, 34,  3)=                 -0.42124693354737413609d0
      iwe=iwe+1
      weighta( 47, 34,  3)=                  0.15921267004696862402d0
      iwe=iwe+1
      weighta( 48, 34,  3)=                  0.20896620956676312253d0
      iwe=iwe+1
      weighta( 49, 34,  3)=                  0.21443899449840267413d0
      iwe=iwe+1
      weighta( 50, 34,  3)=                  0.07488271002261702447d0
      iwe=iwe+1
      biasa( 34,  3)=                  0.30964501604457406181d0
      iwe=iwe+1
      weighta(  1, 35,  3)=                 -0.58173318542704155476d0
      iwe=iwe+1
      weighta(  2, 35,  3)=                 -0.27195509316857774396d0
      iwe=iwe+1
      weighta(  3, 35,  3)=                  0.33021347193917455209d0
      iwe=iwe+1
      weighta(  4, 35,  3)=                  0.20919040528832555381d0
      iwe=iwe+1
      weighta(  5, 35,  3)=                  0.27706812520039769687d0
      iwe=iwe+1
      weighta(  6, 35,  3)=                  0.06636328822879962452d0
      iwe=iwe+1
      weighta(  7, 35,  3)=                 -0.30265448218452073448d0
      iwe=iwe+1
      weighta(  8, 35,  3)=                  0.17055639237210598602d0
      iwe=iwe+1
      weighta(  9, 35,  3)=                  0.08412210775892313419d0
      iwe=iwe+1
      weighta( 10, 35,  3)=                 -0.35906405742766811517d0
      iwe=iwe+1
      weighta( 11, 35,  3)=                  0.10162465124809015593d0
      iwe=iwe+1
      weighta( 12, 35,  3)=                 -0.11527817743832508013d0
      iwe=iwe+1
      weighta( 13, 35,  3)=                 -0.18133553613010275352d0
      iwe=iwe+1
      weighta( 14, 35,  3)=                 -0.22019383923336868780d0
      iwe=iwe+1
      weighta( 15, 35,  3)=                 -0.09758204329714238734d0
      iwe=iwe+1
      weighta( 16, 35,  3)=                  0.04549859278686757547d0
      iwe=iwe+1
      weighta( 17, 35,  3)=                  0.05663953538928984816d0
      iwe=iwe+1
      weighta( 18, 35,  3)=                 -0.36270792683888386509d0
      iwe=iwe+1
      weighta( 19, 35,  3)=                  0.15774321564931942374d0
      iwe=iwe+1
      weighta( 20, 35,  3)=                 -0.07964177753090208312d0
      iwe=iwe+1
      weighta( 21, 35,  3)=                 -0.36933983882890769612d0
      iwe=iwe+1
      weighta( 22, 35,  3)=                  0.28919018897624443332d0
      iwe=iwe+1
      weighta( 23, 35,  3)=                  0.04329302500326323577d0
      iwe=iwe+1
      weighta( 24, 35,  3)=                 -0.07988841348750191917d0
      iwe=iwe+1
      weighta( 25, 35,  3)=                  0.13971720664845119209d0
      iwe=iwe+1
      weighta( 26, 35,  3)=                 -0.27559087883263821972d0
      iwe=iwe+1
      weighta( 27, 35,  3)=                 -0.42309230452854679205d0
      iwe=iwe+1
      weighta( 28, 35,  3)=                 -0.00367581173313793336d0
      iwe=iwe+1
      weighta( 29, 35,  3)=                 -0.27121742805210763416d0
      iwe=iwe+1
      weighta( 30, 35,  3)=                 -0.32487373778796430068d0
      iwe=iwe+1
      weighta( 31, 35,  3)=                  0.31050516150421869632d0
      iwe=iwe+1
      weighta( 32, 35,  3)=                  0.30004087577720095492d0
      iwe=iwe+1
      weighta( 33, 35,  3)=                  0.38466696704949687735d0
      iwe=iwe+1
      weighta( 34, 35,  3)=                 -0.00418546444845605686d0
      iwe=iwe+1
      weighta( 35, 35,  3)=                  0.35212205754342457142d0
      iwe=iwe+1
      weighta( 36, 35,  3)=                 -0.02704717354661287376d0
      iwe=iwe+1
      weighta( 37, 35,  3)=                  0.31773117158969349516d0
      iwe=iwe+1
      weighta( 38, 35,  3)=                  0.09191344862345947331d0
      iwe=iwe+1
      weighta( 39, 35,  3)=                 -0.03599657229931835234d0
      iwe=iwe+1
      weighta( 40, 35,  3)=                 -0.23078195588563923946d0
      iwe=iwe+1
      weighta( 41, 35,  3)=                  0.31367223038719654893d0
      iwe=iwe+1
      weighta( 42, 35,  3)=                 -0.13269603835620202847d0
      iwe=iwe+1
      weighta( 43, 35,  3)=                  0.02333284231962453117d0
      iwe=iwe+1
      weighta( 44, 35,  3)=                 -0.01951490843109336334d0
      iwe=iwe+1
      weighta( 45, 35,  3)=                  0.05927041899436276406d0
      iwe=iwe+1
      weighta( 46, 35,  3)=                 -0.26989058992636144607d0
      iwe=iwe+1
      weighta( 47, 35,  3)=                 -0.04051471131428918682d0
      iwe=iwe+1
      weighta( 48, 35,  3)=                 -0.27808065693799349782d0
      iwe=iwe+1
      weighta( 49, 35,  3)=                  0.19546367322411853373d0
      iwe=iwe+1
      weighta( 50, 35,  3)=                  0.07707034994339485856d0
      iwe=iwe+1
      biasa( 35,  3)=                  0.23201376421843569742d0
      iwe=iwe+1
      weighta(  1, 36,  3)=                  0.08033292185475168767d0
      iwe=iwe+1
      weighta(  2, 36,  3)=                 -0.11371726085200611900d0
      iwe=iwe+1
      weighta(  3, 36,  3)=                  0.21399998918271376236d0
      iwe=iwe+1
      weighta(  4, 36,  3)=                 -0.31986220827058670091d0
      iwe=iwe+1
      weighta(  5, 36,  3)=                 -0.16395123427744676126d0
      iwe=iwe+1
      weighta(  6, 36,  3)=                 -0.38463559880619718756d0
      iwe=iwe+1
      weighta(  7, 36,  3)=                 -0.05718789848301834150d0
      iwe=iwe+1
      weighta(  8, 36,  3)=                  0.27036705732664362278d0
      iwe=iwe+1
      weighta(  9, 36,  3)=                  0.26564542987103884064d0
      iwe=iwe+1
      weighta( 10, 36,  3)=                  0.03921109572102886992d0
      iwe=iwe+1
      weighta( 11, 36,  3)=                  0.55001101871396951282d0
      iwe=iwe+1
      weighta( 12, 36,  3)=                  0.05580373162811660959d0
      iwe=iwe+1
      weighta( 13, 36,  3)=                  0.28744496828453719450d0
      iwe=iwe+1
      weighta( 14, 36,  3)=                 -0.21914454561134136257d0
      iwe=iwe+1
      weighta( 15, 36,  3)=                 -0.03670247418646321869d0
      iwe=iwe+1
      weighta( 16, 36,  3)=                 -0.05775169739742525010d0
      iwe=iwe+1
      weighta( 17, 36,  3)=                 -0.09196287033684279189d0
      iwe=iwe+1
      weighta( 18, 36,  3)=                 -0.15784478771012802611d0
      iwe=iwe+1
      weighta( 19, 36,  3)=                 -0.26778313549508536706d0
      iwe=iwe+1
      weighta( 20, 36,  3)=                 -0.12391108521072652371d0
      iwe=iwe+1
      weighta( 21, 36,  3)=                 -0.17753156123041055614d0
      iwe=iwe+1
      weighta( 22, 36,  3)=                  0.18044833102394117197d0
      iwe=iwe+1
      weighta( 23, 36,  3)=                 -0.05572512641087001839d0
      iwe=iwe+1
      weighta( 24, 36,  3)=                 -0.10024882751151983906d0
      iwe=iwe+1
      weighta( 25, 36,  3)=                  0.03232023403606289202d0
      iwe=iwe+1
      weighta( 26, 36,  3)=                 -0.38521000865791199530d0
      iwe=iwe+1
      weighta( 27, 36,  3)=                  0.13516795594079877851d0
      iwe=iwe+1
      weighta( 28, 36,  3)=                 -0.11567190404496439926d0
      iwe=iwe+1
      weighta( 29, 36,  3)=                  0.62361162651451362837d0
      iwe=iwe+1
      weighta( 30, 36,  3)=                 -0.02889040387843713753d0
      iwe=iwe+1
      weighta( 31, 36,  3)=                  0.39048806161442400908d0
      iwe=iwe+1
      weighta( 32, 36,  3)=                  0.65004431036780740971d0
      iwe=iwe+1
      weighta( 33, 36,  3)=                 -0.24005696112346527893d0
      iwe=iwe+1
      weighta( 34, 36,  3)=                  0.15374744952038593704d0
      iwe=iwe+1
      weighta( 35, 36,  3)=                  0.28216587913347468408d0
      iwe=iwe+1
      weighta( 36, 36,  3)=                 -0.39140495614813114456d0
      iwe=iwe+1
      weighta( 37, 36,  3)=                 -0.44391531344430201766d0
      iwe=iwe+1
      weighta( 38, 36,  3)=                  0.13612460209528279287d0
      iwe=iwe+1
      weighta( 39, 36,  3)=                 -0.67395245984501483960d0
      iwe=iwe+1
      weighta( 40, 36,  3)=                 -0.16013597814020663623d0
      iwe=iwe+1
      weighta( 41, 36,  3)=                 -0.09906088365714459110d0
      iwe=iwe+1
      weighta( 42, 36,  3)=                 -0.26976818170308192180d0
      iwe=iwe+1
      weighta( 43, 36,  3)=                  0.56253811477487003501d0
      iwe=iwe+1
      weighta( 44, 36,  3)=                  0.70536487411970616446d0
      iwe=iwe+1
      weighta( 45, 36,  3)=                 -0.21016731844653468997d0
      iwe=iwe+1
      weighta( 46, 36,  3)=                 -0.06045633612216009395d0
      iwe=iwe+1
      weighta( 47, 36,  3)=                  0.45741745997174482197d0
      iwe=iwe+1
      weighta( 48, 36,  3)=                 -0.27303948484582490908d0
      iwe=iwe+1
      weighta( 49, 36,  3)=                  0.07098427698285525445d0
      iwe=iwe+1
      weighta( 50, 36,  3)=                  0.27322946730270014637d0
      iwe=iwe+1
      biasa( 36,  3)=                 -0.31639584268985526672d0
      iwe=iwe+1
      weighta(  1, 37,  3)=                 -0.38589033515144310904d0
      iwe=iwe+1
      weighta(  2, 37,  3)=                 -0.07711475912038086300d0
      iwe=iwe+1
      weighta(  3, 37,  3)=                 -0.08632038781462279819d0
      iwe=iwe+1
      weighta(  4, 37,  3)=                 -0.37531197786944747730d0
      iwe=iwe+1
      weighta(  5, 37,  3)=                 -0.15000208079561455632d0
      iwe=iwe+1
      weighta(  6, 37,  3)=                 -0.13557056551295898483d0
      iwe=iwe+1
      weighta(  7, 37,  3)=                 -0.42817763604214725826d0
      iwe=iwe+1
      weighta(  8, 37,  3)=                 -0.42039085803287368215d0
      iwe=iwe+1
      weighta(  9, 37,  3)=                  0.16919852815169553195d0
      iwe=iwe+1
      weighta( 10, 37,  3)=                  0.07252217248889945844d0
      iwe=iwe+1
      weighta( 11, 37,  3)=                  0.32626579211299533423d0
      iwe=iwe+1
      weighta( 12, 37,  3)=                  0.04018905627857167345d0
      iwe=iwe+1
      weighta( 13, 37,  3)=                  0.01469561528892321736d0
      iwe=iwe+1
      weighta( 14, 37,  3)=                  0.24969809357743433242d0
      iwe=iwe+1
      weighta( 15, 37,  3)=                  0.31398751485895265434d0
      iwe=iwe+1
      weighta( 16, 37,  3)=                  0.29487692955383060234d0
      iwe=iwe+1
      weighta( 17, 37,  3)=                  0.11549611480751234560d0
      iwe=iwe+1
      weighta( 18, 37,  3)=                  0.23008197613883996091d0
      iwe=iwe+1
      weighta( 19, 37,  3)=                 -0.19832472367399353597d0
      iwe=iwe+1
      weighta( 20, 37,  3)=                 -0.40078996404818478805d0
      iwe=iwe+1
      weighta( 21, 37,  3)=                 -0.06339343517708065368d0
      iwe=iwe+1
      weighta( 22, 37,  3)=                 -0.67780164586591984399d0
      iwe=iwe+1
      weighta( 23, 37,  3)=                  0.19321761926701477852d0
      iwe=iwe+1
      weighta( 24, 37,  3)=                  0.24346972223224713772d0
      iwe=iwe+1
      weighta( 25, 37,  3)=                 -0.03429297540834682495d0
      iwe=iwe+1
      weighta( 26, 37,  3)=                  0.44610859107248912458d0
      iwe=iwe+1
      weighta( 27, 37,  3)=                 -0.05775303873078724975d0
      iwe=iwe+1
      weighta( 28, 37,  3)=                  0.10952904657412471101d0
      iwe=iwe+1
      weighta( 29, 37,  3)=                  0.32608531506601784455d0
      iwe=iwe+1
      weighta( 30, 37,  3)=                 -0.16390062348458045438d0
      iwe=iwe+1
      weighta( 31, 37,  3)=                 -0.00864565757767284809d0
      iwe=iwe+1
      weighta( 32, 37,  3)=                 -0.15206809716599434257d0
      iwe=iwe+1
      weighta( 33, 37,  3)=                  0.15982206056317688203d0
      iwe=iwe+1
      weighta( 34, 37,  3)=                  0.04913953815027404665d0
      iwe=iwe+1
      weighta( 35, 37,  3)=                 -0.00708300148008718725d0
      iwe=iwe+1
      weighta( 36, 37,  3)=                 -0.10542752360371650255d0
      iwe=iwe+1
      weighta( 37, 37,  3)=                 -0.05160468219872800522d0
      iwe=iwe+1
      weighta( 38, 37,  3)=                 -0.00086426951279617074d0
      iwe=iwe+1
      weighta( 39, 37,  3)=                  0.00758626287189912481d0
      iwe=iwe+1
      weighta( 40, 37,  3)=                 -0.10469521286811020455d0
      iwe=iwe+1
      weighta( 41, 37,  3)=                 -0.35465851681681620500d0
      iwe=iwe+1
      weighta( 42, 37,  3)=                 -0.08612850047825623689d0
      iwe=iwe+1
      weighta( 43, 37,  3)=                  0.37942397116017562153d0
      iwe=iwe+1
      weighta( 44, 37,  3)=                  0.38732350114904778859d0
      iwe=iwe+1
      weighta( 45, 37,  3)=                 -0.19494821910800347320d0
      iwe=iwe+1
      weighta( 46, 37,  3)=                  0.06066891107830737345d0
      iwe=iwe+1
      weighta( 47, 37,  3)=                  0.52689538100537081089d0
      iwe=iwe+1
      weighta( 48, 37,  3)=                  0.27135405183743194213d0
      iwe=iwe+1
      weighta( 49, 37,  3)=                 -0.16022914188259432255d0
      iwe=iwe+1
      weighta( 50, 37,  3)=                  0.07592736297635484244d0
      iwe=iwe+1
      biasa( 37,  3)=                  0.14652803453559218316d0
      iwe=iwe+1
      weighta(  1, 38,  3)=                  0.27408041145541378603d0
      iwe=iwe+1
      weighta(  2, 38,  3)=                  0.42265878805620105130d0
      iwe=iwe+1
      weighta(  3, 38,  3)=                  0.31104207708918901742d0
      iwe=iwe+1
      weighta(  4, 38,  3)=                  0.25746664374912298090d0
      iwe=iwe+1
      weighta(  5, 38,  3)=                 -0.09127062233730684482d0
      iwe=iwe+1
      weighta(  6, 38,  3)=                 -0.44441079164637270482d0
      iwe=iwe+1
      weighta(  7, 38,  3)=                  0.59468480197716877544d0
      iwe=iwe+1
      weighta(  8, 38,  3)=                  0.33602765603304091124d0
      iwe=iwe+1
      weighta(  9, 38,  3)=                 -0.07859837168593833412d0
      iwe=iwe+1
      weighta( 10, 38,  3)=                 -0.13083430837933504587d0
      iwe=iwe+1
      weighta( 11, 38,  3)=                  0.28154797750214627383d0
      iwe=iwe+1
      weighta( 12, 38,  3)=                 -0.00713390828746465408d0
      iwe=iwe+1
      weighta( 13, 38,  3)=                 -0.17553814874108603084d0
      iwe=iwe+1
      weighta( 14, 38,  3)=                 -0.21406259160017046539d0
      iwe=iwe+1
      weighta( 15, 38,  3)=                  0.02343518354072603171d0
      iwe=iwe+1
      weighta( 16, 38,  3)=                  0.14826094891917915297d0
      iwe=iwe+1
      weighta( 17, 38,  3)=                 -0.42641211599493322737d0
      iwe=iwe+1
      weighta( 18, 38,  3)=                  0.43786963882219209765d0
      iwe=iwe+1
      weighta( 19, 38,  3)=                  0.13131367367683322023d0
      iwe=iwe+1
      weighta( 20, 38,  3)=                 -0.06230037490284934948d0
      iwe=iwe+1
      weighta( 21, 38,  3)=                  0.12045936099489297499d0
      iwe=iwe+1
      weighta( 22, 38,  3)=                  0.24274148421473690229d0
      iwe=iwe+1
      weighta( 23, 38,  3)=                 -0.37534622543870305167d0
      iwe=iwe+1
      weighta( 24, 38,  3)=                 -0.37145565566953425707d0
      iwe=iwe+1
      weighta( 25, 38,  3)=                  0.40571768276726327684d0
      iwe=iwe+1
      weighta( 26, 38,  3)=                 -0.10288622303779892952d0
      iwe=iwe+1
      weighta( 27, 38,  3)=                  0.52472986376013919241d0
      iwe=iwe+1
      weighta( 28, 38,  3)=                 -0.72825756121480778038d0
      iwe=iwe+1
      weighta( 29, 38,  3)=                 -0.22617270330298458458d0
      iwe=iwe+1
      weighta( 30, 38,  3)=                 -0.24810668036645031065d0
      iwe=iwe+1
      weighta( 31, 38,  3)=                  0.05103489426123726524d0
      iwe=iwe+1
      weighta( 32, 38,  3)=                  0.21298522415504864136d0
      iwe=iwe+1
      weighta( 33, 38,  3)=                  0.09527108109540557979d0
      iwe=iwe+1
      weighta( 34, 38,  3)=                  0.10201855930447353837d0
      iwe=iwe+1
      weighta( 35, 38,  3)=                 -0.41980023312796033164d0
      iwe=iwe+1
      weighta( 36, 38,  3)=                 -0.47910785391722188198d0
      iwe=iwe+1
      weighta( 37, 38,  3)=                  0.09514241388879410288d0
      iwe=iwe+1
      weighta( 38, 38,  3)=                 -0.43268128196087612958d0
      iwe=iwe+1
      weighta( 39, 38,  3)=                 -0.00055090827337831707d0
      iwe=iwe+1
      weighta( 40, 38,  3)=                  0.28369496225530377309d0
      iwe=iwe+1
      weighta( 41, 38,  3)=                  0.52678921562392921896d0
      iwe=iwe+1
      weighta( 42, 38,  3)=                  0.19248098985215286727d0
      iwe=iwe+1
      weighta( 43, 38,  3)=                 -0.44261819646363786962d0
      iwe=iwe+1
      weighta( 44, 38,  3)=                  0.41317523114821641528d0
      iwe=iwe+1
      weighta( 45, 38,  3)=                 -0.47245068248647009712d0
      iwe=iwe+1
      weighta( 46, 38,  3)=                  0.55594172345019454706d0
      iwe=iwe+1
      weighta( 47, 38,  3)=                 -0.06061358716817080022d0
      iwe=iwe+1
      weighta( 48, 38,  3)=                 -0.58096119703948179147d0
      iwe=iwe+1
      weighta( 49, 38,  3)=                  0.39323877120990113898d0
      iwe=iwe+1
      weighta( 50, 38,  3)=                  0.49090709866693937879d0
      iwe=iwe+1
      biasa( 38,  3)=                 -0.17479229099585885665d0
      iwe=iwe+1
      weighta(  1, 39,  3)=                  0.20492057610361591458d0
      iwe=iwe+1
      weighta(  2, 39,  3)=                  0.12596671817155882800d0
      iwe=iwe+1
      weighta(  3, 39,  3)=                 -0.26178367817380510107d0
      iwe=iwe+1
      weighta(  4, 39,  3)=                  0.17714912223712331318d0
      iwe=iwe+1
      weighta(  5, 39,  3)=                 -0.04937448032003667608d0
      iwe=iwe+1
      weighta(  6, 39,  3)=                  0.12589304786737029462d0
      iwe=iwe+1
      weighta(  7, 39,  3)=                 -0.08124386256772206383d0
      iwe=iwe+1
      weighta(  8, 39,  3)=                  0.01123052301139486689d0
      iwe=iwe+1
      weighta(  9, 39,  3)=                 -0.10045642329843454399d0
      iwe=iwe+1
      weighta( 10, 39,  3)=                  0.66257602179728680714d0
      iwe=iwe+1
      weighta( 11, 39,  3)=                 -0.45174857142583851877d0
      iwe=iwe+1
      weighta( 12, 39,  3)=                 -0.43923353716250784773d0
      iwe=iwe+1
      weighta( 13, 39,  3)=                 -0.31934489841167901236d0
      iwe=iwe+1
      weighta( 14, 39,  3)=                  0.02813922446514539183d0
      iwe=iwe+1
      weighta( 15, 39,  3)=                 -0.25141002529193101633d0
      iwe=iwe+1
      weighta( 16, 39,  3)=                 -0.04086075406953937339d0
      iwe=iwe+1
      weighta( 17, 39,  3)=                 -0.07653367140332861807d0
      iwe=iwe+1
      weighta( 18, 39,  3)=                 -0.27656534840410895715d0
      iwe=iwe+1
      weighta( 19, 39,  3)=                 -0.27287879670798320664d0
      iwe=iwe+1
      weighta( 20, 39,  3)=                  0.01040731965102395691d0
      iwe=iwe+1
      weighta( 21, 39,  3)=                 -0.30989608568694959612d0
      iwe=iwe+1
      weighta( 22, 39,  3)=                 -0.08267197400218383174d0
      iwe=iwe+1
      weighta( 23, 39,  3)=                  0.00367823465383376475d0
      iwe=iwe+1
      weighta( 24, 39,  3)=                 -0.14288743976387163759d0
      iwe=iwe+1
      weighta( 25, 39,  3)=                  0.36900023958501804167d0
      iwe=iwe+1
      weighta( 26, 39,  3)=                  0.01712200818123125329d0
      iwe=iwe+1
      weighta( 27, 39,  3)=                 -0.13775873402525148914d0
      iwe=iwe+1
      weighta( 28, 39,  3)=                  0.25311095155166934978d0
      iwe=iwe+1
      weighta( 29, 39,  3)=                  0.30598967913622499015d0
      iwe=iwe+1
      weighta( 30, 39,  3)=                  0.38793175335356827604d0
      iwe=iwe+1
      weighta( 31, 39,  3)=                 -0.22625589453836450482d0
      iwe=iwe+1
      weighta( 32, 39,  3)=                  0.27135084342063159335d0
      iwe=iwe+1
      weighta( 33, 39,  3)=                  0.32069637416046103962d0
      iwe=iwe+1
      weighta( 34, 39,  3)=                 -0.34518068359256598443d0
      iwe=iwe+1
      weighta( 35, 39,  3)=                 -0.46368124026700030527d0
      iwe=iwe+1
      weighta( 36, 39,  3)=                  0.19364305728771435966d0
      iwe=iwe+1
      weighta( 37, 39,  3)=                  0.05461287887545338698d0
      iwe=iwe+1
      weighta( 38, 39,  3)=                  0.37846823738963936146d0
      iwe=iwe+1
      weighta( 39, 39,  3)=                 -0.16226078629686579990d0
      iwe=iwe+1
      weighta( 40, 39,  3)=                  0.02477542613186176079d0
      iwe=iwe+1
      weighta( 41, 39,  3)=                 -0.05725705443440359116d0
      iwe=iwe+1
      weighta( 42, 39,  3)=                 -0.47273195855722061065d0
      iwe=iwe+1
      weighta( 43, 39,  3)=                  0.11468263203073034151d0
      iwe=iwe+1
      weighta( 44, 39,  3)=                 -0.06111085739252304638d0
      iwe=iwe+1
      weighta( 45, 39,  3)=                 -0.05230917708145661760d0
      iwe=iwe+1
      weighta( 46, 39,  3)=                  0.09960959786232256863d0
      iwe=iwe+1
      weighta( 47, 39,  3)=                  0.11852069546326750304d0
      iwe=iwe+1
      weighta( 48, 39,  3)=                 -0.35198502590230207332d0
      iwe=iwe+1
      weighta( 49, 39,  3)=                  0.26501221137721076015d0
      iwe=iwe+1
      weighta( 50, 39,  3)=                  0.04234589878245884065d0
      iwe=iwe+1
      biasa( 39,  3)=                  0.23807667456838182973d0
      iwe=iwe+1
      weighta(  1, 40,  3)=                 -0.32420548660829662246d0
      iwe=iwe+1
      weighta(  2, 40,  3)=                  0.05618920455543020831d0
      iwe=iwe+1
      weighta(  3, 40,  3)=                  0.02279982890154163069d0
      iwe=iwe+1
      weighta(  4, 40,  3)=                  0.15731778618919003976d0
      iwe=iwe+1
      weighta(  5, 40,  3)=                 -0.15932875258671783114d0
      iwe=iwe+1
      weighta(  6, 40,  3)=                  0.47812045848300399609d0
      iwe=iwe+1
      weighta(  7, 40,  3)=                  0.50337454342227372361d0
      iwe=iwe+1
      weighta(  8, 40,  3)=                  0.45384489054996351998d0
      iwe=iwe+1
      weighta(  9, 40,  3)=                  0.22066619989372662780d0
      iwe=iwe+1
      weighta( 10, 40,  3)=                 -0.22324111551579650659d0
      iwe=iwe+1
      weighta( 11, 40,  3)=                 -0.31028155300677184858d0
      iwe=iwe+1
      weighta( 12, 40,  3)=                 -0.31730118656716072012d0
      iwe=iwe+1
      weighta( 13, 40,  3)=                  0.21233769738780214342d0
      iwe=iwe+1
      weighta( 14, 40,  3)=                  0.24263199137304145014d0
      iwe=iwe+1
      weighta( 15, 40,  3)=                  0.22615574442712516046d0
      iwe=iwe+1
      weighta( 16, 40,  3)=                  0.17866603417029863765d0
      iwe=iwe+1
      weighta( 17, 40,  3)=                  0.14379275490214760147d0
      iwe=iwe+1
      weighta( 18, 40,  3)=                  0.31634373322564413034d0
      iwe=iwe+1
      weighta( 19, 40,  3)=                  0.03733390938135563997d0
      iwe=iwe+1
      weighta( 20, 40,  3)=                  0.24003743960220849663d0
      iwe=iwe+1
      weighta( 21, 40,  3)=                  0.17458068387503225538d0
      iwe=iwe+1
      weighta( 22, 40,  3)=                 -0.27684928843008826949d0
      iwe=iwe+1
      weighta( 23, 40,  3)=                  0.19820554643509455395d0
      iwe=iwe+1
      weighta( 24, 40,  3)=                  0.05181845123118188762d0
      iwe=iwe+1
      weighta( 25, 40,  3)=                 -0.15657765736197962192d0
      iwe=iwe+1
      weighta( 26, 40,  3)=                 -0.02700666139554603815d0
      iwe=iwe+1
      weighta( 27, 40,  3)=                 -0.45846205286682861768d0
      iwe=iwe+1
      weighta( 28, 40,  3)=                 -0.48989492301922021866d0
      iwe=iwe+1
      weighta( 29, 40,  3)=                 -0.40303719324835568516d0
      iwe=iwe+1
      weighta( 30, 40,  3)=                 -0.29798872592944780635d0
      iwe=iwe+1
      weighta( 31, 40,  3)=                  0.09319637640279897217d0
      iwe=iwe+1
      weighta( 32, 40,  3)=                  0.35840795993007545928d0
      iwe=iwe+1
      weighta( 33, 40,  3)=                  0.18360024492737894719d0
      iwe=iwe+1
      weighta( 34, 40,  3)=                 -0.02578239173075729668d0
      iwe=iwe+1
      weighta( 35, 40,  3)=                 -0.15865447086750553152d0
      iwe=iwe+1
      weighta( 36, 40,  3)=                 -0.76270700541750158230d0
      iwe=iwe+1
      weighta( 37, 40,  3)=                  0.28866436013355512014d0
      iwe=iwe+1
      weighta( 38, 40,  3)=                 -0.77867062859722635526d0
      iwe=iwe+1
      weighta( 39, 40,  3)=                 -0.21822155036821377916d0
      iwe=iwe+1
      weighta( 40, 40,  3)=                 -0.28784907354164074311d0
      iwe=iwe+1
      weighta( 41, 40,  3)=                 -0.58622614581406351508d0
      iwe=iwe+1
      weighta( 42, 40,  3)=                  0.66082243802988882564d0
      iwe=iwe+1
      weighta( 43, 40,  3)=                  0.11752911618872984023d0
      iwe=iwe+1
      weighta( 44, 40,  3)=                 -0.23533145925827617106d0
      iwe=iwe+1
      weighta( 45, 40,  3)=                  0.16743288859758648224d0
      iwe=iwe+1
      weighta( 46, 40,  3)=                  0.10401773510638753772d0
      iwe=iwe+1
      weighta( 47, 40,  3)=                 -0.17794158347271479825d0
      iwe=iwe+1
      weighta( 48, 40,  3)=                 -0.60937854896441856489d0
      iwe=iwe+1
      weighta( 49, 40,  3)=                  0.13277367645309245958d0
      iwe=iwe+1
      weighta( 50, 40,  3)=                  0.41962963496766919613d0
      iwe=iwe+1
      biasa( 40,  3)=                 -0.08372498504775092998d0
      iwe=iwe+1
      weighta(  1, 41,  3)=                  0.50222130722907687428d0
      iwe=iwe+1
      weighta(  2, 41,  3)=                  0.02610745965849936914d0
      iwe=iwe+1
      weighta(  3, 41,  3)=                 -0.38330319044397265227d0
      iwe=iwe+1
      weighta(  4, 41,  3)=                 -0.40266703061010533649d0
      iwe=iwe+1
      weighta(  5, 41,  3)=                 -0.20611059443652801626d0
      iwe=iwe+1
      weighta(  6, 41,  3)=                 -0.10053364635737299659d0
      iwe=iwe+1
      weighta(  7, 41,  3)=                 -0.10661060812492968719d0
      iwe=iwe+1
      weighta(  8, 41,  3)=                 -0.45861477743277911934d0
      iwe=iwe+1
      weighta(  9, 41,  3)=                 -0.44808241818583588456d0
      iwe=iwe+1
      weighta( 10, 41,  3)=                  0.25374156307747675054d0
      iwe=iwe+1
      weighta( 11, 41,  3)=                  0.04844963696386697660d0
      iwe=iwe+1
      weighta( 12, 41,  3)=                  0.19854093231769906480d0
      iwe=iwe+1
      weighta( 13, 41,  3)=                 -0.35374480130157115454d0
      iwe=iwe+1
      weighta( 14, 41,  3)=                 -0.10241635971384921433d0
      iwe=iwe+1
      weighta( 15, 41,  3)=                 -0.07302361044036605187d0
      iwe=iwe+1
      weighta( 16, 41,  3)=                 -0.25090143890285615536d0
      iwe=iwe+1
      weighta( 17, 41,  3)=                 -0.29522866908312289658d0
      iwe=iwe+1
      weighta( 18, 41,  3)=                  0.07122719927818917107d0
      iwe=iwe+1
      weighta( 19, 41,  3)=                 -0.20216240385392378331d0
      iwe=iwe+1
      weighta( 20, 41,  3)=                 -0.19155292406043705755d0
      iwe=iwe+1
      weighta( 21, 41,  3)=                  0.13569734905729913255d0
      iwe=iwe+1
      weighta( 22, 41,  3)=                  0.03552324127743050619d0
      iwe=iwe+1
      weighta( 23, 41,  3)=                 -0.09033140375525268440d0
      iwe=iwe+1
      weighta( 24, 41,  3)=                  0.06393365951329921248d0
      iwe=iwe+1
      weighta( 25, 41,  3)=                 -0.08980507065893782170d0
      iwe=iwe+1
      weighta( 26, 41,  3)=                  0.17716470370846132409d0
      iwe=iwe+1
      weighta( 27, 41,  3)=                  0.25180296541253005538d0
      iwe=iwe+1
      weighta( 28, 41,  3)=                 -0.35711062786039599048d0
      iwe=iwe+1
      weighta( 29, 41,  3)=                 -0.39535449498930702594d0
      iwe=iwe+1
      weighta( 30, 41,  3)=                 -0.25656664778806681504d0
      iwe=iwe+1
      weighta( 31, 41,  3)=                 -0.30201822519807036693d0
      iwe=iwe+1
      weighta( 32, 41,  3)=                 -0.07921727316415846931d0
      iwe=iwe+1
      weighta( 33, 41,  3)=                  0.32628964866827675495d0
      iwe=iwe+1
      weighta( 34, 41,  3)=                 -0.20494531756089712227d0
      iwe=iwe+1
      weighta( 35, 41,  3)=                 -0.08816736673772705701d0
      iwe=iwe+1
      weighta( 36, 41,  3)=                  0.57710600779800125260d0
      iwe=iwe+1
      weighta( 37, 41,  3)=                 -0.36092547953551196160d0
      iwe=iwe+1
      weighta( 38, 41,  3)=                  0.34503661967366056063d0
      iwe=iwe+1
      weighta( 39, 41,  3)=                  0.35019747910379156464d0
      iwe=iwe+1
      weighta( 40, 41,  3)=                 -0.20827988358294957649d0
      iwe=iwe+1
      weighta( 41, 41,  3)=                 -0.21338774219901462947d0
      iwe=iwe+1
      weighta( 42, 41,  3)=                 -0.11611296930372934366d0
      iwe=iwe+1
      weighta( 43, 41,  3)=                 -0.34282936203991798418d0
      iwe=iwe+1
      weighta( 44, 41,  3)=                 -0.00830461686221844152d0
      iwe=iwe+1
      weighta( 45, 41,  3)=                  0.21012487320160014304d0
      iwe=iwe+1
      weighta( 46, 41,  3)=                  0.22826409306630324192d0
      iwe=iwe+1
      weighta( 47, 41,  3)=                  0.29898856894037439957d0
      iwe=iwe+1
      weighta( 48, 41,  3)=                 -0.32097749022498206495d0
      iwe=iwe+1
      weighta( 49, 41,  3)=                  0.23833931477854694569d0
      iwe=iwe+1
      weighta( 50, 41,  3)=                  0.17552445129953928027d0
      iwe=iwe+1
      biasa( 41,  3)=                  0.21437088939306639390d0
      iwe=iwe+1
      weighta(  1, 42,  3)=                  0.18335673474809746630d0
      iwe=iwe+1
      weighta(  2, 42,  3)=                 -0.09123030746403874847d0
      iwe=iwe+1
      weighta(  3, 42,  3)=                  0.07659196994262523761d0
      iwe=iwe+1
      weighta(  4, 42,  3)=                 -0.17746833696274252890d0
      iwe=iwe+1
      weighta(  5, 42,  3)=                 -0.37459669753058760788d0
      iwe=iwe+1
      weighta(  6, 42,  3)=                 -0.01687463019015736365d0
      iwe=iwe+1
      weighta(  7, 42,  3)=                 -0.19219147627300312009d0
      iwe=iwe+1
      weighta(  8, 42,  3)=                 -0.06039887368028060144d0
      iwe=iwe+1
      weighta(  9, 42,  3)=                 -0.29567050316024268142d0
      iwe=iwe+1
      weighta( 10, 42,  3)=                 -0.14528399394168015069d0
      iwe=iwe+1
      weighta( 11, 42,  3)=                  0.11234320681344600601d0
      iwe=iwe+1
      weighta( 12, 42,  3)=                 -0.09036366033294800093d0
      iwe=iwe+1
      weighta( 13, 42,  3)=                 -0.44656979772185079192d0
      iwe=iwe+1
      weighta( 14, 42,  3)=                 -0.04171040758314902008d0
      iwe=iwe+1
      weighta( 15, 42,  3)=                  0.22995908775232032362d0
      iwe=iwe+1
      weighta( 16, 42,  3)=                 -0.05747049187557384808d0
      iwe=iwe+1
      weighta( 17, 42,  3)=                 -0.14876754743576733886d0
      iwe=iwe+1
      weighta( 18, 42,  3)=                 -0.01788971028605421815d0
      iwe=iwe+1
      weighta( 19, 42,  3)=                  0.47159060350174308862d0
      iwe=iwe+1
      weighta( 20, 42,  3)=                  0.14537296825308093640d0
      iwe=iwe+1
      weighta( 21, 42,  3)=                  0.05691347397099123101d0
      iwe=iwe+1
      weighta( 22, 42,  3)=                 -0.20296862710009877517d0
      iwe=iwe+1
      weighta( 23, 42,  3)=                 -0.34727059168101015452d0
      iwe=iwe+1
      weighta( 24, 42,  3)=                  0.50052070750350929895d0
      iwe=iwe+1
      weighta( 25, 42,  3)=                  0.04608415935835983440d0
      iwe=iwe+1
      weighta( 26, 42,  3)=                 -0.44329903642921936191d0
      iwe=iwe+1
      weighta( 27, 42,  3)=                  0.04785506103102591530d0
      iwe=iwe+1
      weighta( 28, 42,  3)=                 -0.04141710368243245455d0
      iwe=iwe+1
      weighta( 29, 42,  3)=                  0.03296043603140652589d0
      iwe=iwe+1
      weighta( 30, 42,  3)=                  0.00805685704882717207d0
      iwe=iwe+1
      weighta( 31, 42,  3)=                 -0.40156263691920623948d0
      iwe=iwe+1
      weighta( 32, 42,  3)=                 -0.40544524266564324622d0
      iwe=iwe+1
      weighta( 33, 42,  3)=                  0.34258817616734926759d0
      iwe=iwe+1
      weighta( 34, 42,  3)=                  0.01343268163273629925d0
      iwe=iwe+1
      weighta( 35, 42,  3)=                 -0.24186766433524259368d0
      iwe=iwe+1
      weighta( 36, 42,  3)=                  0.18948594154903053433d0
      iwe=iwe+1
      weighta( 37, 42,  3)=                  0.04754409337465313051d0
      iwe=iwe+1
      weighta( 38, 42,  3)=                 -0.04527491119731214680d0
      iwe=iwe+1
      weighta( 39, 42,  3)=                 -0.13642604799529703397d0
      iwe=iwe+1
      weighta( 40, 42,  3)=                  0.19320321116999000788d0
      iwe=iwe+1
      weighta( 41, 42,  3)=                 -0.17702264028183783973d0
      iwe=iwe+1
      weighta( 42, 42,  3)=                  0.16650222700945127574d0
      iwe=iwe+1
      weighta( 43, 42,  3)=                 -0.21895160353423873123d0
      iwe=iwe+1
      weighta( 44, 42,  3)=                 -0.38638487289432799088d0
      iwe=iwe+1
      weighta( 45, 42,  3)=                  0.18637174471133735598d0
      iwe=iwe+1
      weighta( 46, 42,  3)=                 -0.05097157806063497970d0
      iwe=iwe+1
      weighta( 47, 42,  3)=                 -0.10612133050394532974d0
      iwe=iwe+1
      weighta( 48, 42,  3)=                  0.21334332892615046062d0
      iwe=iwe+1
      weighta( 49, 42,  3)=                  0.19922396961342186961d0
      iwe=iwe+1
      weighta( 50, 42,  3)=                  0.07531437773853004447d0
      iwe=iwe+1
      biasa( 42,  3)=                  0.13229874460767157562d0
      iwe=iwe+1
      weighta(  1, 43,  3)=                  0.03281124564688137069d0
      iwe=iwe+1
      weighta(  2, 43,  3)=                 -0.24121523463942096122d0
      iwe=iwe+1
      weighta(  3, 43,  3)=                 -0.18836576171637836596d0
      iwe=iwe+1
      weighta(  4, 43,  3)=                 -0.37548359662873498355d0
      iwe=iwe+1
      weighta(  5, 43,  3)=                 -0.11520554716846992394d0
      iwe=iwe+1
      weighta(  6, 43,  3)=                 -0.14389234472799450337d0
      iwe=iwe+1
      weighta(  7, 43,  3)=                 -0.15569117363036560908d0
      iwe=iwe+1
      weighta(  8, 43,  3)=                  0.18336163448901884876d0
      iwe=iwe+1
      weighta(  9, 43,  3)=                 -0.34982650900279893547d0
      iwe=iwe+1
      weighta( 10, 43,  3)=                 -0.03015734634092476218d0
      iwe=iwe+1
      weighta( 11, 43,  3)=                 -0.47882457392802058038d0
      iwe=iwe+1
      weighta( 12, 43,  3)=                 -0.05746246956294329827d0
      iwe=iwe+1
      weighta( 13, 43,  3)=                  0.36173877756721556365d0
      iwe=iwe+1
      weighta( 14, 43,  3)=                  0.07667209858471378536d0
      iwe=iwe+1
      weighta( 15, 43,  3)=                  0.01627898378933322412d0
      iwe=iwe+1
      weighta( 16, 43,  3)=                  0.56558297449394034917d0
      iwe=iwe+1
      weighta( 17, 43,  3)=                 -0.38579133173442309301d0
      iwe=iwe+1
      weighta( 18, 43,  3)=                  0.18722353453397089229d0
      iwe=iwe+1
      weighta( 19, 43,  3)=                 -0.24619937291183635608d0
      iwe=iwe+1
      weighta( 20, 43,  3)=                 -0.02446653563536747497d0
      iwe=iwe+1
      weighta( 21, 43,  3)=                 -0.17010012315535311123d0
      iwe=iwe+1
      weighta( 22, 43,  3)=                 -0.10303544763253584537d0
      iwe=iwe+1
      weighta( 23, 43,  3)=                  0.23404876375278912959d0
      iwe=iwe+1
      weighta( 24, 43,  3)=                 -0.18814459036259162383d0
      iwe=iwe+1
      weighta( 25, 43,  3)=                 -0.50270232776093393134d0
      iwe=iwe+1
      weighta( 26, 43,  3)=                 -0.43488902751571506533d0
      iwe=iwe+1
      weighta( 27, 43,  3)=                 -0.21411766253330449805d0
      iwe=iwe+1
      weighta( 28, 43,  3)=                 -0.26744755083443577659d0
      iwe=iwe+1
      weighta( 29, 43,  3)=                 -0.04582791324501507557d0
      iwe=iwe+1
      weighta( 30, 43,  3)=                  0.14330623655710100772d0
      iwe=iwe+1
      weighta( 31, 43,  3)=                  0.29437551624000879436d0
      iwe=iwe+1
      weighta( 32, 43,  3)=                  0.10690760329521153960d0
      iwe=iwe+1
      weighta( 33, 43,  3)=                 -0.00307393733550477902d0
      iwe=iwe+1
      weighta( 34, 43,  3)=                 -0.22361604866244688683d0
      iwe=iwe+1
      weighta( 35, 43,  3)=                  0.11685046849913571787d0
      iwe=iwe+1
      weighta( 36, 43,  3)=                 -0.05724514953126528388d0
      iwe=iwe+1
      weighta( 37, 43,  3)=                  0.47950015366006204509d0
      iwe=iwe+1
      weighta( 38, 43,  3)=                  0.30435204767363677192d0
      iwe=iwe+1
      weighta( 39, 43,  3)=                 -0.14225703924670701772d0
      iwe=iwe+1
      weighta( 40, 43,  3)=                  0.25733248797635166483d0
      iwe=iwe+1
      weighta( 41, 43,  3)=                 -0.26808659166130915930d0
      iwe=iwe+1
      weighta( 42, 43,  3)=                  0.18890295072158946876d0
      iwe=iwe+1
      weighta( 43, 43,  3)=                 -0.20787103323135902588d0
      iwe=iwe+1
      weighta( 44, 43,  3)=                  0.10173225437870313248d0
      iwe=iwe+1
      weighta( 45, 43,  3)=                 -0.14553347281255910040d0
      iwe=iwe+1
      weighta( 46, 43,  3)=                 -0.23167266701356023506d0
      iwe=iwe+1
      weighta( 47, 43,  3)=                  0.34360929074703333574d0
      iwe=iwe+1
      weighta( 48, 43,  3)=                  0.05584171456450012783d0
      iwe=iwe+1
      weighta( 49, 43,  3)=                  0.02727141168590780859d0
      iwe=iwe+1
      weighta( 50, 43,  3)=                  0.03164617437325260851d0
      iwe=iwe+1
      biasa( 43,  3)=                 -0.07542115846577518434d0
      iwe=iwe+1
      weighta(  1, 44,  3)=                  0.20425098424749185688d0
      iwe=iwe+1
      weighta(  2, 44,  3)=                 -0.10239954837786414965d0
      iwe=iwe+1
      weighta(  3, 44,  3)=                 -0.26330364961064017804d0
      iwe=iwe+1
      weighta(  4, 44,  3)=                  0.01533360205474814351d0
      iwe=iwe+1
      weighta(  5, 44,  3)=                  0.10514373368775040141d0
      iwe=iwe+1
      weighta(  6, 44,  3)=                  0.06885174477069622156d0
      iwe=iwe+1
      weighta(  7, 44,  3)=                  0.05269451245932649242d0
      iwe=iwe+1
      weighta(  8, 44,  3)=                 -0.14868659126091343659d0
      iwe=iwe+1
      weighta(  9, 44,  3)=                 -0.16795836086046589397d0
      iwe=iwe+1
      weighta( 10, 44,  3)=                  0.30353586250219327658d0
      iwe=iwe+1
      weighta( 11, 44,  3)=                 -0.19099696359644130483d0
      iwe=iwe+1
      weighta( 12, 44,  3)=                  0.39229640221803163680d0
      iwe=iwe+1
      weighta( 13, 44,  3)=                 -0.23720356127911079724d0
      iwe=iwe+1
      weighta( 14, 44,  3)=                 -0.27051126445491435746d0
      iwe=iwe+1
      weighta( 15, 44,  3)=                 -0.24229417130134711655d0
      iwe=iwe+1
      weighta( 16, 44,  3)=                 -0.17732894293711620737d0
      iwe=iwe+1
      weighta( 17, 44,  3)=                  0.29369211846319587256d0
      iwe=iwe+1
      weighta( 18, 44,  3)=                  0.08304148443936353041d0
      iwe=iwe+1
      weighta( 19, 44,  3)=                 -0.13340429481915019871d0
      iwe=iwe+1
      weighta( 20, 44,  3)=                 -0.24733796173546013231d0
      iwe=iwe+1
      weighta( 21, 44,  3)=                 -0.08876165944544274489d0
      iwe=iwe+1
      weighta( 22, 44,  3)=                 -0.25226327481089960703d0
      iwe=iwe+1
      weighta( 23, 44,  3)=                  0.19265096285415170274d0
      iwe=iwe+1
      weighta( 24, 44,  3)=                 -0.03658814881590516377d0
      iwe=iwe+1
      weighta( 25, 44,  3)=                 -0.14849888372223973843d0
      iwe=iwe+1
      weighta( 26, 44,  3)=                 -0.37927636729009367444d0
      iwe=iwe+1
      weighta( 27, 44,  3)=                  0.03066297318109511075d0
      iwe=iwe+1
      weighta( 28, 44,  3)=                  0.16988677514738512175d0
      iwe=iwe+1
      weighta( 29, 44,  3)=                  0.14179052410109832527d0
      iwe=iwe+1
      weighta( 30, 44,  3)=                  0.24119194904713664451d0
      iwe=iwe+1
      weighta( 31, 44,  3)=                  0.18595101699397548201d0
      iwe=iwe+1
      weighta( 32, 44,  3)=                  0.21933066312564325484d0
      iwe=iwe+1
      weighta( 33, 44,  3)=                 -0.23176781417175451594d0
      iwe=iwe+1
      weighta( 34, 44,  3)=                  0.03620178681225964118d0
      iwe=iwe+1
      weighta( 35, 44,  3)=                 -0.32959397084965891267d0
      iwe=iwe+1
      weighta( 36, 44,  3)=                 -0.18427030265076124738d0
      iwe=iwe+1
      weighta( 37, 44,  3)=                 -0.37119939593082906804d0
      iwe=iwe+1
      weighta( 38, 44,  3)=                  0.38616399296191927792d0
      iwe=iwe+1
      weighta( 39, 44,  3)=                 -0.03096202482999418915d0
      iwe=iwe+1
      weighta( 40, 44,  3)=                 -0.06711953305264668768d0
      iwe=iwe+1
      weighta( 41, 44,  3)=                 -0.26002696728572061158d0
      iwe=iwe+1
      weighta( 42, 44,  3)=                  0.06120718058914297044d0
      iwe=iwe+1
      weighta( 43, 44,  3)=                  0.13435342161689159401d0
      iwe=iwe+1
      weighta( 44, 44,  3)=                 -0.06817800621116723581d0
      iwe=iwe+1
      weighta( 45, 44,  3)=                 -0.06532483278476741706d0
      iwe=iwe+1
      weighta( 46, 44,  3)=                 -0.17181951142536849853d0
      iwe=iwe+1
      weighta( 47, 44,  3)=                 -0.03361650921306755246d0
      iwe=iwe+1
      weighta( 48, 44,  3)=                 -0.40927440415414995112d0
      iwe=iwe+1
      weighta( 49, 44,  3)=                  0.26818523862926724188d0
      iwe=iwe+1
      weighta( 50, 44,  3)=                 -0.15098433897151788963d0
      iwe=iwe+1
      biasa( 44,  3)=                  0.12921835450045010552d0
      iwe=iwe+1
      weighta(  1, 45,  3)=                 -0.01403213654301439448d0
      iwe=iwe+1
      weighta(  2, 45,  3)=                  0.28565309532025218164d0
      iwe=iwe+1
      weighta(  3, 45,  3)=                  0.06447156867399585212d0
      iwe=iwe+1
      weighta(  4, 45,  3)=                 -0.30610068684969909958d0
      iwe=iwe+1
      weighta(  5, 45,  3)=                  0.20759892125664150542d0
      iwe=iwe+1
      weighta(  6, 45,  3)=                  0.13367804642653319247d0
      iwe=iwe+1
      weighta(  7, 45,  3)=                 -0.03989999135810424341d0
      iwe=iwe+1
      weighta(  8, 45,  3)=                 -0.39107729715701633477d0
      iwe=iwe+1
      weighta(  9, 45,  3)=                  0.20660484580493979068d0
      iwe=iwe+1
      weighta( 10, 45,  3)=                 -0.12864985644513585172d0
      iwe=iwe+1
      weighta( 11, 45,  3)=                  0.04727584328070157105d0
      iwe=iwe+1
      weighta( 12, 45,  3)=                 -0.11358763123708072451d0
      iwe=iwe+1
      weighta( 13, 45,  3)=                 -0.03869065908966526357d0
      iwe=iwe+1
      weighta( 14, 45,  3)=                  0.21895284233675721408d0
      iwe=iwe+1
      weighta( 15, 45,  3)=                  0.31479204959758355642d0
      iwe=iwe+1
      weighta( 16, 45,  3)=                  0.04284671255325671335d0
      iwe=iwe+1
      weighta( 17, 45,  3)=                  0.35644641826957135233d0
      iwe=iwe+1
      weighta( 18, 45,  3)=                 -0.37259964387998445456d0
      iwe=iwe+1
      weighta( 19, 45,  3)=                 -0.00011942944889940300d0
      iwe=iwe+1
      weighta( 20, 45,  3)=                  0.46134225449082216786d0
      iwe=iwe+1
      weighta( 21, 45,  3)=                  0.24242587711260260575d0
      iwe=iwe+1
      weighta( 22, 45,  3)=                  0.26109118904297751174d0
      iwe=iwe+1
      weighta( 23, 45,  3)=                  0.03378785734863384155d0
      iwe=iwe+1
      weighta( 24, 45,  3)=                  0.47899245631526043976d0
      iwe=iwe+1
      weighta( 25, 45,  3)=                 -0.51136089251655958421d0
      iwe=iwe+1
      weighta( 26, 45,  3)=                 -0.25872877790207565729d0
      iwe=iwe+1
      weighta( 27, 45,  3)=                  0.12185966360090641492d0
      iwe=iwe+1
      weighta( 28, 45,  3)=                 -0.39450991819687980522d0
      iwe=iwe+1
      weighta( 29, 45,  3)=                 -0.18291549336780205115d0
      iwe=iwe+1
      weighta( 30, 45,  3)=                 -0.46834485653636409586d0
      iwe=iwe+1
      weighta( 31, 45,  3)=                  0.11721944059148409201d0
      iwe=iwe+1
      weighta( 32, 45,  3)=                 -0.80588577648840842294d0
      iwe=iwe+1
      weighta( 33, 45,  3)=                 -0.30832335721574588572d0
      iwe=iwe+1
      weighta( 34, 45,  3)=                 -0.42681572181013482936d0
      iwe=iwe+1
      weighta( 35, 45,  3)=                 -0.09330252029858167317d0
      iwe=iwe+1
      weighta( 36, 45,  3)=                  0.08637691944610056960d0
      iwe=iwe+1
      weighta( 37, 45,  3)=                 -0.14108095904917392072d0
      iwe=iwe+1
      weighta( 38, 45,  3)=                 -0.24102057099176257826d0
      iwe=iwe+1
      weighta( 39, 45,  3)=                  0.11291433622611181387d0
      iwe=iwe+1
      weighta( 40, 45,  3)=                 -0.16721553695085969449d0
      iwe=iwe+1
      weighta( 41, 45,  3)=                 -0.28529006582027194305d0
      iwe=iwe+1
      weighta( 42, 45,  3)=                 -0.20737976565100543769d0
      iwe=iwe+1
      weighta( 43, 45,  3)=                 -0.12165602354246733696d0
      iwe=iwe+1
      weighta( 44, 45,  3)=                  0.47373143835367909071d0
      iwe=iwe+1
      weighta( 45, 45,  3)=                 -0.32924267692657865902d0
      iwe=iwe+1
      weighta( 46, 45,  3)=                 -0.31507474586867056932d0
      iwe=iwe+1
      weighta( 47, 45,  3)=                 -0.26251554036979352080d0
      iwe=iwe+1
      weighta( 48, 45,  3)=                  0.07936343568792909864d0
      iwe=iwe+1
      weighta( 49, 45,  3)=                 -0.25398706518692837353d0
      iwe=iwe+1
      weighta( 50, 45,  3)=                  0.39591297127115276933d0
      iwe=iwe+1
      biasa( 45,  3)=                  0.14772025707131614114d0
      iwe=iwe+1
      weighta(  1, 46,  3)=                 -0.30233792558055616606d0
      iwe=iwe+1
      weighta(  2, 46,  3)=                  0.06506469282164961676d0
      iwe=iwe+1
      weighta(  3, 46,  3)=                  0.29774083992619782002d0
      iwe=iwe+1
      weighta(  4, 46,  3)=                  0.00016227208550794402d0
      iwe=iwe+1
      weighta(  5, 46,  3)=                 -0.35569575187368046576d0
      iwe=iwe+1
      weighta(  6, 46,  3)=                 -0.38703888373508360532d0
      iwe=iwe+1
      weighta(  7, 46,  3)=                 -0.24813582799908523446d0
      iwe=iwe+1
      weighta(  8, 46,  3)=                  0.30131469353895118379d0
      iwe=iwe+1
      weighta(  9, 46,  3)=                  0.02398413862591231016d0
      iwe=iwe+1
      weighta( 10, 46,  3)=                  0.26504066528469355513d0
      iwe=iwe+1
      weighta( 11, 46,  3)=                 -0.34749641619671894910d0
      iwe=iwe+1
      weighta( 12, 46,  3)=                  0.05323729556370478122d0
      iwe=iwe+1
      weighta( 13, 46,  3)=                 -0.11043337610105333213d0
      iwe=iwe+1
      weighta( 14, 46,  3)=                  0.31295006129520624993d0
      iwe=iwe+1
      weighta( 15, 46,  3)=                 -0.11334462299860605106d0
      iwe=iwe+1
      weighta( 16, 46,  3)=                  0.11049076059254241133d0
      iwe=iwe+1
      weighta( 17, 46,  3)=                  0.02732628042094739640d0
      iwe=iwe+1
      weighta( 18, 46,  3)=                  0.02327172389033329777d0
      iwe=iwe+1
      weighta( 19, 46,  3)=                 -0.02838686234491194851d0
      iwe=iwe+1
      weighta( 20, 46,  3)=                 -0.18442006909413152793d0
      iwe=iwe+1
      weighta( 21, 46,  3)=                  0.40286629823108943693d0
      iwe=iwe+1
      weighta( 22, 46,  3)=                 -0.05384148263236936127d0
      iwe=iwe+1
      weighta( 23, 46,  3)=                 -0.28651145598974436801d0
      iwe=iwe+1
      weighta( 24, 46,  3)=                 -0.09838618098809981394d0
      iwe=iwe+1
      weighta( 25, 46,  3)=                  0.03928217159526448815d0
      iwe=iwe+1
      weighta( 26, 46,  3)=                 -0.34817546371007701556d0
      iwe=iwe+1
      weighta( 27, 46,  3)=                  0.14004020782785783772d0
      iwe=iwe+1
      weighta( 28, 46,  3)=                  0.05723595589542019441d0
      iwe=iwe+1
      weighta( 29, 46,  3)=                 -0.13890665266542492895d0
      iwe=iwe+1
      weighta( 30, 46,  3)=                  0.34665479300827473086d0
      iwe=iwe+1
      weighta( 31, 46,  3)=                 -0.16367783831348178825d0
      iwe=iwe+1
      weighta( 32, 46,  3)=                 -0.15576208889795437051d0
      iwe=iwe+1
      weighta( 33, 46,  3)=                  0.32290803473143059321d0
      iwe=iwe+1
      weighta( 34, 46,  3)=                 -0.17732626156540629014d0
      iwe=iwe+1
      weighta( 35, 46,  3)=                 -0.05828078697134970315d0
      iwe=iwe+1
      weighta( 36, 46,  3)=                  0.06688667494177216732d0
      iwe=iwe+1
      weighta( 37, 46,  3)=                 -0.08800447355612332767d0
      iwe=iwe+1
      weighta( 38, 46,  3)=                  0.08944374477910925492d0
      iwe=iwe+1
      weighta( 39, 46,  3)=                  0.15093804741934188640d0
      iwe=iwe+1
      weighta( 40, 46,  3)=                 -0.04867412805450584828d0
      iwe=iwe+1
      weighta( 41, 46,  3)=                  0.41141063383439041568d0
      iwe=iwe+1
      weighta( 42, 46,  3)=                 -0.00969963499666517959d0
      iwe=iwe+1
      weighta( 43, 46,  3)=                  0.07279246841471977147d0
      iwe=iwe+1
      weighta( 44, 46,  3)=                 -0.19410958311611370419d0
      iwe=iwe+1
      weighta( 45, 46,  3)=                 -0.57799854572831910193d0
      iwe=iwe+1
      weighta( 46, 46,  3)=                 -0.42287707444077810015d0
      iwe=iwe+1
      weighta( 47, 46,  3)=                  0.27256409410925691583d0
      iwe=iwe+1
      weighta( 48, 46,  3)=                 -0.00867281328451732260d0
      iwe=iwe+1
      weighta( 49, 46,  3)=                 -0.41546912185096718240d0
      iwe=iwe+1
      weighta( 50, 46,  3)=                 -0.29339193480556507998d0
      iwe=iwe+1
      biasa( 46,  3)=                 -0.10723733072561775215d0
      iwe=iwe+1
      weighta(  1, 47,  3)=                  0.09112252149132375745d0
      iwe=iwe+1
      weighta(  2, 47,  3)=                  0.25826210984985964458d0
      iwe=iwe+1
      weighta(  3, 47,  3)=                  0.03413501389264146646d0
      iwe=iwe+1
      weighta(  4, 47,  3)=                 -0.05710047478781915542d0
      iwe=iwe+1
      weighta(  5, 47,  3)=                  0.12388745884456825452d0
      iwe=iwe+1
      weighta(  6, 47,  3)=                 -0.13746556370481946563d0
      iwe=iwe+1
      weighta(  7, 47,  3)=                 -0.29104631317219109565d0
      iwe=iwe+1
      weighta(  8, 47,  3)=                  0.04060447605756253159d0
      iwe=iwe+1
      weighta(  9, 47,  3)=                 -0.03631426823286131728d0
      iwe=iwe+1
      weighta( 10, 47,  3)=                  0.01830442561635716586d0
      iwe=iwe+1
      weighta( 11, 47,  3)=                 -0.09065649184492109713d0
      iwe=iwe+1
      weighta( 12, 47,  3)=                 -0.00223873520570928505d0
      iwe=iwe+1
      weighta( 13, 47,  3)=                 -0.26697047397780071520d0
      iwe=iwe+1
      weighta( 14, 47,  3)=                 -0.34934152578366745034d0
      iwe=iwe+1
      weighta( 15, 47,  3)=                  0.21246888143907011193d0
      iwe=iwe+1
      weighta( 16, 47,  3)=                 -0.46176065054987225356d0
      iwe=iwe+1
      weighta( 17, 47,  3)=                  0.39523079046799980407d0
      iwe=iwe+1
      weighta( 18, 47,  3)=                  0.19824091640934252134d0
      iwe=iwe+1
      weighta( 19, 47,  3)=                  0.23857235753075964335d0
      iwe=iwe+1
      weighta( 20, 47,  3)=                 -0.40073716779058227155d0
      iwe=iwe+1
      weighta( 21, 47,  3)=                 -0.04737541130503531567d0
      iwe=iwe+1
      weighta( 22, 47,  3)=                 -0.12969919601230722739d0
      iwe=iwe+1
      weighta( 23, 47,  3)=                  0.05573534434081833105d0
      iwe=iwe+1
      weighta( 24, 47,  3)=                 -0.10060623829100329152d0
      iwe=iwe+1
      weighta( 25, 47,  3)=                 -0.28413776303641596899d0
      iwe=iwe+1
      weighta( 26, 47,  3)=                 -0.15933091769928059422d0
      iwe=iwe+1
      weighta( 27, 47,  3)=                  0.39399457199518878037d0
      iwe=iwe+1
      weighta( 28, 47,  3)=                 -0.26824972195350943460d0
      iwe=iwe+1
      weighta( 29, 47,  3)=                 -0.01530942054021564372d0
      iwe=iwe+1
      weighta( 30, 47,  3)=                  0.27537401015062146215d0
      iwe=iwe+1
      weighta( 31, 47,  3)=                  0.21209644017012319051d0
      iwe=iwe+1
      weighta( 32, 47,  3)=                 -0.18787841621927883762d0
      iwe=iwe+1
      weighta( 33, 47,  3)=                 -0.09766019463949875135d0
      iwe=iwe+1
      weighta( 34, 47,  3)=                 -0.41993940281386027413d0
      iwe=iwe+1
      weighta( 35, 47,  3)=                 -0.16145141767693629853d0
      iwe=iwe+1
      weighta( 36, 47,  3)=                  0.38878565537895815041d0
      iwe=iwe+1
      weighta( 37, 47,  3)=                 -0.35269053837070196700d0
      iwe=iwe+1
      weighta( 38, 47,  3)=                  0.09744358144923521980d0
      iwe=iwe+1
      weighta( 39, 47,  3)=                 -0.42796631450944011554d0
      iwe=iwe+1
      weighta( 40, 47,  3)=                 -0.24378202287968714357d0
      iwe=iwe+1
      weighta( 41, 47,  3)=                 -0.27300660275032012647d0
      iwe=iwe+1
      weighta( 42, 47,  3)=                 -0.16788502670101809744d0
      iwe=iwe+1
      weighta( 43, 47,  3)=                 -0.25727940378707647717d0
      iwe=iwe+1
      weighta( 44, 47,  3)=                  0.20306896105009045184d0
      iwe=iwe+1
      weighta( 45, 47,  3)=                 -0.00591990659704896404d0
      iwe=iwe+1
      weighta( 46, 47,  3)=                  0.40829311851926430865d0
      iwe=iwe+1
      weighta( 47, 47,  3)=                  0.18539544146512459966d0
      iwe=iwe+1
      weighta( 48, 47,  3)=                 -0.27608778175552872725d0
      iwe=iwe+1
      weighta( 49, 47,  3)=                  0.13080575457346432788d0
      iwe=iwe+1
      weighta( 50, 47,  3)=                 -0.16723946625198093940d0
      iwe=iwe+1
      biasa( 47,  3)=                 -0.24762515839809270957d0
      iwe=iwe+1
      weighta(  1, 48,  3)=                 -0.08713202874286242461d0
      iwe=iwe+1
      weighta(  2, 48,  3)=                 -0.01771674580411849650d0
      iwe=iwe+1
      weighta(  3, 48,  3)=                  0.24956499855999536575d0
      iwe=iwe+1
      weighta(  4, 48,  3)=                 -0.09327770726028961068d0
      iwe=iwe+1
      weighta(  5, 48,  3)=                  0.04034485124232379399d0
      iwe=iwe+1
      weighta(  6, 48,  3)=                  0.07002108569537941751d0
      iwe=iwe+1
      weighta(  7, 48,  3)=                 -0.32949720820615463479d0
      iwe=iwe+1
      weighta(  8, 48,  3)=                 -0.34816875117073148305d0
      iwe=iwe+1
      weighta(  9, 48,  3)=                 -0.06261520848094134784d0
      iwe=iwe+1
      weighta( 10, 48,  3)=                  0.07835313739722639392d0
      iwe=iwe+1
      weighta( 11, 48,  3)=                 -0.28560852969717259731d0
      iwe=iwe+1
      weighta( 12, 48,  3)=                 -0.08671690756670991096d0
      iwe=iwe+1
      weighta( 13, 48,  3)=                 -0.23502796360793273833d0
      iwe=iwe+1
      weighta( 14, 48,  3)=                  0.47361284167581979565d0
      iwe=iwe+1
      weighta( 15, 48,  3)=                  0.51260904312596788923d0
      iwe=iwe+1
      weighta( 16, 48,  3)=                  0.60027088378578274952d0
      iwe=iwe+1
      weighta( 17, 48,  3)=                 -0.19573122697053843555d0
      iwe=iwe+1
      weighta( 18, 48,  3)=                  0.15451034935304294726d0
      iwe=iwe+1
      weighta( 19, 48,  3)=                 -0.21718642565672824363d0
      iwe=iwe+1
      weighta( 20, 48,  3)=                 -0.16075854622665192162d0
      iwe=iwe+1
      weighta( 21, 48,  3)=                 -0.16651394869956120948d0
      iwe=iwe+1
      weighta( 22, 48,  3)=                 -0.98428040535090721708d0
      iwe=iwe+1
      weighta( 23, 48,  3)=                  0.32201637214359241090d0
      iwe=iwe+1
      weighta( 24, 48,  3)=                 -0.14567194225454416223d0
      iwe=iwe+1
      weighta( 25, 48,  3)=                 -0.18525592248913269611d0
      iwe=iwe+1
      weighta( 26, 48,  3)=                  0.51597934839124903750d0
      iwe=iwe+1
      weighta( 27, 48,  3)=                  0.41989885425117257078d0
      iwe=iwe+1
      weighta( 28, 48,  3)=                  0.52412979895402800334d0
      iwe=iwe+1
      weighta( 29, 48,  3)=                  0.38787338278201582975d0
      iwe=iwe+1
      weighta( 30, 48,  3)=                  0.03153167121301734405d0
      iwe=iwe+1
      weighta( 31, 48,  3)=                  0.04499111356650841581d0
      iwe=iwe+1
      weighta( 32, 48,  3)=                  0.68453707010840991742d0
      iwe=iwe+1
      weighta( 33, 48,  3)=                 -0.14029295827109655725d0
      iwe=iwe+1
      weighta( 34, 48,  3)=                  0.31550903549352193878d0
      iwe=iwe+1
      weighta( 35, 48,  3)=                  0.42883630162665398178d0
      iwe=iwe+1
      weighta( 36, 48,  3)=                  0.06012682033522363800d0
      iwe=iwe+1
      weighta( 37, 48,  3)=                 -0.12569120150012455528d0
      iwe=iwe+1
      weighta( 38, 48,  3)=                  0.00374389208445641318d0
      iwe=iwe+1
      weighta( 39, 48,  3)=                  0.51551775273732258764d0
      iwe=iwe+1
      weighta( 40, 48,  3)=                 -0.54981402040386240238d0
      iwe=iwe+1
      weighta( 41, 48,  3)=                  0.09858718273094928264d0
      iwe=iwe+1
      weighta( 42, 48,  3)=                  0.12737683639328706287d0
      iwe=iwe+1
      weighta( 43, 48,  3)=                 -0.33273060473405996484d0
      iwe=iwe+1
      weighta( 44, 48,  3)=                 -0.14518357007523910451d0
      iwe=iwe+1
      weighta( 45, 48,  3)=                 -0.19791815096460652068d0
      iwe=iwe+1
      weighta( 46, 48,  3)=                 -0.48163608261544715861d0
      iwe=iwe+1
      weighta( 47, 48,  3)=                 -0.46911552907816417290d0
      iwe=iwe+1
      weighta( 48, 48,  3)=                  0.39977471932398084276d0
      iwe=iwe+1
      weighta( 49, 48,  3)=                  0.31892321711890275759d0
      iwe=iwe+1
      weighta( 50, 48,  3)=                 -0.32510046744823611897d0
      iwe=iwe+1
      biasa( 48,  3)=                 -0.35788418280220146706d0
      iwe=iwe+1
      weighta(  1, 49,  3)=                 -0.26662633674057795163d0
      iwe=iwe+1
      weighta(  2, 49,  3)=                  0.28579321041554006655d0
      iwe=iwe+1
      weighta(  3, 49,  3)=                 -0.07640147854385791193d0
      iwe=iwe+1
      weighta(  4, 49,  3)=                  0.21181266555017758124d0
      iwe=iwe+1
      weighta(  5, 49,  3)=                 -0.03849457771695929953d0
      iwe=iwe+1
      weighta(  6, 49,  3)=                 -0.48901792677252048369d0
      iwe=iwe+1
      weighta(  7, 49,  3)=                 -0.21636040178692728109d0
      iwe=iwe+1
      weighta(  8, 49,  3)=                 -0.04265967775998780881d0
      iwe=iwe+1
      weighta(  9, 49,  3)=                  0.09120844842320191548d0
      iwe=iwe+1
      weighta( 10, 49,  3)=                  0.14923854321918264554d0
      iwe=iwe+1
      weighta( 11, 49,  3)=                  0.25107017638410145111d0
      iwe=iwe+1
      weighta( 12, 49,  3)=                  0.32833858185757169856d0
      iwe=iwe+1
      weighta( 13, 49,  3)=                  0.26663264221307075852d0
      iwe=iwe+1
      weighta( 14, 49,  3)=                 -0.37318089692879419239d0
      iwe=iwe+1
      weighta( 15, 49,  3)=                  0.02179946864843821525d0
      iwe=iwe+1
      weighta( 16, 49,  3)=                  0.06104425962572563452d0
      iwe=iwe+1
      weighta( 17, 49,  3)=                 -0.10780797171191319750d0
      iwe=iwe+1
      weighta( 18, 49,  3)=                 -0.20709636058533106850d0
      iwe=iwe+1
      weighta( 19, 49,  3)=                 -0.23587181735135379079d0
      iwe=iwe+1
      weighta( 20, 49,  3)=                 -0.26401963446851250961d0
      iwe=iwe+1
      weighta( 21, 49,  3)=                  0.22655096183526218789d0
      iwe=iwe+1
      weighta( 22, 49,  3)=                  0.48901188782644550157d0
      iwe=iwe+1
      weighta( 23, 49,  3)=                  0.33223130855173971243d0
      iwe=iwe+1
      weighta( 24, 49,  3)=                 -0.37532787118351834676d0
      iwe=iwe+1
      weighta( 25, 49,  3)=                 -0.37840910485077233760d0
      iwe=iwe+1
      weighta( 26, 49,  3)=                  0.27023078607400358164d0
      iwe=iwe+1
      weighta( 27, 49,  3)=                 -0.00854316686815641962d0
      iwe=iwe+1
      weighta( 28, 49,  3)=                  0.50534065616033829738d0
      iwe=iwe+1
      weighta( 29, 49,  3)=                 -0.20996656090700338559d0
      iwe=iwe+1
      weighta( 30, 49,  3)=                 -0.12081852584152021068d0
      iwe=iwe+1
      weighta( 31, 49,  3)=                 -0.35629748205541644790d0
      iwe=iwe+1
      weighta( 32, 49,  3)=                 -0.50935103952095606150d0
      iwe=iwe+1
      weighta( 33, 49,  3)=                 -0.41791905157277492444d0
      iwe=iwe+1
      weighta( 34, 49,  3)=                 -0.24008993699054198556d0
      iwe=iwe+1
      weighta( 35, 49,  3)=                  0.13844048487694582406d0
      iwe=iwe+1
      weighta( 36, 49,  3)=                  0.45935470687443258342d0
      iwe=iwe+1
      weighta( 37, 49,  3)=                 -0.14160061078899338627d0
      iwe=iwe+1
      weighta( 38, 49,  3)=                  0.45109896506514524095d0
      iwe=iwe+1
      weighta( 39, 49,  3)=                  0.08695693632035014775d0
      iwe=iwe+1
      weighta( 40, 49,  3)=                  0.20509975103266814278d0
      iwe=iwe+1
      weighta( 41, 49,  3)=                  0.21369734591213712660d0
      iwe=iwe+1
      weighta( 42, 49,  3)=                  0.28896624048705926713d0
      iwe=iwe+1
      weighta( 43, 49,  3)=                 -0.47258632093956498554d0
      iwe=iwe+1
      weighta( 44, 49,  3)=                  0.29459458475264688193d0
      iwe=iwe+1
      weighta( 45, 49,  3)=                  0.19203187796181092617d0
      iwe=iwe+1
      weighta( 46, 49,  3)=                 -0.00371796111044168150d0
      iwe=iwe+1
      weighta( 47, 49,  3)=                 -0.09446339896977974659d0
      iwe=iwe+1
      weighta( 48, 49,  3)=                 -0.14415940387964532032d0
      iwe=iwe+1
      weighta( 49, 49,  3)=                 -0.39200452551509357146d0
      iwe=iwe+1
      weighta( 50, 49,  3)=                 -0.23791452738974627756d0
      iwe=iwe+1
      biasa( 49,  3)=                 -0.34047752945974268934d0
      iwe=iwe+1
      weighta(  1, 50,  3)=                 -0.42557897757062346233d0
      iwe=iwe+1
      weighta(  2, 50,  3)=                  0.06516240042776755281d0
      iwe=iwe+1
      weighta(  3, 50,  3)=                 -0.15273023238311722594d0
      iwe=iwe+1
      weighta(  4, 50,  3)=                  0.04476565996379847784d0
      iwe=iwe+1
      weighta(  5, 50,  3)=                 -0.04187908540670573498d0
      iwe=iwe+1
      weighta(  6, 50,  3)=                 -0.53420629842160660683d0
      iwe=iwe+1
      weighta(  7, 50,  3)=                 -0.02383142460344092606d0
      iwe=iwe+1
      weighta(  8, 50,  3)=                  0.22824958869547590234d0
      iwe=iwe+1
      weighta(  9, 50,  3)=                 -0.42117659210414143400d0
      iwe=iwe+1
      weighta( 10, 50,  3)=                 -0.10342747351196671102d0
      iwe=iwe+1
      weighta( 11, 50,  3)=                 -0.06833188385333520409d0
      iwe=iwe+1
      weighta( 12, 50,  3)=                  0.15245125231964079537d0
      iwe=iwe+1
      weighta( 13, 50,  3)=                 -0.48964839932960568802d0
      iwe=iwe+1
      weighta( 14, 50,  3)=                  0.12420134069968470636d0
      iwe=iwe+1
      weighta( 15, 50,  3)=                  0.51661853449416061945d0
      iwe=iwe+1
      weighta( 16, 50,  3)=                 -0.05178193407652956215d0
      iwe=iwe+1
      weighta( 17, 50,  3)=                 -0.08982535912804930078d0
      iwe=iwe+1
      weighta( 18, 50,  3)=                 -0.72101796743303869786d0
      iwe=iwe+1
      weighta( 19, 50,  3)=                 -0.14346917411311055357d0
      iwe=iwe+1
      weighta( 20, 50,  3)=                  0.30176141496179731405d0
      iwe=iwe+1
      weighta( 21, 50,  3)=                 -0.24474023343696330035d0
      iwe=iwe+1
      weighta( 22, 50,  3)=                 -0.37849444802465553872d0
      iwe=iwe+1
      weighta( 23, 50,  3)=                  0.25006548684439006136d0
      iwe=iwe+1
      weighta( 24, 50,  3)=                  0.01120064691893785797d0
      iwe=iwe+1
      weighta( 25, 50,  3)=                 -0.17287601585052631004d0
      iwe=iwe+1
      weighta( 26, 50,  3)=                 -0.06827603765595684215d0
      iwe=iwe+1
      weighta( 27, 50,  3)=                  0.17800335547686318982d0
      iwe=iwe+1
      weighta( 28, 50,  3)=                  0.22307404115194842675d0
      iwe=iwe+1
      weighta( 29, 50,  3)=                 -0.53273084801505188324d0
      iwe=iwe+1
      weighta( 30, 50,  3)=                 -0.28082223447137538708d0
      iwe=iwe+1
      weighta( 31, 50,  3)=                  0.53784457626845860734d0
      iwe=iwe+1
      weighta( 32, 50,  3)=                 -0.20776230163838954601d0
      iwe=iwe+1
      weighta( 33, 50,  3)=                  0.21095033278818944855d0
      iwe=iwe+1
      weighta( 34, 50,  3)=                  0.13988024787339106703d0
      iwe=iwe+1
      weighta( 35, 50,  3)=                  0.09493279410673853558d0
      iwe=iwe+1
      weighta( 36, 50,  3)=                  0.06311520522113084342d0
      iwe=iwe+1
      weighta( 37, 50,  3)=                  0.21313806071893115490d0
      iwe=iwe+1
      weighta( 38, 50,  3)=                 -0.00593440316086056401d0
      iwe=iwe+1
      weighta( 39, 50,  3)=                  0.53807602839854784538d0
      iwe=iwe+1
      weighta( 40, 50,  3)=                 -0.18006540041780885741d0
      iwe=iwe+1
      weighta( 41, 50,  3)=                  0.17378216973337967666d0
      iwe=iwe+1
      weighta( 42, 50,  3)=                  0.32303906842945384614d0
      iwe=iwe+1
      weighta( 43, 50,  3)=                 -0.30068790658318417242d0
      iwe=iwe+1
      weighta( 44, 50,  3)=                 -0.11636128937176644371d0
      iwe=iwe+1
      weighta( 45, 50,  3)=                 -0.16518872304378728888d0
      iwe=iwe+1
      weighta( 46, 50,  3)=                 -0.19615981176938804276d0
      iwe=iwe+1
      weighta( 47, 50,  3)=                 -0.38155361517993680032d0
      iwe=iwe+1
      weighta( 48, 50,  3)=                 -0.27275813153363592800d0
      iwe=iwe+1
      weighta( 49, 50,  3)=                 -0.14411220560482998487d0
      iwe=iwe+1
      weighta( 50, 50,  3)=                  0.38917693177748297062d0
      iwe=iwe+1
      biasa( 50,  3)=                 -0.38088933393035850905d0
      iwe=iwe+1
      weighta(  1, 51,  3)=                 -0.12160083992382665630d0
      iwe=iwe+1
      weighta(  2, 51,  3)=                  0.22173178900638110256d0
      iwe=iwe+1
      weighta(  3, 51,  3)=                  0.21192823525712164989d0
      iwe=iwe+1
      weighta(  4, 51,  3)=                 -0.05029480573345532918d0
      iwe=iwe+1
      weighta(  5, 51,  3)=                  0.61924399693461684713d0
      iwe=iwe+1
      weighta(  6, 51,  3)=                  0.02915393178246624903d0
      iwe=iwe+1
      weighta(  7, 51,  3)=                  0.06360215584974451830d0
      iwe=iwe+1
      weighta(  8, 51,  3)=                 -0.03168244319009291127d0
      iwe=iwe+1
      weighta(  9, 51,  3)=                  0.13691121654443116906d0
      iwe=iwe+1
      weighta( 10, 51,  3)=                 -0.03681501326691287435d0
      iwe=iwe+1
      weighta( 11, 51,  3)=                  0.39655869716724206908d0
      iwe=iwe+1
      weighta( 12, 51,  3)=                 -0.64993123193697110995d0
      iwe=iwe+1
      weighta( 13, 51,  3)=                 -0.28360653002354324626d0
      iwe=iwe+1
      weighta( 14, 51,  3)=                 -0.11859137859401042148d0
      iwe=iwe+1
      weighta( 15, 51,  3)=                  0.08509335142106738692d0
      iwe=iwe+1
      weighta( 16, 51,  3)=                 -0.12277089603798695128d0
      iwe=iwe+1
      weighta( 17, 51,  3)=                 -0.20300511847647323416d0
      iwe=iwe+1
      weighta( 18, 51,  3)=                 -0.25610854629039941921d0
      iwe=iwe+1
      weighta( 19, 51,  3)=                 -0.01887631188932527293d0
      iwe=iwe+1
      weighta( 20, 51,  3)=                 -0.41732144942251325759d0
      iwe=iwe+1
      weighta( 21, 51,  3)=                 -0.30318271728541845711d0
      iwe=iwe+1
      weighta( 22, 51,  3)=                  0.35701647206664965939d0
      iwe=iwe+1
      weighta( 23, 51,  3)=                 -0.02197212948940024946d0
      iwe=iwe+1
      weighta( 24, 51,  3)=                 -0.42381549907459370452d0
      iwe=iwe+1
      weighta( 25, 51,  3)=                 -0.02035152359950821721d0
      iwe=iwe+1
      weighta( 26, 51,  3)=                 -0.26994757248696460428d0
      iwe=iwe+1
      weighta( 27, 51,  3)=                  0.32696144469285087775d0
      iwe=iwe+1
      weighta( 28, 51,  3)=                 -0.28306378518263064503d0
      iwe=iwe+1
      weighta( 29, 51,  3)=                  0.40689968949595600733d0
      iwe=iwe+1
      weighta( 30, 51,  3)=                  0.26814334581250170997d0
      iwe=iwe+1
      weighta( 31, 51,  3)=                  0.13242797250819446364d0
      iwe=iwe+1
      weighta( 32, 51,  3)=                  0.23475743173470642322d0
      iwe=iwe+1
      weighta( 33, 51,  3)=                 -0.01704992548264180549d0
      iwe=iwe+1
      weighta( 34, 51,  3)=                  0.03400051071852153856d0
      iwe=iwe+1
      weighta( 35, 51,  3)=                 -0.35000319694279297122d0
      iwe=iwe+1
      weighta( 36, 51,  3)=                 -0.07343181754408369122d0
      iwe=iwe+1
      weighta( 37, 51,  3)=                  0.12508394729370891918d0
      iwe=iwe+1
      weighta( 38, 51,  3)=                 -0.39130566164926361417d0
      iwe=iwe+1
      weighta( 39, 51,  3)=                 -0.54309971624015129787d0
      iwe=iwe+1
      weighta( 40, 51,  3)=                 -0.22465935163287970022d0
      iwe=iwe+1
      weighta( 41, 51,  3)=                 -0.36678339499686446468d0
      iwe=iwe+1
      weighta( 42, 51,  3)=                 -0.12475850135272278929d0
      iwe=iwe+1
      weighta( 43, 51,  3)=                  0.10179494120813879776d0
      iwe=iwe+1
      weighta( 44, 51,  3)=                 -0.06775373871379407331d0
      iwe=iwe+1
      weighta( 45, 51,  3)=                 -0.06104901547173256088d0
      iwe=iwe+1
      weighta( 46, 51,  3)=                 -0.09569413888661205958d0
      iwe=iwe+1
      weighta( 47, 51,  3)=                 -0.34965659538303250908d0
      iwe=iwe+1
      weighta( 48, 51,  3)=                  0.34036021435080854314d0
      iwe=iwe+1
      weighta( 49, 51,  3)=                  0.11262522652240997134d0
      iwe=iwe+1
      weighta( 50, 51,  3)=                  0.04186598181634541838d0
      iwe=iwe+1
      biasa( 51,  3)=                 -0.34373597488276058654d0
      iwe=iwe+1
      weighta(  1, 52,  3)=                 -0.31751179359110187628d0
      iwe=iwe+1
      weighta(  2, 52,  3)=                  0.24569062200542929331d0
      iwe=iwe+1
      weighta(  3, 52,  3)=                 -0.05259467393444321875d0
      iwe=iwe+1
      weighta(  4, 52,  3)=                 -0.00301579508591564563d0
      iwe=iwe+1
      weighta(  5, 52,  3)=                  0.72476009241513938974d0
      iwe=iwe+1
      weighta(  6, 52,  3)=                  0.80996661914245382530d0
      iwe=iwe+1
      weighta(  7, 52,  3)=                 -0.30182194552337171523d0
      iwe=iwe+1
      weighta(  8, 52,  3)=                 -0.41580070800423235555d0
      iwe=iwe+1
      weighta(  9, 52,  3)=                 -0.06575469219896359907d0
      iwe=iwe+1
      weighta( 10, 52,  3)=                 -0.21571988260819377481d0
      iwe=iwe+1
      weighta( 11, 52,  3)=                  0.30432702970455072222d0
      iwe=iwe+1
      weighta( 12, 52,  3)=                 -0.03017456155750676897d0
      iwe=iwe+1
      weighta( 13, 52,  3)=                  0.42832269563588010186d0
      iwe=iwe+1
      weighta( 14, 52,  3)=                  0.42323474735526245283d0
      iwe=iwe+1
      weighta( 15, 52,  3)=                  0.13726060142479179493d0
      iwe=iwe+1
      weighta( 16, 52,  3)=                  0.14624909930534710223d0
      iwe=iwe+1
      weighta( 17, 52,  3)=                  0.12505594164436079074d0
      iwe=iwe+1
      weighta( 18, 52,  3)=                 -0.39524559110070084378d0
      iwe=iwe+1
      weighta( 19, 52,  3)=                 -0.58835669213914110198d0
      iwe=iwe+1
      weighta( 20, 52,  3)=                  0.30669961964495856543d0
      iwe=iwe+1
      weighta( 21, 52,  3)=                 -0.34718142881274416389d0
      iwe=iwe+1
      weighta( 22, 52,  3)=                  0.01719341783334053797d0
      iwe=iwe+1
      weighta( 23, 52,  3)=                 -0.36094724894115742808d0
      iwe=iwe+1
      weighta( 24, 52,  3)=                 -0.17959505578123421965d0
      iwe=iwe+1
      weighta( 25, 52,  3)=                  0.06512872284171365711d0
      iwe=iwe+1
      weighta( 26, 52,  3)=                  0.37495893792552498214d0
      iwe=iwe+1
      weighta( 27, 52,  3)=                  0.03838046611153952958d0
      iwe=iwe+1
      weighta( 28, 52,  3)=                 -0.05747365182271717277d0
      iwe=iwe+1
      weighta( 29, 52,  3)=                 -0.18775768071630088984d0
      iwe=iwe+1
      weighta( 30, 52,  3)=                  0.08843748375896376412d0
      iwe=iwe+1
      weighta( 31, 52,  3)=                 -0.01086424758376203920d0
      iwe=iwe+1
      weighta( 32, 52,  3)=                 -0.14598318257198314440d0
      iwe=iwe+1
      weighta( 33, 52,  3)=                  0.17167639596256120682d0
      iwe=iwe+1
      weighta( 34, 52,  3)=                 -0.22916700937904341262d0
      iwe=iwe+1
      weighta( 35, 52,  3)=                  0.66010369646118149944d0
      iwe=iwe+1
      weighta( 36, 52,  3)=                  0.34118491305914838696d0
      iwe=iwe+1
      weighta( 37, 52,  3)=                  0.29357084276836536985d0
      iwe=iwe+1
      weighta( 38, 52,  3)=                  0.21840622031815756787d0
      iwe=iwe+1
      weighta( 39, 52,  3)=                  0.13407980488498993932d0
      iwe=iwe+1
      weighta( 40, 52,  3)=                  0.09524533538768215069d0
      iwe=iwe+1
      weighta( 41, 52,  3)=                  0.32816512749897197576d0
      iwe=iwe+1
      weighta( 42, 52,  3)=                 -0.07441694443232162171d0
      iwe=iwe+1
      weighta( 43, 52,  3)=                 -0.11419702314299856605d0
      iwe=iwe+1
      weighta( 44, 52,  3)=                 -0.38168875386946266026d0
      iwe=iwe+1
      weighta( 45, 52,  3)=                  0.00575832292337622766d0
      iwe=iwe+1
      weighta( 46, 52,  3)=                  0.21934490809611151274d0
      iwe=iwe+1
      weighta( 47, 52,  3)=                  0.17301200099587776826d0
      iwe=iwe+1
      weighta( 48, 52,  3)=                 -0.22891317356493695589d0
      iwe=iwe+1
      weighta( 49, 52,  3)=                 -0.00988477660951023705d0
      iwe=iwe+1
      weighta( 50, 52,  3)=                 -0.63769666022285298457d0
      iwe=iwe+1
      biasa( 52,  3)=                 -0.47792132698659889334d0
      iwe=iwe+1
      weighta(  1, 53,  3)=                  0.22940805803472769098d0
      iwe=iwe+1
      weighta(  2, 53,  3)=                 -0.16851183438764841260d0
      iwe=iwe+1
      weighta(  3, 53,  3)=                 -0.12459088128773740389d0
      iwe=iwe+1
      weighta(  4, 53,  3)=                  0.34825145813449859267d0
      iwe=iwe+1
      weighta(  5, 53,  3)=                  0.22657196757966460710d0
      iwe=iwe+1
      weighta(  6, 53,  3)=                  0.37857709773639780515d0
      iwe=iwe+1
      weighta(  7, 53,  3)=                  0.29181890888386513572d0
      iwe=iwe+1
      weighta(  8, 53,  3)=                 -0.23378716666080678888d0
      iwe=iwe+1
      weighta(  9, 53,  3)=                  0.29075266897405110944d0
      iwe=iwe+1
      weighta( 10, 53,  3)=                  0.38861835427744817473d0
      iwe=iwe+1
      weighta( 11, 53,  3)=                 -0.21558295910321673139d0
      iwe=iwe+1
      weighta( 12, 53,  3)=                  0.12203393144987950691d0
      iwe=iwe+1
      weighta( 13, 53,  3)=                 -0.05329111170792829449d0
      iwe=iwe+1
      weighta( 14, 53,  3)=                 -0.07988718266626006204d0
      iwe=iwe+1
      weighta( 15, 53,  3)=                 -0.00761667110285091549d0
      iwe=iwe+1
      weighta( 16, 53,  3)=                  0.15604497520663077048d0
      iwe=iwe+1
      weighta( 17, 53,  3)=                  0.18438172692793888818d0
      iwe=iwe+1
      weighta( 18, 53,  3)=                  0.09753755598963632922d0
      iwe=iwe+1
      weighta( 19, 53,  3)=                 -0.06849525240814766103d0
      iwe=iwe+1
      weighta( 20, 53,  3)=                  0.43381329038578714252d0
      iwe=iwe+1
      weighta( 21, 53,  3)=                  0.21961544785867159746d0
      iwe=iwe+1
      weighta( 22, 53,  3)=                 -0.03202695787794238025d0
      iwe=iwe+1
      weighta( 23, 53,  3)=                 -0.16819722891560404121d0
      iwe=iwe+1
      weighta( 24, 53,  3)=                  0.19662273211031811027d0
      iwe=iwe+1
      weighta( 25, 53,  3)=                 -0.20221188416672539190d0
      iwe=iwe+1
      weighta( 26, 53,  3)=                 -0.41253790060662037797d0
      iwe=iwe+1
      weighta( 27, 53,  3)=                 -0.37447744825689832648d0
      iwe=iwe+1
      weighta( 28, 53,  3)=                  0.38073387643801986924d0
      iwe=iwe+1
      weighta( 29, 53,  3)=                 -0.15129557043534841432d0
      iwe=iwe+1
      weighta( 30, 53,  3)=                 -0.21481635930081069419d0
      iwe=iwe+1
      weighta( 31, 53,  3)=                 -0.19651971131281095739d0
      iwe=iwe+1
      weighta( 32, 53,  3)=                  0.13291856731764484234d0
      iwe=iwe+1
      weighta( 33, 53,  3)=                 -0.09193718867127323446d0
      iwe=iwe+1
      weighta( 34, 53,  3)=                  0.28112899343849634404d0
      iwe=iwe+1
      weighta( 35, 53,  3)=                  0.15531006075876088723d0
      iwe=iwe+1
      weighta( 36, 53,  3)=                  0.17289618451491220452d0
      iwe=iwe+1
      weighta( 37, 53,  3)=                 -0.05919448688169638012d0
      iwe=iwe+1
      weighta( 38, 53,  3)=                 -0.15643197702168054608d0
      iwe=iwe+1
      weighta( 39, 53,  3)=                 -0.09410646735994647460d0
      iwe=iwe+1
      weighta( 40, 53,  3)=                  0.38179805187987775339d0
      iwe=iwe+1
      weighta( 41, 53,  3)=                  0.33113556408791045005d0
      iwe=iwe+1
      weighta( 42, 53,  3)=                  0.29269250523779977158d0
      iwe=iwe+1
      weighta( 43, 53,  3)=                  0.50175694161097406099d0
      iwe=iwe+1
      weighta( 44, 53,  3)=                 -0.17881587853569078095d0
      iwe=iwe+1
      weighta( 45, 53,  3)=                  0.05094938902611843845d0
      iwe=iwe+1
      weighta( 46, 53,  3)=                 -0.30900236943843117920d0
      iwe=iwe+1
      weighta( 47, 53,  3)=                  0.28211970502128164151d0
      iwe=iwe+1
      weighta( 48, 53,  3)=                  0.54422800371918100826d0
      iwe=iwe+1
      weighta( 49, 53,  3)=                 -0.10608129376652203346d0
      iwe=iwe+1
      weighta( 50, 53,  3)=                  0.01653968454086582676d0
      iwe=iwe+1
      biasa( 53,  3)=                  0.48141666919731773699d0
      iwe=iwe+1
      weighta(  1, 54,  3)=                  0.10604604109389864641d0
      iwe=iwe+1
      weighta(  2, 54,  3)=                 -0.38410216047263379124d0
      iwe=iwe+1
      weighta(  3, 54,  3)=                  0.19627229305423804506d0
      iwe=iwe+1
      weighta(  4, 54,  3)=                  0.24106933999704618921d0
      iwe=iwe+1
      weighta(  5, 54,  3)=                  0.27789159602009011474d0
      iwe=iwe+1
      weighta(  6, 54,  3)=                 -0.47682703508941998161d0
      iwe=iwe+1
      weighta(  7, 54,  3)=                 -0.14970177056443581542d0
      iwe=iwe+1
      weighta(  8, 54,  3)=                 -0.43584403745632538385d0
      iwe=iwe+1
      weighta(  9, 54,  3)=                 -0.18484287063030818699d0
      iwe=iwe+1
      weighta( 10, 54,  3)=                  0.14593202028022814187d0
      iwe=iwe+1
      weighta( 11, 54,  3)=                  0.26384728702149912172d0
      iwe=iwe+1
      weighta( 12, 54,  3)=                 -0.17424394183016220228d0
      iwe=iwe+1
      weighta( 13, 54,  3)=                 -0.25960677339204157876d0
      iwe=iwe+1
      weighta( 14, 54,  3)=                 -0.26969034146063353141d0
      iwe=iwe+1
      weighta( 15, 54,  3)=                 -0.04917445066703663575d0
      iwe=iwe+1
      weighta( 16, 54,  3)=                  0.26084163123281994823d0
      iwe=iwe+1
      weighta( 17, 54,  3)=                 -0.26262752177804532527d0
      iwe=iwe+1
      weighta( 18, 54,  3)=                  0.25496426137957461933d0
      iwe=iwe+1
      weighta( 19, 54,  3)=                 -0.02991811772248948939d0
      iwe=iwe+1
      weighta( 20, 54,  3)=                 -0.45964806389132817355d0
      iwe=iwe+1
      weighta( 21, 54,  3)=                  0.40343265614752316095d0
      iwe=iwe+1
      weighta( 22, 54,  3)=                 -0.37751546567919724851d0
      iwe=iwe+1
      weighta( 23, 54,  3)=                 -0.27308037305358118241d0
      iwe=iwe+1
      weighta( 24, 54,  3)=                 -0.09215210709371589315d0
      iwe=iwe+1
      weighta( 25, 54,  3)=                 -0.02858818150776050795d0
      iwe=iwe+1
      weighta( 26, 54,  3)=                  0.53703897297690805779d0
      iwe=iwe+1
      weighta( 27, 54,  3)=                  0.23776523684715292206d0
      iwe=iwe+1
      weighta( 28, 54,  3)=                  0.09976444379748494740d0
      iwe=iwe+1
      weighta( 29, 54,  3)=                  0.15387924380454487405d0
      iwe=iwe+1
      weighta( 30, 54,  3)=                  0.22656032157106992253d0
      iwe=iwe+1
      weighta( 31, 54,  3)=                  0.21463755369791437388d0
      iwe=iwe+1
      weighta( 32, 54,  3)=                  0.01944124694399112022d0
      iwe=iwe+1
      weighta( 33, 54,  3)=                  0.45035430166507589567d0
      iwe=iwe+1
      weighta( 34, 54,  3)=                  0.00147254219674691007d0
      iwe=iwe+1
      weighta( 35, 54,  3)=                 -0.10213676896199372357d0
      iwe=iwe+1
      weighta( 36, 54,  3)=                  0.14357521898543776362d0
      iwe=iwe+1
      weighta( 37, 54,  3)=                 -0.28885514165303782796d0
      iwe=iwe+1
      weighta( 38, 54,  3)=                  0.38742702819289059901d0
      iwe=iwe+1
      weighta( 39, 54,  3)=                  0.25979314685668070117d0
      iwe=iwe+1
      weighta( 40, 54,  3)=                  0.14672635179188914245d0
      iwe=iwe+1
      weighta( 41, 54,  3)=                  0.07345941230922681253d0
      iwe=iwe+1
      weighta( 42, 54,  3)=                 -0.02739517256323716413d0
      iwe=iwe+1
      weighta( 43, 54,  3)=                 -0.11195117980106014666d0
      iwe=iwe+1
      weighta( 44, 54,  3)=                 -0.29174616807246761541d0
      iwe=iwe+1
      weighta( 45, 54,  3)=                  0.07775608563366781523d0
      iwe=iwe+1
      weighta( 46, 54,  3)=                 -0.33438226150455341301d0
      iwe=iwe+1
      weighta( 47, 54,  3)=                  0.21048725512028737539d0
      iwe=iwe+1
      weighta( 48, 54,  3)=                  0.17046971138942310087d0
      iwe=iwe+1
      weighta( 49, 54,  3)=                  0.29813714350411263387d0
      iwe=iwe+1
      weighta( 50, 54,  3)=                 -0.47674378659989657958d0
      iwe=iwe+1
      biasa( 54,  3)=                  0.48193107530954654161d0
      iwe=iwe+1
      weighta(  1, 55,  3)=                 -0.61911305481048539701d0
      iwe=iwe+1
      weighta(  2, 55,  3)=                  0.26945625495749969680d0
      iwe=iwe+1
      weighta(  3, 55,  3)=                  0.39853758994734039822d0
      iwe=iwe+1
      weighta(  4, 55,  3)=                  0.05176503642184724502d0
      iwe=iwe+1
      weighta(  5, 55,  3)=                 -0.43856798554246684274d0
      iwe=iwe+1
      weighta(  6, 55,  3)=                  0.24040656172734048424d0
      iwe=iwe+1
      weighta(  7, 55,  3)=                  0.12498553505915663275d0
      iwe=iwe+1
      weighta(  8, 55,  3)=                 -0.01893092498562742518d0
      iwe=iwe+1
      weighta(  9, 55,  3)=                  0.47168908680025517510d0
      iwe=iwe+1
      weighta( 10, 55,  3)=                 -0.20474777192301019113d0
      iwe=iwe+1
      weighta( 11, 55,  3)=                  0.02423177233541147849d0
      iwe=iwe+1
      weighta( 12, 55,  3)=                 -0.28729543244671928992d0
      iwe=iwe+1
      weighta( 13, 55,  3)=                  0.29518242217066675837d0
      iwe=iwe+1
      weighta( 14, 55,  3)=                 -0.17598436565912703444d0
      iwe=iwe+1
      weighta( 15, 55,  3)=                 -0.27244422567201015406d0
      iwe=iwe+1
      weighta( 16, 55,  3)=                  0.33683998962709016389d0
      iwe=iwe+1
      weighta( 17, 55,  3)=                 -0.06675776099095800942d0
      iwe=iwe+1
      weighta( 18, 55,  3)=                  0.34836304046215327279d0
      iwe=iwe+1
      weighta( 19, 55,  3)=                  0.20386200457867356683d0
      iwe=iwe+1
      weighta( 20, 55,  3)=                  0.30547111265235654676d0
      iwe=iwe+1
      weighta( 21, 55,  3)=                 -0.15692981681475412503d0
      iwe=iwe+1
      weighta( 22, 55,  3)=                 -0.18908026319206439059d0
      iwe=iwe+1
      weighta( 23, 55,  3)=                  0.20631000235946495014d0
      iwe=iwe+1
      weighta( 24, 55,  3)=                 -0.07735349957413248378d0
      iwe=iwe+1
      weighta( 25, 55,  3)=                 -0.29404081924817354610d0
      iwe=iwe+1
      weighta( 26, 55,  3)=                 -0.34405034281208185520d0
      iwe=iwe+1
      weighta( 27, 55,  3)=                  0.06068058493365121459d0
      iwe=iwe+1
      weighta( 28, 55,  3)=                  0.11096902609823723618d0
      iwe=iwe+1
      weighta( 29, 55,  3)=                  0.03708881350642630192d0
      iwe=iwe+1
      weighta( 30, 55,  3)=                 -0.03178363277643976581d0
      iwe=iwe+1
      weighta( 31, 55,  3)=                  0.19092342838510767411d0
      iwe=iwe+1
      weighta( 32, 55,  3)=                  0.17262038859962552939d0
      iwe=iwe+1
      weighta( 33, 55,  3)=                  0.06841898742527034727d0
      iwe=iwe+1
      weighta( 34, 55,  3)=                  0.30843129332551905142d0
      iwe=iwe+1
      weighta( 35, 55,  3)=                 -0.28753167858217215658d0
      iwe=iwe+1
      weighta( 36, 55,  3)=                 -0.02976249118559903470d0
      iwe=iwe+1
      weighta( 37, 55,  3)=                  0.13434678932934029927d0
      iwe=iwe+1
      weighta( 38, 55,  3)=                 -0.00045361011427592478d0
      iwe=iwe+1
      weighta( 39, 55,  3)=                  0.05967370972073052920d0
      iwe=iwe+1
      weighta( 40, 55,  3)=                 -0.26409474132669236157d0
      iwe=iwe+1
      weighta( 41, 55,  3)=                  0.14403002627032424066d0
      iwe=iwe+1
      weighta( 42, 55,  3)=                  0.56781931617348557761d0
      iwe=iwe+1
      weighta( 43, 55,  3)=                 -0.22514041230727047105d0
      iwe=iwe+1
      weighta( 44, 55,  3)=                  0.17684110192816934748d0
      iwe=iwe+1
      weighta( 45, 55,  3)=                 -0.45372103212355852087d0
      iwe=iwe+1
      weighta( 46, 55,  3)=                 -0.54157268407678227362d0
      iwe=iwe+1
      weighta( 47, 55,  3)=                 -0.28693988292797822925d0
      iwe=iwe+1
      weighta( 48, 55,  3)=                 -0.24518113735072938342d0
      iwe=iwe+1
      weighta( 49, 55,  3)=                  0.07764174162956435921d0
      iwe=iwe+1
      weighta( 50, 55,  3)=                 -0.02914888992108822033d0
      iwe=iwe+1
      biasa( 55,  3)=                 -0.67581664408429475976d0
      iwe=iwe+1
      weighta(  1, 56,  3)=                  0.29660503372921465104d0
      iwe=iwe+1
      weighta(  2, 56,  3)=                  0.16089268370234965921d0
      iwe=iwe+1
      weighta(  3, 56,  3)=                  0.30085904507485355941d0
      iwe=iwe+1
      weighta(  4, 56,  3)=                 -0.11963018066206991541d0
      iwe=iwe+1
      weighta(  5, 56,  3)=                 -0.43018748231600384413d0
      iwe=iwe+1
      weighta(  6, 56,  3)=                 -0.30038195057197886184d0
      iwe=iwe+1
      weighta(  7, 56,  3)=                 -0.36467644689130268576d0
      iwe=iwe+1
      weighta(  8, 56,  3)=                  0.49136155407181730803d0
      iwe=iwe+1
      weighta(  9, 56,  3)=                 -0.28099382138105072348d0
      iwe=iwe+1
      weighta( 10, 56,  3)=                 -0.10249024585541841037d0
      iwe=iwe+1
      weighta( 11, 56,  3)=                 -0.35057034523037033935d0
      iwe=iwe+1
      weighta( 12, 56,  3)=                 -0.01913901075022083828d0
      iwe=iwe+1
      weighta( 13, 56,  3)=                  0.09699472878989787161d0
      iwe=iwe+1
      weighta( 14, 56,  3)=                 -0.17103081861544336406d0
      iwe=iwe+1
      weighta( 15, 56,  3)=                  0.24087438970141572536d0
      iwe=iwe+1
      weighta( 16, 56,  3)=                  0.01310238420819388912d0
      iwe=iwe+1
      weighta( 17, 56,  3)=                  0.06233360772034396424d0
      iwe=iwe+1
      weighta( 18, 56,  3)=                 -0.08955308922110977177d0
      iwe=iwe+1
      weighta( 19, 56,  3)=                 -0.21837267184156955446d0
      iwe=iwe+1
      weighta( 20, 56,  3)=                 -0.18084629017263875728d0
      iwe=iwe+1
      weighta( 21, 56,  3)=                 -0.02066001363934277454d0
      iwe=iwe+1
      weighta( 22, 56,  3)=                 -0.22587790608168939466d0
      iwe=iwe+1
      weighta( 23, 56,  3)=                  0.17367466591809879728d0
      iwe=iwe+1
      weighta( 24, 56,  3)=                 -0.34865632082641323519d0
      iwe=iwe+1
      weighta( 25, 56,  3)=                 -0.09969316826385452024d0
      iwe=iwe+1
      weighta( 26, 56,  3)=                  0.14163739346050632784d0
      iwe=iwe+1
      weighta( 27, 56,  3)=                  0.05940795720976378702d0
      iwe=iwe+1
      weighta( 28, 56,  3)=                 -0.28571601855217221289d0
      iwe=iwe+1
      weighta( 29, 56,  3)=                 -0.31254924853114479655d0
      iwe=iwe+1
      weighta( 30, 56,  3)=                  0.26472310664177184369d0
      iwe=iwe+1
      weighta( 31, 56,  3)=                  0.14903783157708205831d0
      iwe=iwe+1
      weighta( 32, 56,  3)=                 -0.27148465412395739182d0
      iwe=iwe+1
      weighta( 33, 56,  3)=                 -0.11702943600213908115d0
      iwe=iwe+1
      weighta( 34, 56,  3)=                 -0.24217281280804359156d0
      iwe=iwe+1
      weighta( 35, 56,  3)=                 -0.34270803554235684807d0
      iwe=iwe+1
      weighta( 36, 56,  3)=                 -0.28751405650693728777d0
      iwe=iwe+1
      weighta( 37, 56,  3)=                  0.05699969176724032499d0
      iwe=iwe+1
      weighta( 38, 56,  3)=                  0.27497934462838752312d0
      iwe=iwe+1
      weighta( 39, 56,  3)=                  0.21712251350901767832d0
      iwe=iwe+1
      weighta( 40, 56,  3)=                  0.17330763068012305927d0
      iwe=iwe+1
      weighta( 41, 56,  3)=                 -0.13906579733009627464d0
      iwe=iwe+1
      weighta( 42, 56,  3)=                  0.00867345805040626618d0
      iwe=iwe+1
      weighta( 43, 56,  3)=                 -0.15322462736238517955d0
      iwe=iwe+1
      weighta( 44, 56,  3)=                 -0.14100810359770402092d0
      iwe=iwe+1
      weighta( 45, 56,  3)=                  0.08344294347496951370d0
      iwe=iwe+1
      weighta( 46, 56,  3)=                 -0.22269238822818052115d0
      iwe=iwe+1
      weighta( 47, 56,  3)=                  0.25830065388302975160d0
      iwe=iwe+1
      weighta( 48, 56,  3)=                  0.06217971801377864677d0
      iwe=iwe+1
      weighta( 49, 56,  3)=                  0.15601025800268256138d0
      iwe=iwe+1
      weighta( 50, 56,  3)=                  0.25226196177683540833d0
      iwe=iwe+1
      biasa( 56,  3)=                  0.59633295743916425735d0
      iwe=iwe+1
      weighta(  1, 57,  3)=                 -0.24425621685623830071d0
      iwe=iwe+1
      weighta(  2, 57,  3)=                 -0.04197657223717592145d0
      iwe=iwe+1
      weighta(  3, 57,  3)=                 -0.30677038869186334935d0
      iwe=iwe+1
      weighta(  4, 57,  3)=                 -0.23590749770396832186d0
      iwe=iwe+1
      weighta(  5, 57,  3)=                  0.00849201738978822354d0
      iwe=iwe+1
      weighta(  6, 57,  3)=                 -0.20255465883706508246d0
      iwe=iwe+1
      weighta(  7, 57,  3)=                  0.17124361749913918906d0
      iwe=iwe+1
      weighta(  8, 57,  3)=                 -0.32355627363710898203d0
      iwe=iwe+1
      weighta(  9, 57,  3)=                  0.01484680617564781285d0
      iwe=iwe+1
      weighta( 10, 57,  3)=                 -0.54944641422114326446d0
      iwe=iwe+1
      weighta( 11, 57,  3)=                  0.61489517152007311385d0
      iwe=iwe+1
      weighta( 12, 57,  3)=                 -0.35625676126618105455d0
      iwe=iwe+1
      weighta( 13, 57,  3)=                  0.25925581345015646928d0
      iwe=iwe+1
      weighta( 14, 57,  3)=                  0.45792442857481635565d0
      iwe=iwe+1
      weighta( 15, 57,  3)=                 -0.06524228465331469162d0
      iwe=iwe+1
      weighta( 16, 57,  3)=                  0.93637776360086100169d0
      iwe=iwe+1
      weighta( 17, 57,  3)=                 -0.04345127328281528367d0
      iwe=iwe+1
      weighta( 18, 57,  3)=                 -0.61651501154444809938d0
      iwe=iwe+1
      weighta( 19, 57,  3)=                 -0.36755827971156368461d0
      iwe=iwe+1
      weighta( 20, 57,  3)=                 -0.54767435256111574038d0
      iwe=iwe+1
      weighta( 21, 57,  3)=                  0.14016116596301245179d0
      iwe=iwe+1
      weighta( 22, 57,  3)=                  0.11596242838870254865d0
      iwe=iwe+1
      weighta( 23, 57,  3)=                 -0.11649069008897705579d0
      iwe=iwe+1
      weighta( 24, 57,  3)=                  0.04487348302692623775d0
      iwe=iwe+1
      weighta( 25, 57,  3)=                  0.10506171116543558397d0
      iwe=iwe+1
      weighta( 26, 57,  3)=                  0.40659720391205983470d0
      iwe=iwe+1
      weighta( 27, 57,  3)=                  0.16527335186519695465d0
      iwe=iwe+1
      weighta( 28, 57,  3)=                  0.29727412796512797666d0
      iwe=iwe+1
      weighta( 29, 57,  3)=                  0.24540961702608529715d0
      iwe=iwe+1
      weighta( 30, 57,  3)=                 -0.13164772728971521620d0
      iwe=iwe+1
      weighta( 31, 57,  3)=                  0.13849539582225106615d0
      iwe=iwe+1
      weighta( 32, 57,  3)=                  0.43710303936500360944d0
      iwe=iwe+1
      weighta( 33, 57,  3)=                  0.06811437536978158513d0
      iwe=iwe+1
      weighta( 34, 57,  3)=                  0.22963761778668581592d0
      iwe=iwe+1
      weighta( 35, 57,  3)=                  0.41508085962088597798d0
      iwe=iwe+1
      weighta( 36, 57,  3)=                  0.52390860057799049088d0
      iwe=iwe+1
      weighta( 37, 57,  3)=                  0.07479748543986086684d0
      iwe=iwe+1
      weighta( 38, 57,  3)=                  0.10214783042963945792d0
      iwe=iwe+1
      weighta( 39, 57,  3)=                  0.47613555852337047236d0
      iwe=iwe+1
      weighta( 40, 57,  3)=                  0.04302290860582343168d0
      iwe=iwe+1
      weighta( 41, 57,  3)=                 -0.18547955795501530618d0
      iwe=iwe+1
      weighta( 42, 57,  3)=                 -0.13285444294502934959d0
      iwe=iwe+1
      weighta( 43, 57,  3)=                  0.00407227684604748869d0
      iwe=iwe+1
      weighta( 44, 57,  3)=                 -0.21856402564361065988d0
      iwe=iwe+1
      weighta( 45, 57,  3)=                 -0.61959294069526493764d0
      iwe=iwe+1
      weighta( 46, 57,  3)=                  0.03047007091161111139d0
      iwe=iwe+1
      weighta( 47, 57,  3)=                 -0.02609692574575755292d0
      iwe=iwe+1
      weighta( 48, 57,  3)=                  0.07380316188529065236d0
      iwe=iwe+1
      weighta( 49, 57,  3)=                 -0.40403865982483205821d0
      iwe=iwe+1
      weighta( 50, 57,  3)=                 -0.25213196635588541739d0
      iwe=iwe+1
      biasa( 57,  3)=                 -0.60169966825440002189d0
      iwe=iwe+1
      weighta(  1, 58,  3)=                 -0.37891326307767736470d0
      iwe=iwe+1
      weighta(  2, 58,  3)=                  0.39333959654734018674d0
      iwe=iwe+1
      weighta(  3, 58,  3)=                 -0.20786606908153168471d0
      iwe=iwe+1
      weighta(  4, 58,  3)=                  0.00106443466114608250d0
      iwe=iwe+1
      weighta(  5, 58,  3)=                 -0.44183337067905437134d0
      iwe=iwe+1
      weighta(  6, 58,  3)=                 -0.45391999609160288420d0
      iwe=iwe+1
      weighta(  7, 58,  3)=                  0.42413724532228724851d0
      iwe=iwe+1
      weighta(  8, 58,  3)=                  0.26956069369924617884d0
      iwe=iwe+1
      weighta(  9, 58,  3)=                 -0.27198470760269705115d0
      iwe=iwe+1
      weighta( 10, 58,  3)=                 -0.03786675774028429309d0
      iwe=iwe+1
      weighta( 11, 58,  3)=                 -0.16743856463158787728d0
      iwe=iwe+1
      weighta( 12, 58,  3)=                  0.41648498972956787822d0
      iwe=iwe+1
      weighta( 13, 58,  3)=                  0.00766817167957363835d0
      iwe=iwe+1
      weighta( 14, 58,  3)=                 -0.06509943595995938692d0
      iwe=iwe+1
      weighta( 15, 58,  3)=                 -0.10774957893349434990d0
      iwe=iwe+1
      weighta( 16, 58,  3)=                  0.35077112244273656039d0
      iwe=iwe+1
      weighta( 17, 58,  3)=                 -0.06240145929535430985d0
      iwe=iwe+1
      weighta( 18, 58,  3)=                  0.30982084312955016081d0
      iwe=iwe+1
      weighta( 19, 58,  3)=                 -0.18741793470268822142d0
      iwe=iwe+1
      weighta( 20, 58,  3)=                 -0.33869974368477068216d0
      iwe=iwe+1
      weighta( 21, 58,  3)=                  0.17107331763360025811d0
      iwe=iwe+1
      weighta( 22, 58,  3)=                 -0.34150561950114716181d0
      iwe=iwe+1
      weighta( 23, 58,  3)=                 -0.49962818893903121475d0
      iwe=iwe+1
      weighta( 24, 58,  3)=                 -0.07630662626092563072d0
      iwe=iwe+1
      weighta( 25, 58,  3)=                 -0.19500806549463417516d0
      iwe=iwe+1
      weighta( 26, 58,  3)=                  0.29290698300364420570d0
      iwe=iwe+1
      weighta( 27, 58,  3)=                  0.28116950519483630000d0
      iwe=iwe+1
      weighta( 28, 58,  3)=                  0.24871267268583616139d0
      iwe=iwe+1
      weighta( 29, 58,  3)=                  0.60792720794133547901d0
      iwe=iwe+1
      weighta( 30, 58,  3)=                  0.11852451691985366189d0
      iwe=iwe+1
      weighta( 31, 58,  3)=                  0.29188292352644096272d0
      iwe=iwe+1
      weighta( 32, 58,  3)=                  0.09413635190850773438d0
      iwe=iwe+1
      weighta( 33, 58,  3)=                  0.18631117733308874551d0
      iwe=iwe+1
      weighta( 34, 58,  3)=                 -0.28148426912799490163d0
      iwe=iwe+1
      weighta( 35, 58,  3)=                  0.32155709615309924221d0
      iwe=iwe+1
      weighta( 36, 58,  3)=                  0.06367840958621769076d0
      iwe=iwe+1
      weighta( 37, 58,  3)=                  0.08136103544602700521d0
      iwe=iwe+1
      weighta( 38, 58,  3)=                  0.50307271415191157082d0
      iwe=iwe+1
      weighta( 39, 58,  3)=                 -0.46633655798392992242d0
      iwe=iwe+1
      weighta( 40, 58,  3)=                 -0.24337284213058180127d0
      iwe=iwe+1
      weighta( 41, 58,  3)=                 -0.33302825755869752689d0
      iwe=iwe+1
      weighta( 42, 58,  3)=                 -0.32170932283993725065d0
      iwe=iwe+1
      weighta( 43, 58,  3)=                 -0.40521372597445987074d0
      iwe=iwe+1
      weighta( 44, 58,  3)=                 -0.13856004101125704575d0
      iwe=iwe+1
      weighta( 45, 58,  3)=                  0.13500372639648483553d0
      iwe=iwe+1
      weighta( 46, 58,  3)=                 -0.14770625693818656421d0
      iwe=iwe+1
      weighta( 47, 58,  3)=                 -0.12314456495465546382d0
      iwe=iwe+1
      weighta( 48, 58,  3)=                 -0.15824421549587341929d0
      iwe=iwe+1
      weighta( 49, 58,  3)=                  0.11308913957624842916d0
      iwe=iwe+1
      weighta( 50, 58,  3)=                 -0.14308869377684582669d0
      iwe=iwe+1
      biasa( 58,  3)=                 -0.74628217291779952447d0
      iwe=iwe+1
      weighta(  1, 59,  3)=                  0.16723697308189208743d0
      iwe=iwe+1
      weighta(  2, 59,  3)=                  0.23113127804047287062d0
      iwe=iwe+1
      weighta(  3, 59,  3)=                 -0.18678874016604810060d0
      iwe=iwe+1
      weighta(  4, 59,  3)=                  0.26549108399624382626d0
      iwe=iwe+1
      weighta(  5, 59,  3)=                  0.04777078699491370956d0
      iwe=iwe+1
      weighta(  6, 59,  3)=                  0.04391050515183038405d0
      iwe=iwe+1
      weighta(  7, 59,  3)=                  0.28619712799650876001d0
      iwe=iwe+1
      weighta(  8, 59,  3)=                  0.04352963407248024164d0
      iwe=iwe+1
      weighta(  9, 59,  3)=                 -0.28171262387576806452d0
      iwe=iwe+1
      weighta( 10, 59,  3)=                 -0.40724828371741444988d0
      iwe=iwe+1
      weighta( 11, 59,  3)=                 -0.47089413301374555276d0
      iwe=iwe+1
      weighta( 12, 59,  3)=                 -0.44103639223294993643d0
      iwe=iwe+1
      weighta( 13, 59,  3)=                  0.47320867300407010170d0
      iwe=iwe+1
      weighta( 14, 59,  3)=                 -0.05032010889985422120d0
      iwe=iwe+1
      weighta( 15, 59,  3)=                  0.03879533079547498736d0
      iwe=iwe+1
      weighta( 16, 59,  3)=                  0.39650498728270044957d0
      iwe=iwe+1
      weighta( 17, 59,  3)=                  0.17932477174851255142d0
      iwe=iwe+1
      weighta( 18, 59,  3)=                  0.25310692434459125533d0
      iwe=iwe+1
      weighta( 19, 59,  3)=                 -0.38521687624773331970d0
      iwe=iwe+1
      weighta( 20, 59,  3)=                  0.36952959041995725453d0
      iwe=iwe+1
      weighta( 21, 59,  3)=                 -0.27832817125144204695d0
      iwe=iwe+1
      weighta( 22, 59,  3)=                 -0.02714090238946748751d0
      iwe=iwe+1
      weighta( 23, 59,  3)=                 -0.14235750451028608699d0
      iwe=iwe+1
      weighta( 24, 59,  3)=                 -0.27158477211739040502d0
      iwe=iwe+1
      weighta( 25, 59,  3)=                 -0.24231852142838383735d0
      iwe=iwe+1
      weighta( 26, 59,  3)=                  0.07057080069781505871d0
      iwe=iwe+1
      weighta( 27, 59,  3)=                 -0.11882231225500584915d0
      iwe=iwe+1
      weighta( 28, 59,  3)=                  0.29230816732488446030d0
      iwe=iwe+1
      weighta( 29, 59,  3)=                 -0.11583414735540634166d0
      iwe=iwe+1
      weighta( 30, 59,  3)=                 -0.20350223210563120335d0
      iwe=iwe+1
      weighta( 31, 59,  3)=                 -0.08520328361182885613d0
      iwe=iwe+1
      weighta( 32, 59,  3)=                  0.77400541320482962870d0
      iwe=iwe+1
      weighta( 33, 59,  3)=                  0.28712960195088488291d0
      iwe=iwe+1
      weighta( 34, 59,  3)=                  0.19784852040536674012d0
      iwe=iwe+1
      weighta( 35, 59,  3)=                 -0.19114381323361695486d0
      iwe=iwe+1
      weighta( 36, 59,  3)=                 -0.19531331673305962759d0
      iwe=iwe+1
      weighta( 37, 59,  3)=                 -0.20421083808315221297d0
      iwe=iwe+1
      weighta( 38, 59,  3)=                 -0.41677987217258560815d0
      iwe=iwe+1
      weighta( 39, 59,  3)=                  0.09965544426895255048d0
      iwe=iwe+1
      weighta( 40, 59,  3)=                 -0.17210221798452102204d0
      iwe=iwe+1
      weighta( 41, 59,  3)=                  0.26682387561526971220d0
      iwe=iwe+1
      weighta( 42, 59,  3)=                  0.24737140087453945991d0
      iwe=iwe+1
      weighta( 43, 59,  3)=                 -0.43711867926727582256d0
      iwe=iwe+1
      weighta( 44, 59,  3)=                  0.14994798089063063329d0
      iwe=iwe+1
      weighta( 45, 59,  3)=                 -0.26381706925829861987d0
      iwe=iwe+1
      weighta( 46, 59,  3)=                  0.07617897969547685055d0
      iwe=iwe+1
      weighta( 47, 59,  3)=                  0.19525544245096260187d0
      iwe=iwe+1
      weighta( 48, 59,  3)=                  0.14174280111265938342d0
      iwe=iwe+1
      weighta( 49, 59,  3)=                  0.11706342283978612984d0
      iwe=iwe+1
      weighta( 50, 59,  3)=                 -0.03060077453987613064d0
      iwe=iwe+1
      biasa( 59,  3)=                  0.75462767650472883929d0
      iwe=iwe+1
      weighta(  1, 60,  3)=                 -0.04454443773381018545d0
      iwe=iwe+1
      weighta(  2, 60,  3)=                  0.02032589186853244953d0
      iwe=iwe+1
      weighta(  3, 60,  3)=                  0.26351840531431908188d0
      iwe=iwe+1
      weighta(  4, 60,  3)=                 -0.20381429174162185580d0
      iwe=iwe+1
      weighta(  5, 60,  3)=                  0.07036438759801431908d0
      iwe=iwe+1
      weighta(  6, 60,  3)=                  0.23349782067803501184d0
      iwe=iwe+1
      weighta(  7, 60,  3)=                 -0.15210536174417041422d0
      iwe=iwe+1
      weighta(  8, 60,  3)=                  0.28909570456717004205d0
      iwe=iwe+1
      weighta(  9, 60,  3)=                 -0.24611109631069313930d0
      iwe=iwe+1
      weighta( 10, 60,  3)=                  0.13289175476386086427d0
      iwe=iwe+1
      weighta( 11, 60,  3)=                 -0.46161097384465932247d0
      iwe=iwe+1
      weighta( 12, 60,  3)=                  0.14152788307639790899d0
      iwe=iwe+1
      weighta( 13, 60,  3)=                  0.10645265237764793553d0
      iwe=iwe+1
      weighta( 14, 60,  3)=                 -0.56416403664154046727d0
      iwe=iwe+1
      weighta( 15, 60,  3)=                  0.03460488285084473842d0
      iwe=iwe+1
      weighta( 16, 60,  3)=                 -0.27457758587006220186d0
      iwe=iwe+1
      weighta( 17, 60,  3)=                 -0.28017956580481517825d0
      iwe=iwe+1
      weighta( 18, 60,  3)=                 -0.10074622594731522107d0
      iwe=iwe+1
      weighta( 19, 60,  3)=                 -0.03682278610793653789d0
      iwe=iwe+1
      weighta( 20, 60,  3)=                  0.40296965676539897583d0
      iwe=iwe+1
      weighta( 21, 60,  3)=                 -0.22967014159395290895d0
      iwe=iwe+1
      weighta( 22, 60,  3)=                  0.37144882014984709206d0
      iwe=iwe+1
      weighta( 23, 60,  3)=                  0.42529168431273745021d0
      iwe=iwe+1
      weighta( 24, 60,  3)=                  0.59201042342749088387d0
      iwe=iwe+1
      weighta( 25, 60,  3)=                 -0.06843412241867755097d0
      iwe=iwe+1
      weighta( 26, 60,  3)=                  0.34183056764594271781d0
      iwe=iwe+1
      weighta( 27, 60,  3)=                  0.38279892995733733052d0
      iwe=iwe+1
      weighta( 28, 60,  3)=                 -0.73622564312673810516d0
      iwe=iwe+1
      weighta( 29, 60,  3)=                 -0.26465665648492980866d0
      iwe=iwe+1
      weighta( 30, 60,  3)=                  0.39025138306194284699d0
      iwe=iwe+1
      weighta( 31, 60,  3)=                 -0.18299942660310419829d0
      iwe=iwe+1
      weighta( 32, 60,  3)=                 -0.04520752377825347501d0
      iwe=iwe+1
      weighta( 33, 60,  3)=                  0.06220029563565108305d0
      iwe=iwe+1
      weighta( 34, 60,  3)=                 -0.04336129292393346019d0
      iwe=iwe+1
      weighta( 35, 60,  3)=                  0.06423917937189424499d0
      iwe=iwe+1
      weighta( 36, 60,  3)=                  0.36508410598216112231d0
      iwe=iwe+1
      weighta( 37, 60,  3)=                  0.29316909021403347868d0
      iwe=iwe+1
      weighta( 38, 60,  3)=                 -0.35022753441531406793d0
      iwe=iwe+1
      weighta( 39, 60,  3)=                  0.19885113041757265795d0
      iwe=iwe+1
      weighta( 40, 60,  3)=                  0.16729068967226579101d0
      iwe=iwe+1
      weighta( 41, 60,  3)=                 -0.36434250670299245245d0
      iwe=iwe+1
      weighta( 42, 60,  3)=                  0.52030807777101184541d0
      iwe=iwe+1
      weighta( 43, 60,  3)=                 -0.27342423615384425784d0
      iwe=iwe+1
      weighta( 44, 60,  3)=                 -0.20280170171569755766d0
      iwe=iwe+1
      weighta( 45, 60,  3)=                  0.27611615780805687237d0
      iwe=iwe+1
      weighta( 46, 60,  3)=                 -0.17502285837106451583d0
      iwe=iwe+1
      weighta( 47, 60,  3)=                 -0.04114510268710405705d0
      iwe=iwe+1
      weighta( 48, 60,  3)=                  0.08602617364767969899d0
      iwe=iwe+1
      weighta( 49, 60,  3)=                 -0.01582913526656935452d0
      iwe=iwe+1
      weighta( 50, 60,  3)=                 -0.15043069983917253807d0
      iwe=iwe+1
      biasa( 60,  3)=                 -0.62891304470504516555d0
      iwe=iwe+1
      weighta(  1, 61,  3)=                 -0.05565606159744927728d0
      iwe=iwe+1
      weighta(  2, 61,  3)=                 -0.02378970729403373854d0
      iwe=iwe+1
      weighta(  3, 61,  3)=                 -0.10101912038291355200d0
      iwe=iwe+1
      weighta(  4, 61,  3)=                 -0.10671359583727640929d0
      iwe=iwe+1
      weighta(  5, 61,  3)=                 -0.17822334416025434334d0
      iwe=iwe+1
      weighta(  6, 61,  3)=                 -0.08561258311433367352d0
      iwe=iwe+1
      weighta(  7, 61,  3)=                  0.13663749740551647816d0
      iwe=iwe+1
      weighta(  8, 61,  3)=                 -0.20914540554446037213d0
      iwe=iwe+1
      weighta(  9, 61,  3)=                  0.13835344062475485316d0
      iwe=iwe+1
      weighta( 10, 61,  3)=                  0.46604031214342422906d0
      iwe=iwe+1
      weighta( 11, 61,  3)=                  0.50175399204614790083d0
      iwe=iwe+1
      weighta( 12, 61,  3)=                  0.30070559246467376546d0
      iwe=iwe+1
      weighta( 13, 61,  3)=                 -0.60347503090474963194d0
      iwe=iwe+1
      weighta( 14, 61,  3)=                 -0.04748600007052017347d0
      iwe=iwe+1
      weighta( 15, 61,  3)=                 -0.08886467489450716739d0
      iwe=iwe+1
      weighta( 16, 61,  3)=                 -0.55074175121001500699d0
      iwe=iwe+1
      weighta( 17, 61,  3)=                  0.31379715458724821708d0
      iwe=iwe+1
      weighta( 18, 61,  3)=                 -0.06555142987227118023d0
      iwe=iwe+1
      weighta( 19, 61,  3)=                  0.01188985390905472790d0
      iwe=iwe+1
      weighta( 20, 61,  3)=                 -0.14405528250482069197d0
      iwe=iwe+1
      weighta( 21, 61,  3)=                  0.32876636960418587075d0
      iwe=iwe+1
      weighta( 22, 61,  3)=                 -0.63667414671670552462d0
      iwe=iwe+1
      weighta( 23, 61,  3)=                  0.15710234493554289803d0
      iwe=iwe+1
      weighta( 24, 61,  3)=                 -0.13306467710192443343d0
      iwe=iwe+1
      weighta( 25, 61,  3)=                  0.51795687452862060329d0
      iwe=iwe+1
      weighta( 26, 61,  3)=                 -0.16793157479844186830d0
      iwe=iwe+1
      weighta( 27, 61,  3)=                 -0.49514432086996784665d0
      iwe=iwe+1
      weighta( 28, 61,  3)=                  0.04074796906412763570d0
      iwe=iwe+1
      weighta( 29, 61,  3)=                  0.02693901957475564740d0
      iwe=iwe+1
      weighta( 30, 61,  3)=                  0.14125231206046037769d0
      iwe=iwe+1
      weighta( 31, 61,  3)=                 -0.06795453921875210801d0
      iwe=iwe+1
      weighta( 32, 61,  3)=                 -0.75911175796419938511d0
      iwe=iwe+1
      weighta( 33, 61,  3)=                  0.52395951935999141025d0
      iwe=iwe+1
      weighta( 34, 61,  3)=                 -0.55597876046105165759d0
      iwe=iwe+1
      weighta( 35, 61,  3)=                  0.41300833540001335997d0
      iwe=iwe+1
      weighta( 36, 61,  3)=                 -0.05084935670974034816d0
      iwe=iwe+1
      weighta( 37, 61,  3)=                 -0.50380848371430098087d0
      iwe=iwe+1
      weighta( 38, 61,  3)=                  0.42313893013634162887d0
      iwe=iwe+1
      weighta( 39, 61,  3)=                  0.39092884006489209137d0
      iwe=iwe+1
      weighta( 40, 61,  3)=                  0.47194370635272647752d0
      iwe=iwe+1
      weighta( 41, 61,  3)=                  0.21780051692269197794d0
      iwe=iwe+1
      weighta( 42, 61,  3)=                 -0.07526692021324452031d0
      iwe=iwe+1
      weighta( 43, 61,  3)=                  0.58194880615236643795d0
      iwe=iwe+1
      weighta( 44, 61,  3)=                  0.18340132444485637842d0
      iwe=iwe+1
      weighta( 45, 61,  3)=                  0.54808774410276916988d0
      iwe=iwe+1
      weighta( 46, 61,  3)=                 -0.31099297383202245681d0
      iwe=iwe+1
      weighta( 47, 61,  3)=                 -0.03075974999404100518d0
      iwe=iwe+1
      weighta( 48, 61,  3)=                 -0.25777608246081684662d0
      iwe=iwe+1
      weighta( 49, 61,  3)=                  0.00871136769492427375d0
      iwe=iwe+1
      weighta( 50, 61,  3)=                 -0.08449317902924198542d0
      iwe=iwe+1
      biasa( 61,  3)=                 -0.79579387322227346235d0
      iwe=iwe+1
      weighta(  1, 62,  3)=                  0.11599329585074345805d0
      iwe=iwe+1
      weighta(  2, 62,  3)=                  0.17884740458361378379d0
      iwe=iwe+1
      weighta(  3, 62,  3)=                  0.24603647373705950230d0
      iwe=iwe+1
      weighta(  4, 62,  3)=                  0.15805485243739489376d0
      iwe=iwe+1
      weighta(  5, 62,  3)=                 -0.23422225517465283806d0
      iwe=iwe+1
      weighta(  6, 62,  3)=                  0.33182829981864769842d0
      iwe=iwe+1
      weighta(  7, 62,  3)=                 -0.28448095416514129763d0
      iwe=iwe+1
      weighta(  8, 62,  3)=                  0.01304211521037604467d0
      iwe=iwe+1
      weighta(  9, 62,  3)=                  0.02849129250618031781d0
      iwe=iwe+1
      weighta( 10, 62,  3)=                 -0.15148124751328506665d0
      iwe=iwe+1
      weighta( 11, 62,  3)=                 -0.32421037929242446651d0
      iwe=iwe+1
      weighta( 12, 62,  3)=                 -0.17508960894141481490d0
      iwe=iwe+1
      weighta( 13, 62,  3)=                 -0.18973341928885553709d0
      iwe=iwe+1
      weighta( 14, 62,  3)=                  0.31523788853005879629d0
      iwe=iwe+1
      weighta( 15, 62,  3)=                 -0.16310805178878437505d0
      iwe=iwe+1
      weighta( 16, 62,  3)=                 -0.03311982662479497075d0
      iwe=iwe+1
      weighta( 17, 62,  3)=                 -0.05008138595402575333d0
      iwe=iwe+1
      weighta( 18, 62,  3)=                 -0.11499544163239204531d0
      iwe=iwe+1
      weighta( 19, 62,  3)=                 -0.08665287954720125863d0
      iwe=iwe+1
      weighta( 20, 62,  3)=                  0.24793037939564990801d0
      iwe=iwe+1
      weighta( 21, 62,  3)=                 -0.07919158852728698517d0
      iwe=iwe+1
      weighta( 22, 62,  3)=                  0.04296836385618878901d0
      iwe=iwe+1
      weighta( 23, 62,  3)=                 -0.04673347635053779620d0
      iwe=iwe+1
      weighta( 24, 62,  3)=                 -0.13728172882811934263d0
      iwe=iwe+1
      weighta( 25, 62,  3)=                 -0.10663935837457651223d0
      iwe=iwe+1
      weighta( 26, 62,  3)=                 -0.39417602398776457884d0
      iwe=iwe+1
      weighta( 27, 62,  3)=                 -0.02002370585671506623d0
      iwe=iwe+1
      weighta( 28, 62,  3)=                 -0.05535488589054231301d0
      iwe=iwe+1
      weighta( 29, 62,  3)=                 -0.31576519037232259057d0
      iwe=iwe+1
      weighta( 30, 62,  3)=                 -0.23471517787225235074d0
      iwe=iwe+1
      weighta( 31, 62,  3)=                 -0.31534819777802752805d0
      iwe=iwe+1
      weighta( 32, 62,  3)=                  0.14070506549830755216d0
      iwe=iwe+1
      weighta( 33, 62,  3)=                 -0.34170505943343698618d0
      iwe=iwe+1
      weighta( 34, 62,  3)=                 -0.21057044770532229450d0
      iwe=iwe+1
      weighta( 35, 62,  3)=                  0.41586281950344494707d0
      iwe=iwe+1
      weighta( 36, 62,  3)=                 -0.35271581714281996511d0
      iwe=iwe+1
      weighta( 37, 62,  3)=                 -0.06328552803820146344d0
      iwe=iwe+1
      weighta( 38, 62,  3)=                 -0.33752021361976441982d0
      iwe=iwe+1
      weighta( 39, 62,  3)=                  0.30606331829594268790d0
      iwe=iwe+1
      weighta( 40, 62,  3)=                  0.20287474445719666516d0
      iwe=iwe+1
      weighta( 41, 62,  3)=                 -0.18474129207344505699d0
      iwe=iwe+1
      weighta( 42, 62,  3)=                 -0.01168384753252553650d0
      iwe=iwe+1
      weighta( 43, 62,  3)=                  0.11734241820405660883d0
      iwe=iwe+1
      weighta( 44, 62,  3)=                  0.16013965052157597135d0
      iwe=iwe+1
      weighta( 45, 62,  3)=                  0.19537260930053079733d0
      iwe=iwe+1
      weighta( 46, 62,  3)=                 -0.21118864547525470488d0
      iwe=iwe+1
      weighta( 47, 62,  3)=                  0.17456754677995983682d0
      iwe=iwe+1
      weighta( 48, 62,  3)=                 -0.33731856877651378301d0
      iwe=iwe+1
      weighta( 49, 62,  3)=                 -0.17053362900843507810d0
      iwe=iwe+1
      weighta( 50, 62,  3)=                 -0.22303877070844146946d0
      iwe=iwe+1
      biasa( 62,  3)=                  0.80897622264868385145d0
      iwe=iwe+1
      weighta(  1, 63,  3)=                 -0.38009092791911125442d0
      iwe=iwe+1
      weighta(  2, 63,  3)=                 -0.06554977427239355725d0
      iwe=iwe+1
      weighta(  3, 63,  3)=                  0.40169682846117371611d0
      iwe=iwe+1
      weighta(  4, 63,  3)=                  0.15382745578551559884d0
      iwe=iwe+1
      weighta(  5, 63,  3)=                  0.63149234454767677605d0
      iwe=iwe+1
      weighta(  6, 63,  3)=                  0.41550943326903155839d0
      iwe=iwe+1
      weighta(  7, 63,  3)=                  0.43014312294452167196d0
      iwe=iwe+1
      weighta(  8, 63,  3)=                 -0.16440456422543550663d0
      iwe=iwe+1
      weighta(  9, 63,  3)=                  0.24135937623927211648d0
      iwe=iwe+1
      weighta( 10, 63,  3)=                 -0.01648099724591813378d0
      iwe=iwe+1
      weighta( 11, 63,  3)=                  0.26960490620123889194d0
      iwe=iwe+1
      weighta( 12, 63,  3)=                  0.11275826102591483824d0
      iwe=iwe+1
      weighta( 13, 63,  3)=                  0.07788158683129717264d0
      iwe=iwe+1
      weighta( 14, 63,  3)=                 -0.03896159553452550189d0
      iwe=iwe+1
      weighta( 15, 63,  3)=                  0.15257928386007202359d0
      iwe=iwe+1
      weighta( 16, 63,  3)=                 -0.07486127628815249235d0
      iwe=iwe+1
      weighta( 17, 63,  3)=                  0.04122718819203920887d0
      iwe=iwe+1
      weighta( 18, 63,  3)=                 -0.32258279011571339145d0
      iwe=iwe+1
      weighta( 19, 63,  3)=                 -0.06997730547188243944d0
      iwe=iwe+1
      weighta( 20, 63,  3)=                  0.15435495594373299655d0
      iwe=iwe+1
      weighta( 21, 63,  3)=                 -0.34872516317619112192d0
      iwe=iwe+1
      weighta( 22, 63,  3)=                  0.14226900806540720978d0
      iwe=iwe+1
      weighta( 23, 63,  3)=                 -0.12614392550992392650d0
      iwe=iwe+1
      weighta( 24, 63,  3)=                  0.21944352963238855647d0
      iwe=iwe+1
      weighta( 25, 63,  3)=                 -0.15019191260715464287d0
      iwe=iwe+1
      weighta( 26, 63,  3)=                 -0.29768718144651895585d0
      iwe=iwe+1
      weighta( 27, 63,  3)=                 -0.03766094839294312907d0
      iwe=iwe+1
      weighta( 28, 63,  3)=                 -0.00759103691085494508d0
      iwe=iwe+1
      weighta( 29, 63,  3)=                  0.27351150507277244284d0
      iwe=iwe+1
      weighta( 30, 63,  3)=                 -0.25460702721980887908d0
      iwe=iwe+1
      weighta( 31, 63,  3)=                 -0.23777629512335879403d0
      iwe=iwe+1
      weighta( 32, 63,  3)=                  0.10867535287446510039d0
      iwe=iwe+1
      weighta( 33, 63,  3)=                  0.00412192491377415433d0
      iwe=iwe+1
      weighta( 34, 63,  3)=                  0.39607924006404315875d0
      iwe=iwe+1
      weighta( 35, 63,  3)=                  0.49083121418888431275d0
      iwe=iwe+1
      weighta( 36, 63,  3)=                  0.34999036860063015286d0
      iwe=iwe+1
      weighta( 37, 63,  3)=                 -0.09181849798642541249d0
      iwe=iwe+1
      weighta( 38, 63,  3)=                  0.13994442568383552716d0
      iwe=iwe+1
      weighta( 39, 63,  3)=                  0.35815695978616246542d0
      iwe=iwe+1
      weighta( 40, 63,  3)=                  0.08627200690113784320d0
      iwe=iwe+1
      weighta( 41, 63,  3)=                  0.04261742627351221280d0
      iwe=iwe+1
      weighta( 42, 63,  3)=                  0.02220326279006813730d0
      iwe=iwe+1
      weighta( 43, 63,  3)=                  0.13231260007634099152d0
      iwe=iwe+1
      weighta( 44, 63,  3)=                 -0.41507181729883962928d0
      iwe=iwe+1
      weighta( 45, 63,  3)=                 -0.46718381377774070851d0
      iwe=iwe+1
      weighta( 46, 63,  3)=                  0.44792411780579288738d0
      iwe=iwe+1
      weighta( 47, 63,  3)=                 -0.10908440562116941686d0
      iwe=iwe+1
      weighta( 48, 63,  3)=                 -0.28480801783109771508d0
      iwe=iwe+1
      weighta( 49, 63,  3)=                  0.19812132653969630192d0
      iwe=iwe+1
      weighta( 50, 63,  3)=                  0.08083185398576193947d0
      iwe=iwe+1
      biasa( 63,  3)=                 -0.95716850680339360391d0
      iwe=iwe+1
      weighta(  1, 64,  3)=                  0.04684151600655596381d0
      iwe=iwe+1
      weighta(  2, 64,  3)=                  0.13441211272670910981d0
      iwe=iwe+1
      weighta(  3, 64,  3)=                 -0.41187360930877436882d0
      iwe=iwe+1
      weighta(  4, 64,  3)=                  0.31789132166434480586d0
      iwe=iwe+1
      weighta(  5, 64,  3)=                 -0.10033916349216460973d0
      iwe=iwe+1
      weighta(  6, 64,  3)=                 -0.05621651287635669181d0
      iwe=iwe+1
      weighta(  7, 64,  3)=                 -0.25142553954488222612d0
      iwe=iwe+1
      weighta(  8, 64,  3)=                  0.22059235508015792582d0
      iwe=iwe+1
      weighta(  9, 64,  3)=                  0.09892410518722330459d0
      iwe=iwe+1
      weighta( 10, 64,  3)=                  0.12195565065753090350d0
      iwe=iwe+1
      weighta( 11, 64,  3)=                  0.29770487744463008939d0
      iwe=iwe+1
      weighta( 12, 64,  3)=                  0.12936315652941710042d0
      iwe=iwe+1
      weighta( 13, 64,  3)=                 -0.30388768481512806741d0
      iwe=iwe+1
      weighta( 14, 64,  3)=                 -0.41957868949901461209d0
      iwe=iwe+1
      weighta( 15, 64,  3)=                 -0.06279337893691927519d0
      iwe=iwe+1
      weighta( 16, 64,  3)=                 -0.40627767478298171255d0
      iwe=iwe+1
      weighta( 17, 64,  3)=                 -0.27957720025236765249d0
      iwe=iwe+1
      weighta( 18, 64,  3)=                 -0.23756809933640168908d0
      iwe=iwe+1
      weighta( 19, 64,  3)=                  0.24796940579127552118d0
      iwe=iwe+1
      weighta( 20, 64,  3)=                  0.27973282562824142161d0
      iwe=iwe+1
      weighta( 21, 64,  3)=                  0.17129171376716623154d0
      iwe=iwe+1
      weighta( 22, 64,  3)=                 -0.21132779376127427962d0
      iwe=iwe+1
      weighta( 23, 64,  3)=                  0.41001788310317344166d0
      iwe=iwe+1
      weighta( 24, 64,  3)=                  0.21496876678607243494d0
      iwe=iwe+1
      weighta( 25, 64,  3)=                  0.07747265231732876345d0
      iwe=iwe+1
      weighta( 26, 64,  3)=                 -0.29433006133087369349d0
      iwe=iwe+1
      weighta( 27, 64,  3)=                 -0.40476493534538887653d0
      iwe=iwe+1
      weighta( 28, 64,  3)=                  0.06804433695630342227d0
      iwe=iwe+1
      weighta( 29, 64,  3)=                  0.25653462079163957821d0
      iwe=iwe+1
      weighta( 30, 64,  3)=                 -0.08276539175061772835d0
      iwe=iwe+1
      weighta( 31, 64,  3)=                  0.26428574441963526009d0
      iwe=iwe+1
      weighta( 32, 64,  3)=                 -0.24384746424887768224d0
      iwe=iwe+1
      weighta( 33, 64,  3)=                  0.09410341397864455115d0
      iwe=iwe+1
      weighta( 34, 64,  3)=                 -0.30744987455715117042d0
      iwe=iwe+1
      weighta( 35, 64,  3)=                  0.24512418368558774873d0
      iwe=iwe+1
      weighta( 36, 64,  3)=                 -0.37801275001894829586d0
      iwe=iwe+1
      weighta( 37, 64,  3)=                  0.16452867248143293599d0
      iwe=iwe+1
      weighta( 38, 64,  3)=                 -0.26967165634033585242d0
      iwe=iwe+1
      weighta( 39, 64,  3)=                  0.09992787654983174839d0
      iwe=iwe+1
      weighta( 40, 64,  3)=                  0.22295551203767996484d0
      iwe=iwe+1
      weighta( 41, 64,  3)=                  0.35707549789416109798d0
      iwe=iwe+1
      weighta( 42, 64,  3)=                 -0.08166636607916018253d0
      iwe=iwe+1
      weighta( 43, 64,  3)=                  0.39824967246348913497d0
      iwe=iwe+1
      weighta( 44, 64,  3)=                  0.12251524414226169779d0
      iwe=iwe+1
      weighta( 45, 64,  3)=                 -0.31394978120297623025d0
      iwe=iwe+1
      weighta( 46, 64,  3)=                  0.21985924271286860776d0
      iwe=iwe+1
      weighta( 47, 64,  3)=                 -0.92299514098344181967d0
      iwe=iwe+1
      weighta( 48, 64,  3)=                  0.26213867102936933007d0
      iwe=iwe+1
      weighta( 49, 64,  3)=                  0.10582691471060994004d0
      iwe=iwe+1
      weighta( 50, 64,  3)=                  0.25109335139968230743d0
      iwe=iwe+1
      biasa( 64,  3)=                  0.99840528090434432773d0
      iwe=iwe+1
      weighta(  1, 65,  3)=                 -0.05002075297062912734d0
      iwe=iwe+1
      weighta(  2, 65,  3)=                  0.16847984670214916081d0
      iwe=iwe+1
      weighta(  3, 65,  3)=                 -0.15061948154716212067d0
      iwe=iwe+1
      weighta(  4, 65,  3)=                 -0.23831614659276356694d0
      iwe=iwe+1
      weighta(  5, 65,  3)=                 -0.05115222165010924193d0
      iwe=iwe+1
      weighta(  6, 65,  3)=                  0.12316514643342263424d0
      iwe=iwe+1
      weighta(  7, 65,  3)=                  0.59473695748699439978d0
      iwe=iwe+1
      weighta(  8, 65,  3)=                 -0.06030555893500490899d0
      iwe=iwe+1
      weighta(  9, 65,  3)=                 -0.25469129368890447429d0
      iwe=iwe+1
      weighta( 10, 65,  3)=                  0.18025593240670290118d0
      iwe=iwe+1
      weighta( 11, 65,  3)=                  0.73907110731115943647d0
      iwe=iwe+1
      weighta( 12, 65,  3)=                  0.13518044444075680288d0
      iwe=iwe+1
      weighta( 13, 65,  3)=                 -0.41612612416268840443d0
      iwe=iwe+1
      weighta( 14, 65,  3)=                  0.11958438457871946314d0
      iwe=iwe+1
      weighta( 15, 65,  3)=                  0.22917265846235673754d0
      iwe=iwe+1
      weighta( 16, 65,  3)=                 -0.49669121645634434215d0
      iwe=iwe+1
      weighta( 17, 65,  3)=                 -0.02173096466640114452d0
      iwe=iwe+1
      weighta( 18, 65,  3)=                 -0.01240170556008597311d0
      iwe=iwe+1
      weighta( 19, 65,  3)=                  0.41465205067215782364d0
      iwe=iwe+1
      weighta( 20, 65,  3)=                  0.26839645053773869554d0
      iwe=iwe+1
      weighta( 21, 65,  3)=                  0.05302071136851260746d0
      iwe=iwe+1
      weighta( 22, 65,  3)=                  0.36288188053037767622d0
      iwe=iwe+1
      weighta( 23, 65,  3)=                 -0.00931406934179909891d0
      iwe=iwe+1
      weighta( 24, 65,  3)=                  0.29152829246898037674d0
      iwe=iwe+1
      weighta( 25, 65,  3)=                  0.13686326654514596735d0
      iwe=iwe+1
      weighta( 26, 65,  3)=                 -0.64142982103561818619d0
      iwe=iwe+1
      weighta( 27, 65,  3)=                  0.13253259011091855779d0
      iwe=iwe+1
      weighta( 28, 65,  3)=                 -0.09748694228838478137d0
      iwe=iwe+1
      weighta( 29, 65,  3)=                  0.28229247600341333957d0
      iwe=iwe+1
      weighta( 30, 65,  3)=                 -0.13621362740210174458d0
      iwe=iwe+1
      weighta( 31, 65,  3)=                  0.76261117234359820927d0
      iwe=iwe+1
      weighta( 32, 65,  3)=                 -0.08591773431092206148d0
      iwe=iwe+1
      weighta( 33, 65,  3)=                  0.24616638564094653341d0
      iwe=iwe+1
      weighta( 34, 65,  3)=                 -0.03074401654132153175d0
      iwe=iwe+1
      weighta( 35, 65,  3)=                  0.38035948838678368400d0
      iwe=iwe+1
      weighta( 36, 65,  3)=                 -0.15501810565868923142d0
      iwe=iwe+1
      weighta( 37, 65,  3)=                  0.35185059916964722682d0
      iwe=iwe+1
      weighta( 38, 65,  3)=                  0.11054860404917474237d0
      iwe=iwe+1
      weighta( 39, 65,  3)=                 -0.22903791827727726371d0
      iwe=iwe+1
      weighta( 40, 65,  3)=                  0.24708340350176946631d0
      iwe=iwe+1
      weighta( 41, 65,  3)=                  0.21199064614774892901d0
      iwe=iwe+1
      weighta( 42, 65,  3)=                  0.16452580999532545603d0
      iwe=iwe+1
      weighta( 43, 65,  3)=                  0.04907648881463119728d0
      iwe=iwe+1
      weighta( 44, 65,  3)=                  0.12005191848419133338d0
      iwe=iwe+1
      weighta( 45, 65,  3)=                 -0.32735451214991118096d0
      iwe=iwe+1
      weighta( 46, 65,  3)=                  0.16475656627648865848d0
      iwe=iwe+1
      weighta( 47, 65,  3)=                 -0.01939526989561132092d0
      iwe=iwe+1
      weighta( 48, 65,  3)=                 -0.06808391976758992881d0
      iwe=iwe+1
      weighta( 49, 65,  3)=                 -0.42436162344173616878d0
      iwe=iwe+1
      weighta( 50, 65,  3)=                 -0.16727550571749530417d0
      iwe=iwe+1
      biasa( 65,  3)=                  0.89295274812452818392d0
      iwe=iwe+1
      weighta(  1, 66,  3)=                 -0.42179000777942976530d0
      iwe=iwe+1
      weighta(  2, 66,  3)=                  0.11439470513304073052d0
      iwe=iwe+1
      weighta(  3, 66,  3)=                  0.11559891098763590278d0
      iwe=iwe+1
      weighta(  4, 66,  3)=                 -0.16912987577031349251d0
      iwe=iwe+1
      weighta(  5, 66,  3)=                  0.55398360318701900251d0
      iwe=iwe+1
      weighta(  6, 66,  3)=                  0.08076425826777219874d0
      iwe=iwe+1
      weighta(  7, 66,  3)=                  0.05516988578755796513d0
      iwe=iwe+1
      weighta(  8, 66,  3)=                 -0.33078199565974858443d0
      iwe=iwe+1
      weighta(  9, 66,  3)=                 -0.21830519270535819754d0
      iwe=iwe+1
      weighta( 10, 66,  3)=                 -0.24448366746115018922d0
      iwe=iwe+1
      weighta( 11, 66,  3)=                 -0.04554351001551371070d0
      iwe=iwe+1
      weighta( 12, 66,  3)=                 -0.16476153961236592038d0
      iwe=iwe+1
      weighta( 13, 66,  3)=                 -0.04764667311577230890d0
      iwe=iwe+1
      weighta( 14, 66,  3)=                  0.09528658307354269386d0
      iwe=iwe+1
      weighta( 15, 66,  3)=                  0.36854043719920620559d0
      iwe=iwe+1
      weighta( 16, 66,  3)=                 -0.51663996918668519953d0
      iwe=iwe+1
      weighta( 17, 66,  3)=                  0.27381891462895507905d0
      iwe=iwe+1
      weighta( 18, 66,  3)=                 -0.33676516396977873580d0
      iwe=iwe+1
      weighta( 19, 66,  3)=                  0.29153323390356405964d0
      iwe=iwe+1
      weighta( 20, 66,  3)=                 -0.10320891765556092223d0
      iwe=iwe+1
      weighta( 21, 66,  3)=                  0.12143588471636733439d0
      iwe=iwe+1
      weighta( 22, 66,  3)=                 -0.40787668899298684666d0
      iwe=iwe+1
      weighta( 23, 66,  3)=                  1.04722492323855087548d0
      iwe=iwe+1
      weighta( 24, 66,  3)=                  0.20817437920782461136d0
      iwe=iwe+1
      weighta( 25, 66,  3)=                 -0.31453536241309792976d0
      iwe=iwe+1
      weighta( 26, 66,  3)=                 -0.53444299298354269734d0
      iwe=iwe+1
      weighta( 27, 66,  3)=                  0.11129388572733962814d0
      iwe=iwe+1
      weighta( 28, 66,  3)=                  0.18169360309515358853d0
      iwe=iwe+1
      weighta( 29, 66,  3)=                  0.02300175254101387984d0
      iwe=iwe+1
      weighta( 30, 66,  3)=                 -0.15367906269260223073d0
      iwe=iwe+1
      weighta( 31, 66,  3)=                  0.07498777738431569584d0
      iwe=iwe+1
      weighta( 32, 66,  3)=                 -0.25686822225489269744d0
      iwe=iwe+1
      weighta( 33, 66,  3)=                  0.08009750202334373070d0
      iwe=iwe+1
      weighta( 34, 66,  3)=                  0.19848971179438038015d0
      iwe=iwe+1
      weighta( 35, 66,  3)=                 -0.12917181466339267004d0
      iwe=iwe+1
      weighta( 36, 66,  3)=                  0.29788643064240249991d0
      iwe=iwe+1
      weighta( 37, 66,  3)=                 -0.18801875922959460086d0
      iwe=iwe+1
      weighta( 38, 66,  3)=                 -0.07671187102248822054d0
      iwe=iwe+1
      weighta( 39, 66,  3)=                  0.23174140850661717472d0
      iwe=iwe+1
      weighta( 40, 66,  3)=                 -0.30125935444473722624d0
      iwe=iwe+1
      weighta( 41, 66,  3)=                  0.19562731770259952913d0
      iwe=iwe+1
      weighta( 42, 66,  3)=                 -0.43279070189589163853d0
      iwe=iwe+1
      weighta( 43, 66,  3)=                 -0.58910323072548442802d0
      iwe=iwe+1
      weighta( 44, 66,  3)=                  0.28919096848655734266d0
      iwe=iwe+1
      weighta( 45, 66,  3)=                  0.22596917048741205214d0
      iwe=iwe+1
      weighta( 46, 66,  3)=                  0.03898494971250287405d0
      iwe=iwe+1
      weighta( 47, 66,  3)=                  0.02175204511224356971d0
      iwe=iwe+1
      weighta( 48, 66,  3)=                 -0.06650965139069384136d0
      iwe=iwe+1
      weighta( 49, 66,  3)=                  0.33952362180283163218d0
      iwe=iwe+1
      weighta( 50, 66,  3)=                 -0.33913803430115546655d0
      iwe=iwe+1
      biasa( 66,  3)=                 -0.87289559385275017345d0
      iwe=iwe+1
      weighta(  1, 67,  3)=                 -0.50278076814376226888d0
      iwe=iwe+1
      weighta(  2, 67,  3)=                  0.01896860825849466109d0
      iwe=iwe+1
      weighta(  3, 67,  3)=                  0.00310844958112606535d0
      iwe=iwe+1
      weighta(  4, 67,  3)=                 -0.06756174405505170621d0
      iwe=iwe+1
      weighta(  5, 67,  3)=                 -0.29973433339154975652d0
      iwe=iwe+1
      weighta(  6, 67,  3)=                 -0.22136306975130248809d0
      iwe=iwe+1
      weighta(  7, 67,  3)=                 -0.43756304729010925270d0
      iwe=iwe+1
      weighta(  8, 67,  3)=                  0.17733476925277788516d0
      iwe=iwe+1
      weighta(  9, 67,  3)=                  0.08040507308166885969d0
      iwe=iwe+1
      weighta( 10, 67,  3)=                  0.02297798156872671999d0
      iwe=iwe+1
      weighta( 11, 67,  3)=                  0.31748665808773901542d0
      iwe=iwe+1
      weighta( 12, 67,  3)=                 -0.62494642704261760269d0
      iwe=iwe+1
      weighta( 13, 67,  3)=                  0.35096376344015267623d0
      iwe=iwe+1
      weighta( 14, 67,  3)=                 -0.19188457469286629431d0
      iwe=iwe+1
      weighta( 15, 67,  3)=                  0.21488597546858162479d0
      iwe=iwe+1
      weighta( 16, 67,  3)=                 -0.59594099661905419740d0
      iwe=iwe+1
      weighta( 17, 67,  3)=                  0.32124079679380435071d0
      iwe=iwe+1
      weighta( 18, 67,  3)=                 -0.15509806464523101521d0
      iwe=iwe+1
      weighta( 19, 67,  3)=                  0.07271042008399654366d0
      iwe=iwe+1
      weighta( 20, 67,  3)=                 -0.12042304868989320288d0
      iwe=iwe+1
      weighta( 21, 67,  3)=                  0.02734367232766116151d0
      iwe=iwe+1
      weighta( 22, 67,  3)=                  0.40923511351591873586d0
      iwe=iwe+1
      weighta( 23, 67,  3)=                  0.07792041029290378007d0
      iwe=iwe+1
      weighta( 24, 67,  3)=                  0.08880206193821622851d0
      iwe=iwe+1
      weighta( 25, 67,  3)=                  0.22773436683921247092d0
      iwe=iwe+1
      weighta( 26, 67,  3)=                 -0.04246994668019096753d0
      iwe=iwe+1
      weighta( 27, 67,  3)=                  0.04500835028497083418d0
      iwe=iwe+1
      weighta( 28, 67,  3)=                  0.55833274105424557376d0
      iwe=iwe+1
      weighta( 29, 67,  3)=                 -0.38096384993979548472d0
      iwe=iwe+1
      weighta( 30, 67,  3)=                  0.10301481942146696602d0
      iwe=iwe+1
      weighta( 31, 67,  3)=                 -0.18648178776611534779d0
      iwe=iwe+1
      weighta( 32, 67,  3)=                  0.03143908418535895644d0
      iwe=iwe+1
      weighta( 33, 67,  3)=                 -0.14913999529541580036d0
      iwe=iwe+1
      weighta( 34, 67,  3)=                 -0.15641731368871675256d0
      iwe=iwe+1
      weighta( 35, 67,  3)=                 -0.53523938283563998741d0
      iwe=iwe+1
      weighta( 36, 67,  3)=                 -0.14697248490277922683d0
      iwe=iwe+1
      weighta( 37, 67,  3)=                  0.28695833309840912406d0
      iwe=iwe+1
      weighta( 38, 67,  3)=                  0.24900077184589097801d0
      iwe=iwe+1
      weighta( 39, 67,  3)=                  0.12598683815173986056d0
      iwe=iwe+1
      weighta( 40, 67,  3)=                  0.28318115271990601522d0
      iwe=iwe+1
      weighta( 41, 67,  3)=                  0.29828607886357078049d0
      iwe=iwe+1
      weighta( 42, 67,  3)=                  0.13424909074164398382d0
      iwe=iwe+1
      weighta( 43, 67,  3)=                 -0.17357208391432643602d0
      iwe=iwe+1
      weighta( 44, 67,  3)=                 -0.27384506987440726533d0
      iwe=iwe+1
      weighta( 45, 67,  3)=                  0.34682260816006427184d0
      iwe=iwe+1
      weighta( 46, 67,  3)=                 -0.46125763118301582599d0
      iwe=iwe+1
      weighta( 47, 67,  3)=                  0.20913992239992343358d0
      iwe=iwe+1
      weighta( 48, 67,  3)=                  0.07553859864713417804d0
      iwe=iwe+1
      weighta( 49, 67,  3)=                  0.13776204471388905914d0
      iwe=iwe+1
      weighta( 50, 67,  3)=                 -0.34508179855603310360d0
      iwe=iwe+1
      biasa( 67,  3)=                 -1.04435559862205851189d0
      iwe=iwe+1
      weighta(  1, 68,  3)=                  0.20051013829306679748d0
      iwe=iwe+1
      weighta(  2, 68,  3)=                 -0.05007620482850074634d0
      iwe=iwe+1
      weighta(  3, 68,  3)=                  0.01329612002114251811d0
      iwe=iwe+1
      weighta(  4, 68,  3)=                 -0.14770261158755704223d0
      iwe=iwe+1
      weighta(  5, 68,  3)=                 -0.21000767783860666005d0
      iwe=iwe+1
      weighta(  6, 68,  3)=                  0.13789351017085332840d0
      iwe=iwe+1
      weighta(  7, 68,  3)=                  0.34355204906947806043d0
      iwe=iwe+1
      weighta(  8, 68,  3)=                 -0.16479680972607968492d0
      iwe=iwe+1
      weighta(  9, 68,  3)=                 -0.07965669359231046520d0
      iwe=iwe+1
      weighta( 10, 68,  3)=                 -0.02468910833464227697d0
      iwe=iwe+1
      weighta( 11, 68,  3)=                  0.30607550827006757554d0
      iwe=iwe+1
      weighta( 12, 68,  3)=                 -0.23284094779798242270d0
      iwe=iwe+1
      weighta( 13, 68,  3)=                  0.57196175515179026316d0
      iwe=iwe+1
      weighta( 14, 68,  3)=                 -0.46504892690871907357d0
      iwe=iwe+1
      weighta( 15, 68,  3)=                  0.18108748266094978896d0
      iwe=iwe+1
      weighta( 16, 68,  3)=                  0.19222040368291973267d0
      iwe=iwe+1
      weighta( 17, 68,  3)=                  0.09048073865553918349d0
      iwe=iwe+1
      weighta( 18, 68,  3)=                 -0.12236937370817956017d0
      iwe=iwe+1
      weighta( 19, 68,  3)=                  0.03070075223609525922d0
      iwe=iwe+1
      weighta( 20, 68,  3)=                  0.03614639156998562808d0
      iwe=iwe+1
      weighta( 21, 68,  3)=                  0.24330876364456413552d0
      iwe=iwe+1
      weighta( 22, 68,  3)=                  0.02523769305016883638d0
      iwe=iwe+1
      weighta( 23, 68,  3)=                  0.01191555015034103000d0
      iwe=iwe+1
      weighta( 24, 68,  3)=                 -0.11660192448055746450d0
      iwe=iwe+1
      weighta( 25, 68,  3)=                  0.38362080620160626809d0
      iwe=iwe+1
      weighta( 26, 68,  3)=                  0.14277683348611808212d0
      iwe=iwe+1
      weighta( 27, 68,  3)=                 -0.40499768344535552744d0
      iwe=iwe+1
      weighta( 28, 68,  3)=                  0.24008459951227884011d0
      iwe=iwe+1
      weighta( 29, 68,  3)=                  0.25316014862351848835d0
      iwe=iwe+1
      weighta( 30, 68,  3)=                  0.12249368098257062965d0
      iwe=iwe+1
      weighta( 31, 68,  3)=                  0.65827539820438096818d0
      iwe=iwe+1
      weighta( 32, 68,  3)=                 -0.20577166110655945030d0
      iwe=iwe+1
      weighta( 33, 68,  3)=                  0.17731747657025218046d0
      iwe=iwe+1
      weighta( 34, 68,  3)=                  0.16095638458092639822d0
      iwe=iwe+1
      weighta( 35, 68,  3)=                 -0.01048533577114388500d0
      iwe=iwe+1
      weighta( 36, 68,  3)=                  0.05407998499939529330d0
      iwe=iwe+1
      weighta( 37, 68,  3)=                 -0.01686094608738011175d0
      iwe=iwe+1
      weighta( 38, 68,  3)=                 -0.18220687966139162417d0
      iwe=iwe+1
      weighta( 39, 68,  3)=                 -0.13441952985910887719d0
      iwe=iwe+1
      weighta( 40, 68,  3)=                 -0.48111353876147272546d0
      iwe=iwe+1
      weighta( 41, 68,  3)=                 -0.06410146174134923047d0
      iwe=iwe+1
      weighta( 42, 68,  3)=                 -0.03518382452042364411d0
      iwe=iwe+1
      weighta( 43, 68,  3)=                 -0.40133393531695699119d0
      iwe=iwe+1
      weighta( 44, 68,  3)=                  0.31302432093867205154d0
      iwe=iwe+1
      weighta( 45, 68,  3)=                 -0.00882759202014932361d0
      iwe=iwe+1
      weighta( 46, 68,  3)=                  0.29688190972056621719d0
      iwe=iwe+1
      weighta( 47, 68,  3)=                  0.15964558103161366476d0
      iwe=iwe+1
      weighta( 48, 68,  3)=                  0.02826209087428892264d0
      iwe=iwe+1
      weighta( 49, 68,  3)=                 -0.07840356546080382016d0
      iwe=iwe+1
      weighta( 50, 68,  3)=                 -0.20515503128177245418d0
      iwe=iwe+1
      biasa( 68,  3)=                  0.90946343112239513840d0
      iwe=iwe+1
      weighta(  1, 69,  3)=                 -0.08154485261334908086d0
      iwe=iwe+1
      weighta(  2, 69,  3)=                  0.27754842460018502859d0
      iwe=iwe+1
      weighta(  3, 69,  3)=                 -0.03066385514906348059d0
      iwe=iwe+1
      weighta(  4, 69,  3)=                  0.37167650172394339769d0
      iwe=iwe+1
      weighta(  5, 69,  3)=                 -0.02641093242236898161d0
      iwe=iwe+1
      weighta(  6, 69,  3)=                 -0.32839740118390681189d0
      iwe=iwe+1
      weighta(  7, 69,  3)=                 -0.32484416707863994489d0
      iwe=iwe+1
      weighta(  8, 69,  3)=                 -0.08748147273795131573d0
      iwe=iwe+1
      weighta(  9, 69,  3)=                 -0.00104931997013377144d0
      iwe=iwe+1
      weighta( 10, 69,  3)=                 -0.21377530904382108234d0
      iwe=iwe+1
      weighta( 11, 69,  3)=                 -0.26318731918925519775d0
      iwe=iwe+1
      weighta( 12, 69,  3)=                  0.37644442544006134765d0
      iwe=iwe+1
      weighta( 13, 69,  3)=                  0.39396932913867416248d0
      iwe=iwe+1
      weighta( 14, 69,  3)=                  0.16022352157137964568d0
      iwe=iwe+1
      weighta( 15, 69,  3)=                  0.06870136357710369956d0
      iwe=iwe+1
      weighta( 16, 69,  3)=                  0.30959188539678067498d0
      iwe=iwe+1
      weighta( 17, 69,  3)=                 -0.25182731871505931176d0
      iwe=iwe+1
      weighta( 18, 69,  3)=                  0.18999958332351435386d0
      iwe=iwe+1
      weighta( 19, 69,  3)=                 -0.40169777884930624179d0
      iwe=iwe+1
      weighta( 20, 69,  3)=                  0.25971584510031492377d0
      iwe=iwe+1
      weighta( 21, 69,  3)=                  0.27476036308277212994d0
      iwe=iwe+1
      weighta( 22, 69,  3)=                  0.00521877822372552886d0
      iwe=iwe+1
      weighta( 23, 69,  3)=                  0.05415298669269447834d0
      iwe=iwe+1
      weighta( 24, 69,  3)=                 -0.23341486416624523947d0
      iwe=iwe+1
      weighta( 25, 69,  3)=                 -0.08535817365549223934d0
      iwe=iwe+1
      weighta( 26, 69,  3)=                  0.41797416921846924920d0
      iwe=iwe+1
      weighta( 27, 69,  3)=                 -0.21177922355255793252d0
      iwe=iwe+1
      weighta( 28, 69,  3)=                  0.17955603929785002304d0
      iwe=iwe+1
      weighta( 29, 69,  3)=                 -0.25191866897657833047d0
      iwe=iwe+1
      weighta( 30, 69,  3)=                 -0.10543939933670108677d0
      iwe=iwe+1
      weighta( 31, 69,  3)=                  0.00531184016751073441d0
      iwe=iwe+1
      weighta( 32, 69,  3)=                 -0.21400573408825446231d0
      iwe=iwe+1
      weighta( 33, 69,  3)=                 -0.23713022752972498508d0
      iwe=iwe+1
      weighta( 34, 69,  3)=                  0.28349308451253923957d0
      iwe=iwe+1
      weighta( 35, 69,  3)=                  0.15140535293960105667d0
      iwe=iwe+1
      weighta( 36, 69,  3)=                 -0.34065841129492280270d0
      iwe=iwe+1
      weighta( 37, 69,  3)=                  0.34287372702927859658d0
      iwe=iwe+1
      weighta( 38, 69,  3)=                  0.35194378348368343667d0
      iwe=iwe+1
      weighta( 39, 69,  3)=                  0.49403906110472350921d0
      iwe=iwe+1
      weighta( 40, 69,  3)=                  0.23959987380187436345d0
      iwe=iwe+1
      weighta( 41, 69,  3)=                 -0.32410858657994295884d0
      iwe=iwe+1
      weighta( 42, 69,  3)=                 -0.21698956204848565688d0
      iwe=iwe+1
      weighta( 43, 69,  3)=                  0.30494640727527866364d0
      iwe=iwe+1
      weighta( 44, 69,  3)=                 -0.05728433052449679458d0
      iwe=iwe+1
      weighta( 45, 69,  3)=                  0.07685681208778427642d0
      iwe=iwe+1
      weighta( 46, 69,  3)=                 -0.38669349320607931952d0
      iwe=iwe+1
      weighta( 47, 69,  3)=                  0.01881439351269428503d0
      iwe=iwe+1
      weighta( 48, 69,  3)=                  0.22593813029587450636d0
      iwe=iwe+1
      weighta( 49, 69,  3)=                 -0.07105253835148986341d0
      iwe=iwe+1
      weighta( 50, 69,  3)=                 -0.32802149329028701397d0
      iwe=iwe+1
      biasa( 69,  3)=                 -1.13422693665224283421d0
      iwe=iwe+1
      weighta(  1, 70,  3)=                 -0.31590433497251774186d0
      iwe=iwe+1
      weighta(  2, 70,  3)=                  0.17362838956658235845d0
      iwe=iwe+1
      weighta(  3, 70,  3)=                  0.03194754592304133167d0
      iwe=iwe+1
      weighta(  4, 70,  3)=                  0.42751861456158635200d0
      iwe=iwe+1
      weighta(  5, 70,  3)=                 -0.05365136251944052637d0
      iwe=iwe+1
      weighta(  6, 70,  3)=                  0.40413866176060353474d0
      iwe=iwe+1
      weighta(  7, 70,  3)=                  0.12800627474118028704d0
      iwe=iwe+1
      weighta(  8, 70,  3)=                  0.01318786158717149409d0
      iwe=iwe+1
      weighta(  9, 70,  3)=                  0.36197829557900407238d0
      iwe=iwe+1
      weighta( 10, 70,  3)=                 -0.07708634915282683298d0
      iwe=iwe+1
      weighta( 11, 70,  3)=                  0.21041301221413893918d0
      iwe=iwe+1
      weighta( 12, 70,  3)=                  0.33090989502516438003d0
      iwe=iwe+1
      weighta( 13, 70,  3)=                  0.13168099710674735503d0
      iwe=iwe+1
      weighta( 14, 70,  3)=                  0.23481434782149118723d0
      iwe=iwe+1
      weighta( 15, 70,  3)=                  0.25153325167994400324d0
      iwe=iwe+1
      weighta( 16, 70,  3)=                 -0.28239124827625594616d0
      iwe=iwe+1
      weighta( 17, 70,  3)=                  0.13210861743908278165d0
      iwe=iwe+1
      weighta( 18, 70,  3)=                  0.32108799363374529445d0
      iwe=iwe+1
      weighta( 19, 70,  3)=                 -0.27692105008741330074d0
      iwe=iwe+1
      weighta( 20, 70,  3)=                  0.26025923927030364391d0
      iwe=iwe+1
      weighta( 21, 70,  3)=                  0.32343846949680260527d0
      iwe=iwe+1
      weighta( 22, 70,  3)=                 -0.12100998369746161776d0
      iwe=iwe+1
      weighta( 23, 70,  3)=                 -0.12745926025325016173d0
      iwe=iwe+1
      weighta( 24, 70,  3)=                 -0.25427113334030337910d0
      iwe=iwe+1
      weighta( 25, 70,  3)=                  0.14330513580675854901d0
      iwe=iwe+1
      weighta( 26, 70,  3)=                 -0.15426126455199154486d0
      iwe=iwe+1
      weighta( 27, 70,  3)=                  0.11327329312858053223d0
      iwe=iwe+1
      weighta( 28, 70,  3)=                  0.08929450446375666872d0
      iwe=iwe+1
      weighta( 29, 70,  3)=                  0.00297227844015178488d0
      iwe=iwe+1
      weighta( 30, 70,  3)=                  0.29019812414930379330d0
      iwe=iwe+1
      weighta( 31, 70,  3)=                 -0.04593324780788622663d0
      iwe=iwe+1
      weighta( 32, 70,  3)=                  0.12962196291526514869d0
      iwe=iwe+1
      weighta( 33, 70,  3)=                 -0.03089388936647500389d0
      iwe=iwe+1
      weighta( 34, 70,  3)=                  0.18190266619945075210d0
      iwe=iwe+1
      weighta( 35, 70,  3)=                 -0.15534697011278009171d0
      iwe=iwe+1
      weighta( 36, 70,  3)=                  0.20161568336180746286d0
      iwe=iwe+1
      weighta( 37, 70,  3)=                  0.24052049662547697606d0
      iwe=iwe+1
      weighta( 38, 70,  3)=                  0.14988294760433196195d0
      iwe=iwe+1
      weighta( 39, 70,  3)=                  0.17889963660818239410d0
      iwe=iwe+1
      weighta( 40, 70,  3)=                  0.03962450807234696448d0
      iwe=iwe+1
      weighta( 41, 70,  3)=                 -0.32621970251575022059d0
      iwe=iwe+1
      weighta( 42, 70,  3)=                  0.34100553938459982062d0
      iwe=iwe+1
      weighta( 43, 70,  3)=                  0.12857022123235298250d0
      iwe=iwe+1
      weighta( 44, 70,  3)=                  0.32969886577422385932d0
      iwe=iwe+1
      weighta( 45, 70,  3)=                 -0.15852446627447583372d0
      iwe=iwe+1
      weighta( 46, 70,  3)=                  0.14484088579954126907d0
      iwe=iwe+1
      weighta( 47, 70,  3)=                 -0.26401138721010369848d0
      iwe=iwe+1
      weighta( 48, 70,  3)=                  0.25876120370817728977d0
      iwe=iwe+1
      weighta( 49, 70,  3)=                  0.13276742361897941880d0
      iwe=iwe+1
      weighta( 50, 70,  3)=                  0.24073825315206501263d0
      iwe=iwe+1
      biasa( 70,  3)=                 -1.21320799253173516874d0
      iwe=iwe+1
      weighta(  1, 71,  3)=                 -0.33612351242330096301d0
      iwe=iwe+1
      weighta(  2, 71,  3)=                 -0.13446155616480770512d0
      iwe=iwe+1
      weighta(  3, 71,  3)=                  0.23478323224820979442d0
      iwe=iwe+1
      weighta(  4, 71,  3)=                 -0.08767375673194653662d0
      iwe=iwe+1
      weighta(  5, 71,  3)=                  0.23309481512245866508d0
      iwe=iwe+1
      weighta(  6, 71,  3)=                  0.21183568060535312716d0
      iwe=iwe+1
      weighta(  7, 71,  3)=                  0.11959170335891289305d0
      iwe=iwe+1
      weighta(  8, 71,  3)=                  0.21628319711741658682d0
      iwe=iwe+1
      weighta(  9, 71,  3)=                 -0.25570485430942152538d0
      iwe=iwe+1
      weighta( 10, 71,  3)=                  0.33584743718795234679d0
      iwe=iwe+1
      weighta( 11, 71,  3)=                  0.02007120147864554713d0
      iwe=iwe+1
      weighta( 12, 71,  3)=                  0.35849458907028175503d0
      iwe=iwe+1
      weighta( 13, 71,  3)=                 -0.01514655157133427792d0
      iwe=iwe+1
      weighta( 14, 71,  3)=                 -0.23917269505686933329d0
      iwe=iwe+1
      weighta( 15, 71,  3)=                 -0.05381699684129558764d0
      iwe=iwe+1
      weighta( 16, 71,  3)=                 -0.24363402601065115016d0
      iwe=iwe+1
      weighta( 17, 71,  3)=                  0.01354252911231442272d0
      iwe=iwe+1
      weighta( 18, 71,  3)=                 -0.26215548711928149395d0
      iwe=iwe+1
      weighta( 19, 71,  3)=                  0.19559503253196663941d0
      iwe=iwe+1
      weighta( 20, 71,  3)=                 -0.21355547764671140021d0
      iwe=iwe+1
      weighta( 21, 71,  3)=                  0.32553987282154756011d0
      iwe=iwe+1
      weighta( 22, 71,  3)=                 -0.08522953772738453559d0
      iwe=iwe+1
      weighta( 23, 71,  3)=                  0.06741869426370222795d0
      iwe=iwe+1
      weighta( 24, 71,  3)=                  0.04830270314195526937d0
      iwe=iwe+1
      weighta( 25, 71,  3)=                  0.25896732217381435159d0
      iwe=iwe+1
      weighta( 26, 71,  3)=                  0.08277867906331055903d0
      iwe=iwe+1
      weighta( 27, 71,  3)=                  0.23882940768858035296d0
      iwe=iwe+1
      weighta( 28, 71,  3)=                  0.36484071772566256664d0
      iwe=iwe+1
      weighta( 29, 71,  3)=                  0.14054864589540494446d0
      iwe=iwe+1
      weighta( 30, 71,  3)=                  0.13525681927968846718d0
      iwe=iwe+1
      weighta( 31, 71,  3)=                  0.21619750424592656945d0
      iwe=iwe+1
      weighta( 32, 71,  3)=                 -0.08942777873223989316d0
      iwe=iwe+1
      weighta( 33, 71,  3)=                 -0.26186002553917220315d0
      iwe=iwe+1
      weighta( 34, 71,  3)=                  0.09218756480844364498d0
      iwe=iwe+1
      weighta( 35, 71,  3)=                 -0.15915954557839218086d0
      iwe=iwe+1
      weighta( 36, 71,  3)=                  0.28193900079455003205d0
      iwe=iwe+1
      weighta( 37, 71,  3)=                  0.40611410798623853724d0
      iwe=iwe+1
      weighta( 38, 71,  3)=                 -0.30584880499775418672d0
      iwe=iwe+1
      weighta( 39, 71,  3)=                 -0.27628950596122503480d0
      iwe=iwe+1
      weighta( 40, 71,  3)=                  0.16481764896714931612d0
      iwe=iwe+1
      weighta( 41, 71,  3)=                  0.22627183614860765792d0
      iwe=iwe+1
      weighta( 42, 71,  3)=                  0.36858863820366755126d0
      iwe=iwe+1
      weighta( 43, 71,  3)=                  0.04452897010773849973d0
      iwe=iwe+1
      weighta( 44, 71,  3)=                 -0.04047840626501855027d0
      iwe=iwe+1
      weighta( 45, 71,  3)=                 -0.02459834321540814092d0
      iwe=iwe+1
      weighta( 46, 71,  3)=                  0.25122404905393291852d0
      iwe=iwe+1
      weighta( 47, 71,  3)=                  0.27983747130828084959d0
      iwe=iwe+1
      weighta( 48, 71,  3)=                  0.29820505891725151981d0
      iwe=iwe+1
      weighta( 49, 71,  3)=                 -0.23967602322759073985d0
      iwe=iwe+1
      weighta( 50, 71,  3)=                  0.17559565019908732197d0
      iwe=iwe+1
      biasa( 71,  3)=                 -1.20071893899722925703d0
      iwe=iwe+1
      weighta(  1, 72,  3)=                 -0.28385822235505597799d0
      iwe=iwe+1
      weighta(  2, 72,  3)=                 -0.15295077339338483680d0
      iwe=iwe+1
      weighta(  3, 72,  3)=                 -0.23957526987674593322d0
      iwe=iwe+1
      weighta(  4, 72,  3)=                 -0.14349706123033117988d0
      iwe=iwe+1
      weighta(  5, 72,  3)=                  0.34265571090620700057d0
      iwe=iwe+1
      weighta(  6, 72,  3)=                  0.36471457899235343314d0
      iwe=iwe+1
      weighta(  7, 72,  3)=                 -0.06234998524919756202d0
      iwe=iwe+1
      weighta(  8, 72,  3)=                  0.13243227688314998525d0
      iwe=iwe+1
      weighta(  9, 72,  3)=                  0.24867419110587943298d0
      iwe=iwe+1
      weighta( 10, 72,  3)=                  0.05263417574489048789d0
      iwe=iwe+1
      weighta( 11, 72,  3)=                  0.18824984609716055584d0
      iwe=iwe+1
      weighta( 12, 72,  3)=                 -0.04982780230064012827d0
      iwe=iwe+1
      weighta( 13, 72,  3)=                 -0.36357569852420057455d0
      iwe=iwe+1
      weighta( 14, 72,  3)=                 -0.09226638486776891912d0
      iwe=iwe+1
      weighta( 15, 72,  3)=                 -0.22197279848453330131d0
      iwe=iwe+1
      weighta( 16, 72,  3)=                  0.10896040866025620553d0
      iwe=iwe+1
      weighta( 17, 72,  3)=                  0.10555158896906298438d0
      iwe=iwe+1
      weighta( 18, 72,  3)=                  0.10656219272633001005d0
      iwe=iwe+1
      weighta( 19, 72,  3)=                  0.07611179949960708568d0
      iwe=iwe+1
      weighta( 20, 72,  3)=                  0.29133890348599816855d0
      iwe=iwe+1
      weighta( 21, 72,  3)=                  0.04464284671728124126d0
      iwe=iwe+1
      weighta( 22, 72,  3)=                 -0.17467160549512400491d0
      iwe=iwe+1
      weighta( 23, 72,  3)=                 -0.41429169343790800406d0
      iwe=iwe+1
      weighta( 24, 72,  3)=                 -0.02801736838333420201d0
      iwe=iwe+1
      weighta( 25, 72,  3)=                  0.36638659460403688595d0
      iwe=iwe+1
      weighta( 26, 72,  3)=                 -0.01735316494249873262d0
      iwe=iwe+1
      weighta( 27, 72,  3)=                 -0.11528373518120454966d0
      iwe=iwe+1
      weighta( 28, 72,  3)=                 -0.14615555721114054100d0
      iwe=iwe+1
      weighta( 29, 72,  3)=                 -0.23935135492150336201d0
      iwe=iwe+1
      weighta( 30, 72,  3)=                  0.35030741346334121067d0
      iwe=iwe+1
      weighta( 31, 72,  3)=                 -0.45902953539916285797d0
      iwe=iwe+1
      weighta( 32, 72,  3)=                  0.00748551959471088595d0
      iwe=iwe+1
      weighta( 33, 72,  3)=                  0.23305040477483335293d0
      iwe=iwe+1
      weighta( 34, 72,  3)=                  0.22595509081205597535d0
      iwe=iwe+1
      weighta( 35, 72,  3)=                  0.12411402756481892951d0
      iwe=iwe+1
      weighta( 36, 72,  3)=                 -0.33924740451589180390d0
      iwe=iwe+1
      weighta( 37, 72,  3)=                 -0.28270930725731874267d0
      iwe=iwe+1
      weighta( 38, 72,  3)=                 -0.16060175593403341887d0
      iwe=iwe+1
      weighta( 39, 72,  3)=                  0.03381973354738249810d0
      iwe=iwe+1
      weighta( 40, 72,  3)=                 -0.10470685388391816339d0
      iwe=iwe+1
      weighta( 41, 72,  3)=                  0.30056441996350552470d0
      iwe=iwe+1
      weighta( 42, 72,  3)=                  0.30209949575924771592d0
      iwe=iwe+1
      weighta( 43, 72,  3)=                 -0.39599360822727258657d0
      iwe=iwe+1
      weighta( 44, 72,  3)=                 -0.07279341870318872809d0
      iwe=iwe+1
      weighta( 45, 72,  3)=                 -0.24525380671480703776d0
      iwe=iwe+1
      weighta( 46, 72,  3)=                 -0.22221633524752951172d0
      iwe=iwe+1
      weighta( 47, 72,  3)=                 -0.02733001638950930540d0
      iwe=iwe+1
      weighta( 48, 72,  3)=                 -0.43800867360274337026d0
      iwe=iwe+1
      weighta( 49, 72,  3)=                  0.15243537158069508930d0
      iwe=iwe+1
      weighta( 50, 72,  3)=                 -0.44038152101541655492d0
      iwe=iwe+1
      biasa( 72,  3)=                 -1.15737433932328848130d0
      iwe=iwe+1
      weighta(  1, 73,  3)=                  0.21704456798689036878d0
      iwe=iwe+1
      weighta(  2, 73,  3)=                  0.10514392664862061422d0
      iwe=iwe+1
      weighta(  3, 73,  3)=                 -0.08698613987487693877d0
      iwe=iwe+1
      weighta(  4, 73,  3)=                 -0.28606230963609524665d0
      iwe=iwe+1
      weighta(  5, 73,  3)=                  0.20308181443777273412d0
      iwe=iwe+1
      weighta(  6, 73,  3)=                  0.13568512342708310969d0
      iwe=iwe+1
      weighta(  7, 73,  3)=                 -0.53821625671715811468d0
      iwe=iwe+1
      weighta(  8, 73,  3)=                  0.14638744456119504034d0
      iwe=iwe+1
      weighta(  9, 73,  3)=                  0.29125363251366676032d0
      iwe=iwe+1
      weighta( 10, 73,  3)=                 -0.25140479388302633401d0
      iwe=iwe+1
      weighta( 11, 73,  3)=                  0.26267919428648467406d0
      iwe=iwe+1
      weighta( 12, 73,  3)=                 -0.25012200279189139573d0
      iwe=iwe+1
      weighta( 13, 73,  3)=                 -0.25215249041942261465d0
      iwe=iwe+1
      weighta( 14, 73,  3)=                  0.26180228533714228201d0
      iwe=iwe+1
      weighta( 15, 73,  3)=                 -0.04016927617505497428d0
      iwe=iwe+1
      weighta( 16, 73,  3)=                  0.00352573563537355228d0
      iwe=iwe+1
      weighta( 17, 73,  3)=                  0.34915018005506792687d0
      iwe=iwe+1
      weighta( 18, 73,  3)=                 -0.26318076383588095979d0
      iwe=iwe+1
      weighta( 19, 73,  3)=                  0.21121581303340741798d0
      iwe=iwe+1
      weighta( 20, 73,  3)=                  0.46715171904269320313d0
      iwe=iwe+1
      weighta( 21, 73,  3)=                  0.09651026442090344937d0
      iwe=iwe+1
      weighta( 22, 73,  3)=                  0.49626841670787114058d0
      iwe=iwe+1
      weighta( 23, 73,  3)=                  0.19867652057452903080d0
      iwe=iwe+1
      weighta( 24, 73,  3)=                  0.26126875449449543654d0
      iwe=iwe+1
      weighta( 25, 73,  3)=                 -0.27259387326921519223d0
      iwe=iwe+1
      weighta( 26, 73,  3)=                  0.01554552677193378821d0
      iwe=iwe+1
      weighta( 27, 73,  3)=                 -0.30143222414048004287d0
      iwe=iwe+1
      weighta( 28, 73,  3)=                  0.03381826676342578747d0
      iwe=iwe+1
      weighta( 29, 73,  3)=                  0.11389532861715941092d0
      iwe=iwe+1
      weighta( 30, 73,  3)=                 -0.17498257263318561794d0
      iwe=iwe+1
      weighta( 31, 73,  3)=                  0.28781342347827948425d0
      iwe=iwe+1
      weighta( 32, 73,  3)=                  0.27859663539857565384d0
      iwe=iwe+1
      weighta( 33, 73,  3)=                  0.04226501653620459709d0
      iwe=iwe+1
      weighta( 34, 73,  3)=                  0.07023255689062446461d0
      iwe=iwe+1
      weighta( 35, 73,  3)=                  0.26102808263779264664d0
      iwe=iwe+1
      weighta( 36, 73,  3)=                 -0.26396969281907367577d0
      iwe=iwe+1
      weighta( 37, 73,  3)=                 -0.21708290519698664189d0
      iwe=iwe+1
      weighta( 38, 73,  3)=                 -0.14668876371715239282d0
      iwe=iwe+1
      weighta( 39, 73,  3)=                  0.48257889197106507151d0
      iwe=iwe+1
      weighta( 40, 73,  3)=                 -0.14189424402232939104d0
      iwe=iwe+1
      weighta( 41, 73,  3)=                 -0.31701489109413732992d0
      iwe=iwe+1
      weighta( 42, 73,  3)=                  0.27998715770973803263d0
      iwe=iwe+1
      weighta( 43, 73,  3)=                 -0.25423922766811318796d0
      iwe=iwe+1
      weighta( 44, 73,  3)=                  0.62589616355915667079d0
      iwe=iwe+1
      weighta( 45, 73,  3)=                 -0.12813980901083651953d0
      iwe=iwe+1
      weighta( 46, 73,  3)=                  0.13504888842338585997d0
      iwe=iwe+1
      weighta( 47, 73,  3)=                 -0.20984251816841439919d0
      iwe=iwe+1
      weighta( 48, 73,  3)=                 -0.56275968000404674729d0
      iwe=iwe+1
      weighta( 49, 73,  3)=                  0.29702940446500336602d0
      iwe=iwe+1
      weighta( 50, 73,  3)=                 -0.58683967296484829124d0
      iwe=iwe+1
      biasa( 73,  3)=                 -1.11797042412482405815d0
      iwe=iwe+1
      weighta(  1, 74,  3)=                  0.39279573438133735808d0
      iwe=iwe+1
      weighta(  2, 74,  3)=                 -0.09090005174570164881d0
      iwe=iwe+1
      weighta(  3, 74,  3)=                  0.10168255026393881180d0
      iwe=iwe+1
      weighta(  4, 74,  3)=                  0.30833736195631533672d0
      iwe=iwe+1
      weighta(  5, 74,  3)=                 -0.21628107918658093234d0
      iwe=iwe+1
      weighta(  6, 74,  3)=                  0.11145613251939898158d0
      iwe=iwe+1
      weighta(  7, 74,  3)=                  0.06137316313111825655d0
      iwe=iwe+1
      weighta(  8, 74,  3)=                 -0.13795203597815650087d0
      iwe=iwe+1
      weighta(  9, 74,  3)=                  0.09231804477589043711d0
      iwe=iwe+1
      weighta( 10, 74,  3)=                 -0.28010033443420362387d0
      iwe=iwe+1
      weighta( 11, 74,  3)=                  0.47660288167123626701d0
      iwe=iwe+1
      weighta( 12, 74,  3)=                 -0.15448328824519516611d0
      iwe=iwe+1
      weighta( 13, 74,  3)=                  0.00828871004068429743d0
      iwe=iwe+1
      weighta( 14, 74,  3)=                  0.22253921326891099031d0
      iwe=iwe+1
      weighta( 15, 74,  3)=                 -0.30325382726581384674d0
      iwe=iwe+1
      weighta( 16, 74,  3)=                  0.01795728469002648084d0
      iwe=iwe+1
      weighta( 17, 74,  3)=                 -0.08815888684207420778d0
      iwe=iwe+1
      weighta( 18, 74,  3)=                 -0.17603257913987976901d0
      iwe=iwe+1
      weighta( 19, 74,  3)=                  0.01250698395505072009d0
      iwe=iwe+1
      weighta( 20, 74,  3)=                  0.38787205419842119003d0
      iwe=iwe+1
      weighta( 21, 74,  3)=                  0.32054227588180855824d0
      iwe=iwe+1
      weighta( 22, 74,  3)=                 -0.00015203237419813772d0
      iwe=iwe+1
      weighta( 23, 74,  3)=                 -0.43695764936158043579d0
      iwe=iwe+1
      weighta( 24, 74,  3)=                 -0.19463830496885339838d0
      iwe=iwe+1
      weighta( 25, 74,  3)=                  0.28565640027089461706d0
      iwe=iwe+1
      weighta( 26, 74,  3)=                  0.02221155820801634997d0
      iwe=iwe+1
      weighta( 27, 74,  3)=                  0.22677829726549073031d0
      iwe=iwe+1
      weighta( 28, 74,  3)=                 -0.04760014968978156652d0
      iwe=iwe+1
      weighta( 29, 74,  3)=                  0.05253771057655651222d0
      iwe=iwe+1
      weighta( 30, 74,  3)=                 -0.27778311616773854187d0
      iwe=iwe+1
      weighta( 31, 74,  3)=                 -0.44025291497241425542d0
      iwe=iwe+1
      weighta( 32, 74,  3)=                  0.17374990289191505344d0
      iwe=iwe+1
      weighta( 33, 74,  3)=                 -0.25861883161187393387d0
      iwe=iwe+1
      weighta( 34, 74,  3)=                  0.26230304078467281403d0
      iwe=iwe+1
      weighta( 35, 74,  3)=                 -0.31778725895589610140d0
      iwe=iwe+1
      weighta( 36, 74,  3)=                  0.04577801913379797583d0
      iwe=iwe+1
      weighta( 37, 74,  3)=                 -0.15512896558562952465d0
      iwe=iwe+1
      weighta( 38, 74,  3)=                 -0.19344426774365211519d0
      iwe=iwe+1
      weighta( 39, 74,  3)=                  0.07495688513487382132d0
      iwe=iwe+1
      weighta( 40, 74,  3)=                 -0.19239614763443979584d0
      iwe=iwe+1
      weighta( 41, 74,  3)=                  0.12134672296793982960d0
      iwe=iwe+1
      weighta( 42, 74,  3)=                  0.28648441432161803055d0
      iwe=iwe+1
      weighta( 43, 74,  3)=                 -0.10799794651677228907d0
      iwe=iwe+1
      weighta( 44, 74,  3)=                 -0.23067579145006045227d0
      iwe=iwe+1
      weighta( 45, 74,  3)=                 -0.06895954729069336819d0
      iwe=iwe+1
      weighta( 46, 74,  3)=                 -0.42487883255338998456d0
      iwe=iwe+1
      weighta( 47, 74,  3)=                  0.24175098651274887218d0
      iwe=iwe+1
      weighta( 48, 74,  3)=                 -0.00273088248870833467d0
      iwe=iwe+1
      weighta( 49, 74,  3)=                  0.32469390214358356817d0
      iwe=iwe+1
      weighta( 50, 74,  3)=                 -0.34357977218614593751d0
      iwe=iwe+1
      biasa( 74,  3)=                  1.34446350082600329934d0
      iwe=iwe+1
      weighta(  1, 75,  3)=                  0.19700420216946470942d0
      iwe=iwe+1
      weighta(  2, 75,  3)=                 -0.35106313942559502772d0
      iwe=iwe+1
      weighta(  3, 75,  3)=                 -0.06287338964998867574d0
      iwe=iwe+1
      weighta(  4, 75,  3)=                  0.05538160292091562353d0
      iwe=iwe+1
      weighta(  5, 75,  3)=                 -0.01046251424711730667d0
      iwe=iwe+1
      weighta(  6, 75,  3)=                 -0.16316451441162768687d0
      iwe=iwe+1
      weighta(  7, 75,  3)=                 -0.10057225284391618780d0
      iwe=iwe+1
      weighta(  8, 75,  3)=                 -0.31907220603973446282d0
      iwe=iwe+1
      weighta(  9, 75,  3)=                  0.05973879742999249620d0
      iwe=iwe+1
      weighta( 10, 75,  3)=                  0.15953810560213643743d0
      iwe=iwe+1
      weighta( 11, 75,  3)=                  0.29089161262183377277d0
      iwe=iwe+1
      weighta( 12, 75,  3)=                  0.04105443039233153818d0
      iwe=iwe+1
      weighta( 13, 75,  3)=                 -0.26559481232723353150d0
      iwe=iwe+1
      weighta( 14, 75,  3)=                 -0.16561300737168691000d0
      iwe=iwe+1
      weighta( 15, 75,  3)=                 -0.29261537382793406659d0
      iwe=iwe+1
      weighta( 16, 75,  3)=                  0.00976679093118529816d0
      iwe=iwe+1
      weighta( 17, 75,  3)=                 -0.21514326106107703462d0
      iwe=iwe+1
      weighta( 18, 75,  3)=                  0.06644095586665026143d0
      iwe=iwe+1
      weighta( 19, 75,  3)=                 -0.34507699086015830581d0
      iwe=iwe+1
      weighta( 20, 75,  3)=                 -0.03603150368479938331d0
      iwe=iwe+1
      weighta( 21, 75,  3)=                 -0.07396046912355348779d0
      iwe=iwe+1
      weighta( 22, 75,  3)=                 -0.34280344960249764519d0
      iwe=iwe+1
      weighta( 23, 75,  3)=                  0.05809915115837573085d0
      iwe=iwe+1
      weighta( 24, 75,  3)=                  0.12185493967949906358d0
      iwe=iwe+1
      weighta( 25, 75,  3)=                  0.04689654287057159338d0
      iwe=iwe+1
      weighta( 26, 75,  3)=                  0.34302787935709272427d0
      iwe=iwe+1
      weighta( 27, 75,  3)=                 -0.23102228695494875232d0
      iwe=iwe+1
      weighta( 28, 75,  3)=                  0.28179609005923178522d0
      iwe=iwe+1
      weighta( 29, 75,  3)=                 -0.24620230233847353873d0
      iwe=iwe+1
      weighta( 30, 75,  3)=                  0.31562875657729805301d0
      iwe=iwe+1
      weighta( 31, 75,  3)=                 -0.13362666740092973838d0
      iwe=iwe+1
      weighta( 32, 75,  3)=                  0.15690630872042546362d0
      iwe=iwe+1
      weighta( 33, 75,  3)=                  0.29615322575351554768d0
      iwe=iwe+1
      weighta( 34, 75,  3)=                 -0.18963664451688999613d0
      iwe=iwe+1
      weighta( 35, 75,  3)=                  0.24203582094439024530d0
      iwe=iwe+1
      weighta( 36, 75,  3)=                 -0.18514994051783556506d0
      iwe=iwe+1
      weighta( 37, 75,  3)=                 -0.19546975026971474820d0
      iwe=iwe+1
      weighta( 38, 75,  3)=                  0.31386334655016046025d0
      iwe=iwe+1
      weighta( 39, 75,  3)=                  0.11175450451408711072d0
      iwe=iwe+1
      weighta( 40, 75,  3)=                 -0.22068040989590859136d0
      iwe=iwe+1
      weighta( 41, 75,  3)=                  0.10943324441144421100d0
      iwe=iwe+1
      weighta( 42, 75,  3)=                 -0.32634173225099660787d0
      iwe=iwe+1
      weighta( 43, 75,  3)=                 -0.28911957579027680598d0
      iwe=iwe+1
      weighta( 44, 75,  3)=                  0.11204555117064311787d0
      iwe=iwe+1
      weighta( 45, 75,  3)=                 -0.30051478533540082472d0
      iwe=iwe+1
      weighta( 46, 75,  3)=                  0.36086265867643058103d0
      iwe=iwe+1
      weighta( 47, 75,  3)=                 -0.15853674850563792553d0
      iwe=iwe+1
      weighta( 48, 75,  3)=                  0.14044869556154468415d0
      iwe=iwe+1
      weighta( 49, 75,  3)=                 -0.26680994799999008249d0
      iwe=iwe+1
      weighta( 50, 75,  3)=                 -0.06173891867769891462d0
      iwe=iwe+1
      biasa( 75,  3)=                  1.32903136071357041992d0
      iwe=iwe+1
      weighta(  1, 76,  3)=                  0.12846594512617945383d0
      iwe=iwe+1
      weighta(  2, 76,  3)=                 -0.05452578545985860281d0
      iwe=iwe+1
      weighta(  3, 76,  3)=                 -0.01172710410768136764d0
      iwe=iwe+1
      weighta(  4, 76,  3)=                  0.19267989819604192103d0
      iwe=iwe+1
      weighta(  5, 76,  3)=                  0.42647860372558249464d0
      iwe=iwe+1
      weighta(  6, 76,  3)=                  0.10674103445803020951d0
      iwe=iwe+1
      weighta(  7, 76,  3)=                 -0.40555819878004173429d0
      iwe=iwe+1
      weighta(  8, 76,  3)=                  0.25282607307595506008d0
      iwe=iwe+1
      weighta(  9, 76,  3)=                 -0.26950246842779101986d0
      iwe=iwe+1
      weighta( 10, 76,  3)=                 -0.38138274845783787237d0
      iwe=iwe+1
      weighta( 11, 76,  3)=                 -0.28302330802994429826d0
      iwe=iwe+1
      weighta( 12, 76,  3)=                  0.11484811349125031987d0
      iwe=iwe+1
      weighta( 13, 76,  3)=                 -0.39386248222358827276d0
      iwe=iwe+1
      weighta( 14, 76,  3)=                  0.32968792673759533818d0
      iwe=iwe+1
      weighta( 15, 76,  3)=                  0.08330908753830700009d0
      iwe=iwe+1
      weighta( 16, 76,  3)=                 -0.28723858185678968757d0
      iwe=iwe+1
      weighta( 17, 76,  3)=                 -0.23962339521473993709d0
      iwe=iwe+1
      weighta( 18, 76,  3)=                  0.06013504305191658128d0
      iwe=iwe+1
      weighta( 19, 76,  3)=                 -0.21162956732401733140d0
      iwe=iwe+1
      weighta( 20, 76,  3)=                 -0.31520480737088180101d0
      iwe=iwe+1
      weighta( 21, 76,  3)=                  0.41470267907837882193d0
      iwe=iwe+1
      weighta( 22, 76,  3)=                 -0.12338979619807435850d0
      iwe=iwe+1
      weighta( 23, 76,  3)=                  0.07527013972569385203d0
      iwe=iwe+1
      weighta( 24, 76,  3)=                 -0.47933167749053345874d0
      iwe=iwe+1
      weighta( 25, 76,  3)=                  0.11611368089198227660d0
      iwe=iwe+1
      weighta( 26, 76,  3)=                  0.06469330823260703578d0
      iwe=iwe+1
      weighta( 27, 76,  3)=                  0.05533562633793265989d0
      iwe=iwe+1
      weighta( 28, 76,  3)=                 -0.10281630045936075712d0
      iwe=iwe+1
      weighta( 29, 76,  3)=                  0.07707392965640726123d0
      iwe=iwe+1
      weighta( 30, 76,  3)=                  0.39427466184419596162d0
      iwe=iwe+1
      weighta( 31, 76,  3)=                  0.49888352010633552069d0
      iwe=iwe+1
      weighta( 32, 76,  3)=                 -0.00384401808059134419d0
      iwe=iwe+1
      weighta( 33, 76,  3)=                  0.46058479370031352174d0
      iwe=iwe+1
      weighta( 34, 76,  3)=                 -0.13908077695590792544d0
      iwe=iwe+1
      weighta( 35, 76,  3)=                 -0.15153209735275080527d0
      iwe=iwe+1
      weighta( 36, 76,  3)=                  0.17537828167592767192d0
      iwe=iwe+1
      weighta( 37, 76,  3)=                  0.28924324961038083703d0
      iwe=iwe+1
      weighta( 38, 76,  3)=                  0.21311876539519300500d0
      iwe=iwe+1
      weighta( 39, 76,  3)=                 -0.39836010563220314307d0
      iwe=iwe+1
      weighta( 40, 76,  3)=                 -0.00712680094152657109d0
      iwe=iwe+1
      weighta( 41, 76,  3)=                  0.26942478842930539518d0
      iwe=iwe+1
      weighta( 42, 76,  3)=                 -0.00138943068898755026d0
      iwe=iwe+1
      weighta( 43, 76,  3)=                  0.01626046420440801360d0
      iwe=iwe+1
      weighta( 44, 76,  3)=                  0.27361320094655100510d0
      iwe=iwe+1
      weighta( 45, 76,  3)=                  0.09812323594230770718d0
      iwe=iwe+1
      weighta( 46, 76,  3)=                  0.10327489335539788429d0
      iwe=iwe+1
      weighta( 47, 76,  3)=                  0.20216741645251706805d0
      iwe=iwe+1
      weighta( 48, 76,  3)=                  0.03159930955424861826d0
      iwe=iwe+1
      weighta( 49, 76,  3)=                 -0.17812400942043898899d0
      iwe=iwe+1
      weighta( 50, 76,  3)=                  0.29871749459753899059d0
      iwe=iwe+1
      biasa( 76,  3)=                  1.34332119764599444700d0
      iwe=iwe+1
      weighta(  1, 77,  3)=                  0.37310530296369703862d0
      iwe=iwe+1
      weighta(  2, 77,  3)=                 -0.01805474572943236225d0
      iwe=iwe+1
      weighta(  3, 77,  3)=                  0.47175568660864036774d0
      iwe=iwe+1
      weighta(  4, 77,  3)=                  0.24011883856808166615d0
      iwe=iwe+1
      weighta(  5, 77,  3)=                  0.01998964610950810725d0
      iwe=iwe+1
      weighta(  6, 77,  3)=                  0.36047836455145804146d0
      iwe=iwe+1
      weighta(  7, 77,  3)=                  0.39346066023923564892d0
      iwe=iwe+1
      weighta(  8, 77,  3)=                 -0.33354957773845111957d0
      iwe=iwe+1
      weighta(  9, 77,  3)=                 -0.17323923657298137546d0
      iwe=iwe+1
      weighta( 10, 77,  3)=                  0.05118876178346692951d0
      iwe=iwe+1
      weighta( 11, 77,  3)=                  0.21761053912492739348d0
      iwe=iwe+1
      weighta( 12, 77,  3)=                  0.07436261480339512175d0
      iwe=iwe+1
      weighta( 13, 77,  3)=                 -0.03421796063512971831d0
      iwe=iwe+1
      weighta( 14, 77,  3)=                 -0.14505190689063368614d0
      iwe=iwe+1
      weighta( 15, 77,  3)=                  0.40076396749199144631d0
      iwe=iwe+1
      weighta( 16, 77,  3)=                 -0.17367398792060370627d0
      iwe=iwe+1
      weighta( 17, 77,  3)=                 -0.45210082316434840877d0
      iwe=iwe+1
      weighta( 18, 77,  3)=                  0.21969581724126455158d0
      iwe=iwe+1
      weighta( 19, 77,  3)=                  0.20563841009085559453d0
      iwe=iwe+1
      weighta( 20, 77,  3)=                 -0.59421927609761004963d0
      iwe=iwe+1
      weighta( 21, 77,  3)=                 -0.06745520778100264070d0
      iwe=iwe+1
      weighta( 22, 77,  3)=                  0.14787258147957146881d0
      iwe=iwe+1
      weighta( 23, 77,  3)=                  0.49276055363215898186d0
      iwe=iwe+1
      weighta( 24, 77,  3)=                  0.27328303196346442894d0
      iwe=iwe+1
      weighta( 25, 77,  3)=                  0.11385515396982477665d0
      iwe=iwe+1
      weighta( 26, 77,  3)=                 -0.23075650767238897743d0
      iwe=iwe+1
      weighta( 27, 77,  3)=                  0.29296341282585275367d0
      iwe=iwe+1
      weighta( 28, 77,  3)=                 -0.65394719912075915946d0
      iwe=iwe+1
      weighta( 29, 77,  3)=                 -0.22288901233854593875d0
      iwe=iwe+1
      weighta( 30, 77,  3)=                  0.19630336078095095287d0
      iwe=iwe+1
      weighta( 31, 77,  3)=                  0.08416938314954265643d0
      iwe=iwe+1
      weighta( 32, 77,  3)=                 -0.00714913194251027249d0
      iwe=iwe+1
      weighta( 33, 77,  3)=                 -0.08485306292697560038d0
      iwe=iwe+1
      weighta( 34, 77,  3)=                 -0.37232903917597448551d0
      iwe=iwe+1
      weighta( 35, 77,  3)=                  0.07127597810940916601d0
      iwe=iwe+1
      weighta( 36, 77,  3)=                 -0.52546892176754012027d0
      iwe=iwe+1
      weighta( 37, 77,  3)=                 -0.17762377417340180497d0
      iwe=iwe+1
      weighta( 38, 77,  3)=                  0.21372684046641438060d0
      iwe=iwe+1
      weighta( 39, 77,  3)=                 -0.03733044557847370326d0
      iwe=iwe+1
      weighta( 40, 77,  3)=                 -0.49772298082784249829d0
      iwe=iwe+1
      weighta( 41, 77,  3)=                  0.19381032165196218631d0
      iwe=iwe+1
      weighta( 42, 77,  3)=                  0.36982229342852662723d0
      iwe=iwe+1
      weighta( 43, 77,  3)=                 -0.49706199705756271001d0
      iwe=iwe+1
      weighta( 44, 77,  3)=                 -0.18176973689825429159d0
      iwe=iwe+1
      weighta( 45, 77,  3)=                 -0.09601383952309784642d0
      iwe=iwe+1
      weighta( 46, 77,  3)=                 -0.11438266155420895309d0
      iwe=iwe+1
      weighta( 47, 77,  3)=                  0.53225591717403397674d0
      iwe=iwe+1
      weighta( 48, 77,  3)=                 -0.37160294098636059701d0
      iwe=iwe+1
      weighta( 49, 77,  3)=                  0.31894345104177329597d0
      iwe=iwe+1
      weighta( 50, 77,  3)=                 -0.11140719284852518278d0
      iwe=iwe+1
      biasa( 77,  3)=                  1.36643550528267576638d0
      iwe=iwe+1
      weighta(  1, 78,  3)=                 -0.27055749766905201614d0
      iwe=iwe+1
      weighta(  2, 78,  3)=                  0.30041953931511500286d0
      iwe=iwe+1
      weighta(  3, 78,  3)=                 -0.17452470121143603965d0
      iwe=iwe+1
      weighta(  4, 78,  3)=                 -0.05811281782116190647d0
      iwe=iwe+1
      weighta(  5, 78,  3)=                 -0.18124042570027740218d0
      iwe=iwe+1
      weighta(  6, 78,  3)=                  0.07594618310317224896d0
      iwe=iwe+1
      weighta(  7, 78,  3)=                 -0.30871702719437599249d0
      iwe=iwe+1
      weighta(  8, 78,  3)=                 -0.47723506019804501355d0
      iwe=iwe+1
      weighta(  9, 78,  3)=                 -0.23816502084550036922d0
      iwe=iwe+1
      weighta( 10, 78,  3)=                 -0.49148789626102623584d0
      iwe=iwe+1
      weighta( 11, 78,  3)=                  0.46662930851084799544d0
      iwe=iwe+1
      weighta( 12, 78,  3)=                  0.22654777734194364580d0
      iwe=iwe+1
      weighta( 13, 78,  3)=                 -0.53307550475741027896d0
      iwe=iwe+1
      weighta( 14, 78,  3)=                 -0.32471610081052104668d0
      iwe=iwe+1
      weighta( 15, 78,  3)=                 -0.03972709895183249712d0
      iwe=iwe+1
      weighta( 16, 78,  3)=                  0.23156506915074029362d0
      iwe=iwe+1
      weighta( 17, 78,  3)=                  0.07153866738647608747d0
      iwe=iwe+1
      weighta( 18, 78,  3)=                 -0.28518769021330142577d0
      iwe=iwe+1
      weighta( 19, 78,  3)=                  0.37071563245396393915d0
      iwe=iwe+1
      weighta( 20, 78,  3)=                 -0.24497492894258837692d0
      iwe=iwe+1
      weighta( 21, 78,  3)=                  0.02137884622429595677d0
      iwe=iwe+1
      weighta( 22, 78,  3)=                  0.15005278177124201089d0
      iwe=iwe+1
      weighta( 23, 78,  3)=                 -0.03084821236696107249d0
      iwe=iwe+1
      weighta( 24, 78,  3)=                  0.12402719549919331843d0
      iwe=iwe+1
      weighta( 25, 78,  3)=                 -0.25628249050157253519d0
      iwe=iwe+1
      weighta( 26, 78,  3)=                  0.16223099587072489780d0
      iwe=iwe+1
      weighta( 27, 78,  3)=                  0.23718363706647632716d0
      iwe=iwe+1
      weighta( 28, 78,  3)=                 -0.27725747279995738293d0
      iwe=iwe+1
      weighta( 29, 78,  3)=                 -0.16689513786707035892d0
      iwe=iwe+1
      weighta( 30, 78,  3)=                 -0.27214200777528035902d0
      iwe=iwe+1
      weighta( 31, 78,  3)=                 -0.23527913021844198971d0
      iwe=iwe+1
      weighta( 32, 78,  3)=                 -0.48038939440301514638d0
      iwe=iwe+1
      weighta( 33, 78,  3)=                 -0.13363518314345868010d0
      iwe=iwe+1
      weighta( 34, 78,  3)=                  0.41451632686024292296d0
      iwe=iwe+1
      weighta( 35, 78,  3)=                 -0.34142119745405258291d0
      iwe=iwe+1
      weighta( 36, 78,  3)=                 -0.00231780159481611518d0
      iwe=iwe+1
      weighta( 37, 78,  3)=                 -0.03991594091107387998d0
      iwe=iwe+1
      weighta( 38, 78,  3)=                 -0.18341158644787716736d0
      iwe=iwe+1
      weighta( 39, 78,  3)=                 -0.19450732056485389720d0
      iwe=iwe+1
      weighta( 40, 78,  3)=                  0.01302105195562372128d0
      iwe=iwe+1
      weighta( 41, 78,  3)=                  0.02033252339754543572d0
      iwe=iwe+1
      weighta( 42, 78,  3)=                  0.25015466443823530795d0
      iwe=iwe+1
      weighta( 43, 78,  3)=                 -0.40698450935961100194d0
      iwe=iwe+1
      weighta( 44, 78,  3)=                 -0.24577185233060055980d0
      iwe=iwe+1
      weighta( 45, 78,  3)=                 -0.31768836889993046224d0
      iwe=iwe+1
      weighta( 46, 78,  3)=                 -0.08745859742992426189d0
      iwe=iwe+1
      weighta( 47, 78,  3)=                 -0.02404044472647772282d0
      iwe=iwe+1
      weighta( 48, 78,  3)=                  0.42895768335076372990d0
      iwe=iwe+1
      weighta( 49, 78,  3)=                 -0.07965396411778484509d0
      iwe=iwe+1
      weighta( 50, 78,  3)=                  0.48006576694991953680d0
      iwe=iwe+1
      biasa( 78,  3)=                 -1.49014734224163625242d0
      iwe=iwe+1
      weighta(  1, 79,  3)=                  0.02912314163206400006d0
      iwe=iwe+1
      weighta(  2, 79,  3)=                  0.47172905291551109341d0
      iwe=iwe+1
      weighta(  3, 79,  3)=                  0.06273359827555917423d0
      iwe=iwe+1
      weighta(  4, 79,  3)=                  0.01135686836163140798d0
      iwe=iwe+1
      weighta(  5, 79,  3)=                 -0.00926583860594329747d0
      iwe=iwe+1
      weighta(  6, 79,  3)=                  0.49795512349335591118d0
      iwe=iwe+1
      weighta(  7, 79,  3)=                  0.26802329395879748164d0
      iwe=iwe+1
      weighta(  8, 79,  3)=                  0.04459790163726986417d0
      iwe=iwe+1
      weighta(  9, 79,  3)=                  0.00916064571935812019d0
      iwe=iwe+1
      weighta( 10, 79,  3)=                 -0.28167516820882465556d0
      iwe=iwe+1
      weighta( 11, 79,  3)=                 -0.03848241492633679151d0
      iwe=iwe+1
      weighta( 12, 79,  3)=                 -0.13154213321942676007d0
      iwe=iwe+1
      weighta( 13, 79,  3)=                  0.29547819670681224613d0
      iwe=iwe+1
      weighta( 14, 79,  3)=                 -0.36078715867119753868d0
      iwe=iwe+1
      weighta( 15, 79,  3)=                  0.05299138898303337036d0
      iwe=iwe+1
      weighta( 16, 79,  3)=                  0.46639254598977281097d0
      iwe=iwe+1
      weighta( 17, 79,  3)=                  0.27536683394107508427d0
      iwe=iwe+1
      weighta( 18, 79,  3)=                  0.07401074367210636051d0
      iwe=iwe+1
      weighta( 19, 79,  3)=                  0.43661127337944410920d0
      iwe=iwe+1
      weighta( 20, 79,  3)=                 -0.03690639762879111690d0
      iwe=iwe+1
      weighta( 21, 79,  3)=                 -0.14474909273801395138d0
      iwe=iwe+1
      weighta( 22, 79,  3)=                 -0.39557604997079259812d0
      iwe=iwe+1
      weighta( 23, 79,  3)=                 -0.06320357863410189236d0
      iwe=iwe+1
      weighta( 24, 79,  3)=                  0.08301234482479008525d0
      iwe=iwe+1
      weighta( 25, 79,  3)=                 -0.43357998980295686664d0
      iwe=iwe+1
      weighta( 26, 79,  3)=                  0.15645261376685212773d0
      iwe=iwe+1
      weighta( 27, 79,  3)=                  0.13464154232193364935d0
      iwe=iwe+1
      weighta( 28, 79,  3)=                 -0.45353342311357236483d0
      iwe=iwe+1
      weighta( 29, 79,  3)=                  0.55679363303728701684d0
      iwe=iwe+1
      weighta( 30, 79,  3)=                  0.14709977872297125279d0
      iwe=iwe+1
      weighta( 31, 79,  3)=                 -0.10496975028474687941d0
      iwe=iwe+1
      weighta( 32, 79,  3)=                 -0.09762234587859741630d0
      iwe=iwe+1
      weighta( 33, 79,  3)=                 -0.02138844619830002763d0
      iwe=iwe+1
      weighta( 34, 79,  3)=                  0.46258709309547929589d0
      iwe=iwe+1
      weighta( 35, 79,  3)=                  0.16734377370178230016d0
      iwe=iwe+1
      weighta( 36, 79,  3)=                  0.04174013642811506830d0
      iwe=iwe+1
      weighta( 37, 79,  3)=                  0.12487695016849889584d0
      iwe=iwe+1
      weighta( 38, 79,  3)=                 -0.42836659022575268585d0
      iwe=iwe+1
      weighta( 39, 79,  3)=                  0.32648265740808946056d0
      iwe=iwe+1
      weighta( 40, 79,  3)=                  0.20646753119517879949d0
      iwe=iwe+1
      weighta( 41, 79,  3)=                 -0.18202440472084041589d0
      iwe=iwe+1
      weighta( 42, 79,  3)=                  0.09125496995493108388d0
      iwe=iwe+1
      weighta( 43, 79,  3)=                 -0.27440710252908656619d0
      iwe=iwe+1
      weighta( 44, 79,  3)=                  0.46686862325323180700d0
      iwe=iwe+1
      weighta( 45, 79,  3)=                  0.16328180936410915947d0
      iwe=iwe+1
      weighta( 46, 79,  3)=                 -0.03926323744466664323d0
      iwe=iwe+1
      weighta( 47, 79,  3)=                 -0.32694825994170229055d0
      iwe=iwe+1
      weighta( 48, 79,  3)=                 -0.03657548042275826639d0
      iwe=iwe+1
      weighta( 49, 79,  3)=                  0.30361030357480567332d0
      iwe=iwe+1
      weighta( 50, 79,  3)=                 -0.27494633669610257787d0
      iwe=iwe+1
      biasa( 79,  3)=                 -1.46890213310414696757d0
      iwe=iwe+1
      weighta(  1, 80,  3)=                 -0.07656689533104782397d0
      iwe=iwe+1
      weighta(  2, 80,  3)=                 -0.41136225304156287530d0
      iwe=iwe+1
      weighta(  3, 80,  3)=                  0.10385007491299344529d0
      iwe=iwe+1
      weighta(  4, 80,  3)=                 -0.39442178795163196359d0
      iwe=iwe+1
      weighta(  5, 80,  3)=                 -0.33060785324463132229d0
      iwe=iwe+1
      weighta(  6, 80,  3)=                 -0.03870880709903893463d0
      iwe=iwe+1
      weighta(  7, 80,  3)=                  0.39070630666752298454d0
      iwe=iwe+1
      weighta(  8, 80,  3)=                  0.14907325289634079657d0
      iwe=iwe+1
      weighta(  9, 80,  3)=                 -0.23731676768069967509d0
      iwe=iwe+1
      weighta( 10, 80,  3)=                  0.11493591119086538077d0
      iwe=iwe+1
      weighta( 11, 80,  3)=                 -0.19983512046373838600d0
      iwe=iwe+1
      weighta( 12, 80,  3)=                  0.40310552845630626129d0
      iwe=iwe+1
      weighta( 13, 80,  3)=                 -0.11453472985223571434d0
      iwe=iwe+1
      weighta( 14, 80,  3)=                 -0.42833208047799575802d0
      iwe=iwe+1
      weighta( 15, 80,  3)=                 -0.23177305526413768955d0
      iwe=iwe+1
      weighta( 16, 80,  3)=                  0.43434158512049919620d0
      iwe=iwe+1
      weighta( 17, 80,  3)=                  0.27280629755504343104d0
      iwe=iwe+1
      weighta( 18, 80,  3)=                 -0.06557189664300240584d0
      iwe=iwe+1
      weighta( 19, 80,  3)=                  0.67239793796651536884d0
      iwe=iwe+1
      weighta( 20, 80,  3)=                  0.18357214618222081337d0
      iwe=iwe+1
      weighta( 21, 80,  3)=                  0.12837233795411279180d0
      iwe=iwe+1
      weighta( 22, 80,  3)=                 -0.21926437869029746786d0
      iwe=iwe+1
      weighta( 23, 80,  3)=                  0.01601684704322953179d0
      iwe=iwe+1
      weighta( 24, 80,  3)=                  0.51931789088407465105d0
      iwe=iwe+1
      weighta( 25, 80,  3)=                 -0.83268684496322697974d0
      iwe=iwe+1
      weighta( 26, 80,  3)=                 -0.00891969335912945818d0
      iwe=iwe+1
      weighta( 27, 80,  3)=                  0.19073267073753294443d0
      iwe=iwe+1
      weighta( 28, 80,  3)=                  0.28683160380092487252d0
      iwe=iwe+1
      weighta( 29, 80,  3)=                 -0.23052403985075736736d0
      iwe=iwe+1
      weighta( 30, 80,  3)=                 -0.08446456432839495598d0
      iwe=iwe+1
      weighta( 31, 80,  3)=                  0.18214578776165699092d0
      iwe=iwe+1
      weighta( 32, 80,  3)=                 -0.43593006162697489625d0
      iwe=iwe+1
      weighta( 33, 80,  3)=                  0.01363818844090617863d0
      iwe=iwe+1
      weighta( 34, 80,  3)=                  0.70733979217983433685d0
      iwe=iwe+1
      weighta( 35, 80,  3)=                  0.13738069576573608277d0
      iwe=iwe+1
      weighta( 36, 80,  3)=                 -0.69403144785138748407d0
      iwe=iwe+1
      weighta( 37, 80,  3)=                 -0.29580466792315024405d0
      iwe=iwe+1
      weighta( 38, 80,  3)=                 -0.40145918709082850651d0
      iwe=iwe+1
      weighta( 39, 80,  3)=                  0.22162795990450370742d0
      iwe=iwe+1
      weighta( 40, 80,  3)=                 -0.04673433690328360202d0
      iwe=iwe+1
      weighta( 41, 80,  3)=                  0.06960344342826081665d0
      iwe=iwe+1
      weighta( 42, 80,  3)=                  0.05837956439773937106d0
      iwe=iwe+1
      weighta( 43, 80,  3)=                 -0.00179954784493458527d0
      iwe=iwe+1
      weighta( 44, 80,  3)=                  0.17824482736920971293d0
      iwe=iwe+1
      weighta( 45, 80,  3)=                  0.32428893214005016787d0
      iwe=iwe+1
      weighta( 46, 80,  3)=                 -0.10930715440168564667d0
      iwe=iwe+1
      weighta( 47, 80,  3)=                 -0.60443676944067437073d0
      iwe=iwe+1
      weighta( 48, 80,  3)=                 -0.35550706337779786059d0
      iwe=iwe+1
      weighta( 49, 80,  3)=                 -0.14896730627389201396d0
      iwe=iwe+1
      weighta( 50, 80,  3)=                  0.02685659525105065296d0
      iwe=iwe+1
      biasa( 80,  3)=                 -1.30382280534724603882d0
      iwe=iwe+1
      weighta(  1,  1,  4)=                  1.01980389103633539705d0
      iwe=iwe+1
      weighta(  2,  1,  4)=                  1.46904488882852812814d0
      iwe=iwe+1
      weighta(  3,  1,  4)=                  0.34628993884367098577d0
      iwe=iwe+1
      weighta(  4,  1,  4)=                 -1.24486754365371865561d0
      iwe=iwe+1
      weighta(  5,  1,  4)=                 -0.11978911185243065751d0
      iwe=iwe+1
      weighta(  6,  1,  4)=                 -1.91918669164261479487d0
      iwe=iwe+1
      weighta(  7,  1,  4)=                 -0.86536781526138129017d0
      iwe=iwe+1
      weighta(  8,  1,  4)=                  1.40009015094540445467d0
      iwe=iwe+1
      weighta(  9,  1,  4)=                  0.57550521333623116949d0
      iwe=iwe+1
      weighta( 10,  1,  4)=                  0.75411512107908851288d0
      iwe=iwe+1
      weighta( 11,  1,  4)=                  0.85272916640446638770d0
      iwe=iwe+1
      weighta( 12,  1,  4)=                 -1.01685977103936786570d0
      iwe=iwe+1
      weighta( 13,  1,  4)=                  1.31452538611192237816d0
      iwe=iwe+1
      weighta( 14,  1,  4)=                 -0.88337706269319904440d0
      iwe=iwe+1
      weighta( 15,  1,  4)=                  1.19578148826797558968d0
      iwe=iwe+1
      weighta( 16,  1,  4)=                  1.17057956808622520839d0
      iwe=iwe+1
      weighta( 17,  1,  4)=                  0.96334137434485611617d0
      iwe=iwe+1
      weighta( 18,  1,  4)=                 -0.77597276144242066653d0
      iwe=iwe+1
      weighta( 19,  1,  4)=                  0.78603691902028072214d0
      iwe=iwe+1
      weighta( 20,  1,  4)=                  0.79697549166928438602d0
      iwe=iwe+1
      weighta( 21,  1,  4)=                  0.33215040979991639070d0
      iwe=iwe+1
      weighta( 22,  1,  4)=                  0.76812165985698932502d0
      iwe=iwe+1
      weighta( 23,  1,  4)=                  0.83328487291218811261d0
      iwe=iwe+1
      weighta( 24,  1,  4)=                  0.79410139153443992655d0
      iwe=iwe+1
      weighta( 25,  1,  4)=                 -0.82992549341791843620d0
      iwe=iwe+1
      weighta( 26,  1,  4)=                  0.07143467823144780682d0
      iwe=iwe+1
      weighta( 27,  1,  4)=                 -0.28334848652243421752d0
      iwe=iwe+1
      weighta( 28,  1,  4)=                 -1.43750113696360548587d0
      iwe=iwe+1
      weighta( 29,  1,  4)=                 -0.42461636970655031176d0
      iwe=iwe+1
      weighta( 30,  1,  4)=                  0.48267431009452987922d0
      iwe=iwe+1
      weighta( 31,  1,  4)=                  0.62092350631526749272d0
      iwe=iwe+1
      weighta( 32,  1,  4)=                  0.57458040041061497760d0
      iwe=iwe+1
      weighta( 33,  1,  4)=                  1.13394069436507027859d0
      iwe=iwe+1
      weighta( 34,  1,  4)=                 -0.41660441437035294898d0
      iwe=iwe+1
      weighta( 35,  1,  4)=                 -0.74043755921244958085d0
      iwe=iwe+1
      weighta( 36,  1,  4)=                 -1.10288154798426196734d0
      iwe=iwe+1
      weighta( 37,  1,  4)=                  0.22680783853873706657d0
      iwe=iwe+1
      weighta( 38,  1,  4)=                 -0.42246425105691459700d0
      iwe=iwe+1
      weighta( 39,  1,  4)=                  0.81982789216096774165d0
      iwe=iwe+1
      weighta( 40,  1,  4)=                  0.82760733544870945799d0
      iwe=iwe+1
      weighta( 41,  1,  4)=                  0.82302728249669609983d0
      iwe=iwe+1
      weighta( 42,  1,  4)=                  0.85075244512491310367d0
      iwe=iwe+1
      weighta( 43,  1,  4)=                  0.55920762322148531709d0
      iwe=iwe+1
      weighta( 44,  1,  4)=                  0.01075080963470931988d0
      iwe=iwe+1
      weighta( 45,  1,  4)=                  0.85238600200094449821d0
      iwe=iwe+1
      weighta( 46,  1,  4)=                 -0.36135335387921130312d0
      iwe=iwe+1
      weighta( 47,  1,  4)=                  0.38423160724972166280d0
      iwe=iwe+1
      weighta( 48,  1,  4)=                  0.95419629375409142913d0
      iwe=iwe+1
      weighta( 49,  1,  4)=                  0.96574107495184169370d0
      iwe=iwe+1
      weighta( 50,  1,  4)=                  0.70951130013004659602d0
      iwe=iwe+1
      weighta( 51,  1,  4)=                  0.80787936589908238005d0
      iwe=iwe+1
      weighta( 52,  1,  4)=                  0.81149389815013694971d0
      iwe=iwe+1
      weighta( 53,  1,  4)=                  0.31729632908962657201d0
      iwe=iwe+1
      weighta( 54,  1,  4)=                 -1.01623057955566542532d0
      iwe=iwe+1
      weighta( 55,  1,  4)=                  0.78159399522999084553d0
      iwe=iwe+1
      weighta( 56,  1,  4)=                 -0.15156027800362267821d0
      iwe=iwe+1
      weighta( 57,  1,  4)=                 -1.27740697498336164273d0
      iwe=iwe+1
      weighta( 58,  1,  4)=                 -1.14473991096127503120d0
      iwe=iwe+1
      weighta( 59,  1,  4)=                 -0.61983569398321092248d0
      iwe=iwe+1
      weighta( 60,  1,  4)=                  1.13031761526078144975d0
      iwe=iwe+1
      weighta( 61,  1,  4)=                  0.76989699367931663243d0
      iwe=iwe+1
      weighta( 62,  1,  4)=                  0.13273718786980709394d0
      iwe=iwe+1
      weighta( 63,  1,  4)=                 -0.81184657844181595809d0
      iwe=iwe+1
      weighta( 64,  1,  4)=                  1.01222530853328751554d0
      iwe=iwe+1
      weighta( 65,  1,  4)=                 -0.87656439935399976804d0
      iwe=iwe+1
      weighta( 66,  1,  4)=                 -1.09950563468314221893d0
      iwe=iwe+1
      weighta( 67,  1,  4)=                 -0.94298823164361789129d0
      iwe=iwe+1
      weighta( 68,  1,  4)=                 -1.00664374868281747410d0
      iwe=iwe+1
      weighta( 69,  1,  4)=                 -0.61307106764116836572d0
      iwe=iwe+1
      weighta( 70,  1,  4)=                 -0.80838265209728021876d0
      iwe=iwe+1
      weighta( 71,  1,  4)=                 -0.94900488560847529040d0
      iwe=iwe+1
      weighta( 72,  1,  4)=                  0.52937337375263338046d0
      iwe=iwe+1
      weighta( 73,  1,  4)=                  0.69053405099331421901d0
      iwe=iwe+1
      weighta( 74,  1,  4)=                  0.55500793006294535381d0
      iwe=iwe+1
      weighta( 75,  1,  4)=                  0.07723420198844553608d0
      iwe=iwe+1
      weighta( 76,  1,  4)=                  0.81421877932663100363d0
      iwe=iwe+1
      weighta( 77,  1,  4)=                  1.09858934561064924829d0
      iwe=iwe+1
      weighta( 78,  1,  4)=                  0.82298583081262544070d0
      iwe=iwe+1
      weighta( 79,  1,  4)=                 -0.62795706024833652936d0
      iwe=iwe+1
      weighta( 80,  1,  4)=                  0.72830755540086988820d0
      iwe=iwe+1
      biasa(  1,  4)=                 -0.12273469025273757438d0
      iwe=iwe+1
      iwe= 5061
      if (iwe.ne.nwe) then
      write(*,*)'provided number of parameters ',nwe
      write(*,*)'actual number of parameters ',iwe
      write(*,*)'nwe not equal to iwe, check inputfiles or code'
      stop
      endif
      nhid=  2;noutput=  1
      nscale=ninput+noutput
      nlayer=nhid+2
      allocate(pdelb(nscale),pavgb(nscale))
      nodes(1)=ninput
      nodes(nlayer)=noutput
      nodes( 2)=50
      nodes( 3)=80
      nodemax=0
      do i=1,nlayer
       nodemax=max(nodemax,nodes(i))
      enddo
      allocate(weightb(nodemax,nodemax,2:nlayer),&
     & biasb(nodemax,2:nlayer))
      ifunc=  1;nwe=  5061
      pdelb(  1)=  0.1067562850000000d0
      pavgb(  1)=  0.1067562850000000d0
      pdelb(  2)=  0.3584514100000000d0
      pavgb(  2)=  0.5815815700000000d0
      pdelb(  3)=  0.2995175250000000d0
      pavgb(  3)=  0.2995175250000000d0
      pdelb(  4)=  0.2568390200000000d0
      pavgb(  4)=  0.2568390200000000d0
      pdelb(  5)=  0.0795311450000000d0
      pavgb(  5)=  0.0795311450000000d0
      pdelb(  6)=  0.1104549900000000d0
      pavgb(  6)=  0.1104549900000000d0
      pdelb(  7)=  0.0412553110000000d0
      pavgb(  7)=  0.0412553110000000d0
      pdelb(  8)=  0.1001943800000000d0
      pavgb(  8)=  0.1001943800000000d0
      pdelb(  9)=  0.0447088400000000d0
      pavgb(  9)=  0.0447088400000000d0
      pdelb( 10)=  0.0963427050000000d0
      pavgb( 10)=  0.0963427050000000d0
      pdelb( 11)=  0.0380176695000000d0
      pavgb( 11)=  0.0380176695000000d0
      pdelb( 12)=  0.1950274550000000d0
      pavgb( 12)=  0.1950274550000000d0
      pdelb( 13)=  0.1168573000000000d0
      pavgb( 13)=  0.1168573000000000d0
      pdelb( 14)=  0.0227938090000000d0
      pavgb( 14)=  0.0227938090000000d0
      pdelb( 15)=  0.1960274905000000d0
      pavgb( 15)=  0.2458145595000000d0
      pdelb( 16)=  0.0900038150000000d0
      pavgb( 16)=  0.0900038150000000d0
      pdelb( 17)=  0.1319325650000000d0
      pavgb( 17)=  0.1319325650000000d0
      pdelb( 18)=  2.5885233649999999d0
      pavgb( 18)=  2.4110914349999999d0
      iwe=  0
      weightb(  1,  1,  2)=                 -0.06409044017008197480d0
      iwe=iwe+1
      weightb(  2,  1,  2)=                  0.49156969840152270335d0
      iwe=iwe+1
      weightb(  3,  1,  2)=                  0.22561787887632145377d0
      iwe=iwe+1
      weightb(  4,  1,  2)=                  0.32752893629819807009d0
      iwe=iwe+1
      weightb(  5,  1,  2)=                 -0.34098645371402130921d0
      iwe=iwe+1
      weightb(  6,  1,  2)=                  0.32091791814173209474d0
      iwe=iwe+1
      weightb(  7,  1,  2)=                  1.05426761291963222433d0
      iwe=iwe+1
      weightb(  8,  1,  2)=                 -0.17792538314013084388d0
      iwe=iwe+1
      weightb(  9,  1,  2)=                  1.63507010761440341184d0
      iwe=iwe+1
      weightb( 10,  1,  2)=                  0.71594395589718839990d0
      iwe=iwe+1
      weightb( 11,  1,  2)=                  0.65338580353454156491d0
      iwe=iwe+1
      weightb( 12,  1,  2)=                  0.03535004295743808533d0
      iwe=iwe+1
      weightb( 13,  1,  2)=                 -0.17206435798584640562d0
      iwe=iwe+1
      weightb( 14,  1,  2)=                  0.04838083227536876807d0
      iwe=iwe+1
      weightb( 15,  1,  2)=                 -0.29369986710965434451d0
      iwe=iwe+1
      weightb( 16,  1,  2)=                 -1.56603815596537221388d0
      iwe=iwe+1
      weightb( 17,  1,  2)=                  0.34514762526310227564d0
      iwe=iwe+1
      biasb(  1,  2)=                  2.31988375809778979431d0
      iwe=iwe+1
      weightb(  1,  2,  2)=                 -0.91270677393970556235d0
      iwe=iwe+1
      weightb(  2,  2,  2)=                 -0.32900497914236626062d0
      iwe=iwe+1
      weightb(  3,  2,  2)=                  0.93648555576369263420d0
      iwe=iwe+1
      weightb(  4,  2,  2)=                  0.17100398147167253371d0
      iwe=iwe+1
      weightb(  5,  2,  2)=                  0.45232580430981955688d0
      iwe=iwe+1
      weightb(  6,  2,  2)=                 -0.44539168357795172470d0
      iwe=iwe+1
      weightb(  7,  2,  2)=                 -0.53919503859630868448d0
      iwe=iwe+1
      weightb(  8,  2,  2)=                 -0.09613317655722963817d0
      iwe=iwe+1
      weightb(  9,  2,  2)=                  2.05912865419648838383d0
      iwe=iwe+1
      weightb( 10,  2,  2)=                  0.29217622858865960334d0
      iwe=iwe+1
      weightb( 11,  2,  2)=                  0.80378456667857600682d0
      iwe=iwe+1
      weightb( 12,  2,  2)=                  0.86475431086524012780d0
      iwe=iwe+1
      weightb( 13,  2,  2)=                 -0.74308001261509304403d0
      iwe=iwe+1
      weightb( 14,  2,  2)=                 -0.25220670866804173471d0
      iwe=iwe+1
      weightb( 15,  2,  2)=                 -1.15313050577370224126d0
      iwe=iwe+1
      weightb( 16,  2,  2)=                 -0.46325198493101082953d0
      iwe=iwe+1
      weightb( 17,  2,  2)=                 -0.50372667063400211607d0
      iwe=iwe+1
      biasb(  2,  2)=                  2.07747203795444157493d0
      iwe=iwe+1
      weightb(  1,  3,  2)=                 -0.19789941306236333296d0
      iwe=iwe+1
      weightb(  2,  3,  2)=                 -0.01240138621065409869d0
      iwe=iwe+1
      weightb(  3,  3,  2)=                  0.81685209637135614003d0
      iwe=iwe+1
      weightb(  4,  3,  2)=                 -0.24791904482648044472d0
      iwe=iwe+1
      weightb(  5,  3,  2)=                  0.31013512951632399295d0
      iwe=iwe+1
      weightb(  6,  3,  2)=                 -0.77175101985681626715d0
      iwe=iwe+1
      weightb(  7,  3,  2)=                  0.01965535645314691465d0
      iwe=iwe+1
      weightb(  8,  3,  2)=                 -0.34702674193139254610d0
      iwe=iwe+1
      weightb(  9,  3,  2)=                 -0.26927518785438814275d0
      iwe=iwe+1
      weightb( 10,  3,  2)=                  0.26272109548861549699d0
      iwe=iwe+1
      weightb( 11,  3,  2)=                 -0.13252765095304522291d0
      iwe=iwe+1
      weightb( 12,  3,  2)=                 -0.32412307721050970244d0
      iwe=iwe+1
      weightb( 13,  3,  2)=                  0.92097109533187093700d0
      iwe=iwe+1
      weightb( 14,  3,  2)=                 -0.45797293644372738530d0
      iwe=iwe+1
      weightb( 15,  3,  2)=                  0.53333122338657845685d0
      iwe=iwe+1
      weightb( 16,  3,  2)=                 -0.31978651943991787121d0
      iwe=iwe+1
      weightb( 17,  3,  2)=                  0.09985443115581088547d0
      iwe=iwe+1
      biasb(  3,  2)=                  1.49624316416536040641d0
      iwe=iwe+1
      weightb(  1,  4,  2)=                  0.08700772968701497856d0
      iwe=iwe+1
      weightb(  2,  4,  2)=                  0.64596296525449481418d0
      iwe=iwe+1
      weightb(  3,  4,  2)=                  0.00850029631797379753d0
      iwe=iwe+1
      weightb(  4,  4,  2)=                  0.98708815100995095371d0
      iwe=iwe+1
      weightb(  5,  4,  2)=                  0.56009376243532305040d0
      iwe=iwe+1
      weightb(  6,  4,  2)=                  1.20573068022459217730d0
      iwe=iwe+1
      weightb(  7,  4,  2)=                 -0.13439656596559304558d0
      iwe=iwe+1
      weightb(  8,  4,  2)=                 -1.01779785832334446205d0
      iwe=iwe+1
      weightb(  9,  4,  2)=                  0.54476919045780658468d0
      iwe=iwe+1
      weightb( 10,  4,  2)=                  0.06903181795647528318d0
      iwe=iwe+1
      weightb( 11,  4,  2)=                 -0.77717458936010108683d0
      iwe=iwe+1
      weightb( 12,  4,  2)=                  0.28985277348966975719d0
      iwe=iwe+1
      weightb( 13,  4,  2)=                 -0.00068175310575858700d0
      iwe=iwe+1
      weightb( 14,  4,  2)=                  0.66068669947645886076d0
      iwe=iwe+1
      weightb( 15,  4,  2)=                 -0.23205534163459648478d0
      iwe=iwe+1
      weightb( 16,  4,  2)=                 -0.38979246766526021162d0
      iwe=iwe+1
      weightb( 17,  4,  2)=                  0.14079973406476348208d0
      iwe=iwe+1
      biasb(  4,  2)=                  1.90336638321080409142d0
      iwe=iwe+1
      weightb(  1,  5,  2)=                  0.91807289464792829481d0
      iwe=iwe+1
      weightb(  2,  5,  2)=                 -0.56645544351834808960d0
      iwe=iwe+1
      weightb(  3,  5,  2)=                 -0.53747166790715183993d0
      iwe=iwe+1
      weightb(  4,  5,  2)=                 -0.27642075090743334354d0
      iwe=iwe+1
      weightb(  5,  5,  2)=                  0.88822073809373502939d0
      iwe=iwe+1
      weightb(  6,  5,  2)=                  0.09624107789210915864d0
      iwe=iwe+1
      weightb(  7,  5,  2)=                  0.08958478033715970568d0
      iwe=iwe+1
      weightb(  8,  5,  2)=                  0.67486092426107358033d0
      iwe=iwe+1
      weightb(  9,  5,  2)=                 -1.77045194338493239172d0
      iwe=iwe+1
      weightb( 10,  5,  2)=                 -1.14807659029985931198d0
      iwe=iwe+1
      weightb( 11,  5,  2)=                 -0.25388641309016884984d0
      iwe=iwe+1
      weightb( 12,  5,  2)=                  0.45829256136278440081d0
      iwe=iwe+1
      weightb( 13,  5,  2)=                 -0.33077157833441062085d0
      iwe=iwe+1
      weightb( 14,  5,  2)=                 -0.23112042067656871080d0
      iwe=iwe+1
      weightb( 15,  5,  2)=                  0.35095305334890936066d0
      iwe=iwe+1
      weightb( 16,  5,  2)=                  0.23916089079424987518d0
      iwe=iwe+1
      weightb( 17,  5,  2)=                  0.56442396386182092094d0
      iwe=iwe+1
      biasb(  5,  2)=                 -1.61505650607723816314d0
      iwe=iwe+1
      weightb(  1,  6,  2)=                 -0.41633633748166076760d0
      iwe=iwe+1
      weightb(  2,  6,  2)=                 -0.14856064950739983344d0
      iwe=iwe+1
      weightb(  3,  6,  2)=                 -0.68121335219539225214d0
      iwe=iwe+1
      weightb(  4,  6,  2)=                  0.47068971205381476830d0
      iwe=iwe+1
      weightb(  5,  6,  2)=                 -0.46836214912874846172d0
      iwe=iwe+1
      weightb(  6,  6,  2)=                  0.60960883148028155443d0
      iwe=iwe+1
      weightb(  7,  6,  2)=                 -0.07419956125532503610d0
      iwe=iwe+1
      weightb(  8,  6,  2)=                 -0.40793176466691116744d0
      iwe=iwe+1
      weightb(  9,  6,  2)=                 -0.65527239381531343643d0
      iwe=iwe+1
      weightb( 10,  6,  2)=                  0.67612453879874734319d0
      iwe=iwe+1
      weightb( 11,  6,  2)=                 -0.11042173236255480029d0
      iwe=iwe+1
      weightb( 12,  6,  2)=                  0.56646413229627867736d0
      iwe=iwe+1
      weightb( 13,  6,  2)=                  0.34490216492548458893d0
      iwe=iwe+1
      weightb( 14,  6,  2)=                 -1.04907041791257027441d0
      iwe=iwe+1
      weightb( 15,  6,  2)=                  0.47324736422331398211d0
      iwe=iwe+1
      weightb( 16,  6,  2)=                  0.29726862756636812657d0
      iwe=iwe+1
      weightb( 17,  6,  2)=                 -0.47629592368764345212d0
      iwe=iwe+1
      biasb(  6,  2)=                  1.64457048804306937839d0
      iwe=iwe+1
      weightb(  1,  7,  2)=                 -0.46417309066765777281d0
      iwe=iwe+1
      weightb(  2,  7,  2)=                  0.64768876110138173807d0
      iwe=iwe+1
      weightb(  3,  7,  2)=                 -0.81240862906388400244d0
      iwe=iwe+1
      weightb(  4,  7,  2)=                 -0.06950153445133644414d0
      iwe=iwe+1
      weightb(  5,  7,  2)=                  0.41935063456751781041d0
      iwe=iwe+1
      weightb(  6,  7,  2)=                 -0.06372679068291690896d0
      iwe=iwe+1
      weightb(  7,  7,  2)=                 -0.03677273098638248611d0
      iwe=iwe+1
      weightb(  8,  7,  2)=                  0.10604915143074024331d0
      iwe=iwe+1
      weightb(  9,  7,  2)=                  0.71743415068255145250d0
      iwe=iwe+1
      weightb( 10,  7,  2)=                 -0.31468935105796103091d0
      iwe=iwe+1
      weightb( 11,  7,  2)=                  0.08284097426714968904d0
      iwe=iwe+1
      weightb( 12,  7,  2)=                  0.19308098193832259892d0
      iwe=iwe+1
      weightb( 13,  7,  2)=                 -0.35581462592783558163d0
      iwe=iwe+1
      weightb( 14,  7,  2)=                 -0.03459320524603369529d0
      iwe=iwe+1
      weightb( 15,  7,  2)=                 -0.78776984378180070490d0
      iwe=iwe+1
      weightb( 16,  7,  2)=                 -0.90265047911369777900d0
      iwe=iwe+1
      weightb( 17,  7,  2)=                 -0.22426081363925917667d0
      iwe=iwe+1
      biasb(  7,  2)=                  1.11809161151630598319d0
      iwe=iwe+1
      weightb(  1,  8,  2)=                 -0.76976915928408018441d0
      iwe=iwe+1
      weightb(  2,  8,  2)=                  0.04719149337181778592d0
      iwe=iwe+1
      weightb(  3,  8,  2)=                  0.51720966952646074688d0
      iwe=iwe+1
      weightb(  4,  8,  2)=                 -0.64866666833014652305d0
      iwe=iwe+1
      weightb(  5,  8,  2)=                  0.30803652240143386543d0
      iwe=iwe+1
      weightb(  6,  8,  2)=                  0.56641545188426933866d0
      iwe=iwe+1
      weightb(  7,  8,  2)=                 -0.25739815769175977689d0
      iwe=iwe+1
      weightb(  8,  8,  2)=                  0.55963210935250506939d0
      iwe=iwe+1
      weightb(  9,  8,  2)=                 -0.18220734494467272224d0
      iwe=iwe+1
      weightb( 10,  8,  2)=                  0.27952331992715745423d0
      iwe=iwe+1
      weightb( 11,  8,  2)=                 -0.73381589213321474219d0
      iwe=iwe+1
      weightb( 12,  8,  2)=                 -0.45970190943409189321d0
      iwe=iwe+1
      weightb( 13,  8,  2)=                 -0.37953514218029132943d0
      iwe=iwe+1
      weightb( 14,  8,  2)=                 -0.69584114928299278802d0
      iwe=iwe+1
      weightb( 15,  8,  2)=                 -0.02821707223567214082d0
      iwe=iwe+1
      weightb( 16,  8,  2)=                  0.26940906684911114510d0
      iwe=iwe+1
      weightb( 17,  8,  2)=                  0.39620744836894628005d0
      iwe=iwe+1
      biasb(  8,  2)=                  0.97565527741480040369d0
      iwe=iwe+1
      weightb(  1,  9,  2)=                  0.16475082309195940300d0
      iwe=iwe+1
      weightb(  2,  9,  2)=                  0.00077863036998476569d0
      iwe=iwe+1
      weightb(  3,  9,  2)=                  0.18609693242691230375d0
      iwe=iwe+1
      weightb(  4,  9,  2)=                 -0.02090954319483553925d0
      iwe=iwe+1
      weightb(  5,  9,  2)=                 -0.19369272963058006831d0
      iwe=iwe+1
      weightb(  6,  9,  2)=                  1.11539350509383550225d0
      iwe=iwe+1
      weightb(  7,  9,  2)=                  0.34828154705713032513d0
      iwe=iwe+1
      weightb(  8,  9,  2)=                 -1.12704743821081643240d0
      iwe=iwe+1
      weightb(  9,  9,  2)=                  0.03132402460392626209d0
      iwe=iwe+1
      weightb( 10,  9,  2)=                  0.28216818999150722336d0
      iwe=iwe+1
      weightb( 11,  9,  2)=                  0.19422403155075057546d0
      iwe=iwe+1
      weightb( 12,  9,  2)=                 -0.83978700378739168375d0
      iwe=iwe+1
      weightb( 13,  9,  2)=                  0.26716526349783986660d0
      iwe=iwe+1
      weightb( 14,  9,  2)=                 -0.29488096257274154510d0
      iwe=iwe+1
      weightb( 15,  9,  2)=                 -0.44014230679540300439d0
      iwe=iwe+1
      weightb( 16,  9,  2)=                 -1.08538911959354500425d0
      iwe=iwe+1
      weightb( 17,  9,  2)=                  0.06018098120401456363d0
      iwe=iwe+1
      biasb(  9,  2)=                 -1.53190630011371209385d0
      iwe=iwe+1
      weightb(  1, 10,  2)=                 -0.36920402146793696030d0
      iwe=iwe+1
      weightb(  2, 10,  2)=                 -0.05783296939065044051d0
      iwe=iwe+1
      weightb(  3, 10,  2)=                 -0.31021633898766320936d0
      iwe=iwe+1
      weightb(  4, 10,  2)=                  1.19357736504920297627d0
      iwe=iwe+1
      weightb(  5, 10,  2)=                 -0.01746686893841650767d0
      iwe=iwe+1
      weightb(  6, 10,  2)=                 -1.00200712363864519183d0
      iwe=iwe+1
      weightb(  7, 10,  2)=                  0.40666244292521808168d0
      iwe=iwe+1
      weightb(  8, 10,  2)=                 -0.44674934039945779496d0
      iwe=iwe+1
      weightb(  9, 10,  2)=                 -0.00408803159093649657d0
      iwe=iwe+1
      weightb( 10, 10,  2)=                  0.78394746506898804750d0
      iwe=iwe+1
      weightb( 11, 10,  2)=                  0.40824736944228007252d0
      iwe=iwe+1
      weightb( 12, 10,  2)=                 -0.40816685268587832303d0
      iwe=iwe+1
      weightb( 13, 10,  2)=                 -0.35319989454096989423d0
      iwe=iwe+1
      weightb( 14, 10,  2)=                  0.60415467053029914268d0
      iwe=iwe+1
      weightb( 15, 10,  2)=                  0.24122283257167148607d0
      iwe=iwe+1
      weightb( 16, 10,  2)=                  0.61482940908736527508d0
      iwe=iwe+1
      weightb( 17, 10,  2)=                  0.01746249215150020781d0
      iwe=iwe+1
      biasb( 10,  2)=                  1.38919951966175414526d0
      iwe=iwe+1
      weightb(  1, 11,  2)=                  1.06415052846902002948d0
      iwe=iwe+1
      weightb(  2, 11,  2)=                 -0.55045510692207089143d0
      iwe=iwe+1
      weightb(  3, 11,  2)=                 -0.34531507129907546005d0
      iwe=iwe+1
      weightb(  4, 11,  2)=                 -0.37086921541807843505d0
      iwe=iwe+1
      weightb(  5, 11,  2)=                 -0.67293144697848683577d0
      iwe=iwe+1
      weightb(  6, 11,  2)=                 -0.64504999374902394216d0
      iwe=iwe+1
      weightb(  7, 11,  2)=                  0.21211956123943034869d0
      iwe=iwe+1
      weightb(  8, 11,  2)=                  0.15157301150043706039d0
      iwe=iwe+1
      weightb(  9, 11,  2)=                 -1.12039956425328113276d0
      iwe=iwe+1
      weightb( 10, 11,  2)=                 -0.04004888341627517445d0
      iwe=iwe+1
      weightb( 11, 11,  2)=                  0.52695426230651587485d0
      iwe=iwe+1
      weightb( 12, 11,  2)=                  0.07787768943303205460d0
      iwe=iwe+1
      weightb( 13, 11,  2)=                  0.16572148839266839793d0
      iwe=iwe+1
      weightb( 14, 11,  2)=                 -0.00222757986878873923d0
      iwe=iwe+1
      weightb( 15, 11,  2)=                  0.40214251513823245920d0
      iwe=iwe+1
      weightb( 16, 11,  2)=                 -0.50385862281728754919d0
      iwe=iwe+1
      weightb( 17, 11,  2)=                  0.62491071215121984928d0
      iwe=iwe+1
      biasb( 11,  2)=                 -0.89873086733382989699d0
      iwe=iwe+1
      weightb(  1, 12,  2)=                 -0.25658978420401029608d0
      iwe=iwe+1
      weightb(  2, 12,  2)=                 -0.81756932531192694213d0
      iwe=iwe+1
      weightb(  3, 12,  2)=                  1.39227801890078883851d0
      iwe=iwe+1
      weightb(  4, 12,  2)=                 -0.09364405210316172068d0
      iwe=iwe+1
      weightb(  5, 12,  2)=                  0.49883571354441630374d0
      iwe=iwe+1
      weightb(  6, 12,  2)=                 -0.16029817297739579196d0
      iwe=iwe+1
      weightb(  7, 12,  2)=                 -0.36077927503972384571d0
      iwe=iwe+1
      weightb(  8, 12,  2)=                  0.51455562527524878469d0
      iwe=iwe+1
      weightb(  9, 12,  2)=                  1.11056573923916634961d0
      iwe=iwe+1
      weightb( 10, 12,  2)=                 -0.15980045966233444310d0
      iwe=iwe+1
      weightb( 11, 12,  2)=                  0.06826629846849416317d0
      iwe=iwe+1
      weightb( 12, 12,  2)=                 -0.63576587863390776612d0
      iwe=iwe+1
      weightb( 13, 12,  2)=                  0.19242536035584431597d0
      iwe=iwe+1
      weightb( 14, 12,  2)=                 -0.67665366998840459356d0
      iwe=iwe+1
      weightb( 15, 12,  2)=                  0.47556876980213896866d0
      iwe=iwe+1
      weightb( 16, 12,  2)=                  0.07031448112872923373d0
      iwe=iwe+1
      weightb( 17, 12,  2)=                 -0.02052237662808044719d0
      iwe=iwe+1
      biasb( 12,  2)=                  1.22670069077351362452d0
      iwe=iwe+1
      weightb(  1, 13,  2)=                 -0.59234242629026945259d0
      iwe=iwe+1
      weightb(  2, 13,  2)=                  0.49665025546438956727d0
      iwe=iwe+1
      weightb(  3, 13,  2)=                  0.03637429006875707999d0
      iwe=iwe+1
      weightb(  4, 13,  2)=                  0.35753825654756909991d0
      iwe=iwe+1
      weightb(  5, 13,  2)=                  0.60469350651889730575d0
      iwe=iwe+1
      weightb(  6, 13,  2)=                  0.58811526221195531416d0
      iwe=iwe+1
      weightb(  7, 13,  2)=                  0.09031490212105604265d0
      iwe=iwe+1
      weightb(  8, 13,  2)=                  0.07504876176996337633d0
      iwe=iwe+1
      weightb(  9, 13,  2)=                  0.20477231835455841913d0
      iwe=iwe+1
      weightb( 10, 13,  2)=                  0.74265599955757355399d0
      iwe=iwe+1
      weightb( 11, 13,  2)=                 -0.40022218015240768052d0
      iwe=iwe+1
      weightb( 12, 13,  2)=                 -0.15794101128825244196d0
      iwe=iwe+1
      weightb( 13, 13,  2)=                  0.59646366142704410063d0
      iwe=iwe+1
      weightb( 14, 13,  2)=                 -0.72360834212884372896d0
      iwe=iwe+1
      weightb( 15, 13,  2)=                 -0.43867602426322893638d0
      iwe=iwe+1
      weightb( 16, 13,  2)=                  0.09835724158076197821d0
      iwe=iwe+1
      weightb( 17, 13,  2)=                  0.60415804879847334607d0
      iwe=iwe+1
      biasb( 13,  2)=                  1.12870752065776658313d0
      iwe=iwe+1
      weightb(  1, 14,  2)=                  0.03541553568586319062d0
      iwe=iwe+1
      weightb(  2, 14,  2)=                 -0.15609480284759033597d0
      iwe=iwe+1
      weightb(  3, 14,  2)=                 -0.81733088772576578673d0
      iwe=iwe+1
      weightb(  4, 14,  2)=                  0.79761563030699345056d0
      iwe=iwe+1
      weightb(  5, 14,  2)=                  0.92889678872090797324d0
      iwe=iwe+1
      weightb(  6, 14,  2)=                 -0.45615758478705392687d0
      iwe=iwe+1
      weightb(  7, 14,  2)=                  0.47912955872801249457d0
      iwe=iwe+1
      weightb(  8, 14,  2)=                  0.29329922231175670211d0
      iwe=iwe+1
      weightb(  9, 14,  2)=                  0.68990378301842525399d0
      iwe=iwe+1
      weightb( 10, 14,  2)=                 -1.65762986503485243439d0
      iwe=iwe+1
      weightb( 11, 14,  2)=                  0.56617354059638791419d0
      iwe=iwe+1
      weightb( 12, 14,  2)=                 -0.85999232719791707247d0
      iwe=iwe+1
      weightb( 13, 14,  2)=                 -0.16839148365813255692d0
      iwe=iwe+1
      weightb( 14, 14,  2)=                 -0.49502866612542423264d0
      iwe=iwe+1
      weightb( 15, 14,  2)=                  0.71864074454440574069d0
      iwe=iwe+1
      weightb( 16, 14,  2)=                  0.00577157692211877245d0
      iwe=iwe+1
      weightb( 17, 14,  2)=                  0.19680110780787901659d0
      iwe=iwe+1
      biasb( 14,  2)=                  0.85712293344885059909d0
      iwe=iwe+1
      weightb(  1, 15,  2)=                  0.33562345570268159456d0
      iwe=iwe+1
      weightb(  2, 15,  2)=                  0.74393562146525682444d0
      iwe=iwe+1
      weightb(  3, 15,  2)=                 -0.32062073953904851598d0
      iwe=iwe+1
      weightb(  4, 15,  2)=                  0.96490768227150658376d0
      iwe=iwe+1
      weightb(  5, 15,  2)=                  0.07053896091280516256d0
      iwe=iwe+1
      weightb(  6, 15,  2)=                  0.75293380236470464073d0
      iwe=iwe+1
      weightb(  7, 15,  2)=                  0.07044762129225166924d0
      iwe=iwe+1
      weightb(  8, 15,  2)=                 -0.98349327605316361200d0
      iwe=iwe+1
      weightb(  9, 15,  2)=                  1.52149954792530794911d0
      iwe=iwe+1
      weightb( 10, 15,  2)=                 -0.33965307367943825545d0
      iwe=iwe+1
      weightb( 11, 15,  2)=                 -0.44372001017369600007d0
      iwe=iwe+1
      weightb( 12, 15,  2)=                  0.45380753878505064591d0
      iwe=iwe+1
      weightb( 13, 15,  2)=                  0.01959043140007378503d0
      iwe=iwe+1
      weightb( 14, 15,  2)=                 -0.45369865704446993293d0
      iwe=iwe+1
      weightb( 15, 15,  2)=                 -0.43586403794976491533d0
      iwe=iwe+1
      weightb( 16, 15,  2)=                 -0.92734114353635577199d0
      iwe=iwe+1
      weightb( 17, 15,  2)=                 -0.99884767386906092579d0
      iwe=iwe+1
      biasb( 15,  2)=                 -0.57754402268089510830d0
      iwe=iwe+1
      weightb(  1, 16,  2)=                 -0.35837244258441408595d0
      iwe=iwe+1
      weightb(  2, 16,  2)=                 -0.77744440842093520683d0
      iwe=iwe+1
      weightb(  3, 16,  2)=                 -0.52194147923192812932d0
      iwe=iwe+1
      weightb(  4, 16,  2)=                  0.27952898303244938516d0
      iwe=iwe+1
      weightb(  5, 16,  2)=                  0.06704019773022922013d0
      iwe=iwe+1
      weightb(  6, 16,  2)=                 -0.53426831629869020457d0
      iwe=iwe+1
      weightb(  7, 16,  2)=                 -0.64197900888932657448d0
      iwe=iwe+1
      weightb(  8, 16,  2)=                 -0.16092908498547769947d0
      iwe=iwe+1
      weightb(  9, 16,  2)=                  0.69869643427847261119d0
      iwe=iwe+1
      weightb( 10, 16,  2)=                 -1.46818215735167112435d0
      iwe=iwe+1
      weightb( 11, 16,  2)=                 -0.06319374369893034082d0
      iwe=iwe+1
      weightb( 12, 16,  2)=                  0.36952927989425571331d0
      iwe=iwe+1
      weightb( 13, 16,  2)=                 -0.37942784094625947588d0
      iwe=iwe+1
      weightb( 14, 16,  2)=                 -0.27689518088158909803d0
      iwe=iwe+1
      weightb( 15, 16,  2)=                  1.02977003820022705582d0
      iwe=iwe+1
      weightb( 16, 16,  2)=                  0.99947642900689126488d0
      iwe=iwe+1
      weightb( 17, 16,  2)=                 -0.16130816592498908868d0
      iwe=iwe+1
      biasb( 16,  2)=                  0.50239940383232783994d0
      iwe=iwe+1
      weightb(  1, 17,  2)=                  0.53699237051194137482d0
      iwe=iwe+1
      weightb(  2, 17,  2)=                  0.11196177868569809344d0
      iwe=iwe+1
      weightb(  3, 17,  2)=                  0.69727109106434992380d0
      iwe=iwe+1
      weightb(  4, 17,  2)=                  0.27043446673497473220d0
      iwe=iwe+1
      weightb(  5, 17,  2)=                 -0.26428030738473912153d0
      iwe=iwe+1
      weightb(  6, 17,  2)=                 -0.47094661751543442918d0
      iwe=iwe+1
      weightb(  7, 17,  2)=                  0.38746897435401889132d0
      iwe=iwe+1
      weightb(  8, 17,  2)=                 -0.25675778426887602146d0
      iwe=iwe+1
      weightb(  9, 17,  2)=                  0.54261033597877228463d0
      iwe=iwe+1
      weightb( 10, 17,  2)=                  0.84009536178023902497d0
      iwe=iwe+1
      weightb( 11, 17,  2)=                 -0.55011942598297958185d0
      iwe=iwe+1
      weightb( 12, 17,  2)=                  0.72113296073018773313d0
      iwe=iwe+1
      weightb( 13, 17,  2)=                 -0.80606380619947493038d0
      iwe=iwe+1
      weightb( 14, 17,  2)=                 -0.07948842863129264302d0
      iwe=iwe+1
      weightb( 15, 17,  2)=                  0.51672441469422802918d0
      iwe=iwe+1
      weightb( 16, 17,  2)=                 -0.14470158189383688918d0
      iwe=iwe+1
      weightb( 17, 17,  2)=                 -0.21909580868235389861d0
      iwe=iwe+1
      biasb( 17,  2)=                 -0.14696082474299720921d0
      iwe=iwe+1
      weightb(  1, 18,  2)=                 -0.47471627123965015604d0
      iwe=iwe+1
      weightb(  2, 18,  2)=                  0.33792092390086014841d0
      iwe=iwe+1
      weightb(  3, 18,  2)=                 -0.94711736497507215127d0
      iwe=iwe+1
      weightb(  4, 18,  2)=                  1.10941798777066402693d0
      iwe=iwe+1
      weightb(  5, 18,  2)=                 -0.20414910630439941919d0
      iwe=iwe+1
      weightb(  6, 18,  2)=                 -0.08798195710476340581d0
      iwe=iwe+1
      weightb(  7, 18,  2)=                  0.42952156569205091063d0
      iwe=iwe+1
      weightb(  8, 18,  2)=                 -0.85489022356214516840d0
      iwe=iwe+1
      weightb(  9, 18,  2)=                 -1.64971383431001639153d0
      iwe=iwe+1
      weightb( 10, 18,  2)=                  0.61780904048669049722d0
      iwe=iwe+1
      weightb( 11, 18,  2)=                  0.64994435923773508090d0
      iwe=iwe+1
      weightb( 12, 18,  2)=                  0.22360980023794074789d0
      iwe=iwe+1
      weightb( 13, 18,  2)=                  0.08049483058214884634d0
      iwe=iwe+1
      weightb( 14, 18,  2)=                  0.23380863849912056351d0
      iwe=iwe+1
      weightb( 15, 18,  2)=                  0.29167447827522158255d0
      iwe=iwe+1
      weightb( 16, 18,  2)=                  1.22296310929448703853d0
      iwe=iwe+1
      weightb( 17, 18,  2)=                 -0.43789165732811180520d0
      iwe=iwe+1
      biasb( 18,  2)=                  0.70662466806325963109d0
      iwe=iwe+1
      weightb(  1, 19,  2)=                  0.45194989878796854033d0
      iwe=iwe+1
      weightb(  2, 19,  2)=                  0.07568022406511618061d0
      iwe=iwe+1
      weightb(  3, 19,  2)=                 -0.15923521841349411177d0
      iwe=iwe+1
      weightb(  4, 19,  2)=                  0.53473024004518254770d0
      iwe=iwe+1
      weightb(  5, 19,  2)=                  0.06629857230840305315d0
      iwe=iwe+1
      weightb(  6, 19,  2)=                  0.68890684087529674429d0
      iwe=iwe+1
      weightb(  7, 19,  2)=                 -0.82705541219417022525d0
      iwe=iwe+1
      weightb(  8, 19,  2)=                  0.45793372333363258075d0
      iwe=iwe+1
      weightb(  9, 19,  2)=                  1.15800745263846982525d0
      iwe=iwe+1
      weightb( 10, 19,  2)=                 -0.23939375345096589043d0
      iwe=iwe+1
      weightb( 11, 19,  2)=                  0.16868875546528794285d0
      iwe=iwe+1
      weightb( 12, 19,  2)=                  0.35594785409084750416d0
      iwe=iwe+1
      weightb( 13, 19,  2)=                 -0.76863266997441370698d0
      iwe=iwe+1
      weightb( 14, 19,  2)=                  0.28086749232821595079d0
      iwe=iwe+1
      weightb( 15, 19,  2)=                 -0.16650097754191092725d0
      iwe=iwe+1
      weightb( 16, 19,  2)=                 -0.44133043458250070801d0
      iwe=iwe+1
      weightb( 17, 19,  2)=                 -0.38237303449429976832d0
      iwe=iwe+1
      biasb( 19,  2)=                 -0.30175145996517882541d0
      iwe=iwe+1
      weightb(  1, 20,  2)=                  0.09203022752098065362d0
      iwe=iwe+1
      weightb(  2, 20,  2)=                 -0.00522008620515328897d0
      iwe=iwe+1
      weightb(  3, 20,  2)=                  0.51970432947366829168d0
      iwe=iwe+1
      weightb(  4, 20,  2)=                  1.31576433751827437391d0
      iwe=iwe+1
      weightb(  5, 20,  2)=                  0.02973193502946472680d0
      iwe=iwe+1
      weightb(  6, 20,  2)=                 -0.68241432595278350703d0
      iwe=iwe+1
      weightb(  7, 20,  2)=                  0.03891853599595558599d0
      iwe=iwe+1
      weightb(  8, 20,  2)=                 -0.50851783092024316346d0
      iwe=iwe+1
      weightb(  9, 20,  2)=                  0.36516689659606138552d0
      iwe=iwe+1
      weightb( 10, 20,  2)=                 -0.24943152267238588582d0
      iwe=iwe+1
      weightb( 11, 20,  2)=                  0.55980404893954549550d0
      iwe=iwe+1
      weightb( 12, 20,  2)=                  0.21961956151106962198d0
      iwe=iwe+1
      weightb( 13, 20,  2)=                 -0.66322903707293812126d0
      iwe=iwe+1
      weightb( 14, 20,  2)=                 -0.13132569869748059177d0
      iwe=iwe+1
      weightb( 15, 20,  2)=                 -0.54487738651217332286d0
      iwe=iwe+1
      weightb( 16, 20,  2)=                 -0.87673296143312640094d0
      iwe=iwe+1
      weightb( 17, 20,  2)=                  0.22732985044688625020d0
      iwe=iwe+1
      biasb( 20,  2)=                 -0.37290037127004099782d0
      iwe=iwe+1
      weightb(  1, 21,  2)=                  0.11197119404127504894d0
      iwe=iwe+1
      weightb(  2, 21,  2)=                  0.72643117393175848928d0
      iwe=iwe+1
      weightb(  3, 21,  2)=                 -0.80875062865109692556d0
      iwe=iwe+1
      weightb(  4, 21,  2)=                 -0.40770832689684727290d0
      iwe=iwe+1
      weightb(  5, 21,  2)=                  0.70201852497475047965d0
      iwe=iwe+1
      weightb(  6, 21,  2)=                  0.22772804151767547798d0
      iwe=iwe+1
      weightb(  7, 21,  2)=                 -1.00457212223457537092d0
      iwe=iwe+1
      weightb(  8, 21,  2)=                 -1.12695318509042752275d0
      iwe=iwe+1
      weightb(  9, 21,  2)=                 -1.55267853924599630311d0
      iwe=iwe+1
      weightb( 10, 21,  2)=                 -0.38585178402365472028d0
      iwe=iwe+1
      weightb( 11, 21,  2)=                 -0.89670917169381836320d0
      iwe=iwe+1
      weightb( 12, 21,  2)=                  0.30525213129087680475d0
      iwe=iwe+1
      weightb( 13, 21,  2)=                  1.32550368948901153843d0
      iwe=iwe+1
      weightb( 14, 21,  2)=                  0.23647790982224595191d0
      iwe=iwe+1
      weightb( 15, 21,  2)=                 -0.27809980372540676896d0
      iwe=iwe+1
      weightb( 16, 21,  2)=                  1.24710563060941148628d0
      iwe=iwe+1
      weightb( 17, 21,  2)=                  0.16482312573611718198d0
      iwe=iwe+1
      biasb( 21,  2)=                 -1.36965442404735981974d0
      iwe=iwe+1
      weightb(  1, 22,  2)=                 -0.20868682593750503829d0
      iwe=iwe+1
      weightb(  2, 22,  2)=                 -0.11737941693972424317d0
      iwe=iwe+1
      weightb(  3, 22,  2)=                 -0.03768354084861705311d0
      iwe=iwe+1
      weightb(  4, 22,  2)=                  1.37631175282169282426d0
      iwe=iwe+1
      weightb(  5, 22,  2)=                 -0.14907555850148374033d0
      iwe=iwe+1
      weightb(  6, 22,  2)=                 -1.08338869590315800551d0
      iwe=iwe+1
      weightb(  7, 22,  2)=                 -0.21073910876092752376d0
      iwe=iwe+1
      weightb(  8, 22,  2)=                  0.58680102479017992589d0
      iwe=iwe+1
      weightb(  9, 22,  2)=                 -0.63399150743490539917d0
      iwe=iwe+1
      weightb( 10, 22,  2)=                 -0.12991762327284797629d0
      iwe=iwe+1
      weightb( 11, 22,  2)=                  0.18244317968407619546d0
      iwe=iwe+1
      weightb( 12, 22,  2)=                  1.30152296275243917201d0
      iwe=iwe+1
      weightb( 13, 22,  2)=                  0.52810099399990417801d0
      iwe=iwe+1
      weightb( 14, 22,  2)=                 -0.00175617331680535775d0
      iwe=iwe+1
      weightb( 15, 22,  2)=                 -0.26366400157290637019d0
      iwe=iwe+1
      weightb( 16, 22,  2)=                  0.49834065775834851530d0
      iwe=iwe+1
      weightb( 17, 22,  2)=                 -0.23747820368243705014d0
      iwe=iwe+1
      biasb( 22,  2)=                  1.42096670763527432868d0
      iwe=iwe+1
      weightb(  1, 23,  2)=                 -0.64246096203325819829d0
      iwe=iwe+1
      weightb(  2, 23,  2)=                 -0.38375286305957040378d0
      iwe=iwe+1
      weightb(  3, 23,  2)=                  0.25221683323857968517d0
      iwe=iwe+1
      weightb(  4, 23,  2)=                 -0.51994235941272082258d0
      iwe=iwe+1
      weightb(  5, 23,  2)=                 -0.42312482129077455539d0
      iwe=iwe+1
      weightb(  6, 23,  2)=                 -0.01874728612185560389d0
      iwe=iwe+1
      weightb(  7, 23,  2)=                  0.36775235691163205010d0
      iwe=iwe+1
      weightb(  8, 23,  2)=                  0.86356365242532784343d0
      iwe=iwe+1
      weightb(  9, 23,  2)=                 -0.88231745645796233468d0
      iwe=iwe+1
      weightb( 10, 23,  2)=                 -0.80340724745525438077d0
      iwe=iwe+1
      weightb( 11, 23,  2)=                 -0.50005200154614304342d0
      iwe=iwe+1
      weightb( 12, 23,  2)=                 -0.40052241770887520023d0
      iwe=iwe+1
      weightb( 13, 23,  2)=                  0.12292448232722898160d0
      iwe=iwe+1
      weightb( 14, 23,  2)=                  1.10874384065761999452d0
      iwe=iwe+1
      weightb( 15, 23,  2)=                 -0.55280076911455811040d0
      iwe=iwe+1
      weightb( 16, 23,  2)=                 -0.06561974402005602003d0
      iwe=iwe+1
      weightb( 17, 23,  2)=                  0.39416856390977300650d0
      iwe=iwe+1
      biasb( 23,  2)=                  0.07168898933499370796d0
      iwe=iwe+1
      weightb(  1, 24,  2)=                 -0.08679503106545588542d0
      iwe=iwe+1
      weightb(  2, 24,  2)=                 -0.20348398784238269643d0
      iwe=iwe+1
      weightb(  3, 24,  2)=                 -0.33669255194966918321d0
      iwe=iwe+1
      weightb(  4, 24,  2)=                 -1.24875063974560296387d0
      iwe=iwe+1
      weightb(  5, 24,  2)=                 -0.05240042204177119967d0
      iwe=iwe+1
      weightb(  6, 24,  2)=                  0.77031746319085625530d0
      iwe=iwe+1
      weightb(  7, 24,  2)=                  0.02013097526135600862d0
      iwe=iwe+1
      weightb(  8, 24,  2)=                 -0.46303021313943654169d0
      iwe=iwe+1
      weightb(  9, 24,  2)=                  0.04066748822722242307d0
      iwe=iwe+1
      weightb( 10, 24,  2)=                  0.50991682427404250166d0
      iwe=iwe+1
      weightb( 11, 24,  2)=                 -0.70282336143403323359d0
      iwe=iwe+1
      weightb( 12, 24,  2)=                 -0.75892843541781607186d0
      iwe=iwe+1
      weightb( 13, 24,  2)=                  0.73373982681431160202d0
      iwe=iwe+1
      weightb( 14, 24,  2)=                  0.46449854859990435951d0
      iwe=iwe+1
      weightb( 15, 24,  2)=                 -0.55491322610698845530d0
      iwe=iwe+1
      weightb( 16, 24,  2)=                  0.53067215225403219225d0
      iwe=iwe+1
      weightb( 17, 24,  2)=                  1.21588844422625719233d0
      iwe=iwe+1
      biasb( 24,  2)=                 -0.02426824763676521668d0
      iwe=iwe+1
      weightb(  1, 25,  2)=                  0.96244785307952562814d0
      iwe=iwe+1
      weightb(  2, 25,  2)=                  0.72020900854541225478d0
      iwe=iwe+1
      weightb(  3, 25,  2)=                 -0.83192364222461545609d0
      iwe=iwe+1
      weightb(  4, 25,  2)=                 -0.31134640703870403167d0
      iwe=iwe+1
      weightb(  5, 25,  2)=                 -0.82302137260464858226d0
      iwe=iwe+1
      weightb(  6, 25,  2)=                  1.62822043011022143943d0
      iwe=iwe+1
      weightb(  7, 25,  2)=                  0.04319865933205870728d0
      iwe=iwe+1
      weightb(  8, 25,  2)=                 -1.37015783164892757107d0
      iwe=iwe+1
      weightb(  9, 25,  2)=                  0.32026045544337577997d0
      iwe=iwe+1
      weightb( 10, 25,  2)=                  1.39927259525879499336d0
      iwe=iwe+1
      weightb( 11, 25,  2)=                  0.12061892456289587117d0
      iwe=iwe+1
      weightb( 12, 25,  2)=                  0.11457922179113491645d0
      iwe=iwe+1
      weightb( 13, 25,  2)=                  0.39322943843227131655d0
      iwe=iwe+1
      weightb( 14, 25,  2)=                 -0.50076446608666125293d0
      iwe=iwe+1
      weightb( 15, 25,  2)=                 -0.68394450417407248732d0
      iwe=iwe+1
      weightb( 16, 25,  2)=                 -0.33135269728568178538d0
      iwe=iwe+1
      weightb( 17, 25,  2)=                  0.00071074166121048912d0
      iwe=iwe+1
      biasb( 25,  2)=                 -0.21106941913415366852d0
      iwe=iwe+1
      weightb(  1, 26,  2)=                 -0.06667357121706782297d0
      iwe=iwe+1
      weightb(  2, 26,  2)=                  0.54538834773725131111d0
      iwe=iwe+1
      weightb(  3, 26,  2)=                  0.01498445369292270013d0
      iwe=iwe+1
      weightb(  4, 26,  2)=                  0.93598381728643931243d0
      iwe=iwe+1
      weightb(  5, 26,  2)=                  0.42075238791461194721d0
      iwe=iwe+1
      weightb(  6, 26,  2)=                 -0.28624928014881445559d0
      iwe=iwe+1
      weightb(  7, 26,  2)=                 -0.32655345850144046338d0
      iwe=iwe+1
      weightb(  8, 26,  2)=                  0.35872215254225481296d0
      iwe=iwe+1
      weightb(  9, 26,  2)=                 -1.21925684249310961604d0
      iwe=iwe+1
      weightb( 10, 26,  2)=                 -0.25999340296771089598d0
      iwe=iwe+1
      weightb( 11, 26,  2)=                 -0.08331044229095954656d0
      iwe=iwe+1
      weightb( 12, 26,  2)=                  0.32250698414838824268d0
      iwe=iwe+1
      weightb( 13, 26,  2)=                  0.23119299199899692732d0
      iwe=iwe+1
      weightb( 14, 26,  2)=                  0.17551241745407400452d0
      iwe=iwe+1
      weightb( 15, 26,  2)=                 -0.94851227251132730345d0
      iwe=iwe+1
      weightb( 16, 26,  2)=                  1.03004192332249067121d0
      iwe=iwe+1
      weightb( 17, 26,  2)=                 -0.91946816344673942822d0
      iwe=iwe+1
      biasb( 26,  2)=                  0.24079738010082946120d0
      iwe=iwe+1
      weightb(  1, 27,  2)=                  0.68373508608468402947d0
      iwe=iwe+1
      weightb(  2, 27,  2)=                  0.29173363802350044116d0
      iwe=iwe+1
      weightb(  3, 27,  2)=                 -1.06970050488044754466d0
      iwe=iwe+1
      weightb(  4, 27,  2)=                 -0.56338467761524735344d0
      iwe=iwe+1
      weightb(  5, 27,  2)=                  0.05769112060401614811d0
      iwe=iwe+1
      weightb(  6, 27,  2)=                  0.89086189916443880854d0
      iwe=iwe+1
      weightb(  7, 27,  2)=                  0.33530144131477845892d0
      iwe=iwe+1
      weightb(  8, 27,  2)=                 -0.18156577549646182868d0
      iwe=iwe+1
      weightb(  9, 27,  2)=                 -1.29145320579367872682d0
      iwe=iwe+1
      weightb( 10, 27,  2)=                 -0.50026996707195647840d0
      iwe=iwe+1
      weightb( 11, 27,  2)=                  0.40064059912927102447d0
      iwe=iwe+1
      weightb( 12, 27,  2)=                  0.33031120375320122129d0
      iwe=iwe+1
      weightb( 13, 27,  2)=                  0.08438608238892296443d0
      iwe=iwe+1
      weightb( 14, 27,  2)=                 -0.47357563196064400568d0
      iwe=iwe+1
      weightb( 15, 27,  2)=                 -0.15320391647740494445d0
      iwe=iwe+1
      weightb( 16, 27,  2)=                  0.66861501714966609100d0
      iwe=iwe+1
      weightb( 17, 27,  2)=                 -0.17739523935838488744d0
      iwe=iwe+1
      biasb( 27,  2)=                 -0.30985648374055935195d0
      iwe=iwe+1
      weightb(  1, 28,  2)=                  0.77767379177893924957d0
      iwe=iwe+1
      weightb(  2, 28,  2)=                 -0.02392637067529707756d0
      iwe=iwe+1
      weightb(  3, 28,  2)=                 -0.46536827616811293762d0
      iwe=iwe+1
      weightb(  4, 28,  2)=                  0.73184879389256396465d0
      iwe=iwe+1
      weightb(  5, 28,  2)=                  0.23360374866108002401d0
      iwe=iwe+1
      weightb(  6, 28,  2)=                  0.41273179162921158625d0
      iwe=iwe+1
      weightb(  7, 28,  2)=                  0.26816420440965971217d0
      iwe=iwe+1
      weightb(  8, 28,  2)=                 -0.07270693060941464669d0
      iwe=iwe+1
      weightb(  9, 28,  2)=                 -0.85442731518811709801d0
      iwe=iwe+1
      weightb( 10, 28,  2)=                 -0.51202712478897394188d0
      iwe=iwe+1
      weightb( 11, 28,  2)=                  0.45730181961209270813d0
      iwe=iwe+1
      weightb( 12, 28,  2)=                  0.16390364779287858177d0
      iwe=iwe+1
      weightb( 13, 28,  2)=                 -0.24582068860692826706d0
      iwe=iwe+1
      weightb( 14, 28,  2)=                 -0.83572636939175504178d0
      iwe=iwe+1
      weightb( 15, 28,  2)=                 -0.37490751487273105136d0
      iwe=iwe+1
      weightb( 16, 28,  2)=                  0.68276436657838968092d0
      iwe=iwe+1
      weightb( 17, 28,  2)=                  0.47712953501210420004d0
      iwe=iwe+1
      biasb( 28,  2)=                  0.37641839173776875382d0
      iwe=iwe+1
      weightb(  1, 29,  2)=                 -1.04174794584579255563d0
      iwe=iwe+1
      weightb(  2, 29,  2)=                 -0.06402564600079091450d0
      iwe=iwe+1
      weightb(  3, 29,  2)=                  0.12000407603296976700d0
      iwe=iwe+1
      weightb(  4, 29,  2)=                 -0.20070141147014008975d0
      iwe=iwe+1
      weightb(  5, 29,  2)=                 -0.56261117775954194720d0
      iwe=iwe+1
      weightb(  6, 29,  2)=                 -0.32214469791885347316d0
      iwe=iwe+1
      weightb(  7, 29,  2)=                  0.70254307757216782893d0
      iwe=iwe+1
      weightb(  8, 29,  2)=                 -0.51103344984225385073d0
      iwe=iwe+1
      weightb(  9, 29,  2)=                 -0.18026376052793047222d0
      iwe=iwe+1
      weightb( 10, 29,  2)=                  0.48896461309971145370d0
      iwe=iwe+1
      weightb( 11, 29,  2)=                 -0.29698108286069935247d0
      iwe=iwe+1
      weightb( 12, 29,  2)=                 -0.47423786836090758845d0
      iwe=iwe+1
      weightb( 13, 29,  2)=                  0.07267408969096895988d0
      iwe=iwe+1
      weightb( 14, 29,  2)=                  0.24655988951686047539d0
      iwe=iwe+1
      weightb( 15, 29,  2)=                  0.64112847488409452357d0
      iwe=iwe+1
      weightb( 16, 29,  2)=                 -0.72070933929705016663d0
      iwe=iwe+1
      weightb( 17, 29,  2)=                  0.78512342334500484498d0
      iwe=iwe+1
      biasb( 29,  2)=                  0.12770302882328662952d0
      iwe=iwe+1
      weightb(  1, 30,  2)=                  0.70220670122617168118d0
      iwe=iwe+1
      weightb(  2, 30,  2)=                 -0.59180628534725820966d0
      iwe=iwe+1
      weightb(  3, 30,  2)=                 -0.12955704834306921991d0
      iwe=iwe+1
      weightb(  4, 30,  2)=                 -0.09863856477159883840d0
      iwe=iwe+1
      weightb(  5, 30,  2)=                 -0.12272317504183077874d0
      iwe=iwe+1
      weightb(  6, 30,  2)=                  0.13484070723988023088d0
      iwe=iwe+1
      weightb(  7, 30,  2)=                 -0.04498394464105978652d0
      iwe=iwe+1
      weightb(  8, 30,  2)=                  0.31740082641672456853d0
      iwe=iwe+1
      weightb(  9, 30,  2)=                 -0.25205722020159782026d0
      iwe=iwe+1
      weightb( 10, 30,  2)=                  0.73317178651195080707d0
      iwe=iwe+1
      weightb( 11, 30,  2)=                  0.38056823462019157001d0
      iwe=iwe+1
      weightb( 12, 30,  2)=                 -0.71791234644745316462d0
      iwe=iwe+1
      weightb( 13, 30,  2)=                  0.26619173119994732346d0
      iwe=iwe+1
      weightb( 14, 30,  2)=                 -0.17074940947894409748d0
      iwe=iwe+1
      weightb( 15, 30,  2)=                 -0.73650788382294596346d0
      iwe=iwe+1
      weightb( 16, 30,  2)=                 -0.79234684666002752618d0
      iwe=iwe+1
      weightb( 17, 30,  2)=                 -0.14349260171923247653d0
      iwe=iwe+1
      biasb( 30,  2)=                  0.26909688741570464421d0
      iwe=iwe+1
      weightb(  1, 31,  2)=                 -0.22873139625009467069d0
      iwe=iwe+1
      weightb(  2, 31,  2)=                  0.41598317863216993651d0
      iwe=iwe+1
      weightb(  3, 31,  2)=                  0.89393502786130685234d0
      iwe=iwe+1
      weightb(  4, 31,  2)=                 -0.46433887896048309241d0
      iwe=iwe+1
      weightb(  5, 31,  2)=                  0.65116616635559187998d0
      iwe=iwe+1
      weightb(  6, 31,  2)=                  0.19179550034479836418d0
      iwe=iwe+1
      weightb(  7, 31,  2)=                 -0.77053372898395311452d0
      iwe=iwe+1
      weightb(  8, 31,  2)=                  0.18836677352899758309d0
      iwe=iwe+1
      weightb(  9, 31,  2)=                  1.31686114136409626596d0
      iwe=iwe+1
      weightb( 10, 31,  2)=                  0.08848905350412594739d0
      iwe=iwe+1
      weightb( 11, 31,  2)=                 -1.03967655609582543264d0
      iwe=iwe+1
      weightb( 12, 31,  2)=                  0.21908813443696473211d0
      iwe=iwe+1
      weightb( 13, 31,  2)=                 -0.07145177912717344537d0
      iwe=iwe+1
      weightb( 14, 31,  2)=                  0.71049226600899395567d0
      iwe=iwe+1
      weightb( 15, 31,  2)=                  0.23013013694917092145d0
      iwe=iwe+1
      weightb( 16, 31,  2)=                 -0.89332012087368928288d0
      iwe=iwe+1
      weightb( 17, 31,  2)=                 -0.05196056990598222486d0
      iwe=iwe+1
      biasb( 31,  2)=                 -0.36837448506005587845d0
      iwe=iwe+1
      weightb(  1, 32,  2)=                  0.39937696390596399976d0
      iwe=iwe+1
      weightb(  2, 32,  2)=                 -0.55259066224131581091d0
      iwe=iwe+1
      weightb(  3, 32,  2)=                 -0.05004839200006126060d0
      iwe=iwe+1
      weightb(  4, 32,  2)=                  0.44504922568752369738d0
      iwe=iwe+1
      weightb(  5, 32,  2)=                 -0.27887637848580643096d0
      iwe=iwe+1
      weightb(  6, 32,  2)=                 -0.70776987485361608776d0
      iwe=iwe+1
      weightb(  7, 32,  2)=                 -0.83707813456368973526d0
      iwe=iwe+1
      weightb(  8, 32,  2)=                  0.23188152899922856442d0
      iwe=iwe+1
      weightb(  9, 32,  2)=                  0.50779908340028478975d0
      iwe=iwe+1
      weightb( 10, 32,  2)=                 -0.94510002787647262590d0
      iwe=iwe+1
      weightb( 11, 32,  2)=                  0.36651939802695676640d0
      iwe=iwe+1
      weightb( 12, 32,  2)=                  0.04246087086520382303d0
      iwe=iwe+1
      weightb( 13, 32,  2)=                  0.58827398327104807318d0
      iwe=iwe+1
      weightb( 14, 32,  2)=                  1.20583417020520355933d0
      iwe=iwe+1
      weightb( 15, 32,  2)=                 -0.20274651912100091766d0
      iwe=iwe+1
      weightb( 16, 32,  2)=                 -0.42974849984428903360d0
      iwe=iwe+1
      weightb( 17, 32,  2)=                  0.08909872409650178293d0
      iwe=iwe+1
      biasb( 32,  2)=                  0.47913299985407936665d0
      iwe=iwe+1
      weightb(  1, 33,  2)=                 -0.15667825185353581596d0
      iwe=iwe+1
      weightb(  2, 33,  2)=                 -0.43896232152273745308d0
      iwe=iwe+1
      weightb(  3, 33,  2)=                  0.55453636576931186752d0
      iwe=iwe+1
      weightb(  4, 33,  2)=                 -0.64426983296601680884d0
      iwe=iwe+1
      weightb(  5, 33,  2)=                  0.14528193359805455231d0
      iwe=iwe+1
      weightb(  6, 33,  2)=                 -0.25337647250961076173d0
      iwe=iwe+1
      weightb(  7, 33,  2)=                 -0.24878284669806915996d0
      iwe=iwe+1
      weightb(  8, 33,  2)=                  0.74244424380787699125d0
      iwe=iwe+1
      weightb(  9, 33,  2)=                 -0.87952399016520754760d0
      iwe=iwe+1
      weightb( 10, 33,  2)=                  0.49203796921173331702d0
      iwe=iwe+1
      weightb( 11, 33,  2)=                 -0.69284123825070431657d0
      iwe=iwe+1
      weightb( 12, 33,  2)=                  0.34556393068250507161d0
      iwe=iwe+1
      weightb( 13, 33,  2)=                  0.62293009475257488106d0
      iwe=iwe+1
      weightb( 14, 33,  2)=                 -0.47468216439892263470d0
      iwe=iwe+1
      weightb( 15, 33,  2)=                 -0.70133254846904269364d0
      iwe=iwe+1
      weightb( 16, 33,  2)=                  0.11689957797884324708d0
      iwe=iwe+1
      weightb( 17, 33,  2)=                  0.09395011647487949702d0
      iwe=iwe+1
      biasb( 33,  2)=                  0.38677114708994192460d0
      iwe=iwe+1
      weightb(  1, 34,  2)=                 -0.04065305624506518334d0
      iwe=iwe+1
      weightb(  2, 34,  2)=                  0.06488651678819920554d0
      iwe=iwe+1
      weightb(  3, 34,  2)=                  0.41726636891776691662d0
      iwe=iwe+1
      weightb(  4, 34,  2)=                  0.66499668672497513899d0
      iwe=iwe+1
      weightb(  5, 34,  2)=                  0.44313874073994641289d0
      iwe=iwe+1
      weightb(  6, 34,  2)=                  0.45184619848000290299d0
      iwe=iwe+1
      weightb(  7, 34,  2)=                 -0.19236071738412674481d0
      iwe=iwe+1
      weightb(  8, 34,  2)=                  1.58628148569012972224d0
      iwe=iwe+1
      weightb(  9, 34,  2)=                 -0.63002118007886631634d0
      iwe=iwe+1
      weightb( 10, 34,  2)=                 -0.46099540836994462589d0
      iwe=iwe+1
      weightb( 11, 34,  2)=                 -0.13050403386898912217d0
      iwe=iwe+1
      weightb( 12, 34,  2)=                 -0.73821275506204742101d0
      iwe=iwe+1
      weightb( 13, 34,  2)=                  0.51755163680362048506d0
      iwe=iwe+1
      weightb( 14, 34,  2)=                 -0.96333493078212584226d0
      iwe=iwe+1
      weightb( 15, 34,  2)=                 -1.11021000965666671867d0
      iwe=iwe+1
      weightb( 16, 34,  2)=                  0.61248913330741017180d0
      iwe=iwe+1
      weightb( 17, 34,  2)=                 -0.11342258871805849241d0
      iwe=iwe+1
      biasb( 34,  2)=                  0.55573901273167081172d0
      iwe=iwe+1
      weightb(  1, 35,  2)=                 -0.09208683325074978887d0
      iwe=iwe+1
      weightb(  2, 35,  2)=                 -0.16126578062755600462d0
      iwe=iwe+1
      weightb(  3, 35,  2)=                 -0.68750601684735623831d0
      iwe=iwe+1
      weightb(  4, 35,  2)=                 -1.05208478401866289964d0
      iwe=iwe+1
      weightb(  5, 35,  2)=                  0.16094677141668106701d0
      iwe=iwe+1
      weightb(  6, 35,  2)=                  0.50094592767868872940d0
      iwe=iwe+1
      weightb(  7, 35,  2)=                 -0.32623286925351219212d0
      iwe=iwe+1
      weightb(  8, 35,  2)=                 -0.35965929037613597608d0
      iwe=iwe+1
      weightb(  9, 35,  2)=                  1.24223880897066241147d0
      iwe=iwe+1
      weightb( 10, 35,  2)=                  0.18201436682773561304d0
      iwe=iwe+1
      weightb( 11, 35,  2)=                  0.27686018578653226463d0
      iwe=iwe+1
      weightb( 12, 35,  2)=                 -0.01998854304006117411d0
      iwe=iwe+1
      weightb( 13, 35,  2)=                 -0.89402202923584261907d0
      iwe=iwe+1
      weightb( 14, 35,  2)=                  0.42596132376511752771d0
      iwe=iwe+1
      weightb( 15, 35,  2)=                  0.48196557444281706850d0
      iwe=iwe+1
      weightb( 16, 35,  2)=                  0.07465751058543766694d0
      iwe=iwe+1
      weightb( 17, 35,  2)=                 -0.40483821411239589994d0
      iwe=iwe+1
      biasb( 35,  2)=                  0.05799878794584104741d0
      iwe=iwe+1
      weightb(  1, 36,  2)=                  0.45893862400165863491d0
      iwe=iwe+1
      weightb(  2, 36,  2)=                 -0.19823710029722665937d0
      iwe=iwe+1
      weightb(  3, 36,  2)=                 -0.39965480174256817758d0
      iwe=iwe+1
      weightb(  4, 36,  2)=                  0.03840889793564830623d0
      iwe=iwe+1
      weightb(  5, 36,  2)=                 -0.70195451587346879840d0
      iwe=iwe+1
      weightb(  6, 36,  2)=                  0.15364037297817323413d0
      iwe=iwe+1
      weightb(  7, 36,  2)=                 -0.08047246257074441855d0
      iwe=iwe+1
      weightb(  8, 36,  2)=                  0.80859601689999616170d0
      iwe=iwe+1
      weightb(  9, 36,  2)=                  0.06429267422108120300d0
      iwe=iwe+1
      weightb( 10, 36,  2)=                 -0.68957332234873003340d0
      iwe=iwe+1
      weightb( 11, 36,  2)=                  0.48714783767631242295d0
      iwe=iwe+1
      weightb( 12, 36,  2)=                  0.19708501044494647347d0
      iwe=iwe+1
      weightb( 13, 36,  2)=                  0.79178331676590485433d0
      iwe=iwe+1
      weightb( 14, 36,  2)=                  0.18241139295540148568d0
      iwe=iwe+1
      weightb( 15, 36,  2)=                  1.39475227711477622883d0
      iwe=iwe+1
      weightb( 16, 36,  2)=                  0.02325002371696207812d0
      iwe=iwe+1
      weightb( 17, 36,  2)=                  0.14198249079747626844d0
      iwe=iwe+1
      biasb( 36,  2)=                  0.28482489967507579331d0
      iwe=iwe+1
      weightb(  1, 37,  2)=                  0.81864495696321670781d0
      iwe=iwe+1
      weightb(  2, 37,  2)=                  0.63732789899822706037d0
      iwe=iwe+1
      weightb(  3, 37,  2)=                 -0.26811913611896803777d0
      iwe=iwe+1
      weightb(  4, 37,  2)=                 -0.52637974883356619671d0
      iwe=iwe+1
      weightb(  5, 37,  2)=                 -0.13372478790167671714d0
      iwe=iwe+1
      weightb(  6, 37,  2)=                 -0.42847267362229596310d0
      iwe=iwe+1
      weightb(  7, 37,  2)=                  0.95179267942370926470d0
      iwe=iwe+1
      weightb(  8, 37,  2)=                  0.40914472403748691764d0
      iwe=iwe+1
      weightb(  9, 37,  2)=                  0.61336937257871293472d0
      iwe=iwe+1
      weightb( 10, 37,  2)=                 -0.42708181650343779445d0
      iwe=iwe+1
      weightb( 11, 37,  2)=                 -0.21367267188541902434d0
      iwe=iwe+1
      weightb( 12, 37,  2)=                  0.27662730407898900031d0
      iwe=iwe+1
      weightb( 13, 37,  2)=                 -1.02456715110674712044d0
      iwe=iwe+1
      weightb( 14, 37,  2)=                  0.80453163247971104521d0
      iwe=iwe+1
      weightb( 15, 37,  2)=                 -0.35605363610053197831d0
      iwe=iwe+1
      weightb( 16, 37,  2)=                 -0.61265687956792214131d0
      iwe=iwe+1
      weightb( 17, 37,  2)=                  0.57822837441588814666d0
      iwe=iwe+1
      biasb( 37,  2)=                  1.10535211183735793128d0
      iwe=iwe+1
      weightb(  1, 38,  2)=                  0.24996679084827957973d0
      iwe=iwe+1
      weightb(  2, 38,  2)=                 -0.06469155799144321595d0
      iwe=iwe+1
      weightb(  3, 38,  2)=                  0.85190220219193346640d0
      iwe=iwe+1
      weightb(  4, 38,  2)=                  0.45763448550215030108d0
      iwe=iwe+1
      weightb(  5, 38,  2)=                 -0.20653457292775467824d0
      iwe=iwe+1
      weightb(  6, 38,  2)=                  0.65929173046642830514d0
      iwe=iwe+1
      weightb(  7, 38,  2)=                 -0.70613038358725244148d0
      iwe=iwe+1
      weightb(  8, 38,  2)=                  0.85757421140855949471d0
      iwe=iwe+1
      weightb(  9, 38,  2)=                  0.76318012891040165613d0
      iwe=iwe+1
      weightb( 10, 38,  2)=                 -0.48698856564956394255d0
      iwe=iwe+1
      weightb( 11, 38,  2)=                  0.17823089025646837724d0
      iwe=iwe+1
      weightb( 12, 38,  2)=                  0.09701694055703607988d0
      iwe=iwe+1
      weightb( 13, 38,  2)=                 -0.92284700413507225747d0
      iwe=iwe+1
      weightb( 14, 38,  2)=                 -0.96396510610334129598d0
      iwe=iwe+1
      weightb( 15, 38,  2)=                 -0.22750822813336105122d0
      iwe=iwe+1
      weightb( 16, 38,  2)=                  0.18501901811073889759d0
      iwe=iwe+1
      weightb( 17, 38,  2)=                 -0.35681964208175465103d0
      iwe=iwe+1
      biasb( 38,  2)=                 -0.93232549644198592365d0
      iwe=iwe+1
      weightb(  1, 39,  2)=                  0.09367387622555933824d0
      iwe=iwe+1
      weightb(  2, 39,  2)=                 -0.11991614862710263389d0
      iwe=iwe+1
      weightb(  3, 39,  2)=                  0.23851495252180143769d0
      iwe=iwe+1
      weightb(  4, 39,  2)=                  0.35550093620184042287d0
      iwe=iwe+1
      weightb(  5, 39,  2)=                  0.28691625965955080968d0
      iwe=iwe+1
      weightb(  6, 39,  2)=                 -0.93845057718313806827d0
      iwe=iwe+1
      weightb(  7, 39,  2)=                 -0.12337457404981104492d0
      iwe=iwe+1
      weightb(  8, 39,  2)=                  0.38968245737036161236d0
      iwe=iwe+1
      weightb(  9, 39,  2)=                 -0.63110671762316383759d0
      iwe=iwe+1
      weightb( 10, 39,  2)=                 -0.08996855071756296174d0
      iwe=iwe+1
      weightb( 11, 39,  2)=                  0.31747271103678559312d0
      iwe=iwe+1
      weightb( 12, 39,  2)=                  0.12114589558334408481d0
      iwe=iwe+1
      weightb( 13, 39,  2)=                  0.03242957081545166237d0
      iwe=iwe+1
      weightb( 14, 39,  2)=                  0.63695382613643825032d0
      iwe=iwe+1
      weightb( 15, 39,  2)=                 -0.97799079829144663911d0
      iwe=iwe+1
      weightb( 16, 39,  2)=                 -0.66176816432098184428d0
      iwe=iwe+1
      weightb( 17, 39,  2)=                 -0.69529138883264596238d0
      iwe=iwe+1
      biasb( 39,  2)=                  1.12720591108592649299d0
      iwe=iwe+1
      weightb(  1, 40,  2)=                 -0.04133711655663702828d0
      iwe=iwe+1
      weightb(  2, 40,  2)=                  0.27398478669833092880d0
      iwe=iwe+1
      weightb(  3, 40,  2)=                  0.29404830515866559049d0
      iwe=iwe+1
      weightb(  4, 40,  2)=                  0.03979577391465447672d0
      iwe=iwe+1
      weightb(  5, 40,  2)=                  0.65445645177568634310d0
      iwe=iwe+1
      weightb(  6, 40,  2)=                 -0.70029225885517565331d0
      iwe=iwe+1
      weightb(  7, 40,  2)=                  0.91906490967783105450d0
      iwe=iwe+1
      weightb(  8, 40,  2)=                 -0.90699969166769134343d0
      iwe=iwe+1
      weightb(  9, 40,  2)=                 -0.74755338320408237784d0
      iwe=iwe+1
      weightb( 10, 40,  2)=                  1.02418820441549041078d0
      iwe=iwe+1
      weightb( 11, 40,  2)=                  0.30326845566002880172d0
      iwe=iwe+1
      weightb( 12, 40,  2)=                 -0.37021297311287970633d0
      iwe=iwe+1
      weightb( 13, 40,  2)=                  0.34189986003145833582d0
      iwe=iwe+1
      weightb( 14, 40,  2)=                 -0.19919069409019862782d0
      iwe=iwe+1
      weightb( 15, 40,  2)=                  0.36298860598566573543d0
      iwe=iwe+1
      weightb( 16, 40,  2)=                 -0.09812295653462511924d0
      iwe=iwe+1
      weightb( 17, 40,  2)=                 -0.10681676498822412213d0
      iwe=iwe+1
      biasb( 40,  2)=                 -0.85592751278114476143d0
      iwe=iwe+1
      weightb(  1, 41,  2)=                 -0.51653380711609175879d0
      iwe=iwe+1
      weightb(  2, 41,  2)=                  0.62034197192197659820d0
      iwe=iwe+1
      weightb(  3, 41,  2)=                  0.04932095957533243896d0
      iwe=iwe+1
      weightb(  4, 41,  2)=                 -0.91325134240991379109d0
      iwe=iwe+1
      weightb(  5, 41,  2)=                  0.32890572544044521797d0
      iwe=iwe+1
      weightb(  6, 41,  2)=                 -0.52538334410686993170d0
      iwe=iwe+1
      weightb(  7, 41,  2)=                  0.02689118705365301648d0
      iwe=iwe+1
      weightb(  8, 41,  2)=                 -0.04623025617604179655d0
      iwe=iwe+1
      weightb(  9, 41,  2)=                 -0.79570188166573552202d0
      iwe=iwe+1
      weightb( 10, 41,  2)=                  0.45953661904730624954d0
      iwe=iwe+1
      weightb( 11, 41,  2)=                  0.17315053300366944899d0
      iwe=iwe+1
      weightb( 12, 41,  2)=                  0.34968852094111396722d0
      iwe=iwe+1
      weightb( 13, 41,  2)=                  0.13464996095554854216d0
      iwe=iwe+1
      weightb( 14, 41,  2)=                 -0.54353104178104139077d0
      iwe=iwe+1
      weightb( 15, 41,  2)=                  0.51086365053666893399d0
      iwe=iwe+1
      weightb( 16, 41,  2)=                  0.65335256715625644741d0
      iwe=iwe+1
      weightb( 17, 41,  2)=                 -0.08772804829684316408d0
      iwe=iwe+1
      biasb( 41,  2)=                 -0.99556464335187611070d0
      iwe=iwe+1
      weightb(  1, 42,  2)=                 -0.29642237026125040078d0
      iwe=iwe+1
      weightb(  2, 42,  2)=                 -0.56511429460122808432d0
      iwe=iwe+1
      weightb(  3, 42,  2)=                 -0.19113188785976165107d0
      iwe=iwe+1
      weightb(  4, 42,  2)=                 -0.03069579350769610290d0
      iwe=iwe+1
      weightb(  5, 42,  2)=                  0.08394277409461833872d0
      iwe=iwe+1
      weightb(  6, 42,  2)=                 -0.49266263535888688008d0
      iwe=iwe+1
      weightb(  7, 42,  2)=                  0.60299110089886587271d0
      iwe=iwe+1
      weightb(  8, 42,  2)=                 -0.67103604532108529490d0
      iwe=iwe+1
      weightb(  9, 42,  2)=                 -0.05989063131018129010d0
      iwe=iwe+1
      weightb( 10, 42,  2)=                  0.06869560452926697092d0
      iwe=iwe+1
      weightb( 11, 42,  2)=                 -0.45014434321617025070d0
      iwe=iwe+1
      weightb( 12, 42,  2)=                  0.87179295811365775659d0
      iwe=iwe+1
      weightb( 13, 42,  2)=                 -0.48677667618410808137d0
      iwe=iwe+1
      weightb( 14, 42,  2)=                 -0.61810866552872434365d0
      iwe=iwe+1
      weightb( 15, 42,  2)=                 -0.11995094142219260569d0
      iwe=iwe+1
      weightb( 16, 42,  2)=                 -0.00687291173474148184d0
      iwe=iwe+1
      weightb( 17, 42,  2)=                  0.37643351020588700084d0
      iwe=iwe+1
      biasb( 42,  2)=                 -0.79047036398729642048d0
      iwe=iwe+1
      weightb(  1, 43,  2)=                  0.36309126945902642225d0
      iwe=iwe+1
      weightb(  2, 43,  2)=                  0.32957392490402859231d0
      iwe=iwe+1
      weightb(  3, 43,  2)=                  0.02961814196908077457d0
      iwe=iwe+1
      weightb(  4, 43,  2)=                 -0.40176175790477003380d0
      iwe=iwe+1
      weightb(  5, 43,  2)=                 -0.54947018124918656223d0
      iwe=iwe+1
      weightb(  6, 43,  2)=                 -0.20356183009584774557d0
      iwe=iwe+1
      weightb(  7, 43,  2)=                 -0.30893275976217371426d0
      iwe=iwe+1
      weightb(  8, 43,  2)=                 -0.13148077859469675666d0
      iwe=iwe+1
      weightb(  9, 43,  2)=                 -0.59243432121354355768d0
      iwe=iwe+1
      weightb( 10, 43,  2)=                 -0.39130052684128702190d0
      iwe=iwe+1
      weightb( 11, 43,  2)=                 -0.02748696473542881075d0
      iwe=iwe+1
      weightb( 12, 43,  2)=                 -0.30619096225629527375d0
      iwe=iwe+1
      weightb( 13, 43,  2)=                 -0.62527538432243112698d0
      iwe=iwe+1
      weightb( 14, 43,  2)=                  0.25277550692460831749d0
      iwe=iwe+1
      weightb( 15, 43,  2)=                  0.59984911234431004257d0
      iwe=iwe+1
      weightb( 16, 43,  2)=                 -0.59321442620873787721d0
      iwe=iwe+1
      weightb( 17, 43,  2)=                 -0.67579159509477781942d0
      iwe=iwe+1
      biasb( 43,  2)=                  1.42613943861099445876d0
      iwe=iwe+1
      weightb(  1, 44,  2)=                  0.71475287853162183804d0
      iwe=iwe+1
      weightb(  2, 44,  2)=                 -0.26673084076847408674d0
      iwe=iwe+1
      weightb(  3, 44,  2)=                  0.29482948321592722385d0
      iwe=iwe+1
      weightb(  4, 44,  2)=                  1.22158509774280976679d0
      iwe=iwe+1
      weightb(  5, 44,  2)=                  0.89198514603471834583d0
      iwe=iwe+1
      weightb(  6, 44,  2)=                 -0.93373671915263389831d0
      iwe=iwe+1
      weightb(  7, 44,  2)=                  0.66301643150069478061d0
      iwe=iwe+1
      weightb(  8, 44,  2)=                 -0.41977715184050345965d0
      iwe=iwe+1
      weightb(  9, 44,  2)=                 -0.20025842810699426289d0
      iwe=iwe+1
      weightb( 10, 44,  2)=                 -1.07588216532607816589d0
      iwe=iwe+1
      weightb( 11, 44,  2)=                  0.31419834528409024133d0
      iwe=iwe+1
      weightb( 12, 44,  2)=                  0.00882629118386892182d0
      iwe=iwe+1
      weightb( 13, 44,  2)=                 -0.29869430588637452262d0
      iwe=iwe+1
      weightb( 14, 44,  2)=                  0.32015371269175463276d0
      iwe=iwe+1
      weightb( 15, 44,  2)=                  0.48765510782150228719d0
      iwe=iwe+1
      weightb( 16, 44,  2)=                 -0.39413870803031020307d0
      iwe=iwe+1
      weightb( 17, 44,  2)=                 -0.28085880162127807580d0
      iwe=iwe+1
      biasb( 44,  2)=                  1.59449323266148046407d0
      iwe=iwe+1
      weightb(  1, 45,  2)=                 -0.21198055929153855614d0
      iwe=iwe+1
      weightb(  2, 45,  2)=                  0.46213435830289462114d0
      iwe=iwe+1
      weightb(  3, 45,  2)=                  0.32199790751195811467d0
      iwe=iwe+1
      weightb(  4, 45,  2)=                  0.43595555562074772560d0
      iwe=iwe+1
      weightb(  5, 45,  2)=                 -0.36440442210519241595d0
      iwe=iwe+1
      weightb(  6, 45,  2)=                 -0.19641357531771022615d0
      iwe=iwe+1
      weightb(  7, 45,  2)=                  0.43538240758387131146d0
      iwe=iwe+1
      weightb(  8, 45,  2)=                  0.60864059545974091847d0
      iwe=iwe+1
      weightb(  9, 45,  2)=                  0.55023430961620189983d0
      iwe=iwe+1
      weightb( 10, 45,  2)=                 -0.11124969314846974711d0
      iwe=iwe+1
      weightb( 11, 45,  2)=                  0.32258063739299469574d0
      iwe=iwe+1
      weightb( 12, 45,  2)=                 -0.66328692478070627736d0
      iwe=iwe+1
      weightb( 13, 45,  2)=                  0.45203907314273766849d0
      iwe=iwe+1
      weightb( 14, 45,  2)=                 -0.57073318808343853625d0
      iwe=iwe+1
      weightb( 15, 45,  2)=                 -0.21980294692505253362d0
      iwe=iwe+1
      weightb( 16, 45,  2)=                 -0.64685847851506883543d0
      iwe=iwe+1
      weightb( 17, 45,  2)=                  0.26899184363597816727d0
      iwe=iwe+1
      biasb( 45,  2)=                 -1.28396629746904045177d0
      iwe=iwe+1
      weightb(  1, 46,  2)=                  0.16758526565512804618d0
      iwe=iwe+1
      weightb(  2, 46,  2)=                  0.08938345774751156603d0
      iwe=iwe+1
      weightb(  3, 46,  2)=                  0.53964664850957289044d0
      iwe=iwe+1
      weightb(  4, 46,  2)=                 -0.07254518400893954222d0
      iwe=iwe+1
      weightb(  5, 46,  2)=                 -0.54641926364475867928d0
      iwe=iwe+1
      weightb(  6, 46,  2)=                  0.76523682231581313662d0
      iwe=iwe+1
      weightb(  7, 46,  2)=                 -0.39958577115129628732d0
      iwe=iwe+1
      weightb(  8, 46,  2)=                 -0.28525696774509923248d0
      iwe=iwe+1
      weightb(  9, 46,  2)=                 -0.46162703203222749115d0
      iwe=iwe+1
      weightb( 10, 46,  2)=                  0.55188669360195508062d0
      iwe=iwe+1
      weightb( 11, 46,  2)=                 -0.07072605030423359529d0
      iwe=iwe+1
      weightb( 12, 46,  2)=                 -0.67949642393727904821d0
      iwe=iwe+1
      weightb( 13, 46,  2)=                  0.36515782246742822803d0
      iwe=iwe+1
      weightb( 14, 46,  2)=                 -0.15461176130354187253d0
      iwe=iwe+1
      weightb( 15, 46,  2)=                 -0.66243827881305494820d0
      iwe=iwe+1
      weightb( 16, 46,  2)=                  0.71999005492576340082d0
      iwe=iwe+1
      weightb( 17, 46,  2)=                  0.99359874507832857127d0
      iwe=iwe+1
      biasb( 46,  2)=                  1.15059122468631525038d0
      iwe=iwe+1
      weightb(  1, 47,  2)=                  0.09038122417251928664d0
      iwe=iwe+1
      weightb(  2, 47,  2)=                 -0.65392980724419902394d0
      iwe=iwe+1
      weightb(  3, 47,  2)=                  0.36223541548632903764d0
      iwe=iwe+1
      weightb(  4, 47,  2)=                 -0.68801635678909511817d0
      iwe=iwe+1
      weightb(  5, 47,  2)=                 -0.88755894071653518296d0
      iwe=iwe+1
      weightb(  6, 47,  2)=                 -1.47629658092482207721d0
      iwe=iwe+1
      weightb(  7, 47,  2)=                 -0.80709042905640482335d0
      iwe=iwe+1
      weightb(  8, 47,  2)=                  0.42769440627619337292d0
      iwe=iwe+1
      weightb(  9, 47,  2)=                  0.20092191275138648887d0
      iwe=iwe+1
      weightb( 10, 47,  2)=                  0.38637955720925448722d0
      iwe=iwe+1
      weightb( 11, 47,  2)=                  0.46471880712079771669d0
      iwe=iwe+1
      weightb( 12, 47,  2)=                  0.58530474030233958782d0
      iwe=iwe+1
      weightb( 13, 47,  2)=                 -0.37094916644711112275d0
      iwe=iwe+1
      weightb( 14, 47,  2)=                  0.11142669015171434432d0
      iwe=iwe+1
      weightb( 15, 47,  2)=                  0.01032441996131637854d0
      iwe=iwe+1
      weightb( 16, 47,  2)=                  0.21476546008620872596d0
      iwe=iwe+1
      weightb( 17, 47,  2)=                 -0.11065629063373758068d0
      iwe=iwe+1
      biasb( 47,  2)=                  1.78494052680604697869d0
      iwe=iwe+1
      weightb(  1, 48,  2)=                  0.38619290491614138849d0
      iwe=iwe+1
      weightb(  2, 48,  2)=                  0.04698519290045873736d0
      iwe=iwe+1
      weightb(  3, 48,  2)=                  0.05448822227008819769d0
      iwe=iwe+1
      weightb(  4, 48,  2)=                 -0.29644724074007494652d0
      iwe=iwe+1
      weightb(  5, 48,  2)=                 -0.29289367893775625218d0
      iwe=iwe+1
      weightb(  6, 48,  2)=                 -0.49560814710839112829d0
      iwe=iwe+1
      weightb(  7, 48,  2)=                  0.26727083157828673832d0
      iwe=iwe+1
      weightb(  8, 48,  2)=                 -0.76962489188134397544d0
      iwe=iwe+1
      weightb(  9, 48,  2)=                 -0.43540481598390357032d0
      iwe=iwe+1
      weightb( 10, 48,  2)=                  0.09908973906320309166d0
      iwe=iwe+1
      weightb( 11, 48,  2)=                  0.30981008404619214680d0
      iwe=iwe+1
      weightb( 12, 48,  2)=                  0.60364362079365230240d0
      iwe=iwe+1
      weightb( 13, 48,  2)=                 -0.72281074256032695757d0
      iwe=iwe+1
      weightb( 14, 48,  2)=                 -0.66217255399277741290d0
      iwe=iwe+1
      weightb( 15, 48,  2)=                 -0.11984026593222357748d0
      iwe=iwe+1
      weightb( 16, 48,  2)=                  0.18575714562613188097d0
      iwe=iwe+1
      weightb( 17, 48,  2)=                 -0.11647485980862232191d0
      iwe=iwe+1
      biasb( 48,  2)=                  1.71846829567044445675d0
      iwe=iwe+1
      weightb(  1, 49,  2)=                  0.59931650899663913012d0
      iwe=iwe+1
      weightb(  2, 49,  2)=                 -0.54060184698680757709d0
      iwe=iwe+1
      weightb(  3, 49,  2)=                  0.39290065737528390155d0
      iwe=iwe+1
      weightb(  4, 49,  2)=                 -0.39416386011643483878d0
      iwe=iwe+1
      weightb(  5, 49,  2)=                 -0.32238243848828757043d0
      iwe=iwe+1
      weightb(  6, 49,  2)=                 -0.40360332797017273165d0
      iwe=iwe+1
      weightb(  7, 49,  2)=                  0.62647155762997219774d0
      iwe=iwe+1
      weightb(  8, 49,  2)=                 -0.00107725072130340771d0
      iwe=iwe+1
      weightb(  9, 49,  2)=                  0.54199844997517376832d0
      iwe=iwe+1
      weightb( 10, 49,  2)=                  0.34294019395460184629d0
      iwe=iwe+1
      weightb( 11, 49,  2)=                 -0.37547915871724235615d0
      iwe=iwe+1
      weightb( 12, 49,  2)=                 -0.40432874582114297635d0
      iwe=iwe+1
      weightb( 13, 49,  2)=                 -0.29823506527864002136d0
      iwe=iwe+1
      weightb( 14, 49,  2)=                 -0.20041452219088137787d0
      iwe=iwe+1
      weightb( 15, 49,  2)=                  0.46221623786488008623d0
      iwe=iwe+1
      weightb( 16, 49,  2)=                  0.49923532554471078404d0
      iwe=iwe+1
      weightb( 17, 49,  2)=                 -0.04404445735884660734d0
      iwe=iwe+1
      biasb( 49,  2)=                  1.77303287736050241286d0
      iwe=iwe+1
      weightb(  1, 50,  2)=                  1.01169097329312052125d0
      iwe=iwe+1
      weightb(  2, 50,  2)=                 -0.64672654968872178571d0
      iwe=iwe+1
      weightb(  3, 50,  2)=                 -0.64047560235980893761d0
      iwe=iwe+1
      weightb(  4, 50,  2)=                  0.13369313799500534556d0
      iwe=iwe+1
      weightb(  5, 50,  2)=                  0.58994123585517577180d0
      iwe=iwe+1
      weightb(  6, 50,  2)=                 -0.29882764422736157739d0
      iwe=iwe+1
      weightb(  7, 50,  2)=                  0.45265703626929265635d0
      iwe=iwe+1
      weightb(  8, 50,  2)=                 -0.77047610996080151402d0
      iwe=iwe+1
      weightb(  9, 50,  2)=                  0.17964957345728455040d0
      iwe=iwe+1
      weightb( 10, 50,  2)=                  0.79747527918467087105d0
      iwe=iwe+1
      weightb( 11, 50,  2)=                  0.25189662309165228304d0
      iwe=iwe+1
      weightb( 12, 50,  2)=                  0.88397327958440696793d0
      iwe=iwe+1
      weightb( 13, 50,  2)=                  0.08775329869788005277d0
      iwe=iwe+1
      weightb( 14, 50,  2)=                 -0.59237868882313593488d0
      iwe=iwe+1
      weightb( 15, 50,  2)=                 -0.23300210188214029450d0
      iwe=iwe+1
      weightb( 16, 50,  2)=                  0.05288422810623114034d0
      iwe=iwe+1
      weightb( 17, 50,  2)=                  0.06164637181662507848d0
      iwe=iwe+1
      biasb( 50,  2)=                  2.12110085755086874570d0
      iwe=iwe+1
      weightb(  1,  1,  3)=                 -0.43469623750737412804d0
      iwe=iwe+1
      weightb(  2,  1,  3)=                 -0.62604247193042494857d0
      iwe=iwe+1
      weightb(  3,  1,  3)=                  0.17002787820798170859d0
      iwe=iwe+1
      weightb(  4,  1,  3)=                  1.14333721515080677378d0
      iwe=iwe+1
      weightb(  5,  1,  3)=                 -0.06241364909331816035d0
      iwe=iwe+1
      weightb(  6,  1,  3)=                 -0.02380706286361718160d0
      iwe=iwe+1
      weightb(  7,  1,  3)=                  0.31093729208411757803d0
      iwe=iwe+1
      weightb(  8,  1,  3)=                  0.32317318419785973083d0
      iwe=iwe+1
      weightb(  9,  1,  3)=                  0.16809711548450825824d0
      iwe=iwe+1
      weightb( 10,  1,  3)=                  0.50047140422012093008d0
      iwe=iwe+1
      weightb( 11,  1,  3)=                  0.10623925957224922278d0
      iwe=iwe+1
      weightb( 12,  1,  3)=                 -0.80159848890270279931d0
      iwe=iwe+1
      weightb( 13,  1,  3)=                  0.07565049673355660198d0
      iwe=iwe+1
      weightb( 14,  1,  3)=                  0.17795653926341711837d0
      iwe=iwe+1
      weightb( 15,  1,  3)=                 -0.10419134546996015878d0
      iwe=iwe+1
      weightb( 16,  1,  3)=                  0.52307004836733794750d0
      iwe=iwe+1
      weightb( 17,  1,  3)=                  0.44819611676337617334d0
      iwe=iwe+1
      weightb( 18,  1,  3)=                  0.05513993059647642747d0
      iwe=iwe+1
      weightb( 19,  1,  3)=                  0.17509541099433661993d0
      iwe=iwe+1
      weightb( 20,  1,  3)=                 -0.25379438093940687171d0
      iwe=iwe+1
      weightb( 21,  1,  3)=                  0.17983018337976136580d0
      iwe=iwe+1
      weightb( 22,  1,  3)=                  0.29450926932425819382d0
      iwe=iwe+1
      weightb( 23,  1,  3)=                  0.01987649385004183408d0
      iwe=iwe+1
      weightb( 24,  1,  3)=                  0.38809399107664505069d0
      iwe=iwe+1
      weightb( 25,  1,  3)=                 -0.10972103796221159555d0
      iwe=iwe+1
      weightb( 26,  1,  3)=                  0.08442844595759538273d0
      iwe=iwe+1
      weightb( 27,  1,  3)=                 -0.27795285104865480319d0
      iwe=iwe+1
      weightb( 28,  1,  3)=                 -0.06445947065098742157d0
      iwe=iwe+1
      weightb( 29,  1,  3)=                 -0.54527988266801419304d0
      iwe=iwe+1
      weightb( 30,  1,  3)=                 -0.19975095007659035562d0
      iwe=iwe+1
      weightb( 31,  1,  3)=                 -0.06023489986024992138d0
      iwe=iwe+1
      weightb( 32,  1,  3)=                 -0.18250757840169468116d0
      iwe=iwe+1
      weightb( 33,  1,  3)=                 -0.09575573208638146760d0
      iwe=iwe+1
      weightb( 34,  1,  3)=                 -0.24318767798945772896d0
      iwe=iwe+1
      weightb( 35,  1,  3)=                  0.21374252081020828076d0
      iwe=iwe+1
      weightb( 36,  1,  3)=                  0.00523383795989286991d0
      iwe=iwe+1
      weightb( 37,  1,  3)=                 -0.16279045429004118661d0
      iwe=iwe+1
      weightb( 38,  1,  3)=                  0.04254288141044693106d0
      iwe=iwe+1
      weightb( 39,  1,  3)=                  0.45269012774328709625d0
      iwe=iwe+1
      weightb( 40,  1,  3)=                 -0.18145779744627338337d0
      iwe=iwe+1
      weightb( 41,  1,  3)=                  0.03011027516944519977d0
      iwe=iwe+1
      weightb( 42,  1,  3)=                 -0.16724259186672774113d0
      iwe=iwe+1
      weightb( 43,  1,  3)=                 -0.11696778062583472468d0
      iwe=iwe+1
      weightb( 44,  1,  3)=                 -0.08365402725173921861d0
      iwe=iwe+1
      weightb( 45,  1,  3)=                 -0.04542365701473953521d0
      iwe=iwe+1
      weightb( 46,  1,  3)=                  0.10388073049071999687d0
      iwe=iwe+1
      weightb( 47,  1,  3)=                  0.39082679385080698609d0
      iwe=iwe+1
      weightb( 48,  1,  3)=                 -0.29396510322839819462d0
      iwe=iwe+1
      weightb( 49,  1,  3)=                  0.45935517336168457669d0
      iwe=iwe+1
      weightb( 50,  1,  3)=                  0.18484973594235185046d0
      iwe=iwe+1
      biasb(  1,  3)=                 -1.40707524902501934783d0
      iwe=iwe+1
      weightb(  1,  2,  3)=                  0.18576943919845265163d0
      iwe=iwe+1
      weightb(  2,  2,  3)=                  0.04332706018369013312d0
      iwe=iwe+1
      weightb(  3,  2,  3)=                 -0.02009312086961264135d0
      iwe=iwe+1
      weightb(  4,  2,  3)=                  0.55050616745505920324d0
      iwe=iwe+1
      weightb(  5,  2,  3)=                  0.09504880429218778848d0
      iwe=iwe+1
      weightb(  6,  2,  3)=                  0.50046895604781926892d0
      iwe=iwe+1
      weightb(  7,  2,  3)=                  0.11246165229632018590d0
      iwe=iwe+1
      weightb(  8,  2,  3)=                  0.09402397595409126008d0
      iwe=iwe+1
      weightb(  9,  2,  3)=                  0.47390463397302434734d0
      iwe=iwe+1
      weightb( 10,  2,  3)=                 -0.35965526446360784885d0
      iwe=iwe+1
      weightb( 11,  2,  3)=                 -0.17403890948267042305d0
      iwe=iwe+1
      weightb( 12,  2,  3)=                  0.32428051292263021521d0
      iwe=iwe+1
      weightb( 13,  2,  3)=                  0.12709814657982082542d0
      iwe=iwe+1
      weightb( 14,  2,  3)=                 -0.60265106613760965892d0
      iwe=iwe+1
      weightb( 15,  2,  3)=                  0.09450356055774505881d0
      iwe=iwe+1
      weightb( 16,  2,  3)=                 -0.10650353994797745472d0
      iwe=iwe+1
      weightb( 17,  2,  3)=                 -0.73309219040576634185d0
      iwe=iwe+1
      weightb( 18,  2,  3)=                  0.67336925323836394064d0
      iwe=iwe+1
      weightb( 19,  2,  3)=                  0.38395762910079511698d0
      iwe=iwe+1
      weightb( 20,  2,  3)=                 -0.00627955287896258575d0
      iwe=iwe+1
      weightb( 21,  2,  3)=                 -0.14534532547905676392d0
      iwe=iwe+1
      weightb( 22,  2,  3)=                 -1.12508917414698039750d0
      iwe=iwe+1
      weightb( 23,  2,  3)=                  0.28296989702847591408d0
      iwe=iwe+1
      weightb( 24,  2,  3)=                  0.27485793244885409203d0
      iwe=iwe+1
      weightb( 25,  2,  3)=                 -0.39010326038203801957d0
      iwe=iwe+1
      weightb( 26,  2,  3)=                  0.75311637067528169887d0
      iwe=iwe+1
      weightb( 27,  2,  3)=                  0.67724712921468033233d0
      iwe=iwe+1
      weightb( 28,  2,  3)=                 -0.15603999156673137305d0
      iwe=iwe+1
      weightb( 29,  2,  3)=                  0.02836032876647483214d0
      iwe=iwe+1
      weightb( 30,  2,  3)=                  0.08567285352844292157d0
      iwe=iwe+1
      weightb( 31,  2,  3)=                 -0.18116720855040846505d0
      iwe=iwe+1
      weightb( 32,  2,  3)=                  0.28783641922647251743d0
      iwe=iwe+1
      weightb( 33,  2,  3)=                  0.25270157056294234588d0
      iwe=iwe+1
      weightb( 34,  2,  3)=                  0.12988436431473690535d0
      iwe=iwe+1
      weightb( 35,  2,  3)=                 -0.04701014359489311817d0
      iwe=iwe+1
      weightb( 36,  2,  3)=                  0.78523629210437484449d0
      iwe=iwe+1
      weightb( 37,  2,  3)=                 -0.39014069115540211952d0
      iwe=iwe+1
      weightb( 38,  2,  3)=                 -0.57843704345695279301d0
      iwe=iwe+1
      weightb( 39,  2,  3)=                 -0.08333262812165762035d0
      iwe=iwe+1
      weightb( 40,  2,  3)=                 -0.08017285057998685405d0
      iwe=iwe+1
      weightb( 41,  2,  3)=                 -0.12317718793260233612d0
      iwe=iwe+1
      weightb( 42,  2,  3)=                 -0.16221933411658837065d0
      iwe=iwe+1
      weightb( 43,  2,  3)=                  0.06167756576784468731d0
      iwe=iwe+1
      weightb( 44,  2,  3)=                 -0.13900566923386617479d0
      iwe=iwe+1
      weightb( 45,  2,  3)=                  0.16419859909531511755d0
      iwe=iwe+1
      weightb( 46,  2,  3)=                 -0.08622471740834028453d0
      iwe=iwe+1
      weightb( 47,  2,  3)=                 -0.35010493958732719078d0
      iwe=iwe+1
      weightb( 48,  2,  3)=                 -0.49790037533631081867d0
      iwe=iwe+1
      weightb( 49,  2,  3)=                  0.27159387710134369476d0
      iwe=iwe+1
      weightb( 50,  2,  3)=                 -0.26493973007610066572d0
      iwe=iwe+1
      biasb(  2,  3)=                 -1.69562352502658164610d0
      iwe=iwe+1
      weightb(  1,  3,  3)=                  0.19238248046469708097d0
      iwe=iwe+1
      weightb(  2,  3,  3)=                 -0.05063141784420250452d0
      iwe=iwe+1
      weightb(  3,  3,  3)=                  0.13383778542177143800d0
      iwe=iwe+1
      weightb(  4,  3,  3)=                  0.12273521179634475087d0
      iwe=iwe+1
      weightb(  5,  3,  3)=                  0.06231772127707383563d0
      iwe=iwe+1
      weightb(  6,  3,  3)=                  0.07920856179502633321d0
      iwe=iwe+1
      weightb(  7,  3,  3)=                 -0.29955620252198716935d0
      iwe=iwe+1
      weightb(  8,  3,  3)=                 -0.29208756223653536965d0
      iwe=iwe+1
      weightb(  9,  3,  3)=                  0.05305387051692018324d0
      iwe=iwe+1
      weightb( 10,  3,  3)=                  0.03551221223519286652d0
      iwe=iwe+1
      weightb( 11,  3,  3)=                 -0.23173783697914754343d0
      iwe=iwe+1
      weightb( 12,  3,  3)=                  0.44439974408785787308d0
      iwe=iwe+1
      weightb( 13,  3,  3)=                 -0.02749550312902988500d0
      iwe=iwe+1
      weightb( 14,  3,  3)=                  0.12087705238057219748d0
      iwe=iwe+1
      weightb( 15,  3,  3)=                  0.17038375926667143068d0
      iwe=iwe+1
      weightb( 16,  3,  3)=                 -0.84262311193702543743d0
      iwe=iwe+1
      weightb( 17,  3,  3)=                  0.00639328858672418617d0
      iwe=iwe+1
      weightb( 18,  3,  3)=                 -0.31158583312087495543d0
      iwe=iwe+1
      weightb( 19,  3,  3)=                 -0.12092450277574100237d0
      iwe=iwe+1
      weightb( 20,  3,  3)=                 -0.09060473557939187350d0
      iwe=iwe+1
      weightb( 21,  3,  3)=                  0.07189056403758695146d0
      iwe=iwe+1
      weightb( 22,  3,  3)=                 -0.25704096322796377017d0
      iwe=iwe+1
      weightb( 23,  3,  3)=                 -0.27761131842864428254d0
      iwe=iwe+1
      weightb( 24,  3,  3)=                  0.26660144615793246459d0
      iwe=iwe+1
      weightb( 25,  3,  3)=                  0.79344277054819190020d0
      iwe=iwe+1
      weightb( 26,  3,  3)=                 -0.39490917306220774119d0
      iwe=iwe+1
      weightb( 27,  3,  3)=                  0.15573616421245378705d0
      iwe=iwe+1
      weightb( 28,  3,  3)=                  0.47693871425937284236d0
      iwe=iwe+1
      weightb( 29,  3,  3)=                 -0.00144200118799243026d0
      iwe=iwe+1
      weightb( 30,  3,  3)=                 -0.07890463687391062464d0
      iwe=iwe+1
      weightb( 31,  3,  3)=                  0.31994609430437259689d0
      iwe=iwe+1
      weightb( 32,  3,  3)=                  0.14527889628047141457d0
      iwe=iwe+1
      weightb( 33,  3,  3)=                 -0.01439999850923008411d0
      iwe=iwe+1
      weightb( 34,  3,  3)=                  0.45122042228789582818d0
      iwe=iwe+1
      weightb( 35,  3,  3)=                  0.12253065626211782913d0
      iwe=iwe+1
      weightb( 36,  3,  3)=                 -0.13058048980360686953d0
      iwe=iwe+1
      weightb( 37,  3,  3)=                  0.44623319690034290996d0
      iwe=iwe+1
      weightb( 38,  3,  3)=                  0.31277693816058566023d0
      iwe=iwe+1
      weightb( 39,  3,  3)=                  0.17543048962802307300d0
      iwe=iwe+1
      weightb( 40,  3,  3)=                  0.01761850412655016976d0
      iwe=iwe+1
      weightb( 41,  3,  3)=                 -0.02030534543448219570d0
      iwe=iwe+1
      weightb( 42,  3,  3)=                 -0.06956416019275382667d0
      iwe=iwe+1
      weightb( 43,  3,  3)=                 -0.00749685354914590533d0
      iwe=iwe+1
      weightb( 44,  3,  3)=                  0.07422567728677427479d0
      iwe=iwe+1
      weightb( 45,  3,  3)=                  0.18190389829498315732d0
      iwe=iwe+1
      weightb( 46,  3,  3)=                 -0.19808667768157880995d0
      iwe=iwe+1
      weightb( 47,  3,  3)=                  0.40731854837078396159d0
      iwe=iwe+1
      weightb( 48,  3,  3)=                 -0.21736483788599397782d0
      iwe=iwe+1
      weightb( 49,  3,  3)=                  0.28710848176145853383d0
      iwe=iwe+1
      weightb( 50,  3,  3)=                  0.17799996466711867638d0
      iwe=iwe+1
      biasb(  3,  3)=                  1.58481295064087635005d0
      iwe=iwe+1
      weightb(  1,  4,  3)=                 -0.30067431407116945730d0
      iwe=iwe+1
      weightb(  2,  4,  3)=                 -0.02420630439088460387d0
      iwe=iwe+1
      weightb(  3,  4,  3)=                 -0.22340496165884365931d0
      iwe=iwe+1
      weightb(  4,  4,  3)=                  0.31714031393095915012d0
      iwe=iwe+1
      weightb(  5,  4,  3)=                 -0.16282410205951197701d0
      iwe=iwe+1
      weightb(  6,  4,  3)=                  0.35716721088812930507d0
      iwe=iwe+1
      weightb(  7,  4,  3)=                 -0.28560287012772456183d0
      iwe=iwe+1
      weightb(  8,  4,  3)=                  0.29960268215044760787d0
      iwe=iwe+1
      weightb(  9,  4,  3)=                  0.04380073258515420481d0
      iwe=iwe+1
      weightb( 10,  4,  3)=                  0.28894690355439128782d0
      iwe=iwe+1
      weightb( 11,  4,  3)=                 -0.16375694319733241633d0
      iwe=iwe+1
      weightb( 12,  4,  3)=                 -0.34432728748319368917d0
      iwe=iwe+1
      weightb( 13,  4,  3)=                 -0.05709094977121469128d0
      iwe=iwe+1
      weightb( 14,  4,  3)=                  0.01670108457120750289d0
      iwe=iwe+1
      weightb( 15,  4,  3)=                  0.22292368315579569327d0
      iwe=iwe+1
      weightb( 16,  4,  3)=                  0.25408029232456785795d0
      iwe=iwe+1
      weightb( 17,  4,  3)=                 -0.19350036227075015360d0
      iwe=iwe+1
      weightb( 18,  4,  3)=                  0.29487556056616914812d0
      iwe=iwe+1
      weightb( 19,  4,  3)=                  0.25608576426073553778d0
      iwe=iwe+1
      weightb( 20,  4,  3)=                 -0.27863062369774876936d0
      iwe=iwe+1
      weightb( 21,  4,  3)=                 -0.21621942395792786984d0
      iwe=iwe+1
      weightb( 22,  4,  3)=                 -0.11775922073974666449d0
      iwe=iwe+1
      weightb( 23,  4,  3)=                 -0.32201331759622026096d0
      iwe=iwe+1
      weightb( 24,  4,  3)=                  0.00225175214182557698d0
      iwe=iwe+1
      weightb( 25,  4,  3)=                 -0.15004221691094438151d0
      iwe=iwe+1
      weightb( 26,  4,  3)=                 -0.04377247837905546418d0
      iwe=iwe+1
      weightb( 27,  4,  3)=                  0.20871900731491643821d0
      iwe=iwe+1
      weightb( 28,  4,  3)=                  0.32546807445874792464d0
      iwe=iwe+1
      weightb( 29,  4,  3)=                  0.19717001909254913694d0
      iwe=iwe+1
      weightb( 30,  4,  3)=                 -0.09216130127553201490d0
      iwe=iwe+1
      weightb( 31,  4,  3)=                 -0.16802382992550948804d0
      iwe=iwe+1
      weightb( 32,  4,  3)=                  0.26318133688036771112d0
      iwe=iwe+1
      weightb( 33,  4,  3)=                  0.12236543403141823816d0
      iwe=iwe+1
      weightb( 34,  4,  3)=                 -0.19573732699404064461d0
      iwe=iwe+1
      weightb( 35,  4,  3)=                  0.08013682163903437794d0
      iwe=iwe+1
      weightb( 36,  4,  3)=                 -0.21207243980305781617d0
      iwe=iwe+1
      weightb( 37,  4,  3)=                 -0.16235152554390125390d0
      iwe=iwe+1
      weightb( 38,  4,  3)=                 -0.07525613186725213510d0
      iwe=iwe+1
      weightb( 39,  4,  3)=                  0.11690129267945481573d0
      iwe=iwe+1
      weightb( 40,  4,  3)=                 -0.23468492302447352404d0
      iwe=iwe+1
      weightb( 41,  4,  3)=                 -0.17501578214273780243d0
      iwe=iwe+1
      weightb( 42,  4,  3)=                 -0.13754156215549664943d0
      iwe=iwe+1
      weightb( 43,  4,  3)=                  0.10658734100542331669d0
      iwe=iwe+1
      weightb( 44,  4,  3)=                 -0.01038602969368689587d0
      iwe=iwe+1
      weightb( 45,  4,  3)=                 -0.19980770579599271830d0
      iwe=iwe+1
      weightb( 46,  4,  3)=                 -0.10947927554819875118d0
      iwe=iwe+1
      weightb( 47,  4,  3)=                  0.34645815549751740603d0
      iwe=iwe+1
      weightb( 48,  4,  3)=                 -0.20949469774341716866d0
      iwe=iwe+1
      weightb( 49,  4,  3)=                  0.23809723154428544256d0
      iwe=iwe+1
      weightb( 50,  4,  3)=                  0.08291278232959095607d0
      iwe=iwe+1
      biasb(  4,  3)=                  1.50182065407446296845d0
      iwe=iwe+1
      weightb(  1,  5,  3)=                 -0.18255319880997597504d0
      iwe=iwe+1
      weightb(  2,  5,  3)=                 -0.15417644218204157314d0
      iwe=iwe+1
      weightb(  3,  5,  3)=                  0.35332078307146103091d0
      iwe=iwe+1
      weightb(  4,  5,  3)=                  0.10473579719670875199d0
      iwe=iwe+1
      weightb(  5,  5,  3)=                  0.51474236802326722717d0
      iwe=iwe+1
      weightb(  6,  5,  3)=                  0.16885164765098445439d0
      iwe=iwe+1
      weightb(  7,  5,  3)=                  0.22877451361127659757d0
      iwe=iwe+1
      weightb(  8,  5,  3)=                 -0.30848679673061257800d0
      iwe=iwe+1
      weightb(  9,  5,  3)=                 -0.25152144467694892427d0
      iwe=iwe+1
      weightb( 10,  5,  3)=                  0.52379408422988094074d0
      iwe=iwe+1
      weightb( 11,  5,  3)=                 -0.09171052807015625530d0
      iwe=iwe+1
      weightb( 12,  5,  3)=                 -0.29475521382493991007d0
      iwe=iwe+1
      weightb( 13,  5,  3)=                  0.40466029285516269542d0
      iwe=iwe+1
      weightb( 14,  5,  3)=                 -0.29502134597513440806d0
      iwe=iwe+1
      weightb( 15,  5,  3)=                 -0.48972894222800444908d0
      iwe=iwe+1
      weightb( 16,  5,  3)=                  0.08866653637324713177d0
      iwe=iwe+1
      weightb( 17,  5,  3)=                  0.02922201527150064884d0
      iwe=iwe+1
      weightb( 18,  5,  3)=                 -0.33917719711451754794d0
      iwe=iwe+1
      weightb( 19,  5,  3)=                 -0.07907581062317582676d0
      iwe=iwe+1
      weightb( 20,  5,  3)=                 -0.30435843542898310954d0
      iwe=iwe+1
      weightb( 21,  5,  3)=                  0.40252069174990645628d0
      iwe=iwe+1
      weightb( 22,  5,  3)=                 -0.33703599527344607623d0
      iwe=iwe+1
      weightb( 23,  5,  3)=                 -0.25421320628031013333d0
      iwe=iwe+1
      weightb( 24,  5,  3)=                 -0.16592639788884924745d0
      iwe=iwe+1
      weightb( 25,  5,  3)=                  0.26188005302521100148d0
      iwe=iwe+1
      weightb( 26,  5,  3)=                 -0.22720071418019374687d0
      iwe=iwe+1
      weightb( 27,  5,  3)=                 -0.24388748116464376015d0
      iwe=iwe+1
      weightb( 28,  5,  3)=                  0.32916960046258231243d0
      iwe=iwe+1
      weightb( 29,  5,  3)=                  0.30053111280300148778d0
      iwe=iwe+1
      weightb( 30,  5,  3)=                  0.39420811716044285022d0
      iwe=iwe+1
      weightb( 31,  5,  3)=                 -0.37952040153144978030d0
      iwe=iwe+1
      weightb( 32,  5,  3)=                  0.45069616913890703236d0
      iwe=iwe+1
      weightb( 33,  5,  3)=                  0.32868247477085721364d0
      iwe=iwe+1
      weightb( 34,  5,  3)=                 -0.18573236787807687054d0
      iwe=iwe+1
      weightb( 35,  5,  3)=                 -0.03431394727985159071d0
      iwe=iwe+1
      weightb( 36,  5,  3)=                 -0.21248332023907709476d0
      iwe=iwe+1
      weightb( 37,  5,  3)=                 -0.14370887056356224099d0
      iwe=iwe+1
      weightb( 38,  5,  3)=                 -0.54574378328930417403d0
      iwe=iwe+1
      weightb( 39,  5,  3)=                  0.06832739148100677729d0
      iwe=iwe+1
      weightb( 40,  5,  3)=                  0.32128164756429872240d0
      iwe=iwe+1
      weightb( 41,  5,  3)=                  0.02224436729121442163d0
      iwe=iwe+1
      weightb( 42,  5,  3)=                  0.37509060683381545420d0
      iwe=iwe+1
      weightb( 43,  5,  3)=                 -0.15208563257872270702d0
      iwe=iwe+1
      weightb( 44,  5,  3)=                 -0.21821691830648096144d0
      iwe=iwe+1
      weightb( 45,  5,  3)=                 -0.27163284968118256435d0
      iwe=iwe+1
      weightb( 46,  5,  3)=                  0.30778841024026321049d0
      iwe=iwe+1
      weightb( 47,  5,  3)=                  0.37542757074569549358d0
      iwe=iwe+1
      weightb( 48,  5,  3)=                  0.40613481931720935014d0
      iwe=iwe+1
      weightb( 49,  5,  3)=                  0.40747965409336167619d0
      iwe=iwe+1
      weightb( 50,  5,  3)=                 -0.03599264804042362487d0
      iwe=iwe+1
      biasb(  5,  3)=                 -1.28600010243284534894d0
      iwe=iwe+1
      weightb(  1,  6,  3)=                  0.28766283298859945949d0
      iwe=iwe+1
      weightb(  2,  6,  3)=                  0.82061725555448550296d0
      iwe=iwe+1
      weightb(  3,  6,  3)=                  0.15679313113676532354d0
      iwe=iwe+1
      weightb(  4,  6,  3)=                 -0.57977572206207450556d0
      iwe=iwe+1
      weightb(  5,  6,  3)=                 -0.88319882551941530924d0
      iwe=iwe+1
      weightb(  6,  6,  3)=                  0.06589620184247629853d0
      iwe=iwe+1
      weightb(  7,  6,  3)=                  0.14074679536597087259d0
      iwe=iwe+1
      weightb(  8,  6,  3)=                 -0.18371951633092709066d0
      iwe=iwe+1
      weightb(  9,  6,  3)=                 -0.07459120297864386961d0
      iwe=iwe+1
      weightb( 10,  6,  3)=                 -0.26424108530571227549d0
      iwe=iwe+1
      weightb( 11,  6,  3)=                 -0.30649111359462632986d0
      iwe=iwe+1
      weightb( 12,  6,  3)=                  0.01459186200511776096d0
      iwe=iwe+1
      weightb( 13,  6,  3)=                  0.06336504474122087172d0
      iwe=iwe+1
      weightb( 14,  6,  3)=                 -0.20189588387808618530d0
      iwe=iwe+1
      weightb( 15,  6,  3)=                 -0.32230789154600542057d0
      iwe=iwe+1
      weightb( 16,  6,  3)=                  0.32545250812658588213d0
      iwe=iwe+1
      weightb( 17,  6,  3)=                  0.34232762149334683421d0
      iwe=iwe+1
      weightb( 18,  6,  3)=                 -0.02717315998777749403d0
      iwe=iwe+1
      weightb( 19,  6,  3)=                 -0.07494021739724035513d0
      iwe=iwe+1
      weightb( 20,  6,  3)=                 -0.01493270555057253472d0
      iwe=iwe+1
      weightb( 21,  6,  3)=                 -0.57396630522997393875d0
      iwe=iwe+1
      weightb( 22,  6,  3)=                 -0.07486393931825011117d0
      iwe=iwe+1
      weightb( 23,  6,  3)=                 -0.03941106766162483926d0
      iwe=iwe+1
      weightb( 24,  6,  3)=                 -0.59459106322084676055d0
      iwe=iwe+1
      weightb( 25,  6,  3)=                 -0.22544871987660403123d0
      iwe=iwe+1
      weightb( 26,  6,  3)=                 -0.37141470844501073278d0
      iwe=iwe+1
      weightb( 27,  6,  3)=                  0.35765982972975080001d0
      iwe=iwe+1
      weightb( 28,  6,  3)=                  0.35525035122078069127d0
      iwe=iwe+1
      weightb( 29,  6,  3)=                  0.10235759294849808287d0
      iwe=iwe+1
      weightb( 30,  6,  3)=                 -0.45315976648580924557d0
      iwe=iwe+1
      weightb( 31,  6,  3)=                  0.19584826971353053171d0
      iwe=iwe+1
      weightb( 32,  6,  3)=                  0.40912899819501724608d0
      iwe=iwe+1
      weightb( 33,  6,  3)=                 -0.47035746258913657680d0
      iwe=iwe+1
      weightb( 34,  6,  3)=                 -0.54787217067403415349d0
      iwe=iwe+1
      weightb( 35,  6,  3)=                 -0.26481001936198261815d0
      iwe=iwe+1
      weightb( 36,  6,  3)=                 -0.38169431531080799669d0
      iwe=iwe+1
      weightb( 37,  6,  3)=                 -0.14316967163549362829d0
      iwe=iwe+1
      weightb( 38,  6,  3)=                  0.39466186704743072555d0
      iwe=iwe+1
      weightb( 39,  6,  3)=                  0.46045589042952977943d0
      iwe=iwe+1
      weightb( 40,  6,  3)=                  0.63882733070619501792d0
      iwe=iwe+1
      weightb( 41,  6,  3)=                 -0.33153221332617510697d0
      iwe=iwe+1
      weightb( 42,  6,  3)=                  0.05995675772480546506d0
      iwe=iwe+1
      weightb( 43,  6,  3)=                 -0.33357938580386381489d0
      iwe=iwe+1
      weightb( 44,  6,  3)=                  0.05612290159495649661d0
      iwe=iwe+1
      weightb( 45,  6,  3)=                 -0.02050513789592306804d0
      iwe=iwe+1
      weightb( 46,  6,  3)=                 -0.09419789472094616811d0
      iwe=iwe+1
      weightb( 47,  6,  3)=                 -0.43888341814646458783d0
      iwe=iwe+1
      weightb( 48,  6,  3)=                 -0.20730924425556002122d0
      iwe=iwe+1
      weightb( 49,  6,  3)=                 -0.29405749949729742543d0
      iwe=iwe+1
      weightb( 50,  6,  3)=                  0.05787523632678327062d0
      iwe=iwe+1
      biasb(  6,  3)=                  1.27450569487185672024d0
      iwe=iwe+1
      weightb(  1,  7,  3)=                 -0.10800222926112840183d0
      iwe=iwe+1
      weightb(  2,  7,  3)=                 -0.82427117270796368409d0
      iwe=iwe+1
      weightb(  3,  7,  3)=                  0.25096914842681972146d0
      iwe=iwe+1
      weightb(  4,  7,  3)=                 -0.66827906623272936848d0
      iwe=iwe+1
      weightb(  5,  7,  3)=                  0.06488547282147470729d0
      iwe=iwe+1
      weightb(  6,  7,  3)=                  0.53067140464531648014d0
      iwe=iwe+1
      weightb(  7,  7,  3)=                  0.18242422410856845572d0
      iwe=iwe+1
      weightb(  8,  7,  3)=                 -0.13844572943866972903d0
      iwe=iwe+1
      weightb(  9,  7,  3)=                 -0.05752841554117240491d0
      iwe=iwe+1
      weightb( 10,  7,  3)=                  0.26587151882999532360d0
      iwe=iwe+1
      weightb( 11,  7,  3)=                  0.02675557504575765133d0
      iwe=iwe+1
      weightb( 12,  7,  3)=                  0.35452252689745306080d0
      iwe=iwe+1
      weightb( 13,  7,  3)=                 -0.26431375205195661859d0
      iwe=iwe+1
      weightb( 14,  7,  3)=                 -0.07862323618671739067d0
      iwe=iwe+1
      weightb( 15,  7,  3)=                  0.24173645361030868250d0
      iwe=iwe+1
      weightb( 16,  7,  3)=                  0.61494957036484376722d0
      iwe=iwe+1
      weightb( 17,  7,  3)=                  0.22923940142580687129d0
      iwe=iwe+1
      weightb( 18,  7,  3)=                  0.05943118407693481764d0
      iwe=iwe+1
      weightb( 19,  7,  3)=                  0.17629195455275994964d0
      iwe=iwe+1
      weightb( 20,  7,  3)=                 -0.11840912991385667274d0
      iwe=iwe+1
      weightb( 21,  7,  3)=                  0.22948736580304276989d0
      iwe=iwe+1
      weightb( 22,  7,  3)=                 -0.06277716194491334001d0
      iwe=iwe+1
      weightb( 23,  7,  3)=                 -0.39390235627616804193d0
      iwe=iwe+1
      weightb( 24,  7,  3)=                 -0.38463415836129777325d0
      iwe=iwe+1
      weightb( 25,  7,  3)=                 -0.11757391566402164429d0
      iwe=iwe+1
      weightb( 26,  7,  3)=                 -0.53478473443976659585d0
      iwe=iwe+1
      weightb( 27,  7,  3)=                 -0.09815622001127075058d0
      iwe=iwe+1
      weightb( 28,  7,  3)=                 -0.20062167420446780364d0
      iwe=iwe+1
      weightb( 29,  7,  3)=                  0.07201781406193016877d0
      iwe=iwe+1
      weightb( 30,  7,  3)=                  0.14643722623553015461d0
      iwe=iwe+1
      weightb( 31,  7,  3)=                  0.51847215216542774652d0
      iwe=iwe+1
      weightb( 32,  7,  3)=                 -0.17775754671082250047d0
      iwe=iwe+1
      weightb( 33,  7,  3)=                  0.25941902399044458605d0
      iwe=iwe+1
      weightb( 34,  7,  3)=                 -0.15778221613505866161d0
      iwe=iwe+1
      weightb( 35,  7,  3)=                 -0.49179508221445966676d0
      iwe=iwe+1
      weightb( 36,  7,  3)=                  0.33889868789075217048d0
      iwe=iwe+1
      weightb( 37,  7,  3)=                  0.37301370812221967821d0
      iwe=iwe+1
      weightb( 38,  7,  3)=                  0.20010447028816955028d0
      iwe=iwe+1
      weightb( 39,  7,  3)=                 -0.10103591688804537674d0
      iwe=iwe+1
      weightb( 40,  7,  3)=                  0.57893748826193269785d0
      iwe=iwe+1
      weightb( 41,  7,  3)=                 -0.06290088188571565930d0
      iwe=iwe+1
      weightb( 42,  7,  3)=                 -0.00476203108212257947d0
      iwe=iwe+1
      weightb( 43,  7,  3)=                 -0.32948970784557318758d0
      iwe=iwe+1
      weightb( 44,  7,  3)=                  0.32053341794570039403d0
      iwe=iwe+1
      weightb( 45,  7,  3)=                 -0.24705139158722683179d0
      iwe=iwe+1
      weightb( 46,  7,  3)=                 -0.06782032308695404299d0
      iwe=iwe+1
      weightb( 47,  7,  3)=                  0.02004479722483180903d0
      iwe=iwe+1
      weightb( 48,  7,  3)=                 -0.26536090027405578873d0
      iwe=iwe+1
      weightb( 49,  7,  3)=                  0.06241177717423822269d0
      iwe=iwe+1
      weightb( 50,  7,  3)=                 -0.28688466430416093012d0
      iwe=iwe+1
      biasb(  7,  3)=                  1.20158054419720916606d0
      iwe=iwe+1
      weightb(  1,  8,  3)=                 -0.08728434817196058237d0
      iwe=iwe+1
      weightb(  2,  8,  3)=                 -0.17369383707117214133d0
      iwe=iwe+1
      weightb(  3,  8,  3)=                 -0.43689666135030419403d0
      iwe=iwe+1
      weightb(  4,  8,  3)=                  0.09848633474020321299d0
      iwe=iwe+1
      weightb(  5,  8,  3)=                  0.18489369775385405825d0
      iwe=iwe+1
      weightb(  6,  8,  3)=                  0.43754861736382433257d0
      iwe=iwe+1
      weightb(  7,  8,  3)=                 -0.43468223563878866100d0
      iwe=iwe+1
      weightb(  8,  8,  3)=                 -0.38130035127539146922d0
      iwe=iwe+1
      weightb(  9,  8,  3)=                 -0.12381718423692393560d0
      iwe=iwe+1
      weightb( 10,  8,  3)=                  0.21227814620658863598d0
      iwe=iwe+1
      weightb( 11,  8,  3)=                  0.12918759104678737004d0
      iwe=iwe+1
      weightb( 12,  8,  3)=                  0.12883414848364047045d0
      iwe=iwe+1
      weightb( 13,  8,  3)=                 -0.10416190627072947905d0
      iwe=iwe+1
      weightb( 14,  8,  3)=                 -0.12187084445781426467d0
      iwe=iwe+1
      weightb( 15,  8,  3)=                  0.01728248512120699604d0
      iwe=iwe+1
      weightb( 16,  8,  3)=                  0.17361001373717196983d0
      iwe=iwe+1
      weightb( 17,  8,  3)=                  0.14834028542835242526d0
      iwe=iwe+1
      weightb( 18,  8,  3)=                 -0.06167688280358696318d0
      iwe=iwe+1
      weightb( 19,  8,  3)=                 -0.04965456254712444228d0
      iwe=iwe+1
      weightb( 20,  8,  3)=                 -0.16333817372404693669d0
      iwe=iwe+1
      weightb( 21,  8,  3)=                 -0.20312511066807215077d0
      iwe=iwe+1
      weightb( 22,  8,  3)=                  0.31603038652079934456d0
      iwe=iwe+1
      weightb( 23,  8,  3)=                  0.48952802888258717395d0
      iwe=iwe+1
      weightb( 24,  8,  3)=                 -0.09979111428585912824d0
      iwe=iwe+1
      weightb( 25,  8,  3)=                 -0.19659240629223148633d0
      iwe=iwe+1
      weightb( 26,  8,  3)=                 -0.50418655173827398031d0
      iwe=iwe+1
      weightb( 27,  8,  3)=                 -0.30736032614233943505d0
      iwe=iwe+1
      weightb( 28,  8,  3)=                 -0.11844987253161820551d0
      iwe=iwe+1
      weightb( 29,  8,  3)=                  0.03715389234131815516d0
      iwe=iwe+1
      weightb( 30,  8,  3)=                 -0.55084382598088021954d0
      iwe=iwe+1
      weightb( 31,  8,  3)=                  0.28401103215956985393d0
      iwe=iwe+1
      weightb( 32,  8,  3)=                 -0.01999498504828517431d0
      iwe=iwe+1
      weightb( 33,  8,  3)=                 -0.09354009289090588208d0
      iwe=iwe+1
      weightb( 34,  8,  3)=                 -0.39612151094330555479d0
      iwe=iwe+1
      weightb( 35,  8,  3)=                 -0.13783508950319267594d0
      iwe=iwe+1
      weightb( 36,  8,  3)=                 -0.06711271965060242040d0
      iwe=iwe+1
      weightb( 37,  8,  3)=                  0.35972336192525727894d0
      iwe=iwe+1
      weightb( 38,  8,  3)=                  0.28292288144287319751d0
      iwe=iwe+1
      weightb( 39,  8,  3)=                  0.07717731310621975260d0
      iwe=iwe+1
      weightb( 40,  8,  3)=                 -0.05159881165618616927d0
      iwe=iwe+1
      weightb( 41,  8,  3)=                  0.22529945931211700638d0
      iwe=iwe+1
      weightb( 42,  8,  3)=                  0.15691966102123519611d0
      iwe=iwe+1
      weightb( 43,  8,  3)=                  0.28367886006730813619d0
      iwe=iwe+1
      weightb( 44,  8,  3)=                  0.16746632282477522113d0
      iwe=iwe+1
      weightb( 45,  8,  3)=                  0.21469430933094019176d0
      iwe=iwe+1
      weightb( 46,  8,  3)=                  0.08564086420774238984d0
      iwe=iwe+1
      weightb( 47,  8,  3)=                  0.16240489006782396486d0
      iwe=iwe+1
      weightb( 48,  8,  3)=                 -0.37701043130940603554d0
      iwe=iwe+1
      weightb( 49,  8,  3)=                 -0.17101138903970986016d0
      iwe=iwe+1
      weightb( 50,  8,  3)=                 -0.27776738270206813297d0
      iwe=iwe+1
      biasb(  8,  3)=                  1.15832045687556473013d0
      iwe=iwe+1
      weightb(  1,  9,  3)=                 -0.19377423399547519245d0
      iwe=iwe+1
      weightb(  2,  9,  3)=                 -0.05709700044101191641d0
      iwe=iwe+1
      weightb(  3,  9,  3)=                 -0.15480887894897207846d0
      iwe=iwe+1
      weightb(  4,  9,  3)=                  0.49989819228081233682d0
      iwe=iwe+1
      weightb(  5,  9,  3)=                 -0.21235008528572346664d0
      iwe=iwe+1
      weightb(  6,  9,  3)=                  0.00009431547680415365d0
      iwe=iwe+1
      weightb(  7,  9,  3)=                  0.10604822486012223381d0
      iwe=iwe+1
      weightb(  8,  9,  3)=                  0.07793449243306574403d0
      iwe=iwe+1
      weightb(  9,  9,  3)=                 -0.27577072432390170587d0
      iwe=iwe+1
      weightb( 10,  9,  3)=                  0.18880955522714179540d0
      iwe=iwe+1
      weightb( 11,  9,  3)=                 -0.32571159833292340213d0
      iwe=iwe+1
      weightb( 12,  9,  3)=                  0.03262220336198952408d0
      iwe=iwe+1
      weightb( 13,  9,  3)=                 -0.22157030726808840670d0
      iwe=iwe+1
      weightb( 14,  9,  3)=                  0.43109675326227625547d0
      iwe=iwe+1
      weightb( 15,  9,  3)=                  0.05735738497424312798d0
      iwe=iwe+1
      weightb( 16,  9,  3)=                 -0.35237979638530841919d0
      iwe=iwe+1
      weightb( 17,  9,  3)=                  0.24322166204857170735d0
      iwe=iwe+1
      weightb( 18,  9,  3)=                  0.08481682936358608815d0
      iwe=iwe+1
      weightb( 19,  9,  3)=                  0.41177782202407225975d0
      iwe=iwe+1
      weightb( 20,  9,  3)=                 -0.28595275686051868647d0
      iwe=iwe+1
      weightb( 21,  9,  3)=                  0.18456452439754511552d0
      iwe=iwe+1
      weightb( 22,  9,  3)=                 -0.50891551443088545170d0
      iwe=iwe+1
      weightb( 23,  9,  3)=                 -0.00629903094025370015d0
      iwe=iwe+1
      weightb( 24,  9,  3)=                 -0.27542907256538506910d0
      iwe=iwe+1
      weightb( 25,  9,  3)=                  0.03059656803325972591d0
      iwe=iwe+1
      weightb( 26,  9,  3)=                 -0.20715558090571797867d0
      iwe=iwe+1
      weightb( 27,  9,  3)=                  0.46743942609494021356d0
      iwe=iwe+1
      weightb( 28,  9,  3)=                  0.05412158136679899589d0
      iwe=iwe+1
      weightb( 29,  9,  3)=                  0.03670155001154924712d0
      iwe=iwe+1
      weightb( 30,  9,  3)=                 -0.31616975239246392082d0
      iwe=iwe+1
      weightb( 31,  9,  3)=                 -0.01131378817633713063d0
      iwe=iwe+1
      weightb( 32,  9,  3)=                 -0.20310363897501648722d0
      iwe=iwe+1
      weightb( 33,  9,  3)=                 -0.08021283950540999963d0
      iwe=iwe+1
      weightb( 34,  9,  3)=                  0.03358358442770092295d0
      iwe=iwe+1
      weightb( 35,  9,  3)=                  0.24544620617193935175d0
      iwe=iwe+1
      weightb( 36,  9,  3)=                  0.14546698443394517897d0
      iwe=iwe+1
      weightb( 37,  9,  3)=                 -0.00770646787463109308d0
      iwe=iwe+1
      weightb( 38,  9,  3)=                  0.40226980587159055780d0
      iwe=iwe+1
      weightb( 39,  9,  3)=                  0.31661474949375117971d0
      iwe=iwe+1
      weightb( 40,  9,  3)=                  0.31649739638440588241d0
      iwe=iwe+1
      weightb( 41,  9,  3)=                  0.32612960818442765509d0
      iwe=iwe+1
      weightb( 42,  9,  3)=                 -0.38993210419954960066d0
      iwe=iwe+1
      weightb( 43,  9,  3)=                 -0.01976027871967641833d0
      iwe=iwe+1
      weightb( 44,  9,  3)=                  0.26729516621293419876d0
      iwe=iwe+1
      weightb( 45,  9,  3)=                  0.04726402872591691645d0
      iwe=iwe+1
      weightb( 46,  9,  3)=                  0.06125213879893105090d0
      iwe=iwe+1
      weightb( 47,  9,  3)=                  0.06916096319138145820d0
      iwe=iwe+1
      weightb( 48,  9,  3)=                  0.39582473427548409139d0
      iwe=iwe+1
      weightb( 49,  9,  3)=                  0.05588001652723086771d0
      iwe=iwe+1
      weightb( 50,  9,  3)=                 -0.01826147763856955306d0
      iwe=iwe+1
      biasb(  9,  3)=                  1.27155425417156298096d0
      iwe=iwe+1
      weightb(  1, 10,  3)=                  0.25932563205430808617d0
      iwe=iwe+1
      weightb(  2, 10,  3)=                 -0.15385794693287613288d0
      iwe=iwe+1
      weightb(  3, 10,  3)=                  0.08495402048650974036d0
      iwe=iwe+1
      weightb(  4, 10,  3)=                  0.46718836604151064984d0
      iwe=iwe+1
      weightb(  5, 10,  3)=                 -0.14629378838272777408d0
      iwe=iwe+1
      weightb(  6, 10,  3)=                 -0.13194926243387214426d0
      iwe=iwe+1
      weightb(  7, 10,  3)=                 -0.06462630447832044822d0
      iwe=iwe+1
      weightb(  8, 10,  3)=                 -0.15967139652644551928d0
      iwe=iwe+1
      weightb(  9, 10,  3)=                 -0.07945641647692000542d0
      iwe=iwe+1
      weightb( 10, 10,  3)=                  0.56010374060755696579d0
      iwe=iwe+1
      weightb( 11, 10,  3)=                  0.50390547320564349487d0
      iwe=iwe+1
      weightb( 12, 10,  3)=                 -0.39659984290269878482d0
      iwe=iwe+1
      weightb( 13, 10,  3)=                 -0.08030016908125960085d0
      iwe=iwe+1
      weightb( 14, 10,  3)=                 -0.12897592164093274469d0
      iwe=iwe+1
      weightb( 15, 10,  3)=                 -0.03343182060155116403d0
      iwe=iwe+1
      weightb( 16, 10,  3)=                  0.15855291382334932293d0
      iwe=iwe+1
      weightb( 17, 10,  3)=                 -0.29163299248569701794d0
      iwe=iwe+1
      weightb( 18, 10,  3)=                  0.27794104662829843821d0
      iwe=iwe+1
      weightb( 19, 10,  3)=                 -0.10573940641542908803d0
      iwe=iwe+1
      weightb( 20, 10,  3)=                 -0.08757061459039146289d0
      iwe=iwe+1
      weightb( 21, 10,  3)=                  0.05011462021605805894d0
      iwe=iwe+1
      weightb( 22, 10,  3)=                  0.08288700674607427099d0
      iwe=iwe+1
      weightb( 23, 10,  3)=                  0.40909787068491615392d0
      iwe=iwe+1
      weightb( 24, 10,  3)=                  0.00180432413143407190d0
      iwe=iwe+1
      weightb( 25, 10,  3)=                 -0.43318746998945989457d0
      iwe=iwe+1
      weightb( 26, 10,  3)=                  0.33104474653093873826d0
      iwe=iwe+1
      weightb( 27, 10,  3)=                 -0.35348539577821963542d0
      iwe=iwe+1
      weightb( 28, 10,  3)=                  0.17476026253358986629d0
      iwe=iwe+1
      weightb( 29, 10,  3)=                 -0.54378776225226921337d0
      iwe=iwe+1
      weightb( 30, 10,  3)=                  0.07508322273177994721d0
      iwe=iwe+1
      weightb( 31, 10,  3)=                 -0.53024578716811365808d0
      iwe=iwe+1
      weightb( 32, 10,  3)=                  0.27779531977289767530d0
      iwe=iwe+1
      weightb( 33, 10,  3)=                 -0.05111794439706222881d0
      iwe=iwe+1
      weightb( 34, 10,  3)=                 -0.12131412518195930361d0
      iwe=iwe+1
      weightb( 35, 10,  3)=                  0.35225101833905297921d0
      iwe=iwe+1
      weightb( 36, 10,  3)=                 -0.13317096334805542113d0
      iwe=iwe+1
      weightb( 37, 10,  3)=                  0.07224461445850510755d0
      iwe=iwe+1
      weightb( 38, 10,  3)=                 -0.25939012236499375819d0
      iwe=iwe+1
      weightb( 39, 10,  3)=                 -0.21862902591413410636d0
      iwe=iwe+1
      weightb( 40, 10,  3)=                  0.36052587862693308285d0
      iwe=iwe+1
      weightb( 41, 10,  3)=                  0.54225654965621106207d0
      iwe=iwe+1
      weightb( 42, 10,  3)=                  0.18881751760203102641d0
      iwe=iwe+1
      weightb( 43, 10,  3)=                 -0.35993120258555172386d0
      iwe=iwe+1
      weightb( 44, 10,  3)=                 -0.09195584647644772236d0
      iwe=iwe+1
      weightb( 45, 10,  3)=                 -0.17004120002235623144d0
      iwe=iwe+1
      weightb( 46, 10,  3)=                 -0.16279286801589290534d0
      iwe=iwe+1
      weightb( 47, 10,  3)=                  0.27360819239919942358d0
      iwe=iwe+1
      weightb( 48, 10,  3)=                  0.18779644819261434585d0
      iwe=iwe+1
      weightb( 49, 10,  3)=                  0.26104323125708966957d0
      iwe=iwe+1
      weightb( 50, 10,  3)=                 -0.28356821362334022618d0
      iwe=iwe+1
      biasb( 10,  3)=                 -1.26051026020637335634d0
      iwe=iwe+1
      weightb(  1, 11,  3)=                  0.17729899105051702413d0
      iwe=iwe+1
      weightb(  2, 11,  3)=                  0.19861546429254059443d0
      iwe=iwe+1
      weightb(  3, 11,  3)=                  0.14673429160508319469d0
      iwe=iwe+1
      weightb(  4, 11,  3)=                  0.06730653804963086795d0
      iwe=iwe+1
      weightb(  5, 11,  3)=                 -0.00762766564410074198d0
      iwe=iwe+1
      weightb(  6, 11,  3)=                 -0.34744337829590021816d0
      iwe=iwe+1
      weightb(  7, 11,  3)=                  0.10220636810307789921d0
      iwe=iwe+1
      weightb(  8, 11,  3)=                  0.26643314919133664898d0
      iwe=iwe+1
      weightb(  9, 11,  3)=                  0.31540386465105785252d0
      iwe=iwe+1
      weightb( 10, 11,  3)=                 -0.24445780468257485851d0
      iwe=iwe+1
      weightb( 11, 11,  3)=                  0.12362316072960069513d0
      iwe=iwe+1
      weightb( 12, 11,  3)=                  0.10651985814873701774d0
      iwe=iwe+1
      weightb( 13, 11,  3)=                 -0.46760780123938627817d0
      iwe=iwe+1
      weightb( 14, 11,  3)=                  0.08364028773194447097d0
      iwe=iwe+1
      weightb( 15, 11,  3)=                 -0.12133549099021559425d0
      iwe=iwe+1
      weightb( 16, 11,  3)=                 -0.06153998084670694174d0
      iwe=iwe+1
      weightb( 17, 11,  3)=                  0.36109402993742534260d0
      iwe=iwe+1
      weightb( 18, 11,  3)=                  0.09758255197274301462d0
      iwe=iwe+1
      weightb( 19, 11,  3)=                  0.28821786835445312169d0
      iwe=iwe+1
      weightb( 20, 11,  3)=                 -0.21486121734125218641d0
      iwe=iwe+1
      weightb( 21, 11,  3)=                  0.44664845748467563169d0
      iwe=iwe+1
      weightb( 22, 11,  3)=                 -0.21151639196535321208d0
      iwe=iwe+1
      weightb( 23, 11,  3)=                 -0.25131465132990610245d0
      iwe=iwe+1
      weightb( 24, 11,  3)=                 -0.44684089701306844988d0
      iwe=iwe+1
      weightb( 25, 11,  3)=                  0.30748123930950072014d0
      iwe=iwe+1
      weightb( 26, 11,  3)=                 -0.02945248557404170700d0
      iwe=iwe+1
      weightb( 27, 11,  3)=                  0.43239263750664802544d0
      iwe=iwe+1
      weightb( 28, 11,  3)=                 -0.18338532516766925529d0
      iwe=iwe+1
      weightb( 29, 11,  3)=                 -0.05775849687254748510d0
      iwe=iwe+1
      weightb( 30, 11,  3)=                  0.04127531864665172356d0
      iwe=iwe+1
      weightb( 31, 11,  3)=                 -0.00929170981149872281d0
      iwe=iwe+1
      weightb( 32, 11,  3)=                 -0.09709535258506094002d0
      iwe=iwe+1
      weightb( 33, 11,  3)=                  0.42865277209597013597d0
      iwe=iwe+1
      weightb( 34, 11,  3)=                 -0.07828069332641404698d0
      iwe=iwe+1
      weightb( 35, 11,  3)=                  0.42243610005407422614d0
      iwe=iwe+1
      weightb( 36, 11,  3)=                  0.13561448351502011778d0
      iwe=iwe+1
      weightb( 37, 11,  3)=                 -0.22205568276312762088d0
      iwe=iwe+1
      weightb( 38, 11,  3)=                  0.19763962386120637049d0
      iwe=iwe+1
      weightb( 39, 11,  3)=                 -0.28584287752118092696d0
      iwe=iwe+1
      weightb( 40, 11,  3)=                  0.05334460449821779027d0
      iwe=iwe+1
      weightb( 41, 11,  3)=                  0.54632374864443589146d0
      iwe=iwe+1
      weightb( 42, 11,  3)=                 -0.17994815328626737050d0
      iwe=iwe+1
      weightb( 43, 11,  3)=                 -0.10284819713801632290d0
      iwe=iwe+1
      weightb( 44, 11,  3)=                  0.11824051193126142167d0
      iwe=iwe+1
      weightb( 45, 11,  3)=                  0.27939808901088358795d0
      iwe=iwe+1
      weightb( 46, 11,  3)=                  0.36885246269135613106d0
      iwe=iwe+1
      weightb( 47, 11,  3)=                  0.03397281159159558361d0
      iwe=iwe+1
      weightb( 48, 11,  3)=                  0.22069194668268515835d0
      iwe=iwe+1
      weightb( 49, 11,  3)=                 -0.27230718804452769266d0
      iwe=iwe+1
      weightb( 50, 11,  3)=                  0.08691824879861326236d0
      iwe=iwe+1
      biasb( 11,  3)=                  1.11592957569406925344d0
      iwe=iwe+1
      weightb(  1, 12,  3)=                  0.43805276526408259974d0
      iwe=iwe+1
      weightb(  2, 12,  3)=                 -0.59782066228792596352d0
      iwe=iwe+1
      weightb(  3, 12,  3)=                  0.05392690402822283846d0
      iwe=iwe+1
      weightb(  4, 12,  3)=                  0.26851508972905030470d0
      iwe=iwe+1
      weightb(  5, 12,  3)=                 -0.33378355443181390028d0
      iwe=iwe+1
      weightb(  6, 12,  3)=                  0.23068378747493831216d0
      iwe=iwe+1
      weightb(  7, 12,  3)=                  0.28261847706311221673d0
      iwe=iwe+1
      weightb(  8, 12,  3)=                  0.00605530692161825729d0
      iwe=iwe+1
      weightb(  9, 12,  3)=                 -0.62326801869034531567d0
      iwe=iwe+1
      weightb( 10, 12,  3)=                 -0.32512996250454445635d0
      iwe=iwe+1
      weightb( 11, 12,  3)=                  0.38733810742539870331d0
      iwe=iwe+1
      weightb( 12, 12,  3)=                  0.16087537429860784832d0
      iwe=iwe+1
      weightb( 13, 12,  3)=                  0.23178035913926589573d0
      iwe=iwe+1
      weightb( 14, 12,  3)=                 -0.66055459148998907359d0
      iwe=iwe+1
      weightb( 15, 12,  3)=                  0.59719494785717031071d0
      iwe=iwe+1
      weightb( 16, 12,  3)=                  0.17690030563927097718d0
      iwe=iwe+1
      weightb( 17, 12,  3)=                 -0.05935214933226262007d0
      iwe=iwe+1
      weightb( 18, 12,  3)=                 -0.81814166669555876688d0
      iwe=iwe+1
      weightb( 19, 12,  3)=                  0.06195544661377948292d0
      iwe=iwe+1
      weightb( 20, 12,  3)=                  0.14924805644530358961d0
      iwe=iwe+1
      weightb( 21, 12,  3)=                 -0.42186606388181291383d0
      iwe=iwe+1
      weightb( 22, 12,  3)=                  0.56811218551744557814d0
      iwe=iwe+1
      weightb( 23, 12,  3)=                  0.20249359881263759298d0
      iwe=iwe+1
      weightb( 24, 12,  3)=                  0.27173191816975067470d0
      iwe=iwe+1
      weightb( 25, 12,  3)=                 -0.04177948684356148912d0
      iwe=iwe+1
      weightb( 26, 12,  3)=                  0.08644207387101592033d0
      iwe=iwe+1
      weightb( 27, 12,  3)=                 -0.09395859394584894775d0
      iwe=iwe+1
      weightb( 28, 12,  3)=                 -0.30020630938095149709d0
      iwe=iwe+1
      weightb( 29, 12,  3)=                 -0.52182502434390221069d0
      iwe=iwe+1
      weightb( 30, 12,  3)=                 -0.08862293385067618323d0
      iwe=iwe+1
      weightb( 31, 12,  3)=                 -0.05374074560909355286d0
      iwe=iwe+1
      weightb( 32, 12,  3)=                 -0.08132956893582792002d0
      iwe=iwe+1
      weightb( 33, 12,  3)=                  0.02441488293796269943d0
      iwe=iwe+1
      weightb( 34, 12,  3)=                  0.64958556644022513726d0
      iwe=iwe+1
      weightb( 35, 12,  3)=                  0.41253464244919818560d0
      iwe=iwe+1
      weightb( 36, 12,  3)=                  0.42847581791826527819d0
      iwe=iwe+1
      weightb( 37, 12,  3)=                  0.17694476947556700419d0
      iwe=iwe+1
      weightb( 38, 12,  3)=                 -0.03913257045511303600d0
      iwe=iwe+1
      weightb( 39, 12,  3)=                 -0.09871726163370506124d0
      iwe=iwe+1
      weightb( 40, 12,  3)=                  0.30309671510963542840d0
      iwe=iwe+1
      weightb( 41, 12,  3)=                 -0.22484733077491828035d0
      iwe=iwe+1
      weightb( 42, 12,  3)=                 -0.27308030946481287593d0
      iwe=iwe+1
      weightb( 43, 12,  3)=                 -0.52194233416424595795d0
      iwe=iwe+1
      weightb( 44, 12,  3)=                 -0.01334068225511383064d0
      iwe=iwe+1
      weightb( 45, 12,  3)=                 -0.19300688598974929944d0
      iwe=iwe+1
      weightb( 46, 12,  3)=                  0.40681995783674240741d0
      iwe=iwe+1
      weightb( 47, 12,  3)=                 -0.00805504889147825448d0
      iwe=iwe+1
      weightb( 48, 12,  3)=                 -0.18920194536491261039d0
      iwe=iwe+1
      weightb( 49, 12,  3)=                  0.50241650798872594663d0
      iwe=iwe+1
      weightb( 50, 12,  3)=                 -0.37117634306883634521d0
      iwe=iwe+1
      biasb( 12,  3)=                 -0.94932009711330067603d0
      iwe=iwe+1
      weightb(  1, 13,  3)=                  0.07440468948152270667d0
      iwe=iwe+1
      weightb(  2, 13,  3)=                 -0.26456572998313704348d0
      iwe=iwe+1
      weightb(  3, 13,  3)=                  0.04024450695418187174d0
      iwe=iwe+1
      weightb(  4, 13,  3)=                  0.10326504753482471100d0
      iwe=iwe+1
      weightb(  5, 13,  3)=                 -0.19557001720840516690d0
      iwe=iwe+1
      weightb(  6, 13,  3)=                 -0.04697041173837021577d0
      iwe=iwe+1
      weightb(  7, 13,  3)=                 -0.39725974368375649437d0
      iwe=iwe+1
      weightb(  8, 13,  3)=                  0.24191958750326719718d0
      iwe=iwe+1
      weightb(  9, 13,  3)=                 -0.46968557752488399037d0
      iwe=iwe+1
      weightb( 10, 13,  3)=                 -0.19502504222080596641d0
      iwe=iwe+1
      weightb( 11, 13,  3)=                 -0.25161912248557766203d0
      iwe=iwe+1
      weightb( 12, 13,  3)=                  0.47029056682076558760d0
      iwe=iwe+1
      weightb( 13, 13,  3)=                  0.57452777040229319194d0
      iwe=iwe+1
      weightb( 14, 13,  3)=                  0.02931108968591976394d0
      iwe=iwe+1
      weightb( 15, 13,  3)=                 -0.08139962012997986607d0
      iwe=iwe+1
      weightb( 16, 13,  3)=                  0.17818702836155264624d0
      iwe=iwe+1
      weightb( 17, 13,  3)=                 -0.20630816695889761525d0
      iwe=iwe+1
      weightb( 18, 13,  3)=                 -0.37908491310197611757d0
      iwe=iwe+1
      weightb( 19, 13,  3)=                 -0.34810111077794503309d0
      iwe=iwe+1
      weightb( 20, 13,  3)=                  0.36037776496514239977d0
      iwe=iwe+1
      weightb( 21, 13,  3)=                  0.29471709906800436229d0
      iwe=iwe+1
      weightb( 22, 13,  3)=                 -0.04624172904850796378d0
      iwe=iwe+1
      weightb( 23, 13,  3)=                 -0.61362969290922264598d0
      iwe=iwe+1
      weightb( 24, 13,  3)=                  0.18840078051935002512d0
      iwe=iwe+1
      weightb( 25, 13,  3)=                 -0.31417352124890346454d0
      iwe=iwe+1
      weightb( 26, 13,  3)=                 -0.23607607644210237829d0
      iwe=iwe+1
      weightb( 27, 13,  3)=                 -0.07215253251251152466d0
      iwe=iwe+1
      weightb( 28, 13,  3)=                  0.29941510148601530039d0
      iwe=iwe+1
      weightb( 29, 13,  3)=                  0.03634546632248123604d0
      iwe=iwe+1
      weightb( 30, 13,  3)=                  0.51469692722207605051d0
      iwe=iwe+1
      weightb( 31, 13,  3)=                 -0.27787824090495744089d0
      iwe=iwe+1
      weightb( 32, 13,  3)=                 -0.59098695662526312677d0
      iwe=iwe+1
      weightb( 33, 13,  3)=                  0.20051330078285672931d0
      iwe=iwe+1
      weightb( 34, 13,  3)=                  0.22662238164963247056d0
      iwe=iwe+1
      weightb( 35, 13,  3)=                 -0.35123011571041679035d0
      iwe=iwe+1
      weightb( 36, 13,  3)=                 -0.03897363762908716278d0
      iwe=iwe+1
      weightb( 37, 13,  3)=                 -0.28489231568081629931d0
      iwe=iwe+1
      weightb( 38, 13,  3)=                 -0.45942584322358837046d0
      iwe=iwe+1
      weightb( 39, 13,  3)=                 -0.10659576844770195236d0
      iwe=iwe+1
      weightb( 40, 13,  3)=                 -0.02966343256193968228d0
      iwe=iwe+1
      weightb( 41, 13,  3)=                 -0.27566735913223622267d0
      iwe=iwe+1
      weightb( 42, 13,  3)=                  0.23454265385942790756d0
      iwe=iwe+1
      weightb( 43, 13,  3)=                  0.14495600139215941704d0
      iwe=iwe+1
      weightb( 44, 13,  3)=                 -0.05298121569831086564d0
      iwe=iwe+1
      weightb( 45, 13,  3)=                  0.15996224740678899323d0
      iwe=iwe+1
      weightb( 46, 13,  3)=                  0.15625649527216822765d0
      iwe=iwe+1
      weightb( 47, 13,  3)=                 -0.30673570365062013954d0
      iwe=iwe+1
      weightb( 48, 13,  3)=                  0.17184970626833048768d0
      iwe=iwe+1
      weightb( 49, 13,  3)=                  0.02751640696252202409d0
      iwe=iwe+1
      weightb( 50, 13,  3)=                  0.32077616899928346195d0
      iwe=iwe+1
      biasb( 13,  3)=                  1.02039545508369222659d0
      iwe=iwe+1
      weightb(  1, 14,  3)=                  0.04320963808761154462d0
      iwe=iwe+1
      weightb(  2, 14,  3)=                 -0.09020758295544578642d0
      iwe=iwe+1
      weightb(  3, 14,  3)=                  0.15437074616095275426d0
      iwe=iwe+1
      weightb(  4, 14,  3)=                  0.52246726336988336126d0
      iwe=iwe+1
      weightb(  5, 14,  3)=                 -0.00482194968687198796d0
      iwe=iwe+1
      weightb(  6, 14,  3)=                  0.75319344054028858348d0
      iwe=iwe+1
      weightb(  7, 14,  3)=                 -0.22588835993828054738d0
      iwe=iwe+1
      weightb(  8, 14,  3)=                  0.37535743817458994132d0
      iwe=iwe+1
      weightb(  9, 14,  3)=                 -0.57893662813063051509d0
      iwe=iwe+1
      weightb( 10, 14,  3)=                 -0.48789823086947481379d0
      iwe=iwe+1
      weightb( 11, 14,  3)=                 -0.09037463537651004020d0
      iwe=iwe+1
      weightb( 12, 14,  3)=                  0.07499967342517370461d0
      iwe=iwe+1
      weightb( 13, 14,  3)=                  0.00840760145263268199d0
      iwe=iwe+1
      weightb( 14, 14,  3)=                 -0.03859217262908742896d0
      iwe=iwe+1
      weightb( 15, 14,  3)=                  0.48289100225866909977d0
      iwe=iwe+1
      weightb( 16, 14,  3)=                  0.03636504239286580953d0
      iwe=iwe+1
      weightb( 17, 14,  3)=                 -0.23100519653842901957d0
      iwe=iwe+1
      weightb( 18, 14,  3)=                 -0.03559905973219408548d0
      iwe=iwe+1
      weightb( 19, 14,  3)=                  0.04293303660266199057d0
      iwe=iwe+1
      weightb( 20, 14,  3)=                 -0.14097078656160955124d0
      iwe=iwe+1
      weightb( 21, 14,  3)=                  0.28920567636708632842d0
      iwe=iwe+1
      weightb( 22, 14,  3)=                  0.27213727815743771199d0
      iwe=iwe+1
      weightb( 23, 14,  3)=                  0.71993904319812240811d0
      iwe=iwe+1
      weightb( 24, 14,  3)=                 -0.21661134445588159370d0
      iwe=iwe+1
      weightb( 25, 14,  3)=                  0.38354833093909235231d0
      iwe=iwe+1
      weightb( 26, 14,  3)=                 -0.02957845167176681445d0
      iwe=iwe+1
      weightb( 27, 14,  3)=                  0.30228840002185941582d0
      iwe=iwe+1
      weightb( 28, 14,  3)=                 -0.30803699474290840987d0
      iwe=iwe+1
      weightb( 29, 14,  3)=                  0.06443281858350143054d0
      iwe=iwe+1
      weightb( 30, 14,  3)=                 -0.31416002592005348726d0
      iwe=iwe+1
      weightb( 31, 14,  3)=                 -0.09273444640349304269d0
      iwe=iwe+1
      weightb( 32, 14,  3)=                  0.06117064599667078328d0
      iwe=iwe+1
      weightb( 33, 14,  3)=                 -0.27201233978573613470d0
      iwe=iwe+1
      weightb( 34, 14,  3)=                  0.25068190062938822127d0
      iwe=iwe+1
      weightb( 35, 14,  3)=                 -0.31131768523266545312d0
      iwe=iwe+1
      weightb( 36, 14,  3)=                  0.21713180012052601953d0
      iwe=iwe+1
      weightb( 37, 14,  3)=                 -0.00185384726148608153d0
      iwe=iwe+1
      weightb( 38, 14,  3)=                 -0.06584210085076988572d0
      iwe=iwe+1
      weightb( 39, 14,  3)=                 -0.11797765083871716851d0
      iwe=iwe+1
      weightb( 40, 14,  3)=                 -0.09260808503374456935d0
      iwe=iwe+1
      weightb( 41, 14,  3)=                 -0.53648836234202179618d0
      iwe=iwe+1
      weightb( 42, 14,  3)=                  0.07068819723166842872d0
      iwe=iwe+1
      weightb( 43, 14,  3)=                 -0.02459158821212400342d0
      iwe=iwe+1
      weightb( 44, 14,  3)=                  0.56439845860816395540d0
      iwe=iwe+1
      weightb( 45, 14,  3)=                  0.26361628623595145804d0
      iwe=iwe+1
      weightb( 46, 14,  3)=                  0.06107788560911343867d0
      iwe=iwe+1
      weightb( 47, 14,  3)=                  0.22051976301065054353d0
      iwe=iwe+1
      weightb( 48, 14,  3)=                  0.33737242404842993082d0
      iwe=iwe+1
      weightb( 49, 14,  3)=                 -0.04943411372672457116d0
      iwe=iwe+1
      weightb( 50, 14,  3)=                 -0.10385009991376234484d0
      iwe=iwe+1
      biasb( 14,  3)=                 -0.95721145461827339407d0
      iwe=iwe+1
      weightb(  1, 15,  3)=                  0.05218420999236615676d0
      iwe=iwe+1
      weightb(  2, 15,  3)=                 -0.27110269846175777397d0
      iwe=iwe+1
      weightb(  3, 15,  3)=                 -0.21247754875751936887d0
      iwe=iwe+1
      weightb(  4, 15,  3)=                  0.75741356751439747885d0
      iwe=iwe+1
      weightb(  5, 15,  3)=                  0.35304940959919856036d0
      iwe=iwe+1
      weightb(  6, 15,  3)=                 -0.18123607538986546972d0
      iwe=iwe+1
      weightb(  7, 15,  3)=                  0.06576025521975750743d0
      iwe=iwe+1
      weightb(  8, 15,  3)=                 -0.14038699069380841666d0
      iwe=iwe+1
      weightb(  9, 15,  3)=                  0.42625268802286686576d0
      iwe=iwe+1
      weightb( 10, 15,  3)=                 -0.26886931427812665873d0
      iwe=iwe+1
      weightb( 11, 15,  3)=                  0.01813980538282670280d0
      iwe=iwe+1
      weightb( 12, 15,  3)=                  0.12258810973023440138d0
      iwe=iwe+1
      weightb( 13, 15,  3)=                  0.78851810310845360519d0
      iwe=iwe+1
      weightb( 14, 15,  3)=                 -0.27697625817579180074d0
      iwe=iwe+1
      weightb( 15, 15,  3)=                  0.48378974810257913131d0
      iwe=iwe+1
      weightb( 16, 15,  3)=                  0.37893318665673458856d0
      iwe=iwe+1
      weightb( 17, 15,  3)=                  0.07064498699323096265d0
      iwe=iwe+1
      weightb( 18, 15,  3)=                  0.48493498404013202219d0
      iwe=iwe+1
      weightb( 19, 15,  3)=                 -0.04070042531774845096d0
      iwe=iwe+1
      weightb( 20, 15,  3)=                 -0.48454921537211559368d0
      iwe=iwe+1
      weightb( 21, 15,  3)=                  0.21334080622353912560d0
      iwe=iwe+1
      weightb( 22, 15,  3)=                 -0.15832562759127435936d0
      iwe=iwe+1
      weightb( 23, 15,  3)=                  0.28708669110087248200d0
      iwe=iwe+1
      weightb( 24, 15,  3)=                  0.07179906406012462328d0
      iwe=iwe+1
      weightb( 25, 15,  3)=                 -0.37436957406503867940d0
      iwe=iwe+1
      weightb( 26, 15,  3)=                  0.35140718948680582656d0
      iwe=iwe+1
      weightb( 27, 15,  3)=                 -0.07032000385405368093d0
      iwe=iwe+1
      weightb( 28, 15,  3)=                 -0.02772602956484255393d0
      iwe=iwe+1
      weightb( 29, 15,  3)=                 -0.36330890199761850523d0
      iwe=iwe+1
      weightb( 30, 15,  3)=                  0.04669227229826806297d0
      iwe=iwe+1
      weightb( 31, 15,  3)=                 -0.24944166639420070619d0
      iwe=iwe+1
      weightb( 32, 15,  3)=                 -0.05955672324756304536d0
      iwe=iwe+1
      weightb( 33, 15,  3)=                 -0.36141530623396100896d0
      iwe=iwe+1
      weightb( 34, 15,  3)=                  0.03180695468208455390d0
      iwe=iwe+1
      weightb( 35, 15,  3)=                  0.35607373462383773433d0
      iwe=iwe+1
      weightb( 36, 15,  3)=                 -0.14322919647901294349d0
      iwe=iwe+1
      weightb( 37, 15,  3)=                  0.04554394623491760108d0
      iwe=iwe+1
      weightb( 38, 15,  3)=                 -0.15147350822916283430d0
      iwe=iwe+1
      weightb( 39, 15,  3)=                 -0.14399550135036676135d0
      iwe=iwe+1
      weightb( 40, 15,  3)=                 -0.34647459900912225272d0
      iwe=iwe+1
      weightb( 41, 15,  3)=                  0.00012221960651632828d0
      iwe=iwe+1
      weightb( 42, 15,  3)=                 -0.29950118682506371437d0
      iwe=iwe+1
      weightb( 43, 15,  3)=                  0.20521998116294787318d0
      iwe=iwe+1
      weightb( 44, 15,  3)=                 -0.46125433870967136318d0
      iwe=iwe+1
      weightb( 45, 15,  3)=                 -0.03793150665444025571d0
      iwe=iwe+1
      weightb( 46, 15,  3)=                  0.48346109376502749422d0
      iwe=iwe+1
      weightb( 47, 15,  3)=                 -0.12281714728858683650d0
      iwe=iwe+1
      weightb( 48, 15,  3)=                  0.05644352225962680214d0
      iwe=iwe+1
      weightb( 49, 15,  3)=                 -0.02663541786209498718d0
      iwe=iwe+1
      weightb( 50, 15,  3)=                  0.76740278984027898712d0
      iwe=iwe+1
      biasb( 15,  3)=                 -0.92535405475770027284d0
      iwe=iwe+1
      weightb(  1, 16,  3)=                 -0.25094501391801271595d0
      iwe=iwe+1
      weightb(  2, 16,  3)=                  0.06115224947835390390d0
      iwe=iwe+1
      weightb(  3, 16,  3)=                  0.12210524527112538717d0
      iwe=iwe+1
      weightb(  4, 16,  3)=                  0.28163414426847088734d0
      iwe=iwe+1
      weightb(  5, 16,  3)=                 -0.27158030019503848207d0
      iwe=iwe+1
      weightb(  6, 16,  3)=                  0.19975404648266464891d0
      iwe=iwe+1
      weightb(  7, 16,  3)=                  0.48734843883120720909d0
      iwe=iwe+1
      weightb(  8, 16,  3)=                 -0.02156264837605656112d0
      iwe=iwe+1
      weightb(  9, 16,  3)=                  0.55636087911585785371d0
      iwe=iwe+1
      weightb( 10, 16,  3)=                 -0.09813376625793247821d0
      iwe=iwe+1
      weightb( 11, 16,  3)=                  0.11389320683570366977d0
      iwe=iwe+1
      weightb( 12, 16,  3)=                  0.00667029555931849920d0
      iwe=iwe+1
      weightb( 13, 16,  3)=                 -0.39705105403723234270d0
      iwe=iwe+1
      weightb( 14, 16,  3)=                  0.21502704524090807126d0
      iwe=iwe+1
      weightb( 15, 16,  3)=                 -0.07495690053450387857d0
      iwe=iwe+1
      weightb( 16, 16,  3)=                 -0.53587405213876293519d0
      iwe=iwe+1
      weightb( 17, 16,  3)=                  0.29084354754428543011d0
      iwe=iwe+1
      weightb( 18, 16,  3)=                 -0.26027926168631071446d0
      iwe=iwe+1
      weightb( 19, 16,  3)=                 -0.34076542512908558624d0
      iwe=iwe+1
      weightb( 20, 16,  3)=                  0.26628908322679606391d0
      iwe=iwe+1
      weightb( 21, 16,  3)=                 -0.24102063886768759771d0
      iwe=iwe+1
      weightb( 22, 16,  3)=                  0.16083083028176348162d0
      iwe=iwe+1
      weightb( 23, 16,  3)=                  0.13421230259392305517d0
      iwe=iwe+1
      weightb( 24, 16,  3)=                  0.55203109220360135900d0
      iwe=iwe+1
      weightb( 25, 16,  3)=                  0.60235648103283356836d0
      iwe=iwe+1
      weightb( 26, 16,  3)=                 -0.43879040042084899165d0
      iwe=iwe+1
      weightb( 27, 16,  3)=                 -0.23596480009006268186d0
      iwe=iwe+1
      weightb( 28, 16,  3)=                 -0.09099821243297752382d0
      iwe=iwe+1
      weightb( 29, 16,  3)=                  0.34489887525307189042d0
      iwe=iwe+1
      weightb( 30, 16,  3)=                  0.22498365649934320976d0
      iwe=iwe+1
      weightb( 31, 16,  3)=                  0.19197467084871558396d0
      iwe=iwe+1
      weightb( 32, 16,  3)=                 -0.05034817743214310692d0
      iwe=iwe+1
      weightb( 33, 16,  3)=                 -0.34309367244846677991d0
      iwe=iwe+1
      weightb( 34, 16,  3)=                 -0.07278791160328931809d0
      iwe=iwe+1
      weightb( 35, 16,  3)=                 -0.03271880919451788938d0
      iwe=iwe+1
      weightb( 36, 16,  3)=                 -0.04137294553680833514d0
      iwe=iwe+1
      weightb( 37, 16,  3)=                 -0.21751843506744700241d0
      iwe=iwe+1
      weightb( 38, 16,  3)=                 -0.36401177101820947346d0
      iwe=iwe+1
      weightb( 39, 16,  3)=                  0.09017607590081175295d0
      iwe=iwe+1
      weightb( 40, 16,  3)=                  0.62318765445132984215d0
      iwe=iwe+1
      weightb( 41, 16,  3)=                  0.33648052422592600319d0
      iwe=iwe+1
      weightb( 42, 16,  3)=                  0.08507280762215085890d0
      iwe=iwe+1
      weightb( 43, 16,  3)=                  0.10406963900511924381d0
      iwe=iwe+1
      weightb( 44, 16,  3)=                 -0.37530973591417965407d0
      iwe=iwe+1
      weightb( 45, 16,  3)=                 -0.21362922039850648637d0
      iwe=iwe+1
      weightb( 46, 16,  3)=                  0.20176714287758265587d0
      iwe=iwe+1
      weightb( 47, 16,  3)=                  0.20155404671934962213d0
      iwe=iwe+1
      weightb( 48, 16,  3)=                  0.30409267339043338785d0
      iwe=iwe+1
      weightb( 49, 16,  3)=                 -0.13255842142330459543d0
      iwe=iwe+1
      weightb( 50, 16,  3)=                  0.01566029448807083196d0
      iwe=iwe+1
      biasb( 16,  3)=                 -0.93028338389959430721d0
      iwe=iwe+1
      weightb(  1, 17,  3)=                 -0.13582727729408869410d0
      iwe=iwe+1
      weightb(  2, 17,  3)=                  0.32090390831697668261d0
      iwe=iwe+1
      weightb(  3, 17,  3)=                 -0.05435505227189044164d0
      iwe=iwe+1
      weightb(  4, 17,  3)=                  0.39543162534841186373d0
      iwe=iwe+1
      weightb(  5, 17,  3)=                 -0.58957346591800308122d0
      iwe=iwe+1
      weightb(  6, 17,  3)=                  0.09915454827619607503d0
      iwe=iwe+1
      weightb(  7, 17,  3)=                 -0.36253512438965995734d0
      iwe=iwe+1
      weightb(  8, 17,  3)=                 -0.19058002448308680732d0
      iwe=iwe+1
      weightb(  9, 17,  3)=                  0.27564056095038408367d0
      iwe=iwe+1
      weightb( 10, 17,  3)=                 -0.00970334708584681509d0
      iwe=iwe+1
      weightb( 11, 17,  3)=                  0.22361683291839704046d0
      iwe=iwe+1
      weightb( 12, 17,  3)=                 -0.21612160345336500766d0
      iwe=iwe+1
      weightb( 13, 17,  3)=                  0.01562097227140794853d0
      iwe=iwe+1
      weightb( 14, 17,  3)=                 -0.29954376059995591053d0
      iwe=iwe+1
      weightb( 15, 17,  3)=                  0.29655785143855489805d0
      iwe=iwe+1
      weightb( 16, 17,  3)=                 -0.11028860690668321198d0
      iwe=iwe+1
      weightb( 17, 17,  3)=                 -0.15624221305118643488d0
      iwe=iwe+1
      weightb( 18, 17,  3)=                  0.09370982017482580584d0
      iwe=iwe+1
      weightb( 19, 17,  3)=                  0.18011266055963856547d0
      iwe=iwe+1
      weightb( 20, 17,  3)=                  0.01969494533025803809d0
      iwe=iwe+1
      weightb( 21, 17,  3)=                  0.46471961233336445130d0
      iwe=iwe+1
      weightb( 22, 17,  3)=                 -0.40668481037224080143d0
      iwe=iwe+1
      weightb( 23, 17,  3)=                  0.22417859711238069531d0
      iwe=iwe+1
      weightb( 24, 17,  3)=                  0.07934809007304109707d0
      iwe=iwe+1
      weightb( 25, 17,  3)=                 -0.11117836648642720476d0
      iwe=iwe+1
      weightb( 26, 17,  3)=                  0.06883049223709343523d0
      iwe=iwe+1
      weightb( 27, 17,  3)=                 -0.14118181582773395299d0
      iwe=iwe+1
      weightb( 28, 17,  3)=                 -0.28590612408143206702d0
      iwe=iwe+1
      weightb( 29, 17,  3)=                  0.42807973394672743650d0
      iwe=iwe+1
      weightb( 30, 17,  3)=                  0.09108935194472567165d0
      iwe=iwe+1
      weightb( 31, 17,  3)=                 -0.02666190750067401471d0
      iwe=iwe+1
      weightb( 32, 17,  3)=                 -0.21694638236962091038d0
      iwe=iwe+1
      weightb( 33, 17,  3)=                 -0.04398008721859569120d0
      iwe=iwe+1
      weightb( 34, 17,  3)=                 -0.49454337893850330854d0
      iwe=iwe+1
      weightb( 35, 17,  3)=                 -0.31015012874662256648d0
      iwe=iwe+1
      weightb( 36, 17,  3)=                 -0.06564794310175718628d0
      iwe=iwe+1
      weightb( 37, 17,  3)=                 -0.25512302972974465476d0
      iwe=iwe+1
      weightb( 38, 17,  3)=                 -0.17759803238772248202d0
      iwe=iwe+1
      weightb( 39, 17,  3)=                  0.29818496557283435955d0
      iwe=iwe+1
      weightb( 40, 17,  3)=                  0.08474509085881892778d0
      iwe=iwe+1
      weightb( 41, 17,  3)=                  0.38417774442516727795d0
      iwe=iwe+1
      weightb( 42, 17,  3)=                 -0.25014630920124242275d0
      iwe=iwe+1
      weightb( 43, 17,  3)=                  0.00551170287133836197d0
      iwe=iwe+1
      weightb( 44, 17,  3)=                  0.20853722100465207911d0
      iwe=iwe+1
      weightb( 45, 17,  3)=                  0.01231843216983360967d0
      iwe=iwe+1
      weightb( 46, 17,  3)=                 -0.22281450531548890881d0
      iwe=iwe+1
      weightb( 47, 17,  3)=                  0.62065297951521758435d0
      iwe=iwe+1
      weightb( 48, 17,  3)=                  0.40190034658575707338d0
      iwe=iwe+1
      weightb( 49, 17,  3)=                  0.08055215631298616452d0
      iwe=iwe+1
      weightb( 50, 17,  3)=                 -0.35234741174584127688d0
      iwe=iwe+1
      biasb( 17,  3)=                  0.93523956575985733863d0
      iwe=iwe+1
      weightb(  1, 18,  3)=                  0.83684820598796172408d0
      iwe=iwe+1
      weightb(  2, 18,  3)=                  0.83801985045248150730d0
      iwe=iwe+1
      weightb(  3, 18,  3)=                 -0.08228920481241876195d0
      iwe=iwe+1
      weightb(  4, 18,  3)=                 -0.64538768784498268261d0
      iwe=iwe+1
      weightb(  5, 18,  3)=                 -0.88328971159845803829d0
      iwe=iwe+1
      weightb(  6, 18,  3)=                  0.17274961772577690500d0
      iwe=iwe+1
      weightb(  7, 18,  3)=                  0.44915763286875437510d0
      iwe=iwe+1
      weightb(  8, 18,  3)=                  0.44189495846808835022d0
      iwe=iwe+1
      weightb(  9, 18,  3)=                 -0.03144138966138218527d0
      iwe=iwe+1
      weightb( 10, 18,  3)=                  0.55728729106615193523d0
      iwe=iwe+1
      weightb( 11, 18,  3)=                 -0.39910377597651730541d0
      iwe=iwe+1
      weightb( 12, 18,  3)=                  0.22358717777485237477d0
      iwe=iwe+1
      weightb( 13, 18,  3)=                  0.17292793576816886669d0
      iwe=iwe+1
      weightb( 14, 18,  3)=                  0.03328203375930941649d0
      iwe=iwe+1
      weightb( 15, 18,  3)=                  0.29876856507210119984d0
      iwe=iwe+1
      weightb( 16, 18,  3)=                  0.02750871881190670304d0
      iwe=iwe+1
      weightb( 17, 18,  3)=                 -0.14875131080205558631d0
      iwe=iwe+1
      weightb( 18, 18,  3)=                  0.63409570907824397423d0
      iwe=iwe+1
      weightb( 19, 18,  3)=                  0.43334523257183354961d0
      iwe=iwe+1
      weightb( 20, 18,  3)=                  0.70111882805544345487d0
      iwe=iwe+1
      weightb( 21, 18,  3)=                 -1.35693363892831420081d0
      iwe=iwe+1
      weightb( 22, 18,  3)=                 -0.61539204400398928030d0
      iwe=iwe+1
      weightb( 23, 18,  3)=                 -0.27198614641151980242d0
      iwe=iwe+1
      weightb( 24, 18,  3)=                  0.55385647496810497259d0
      iwe=iwe+1
      weightb( 25, 18,  3)=                 -0.22830647433535458668d0
      iwe=iwe+1
      weightb( 26, 18,  3)=                  0.05445554577223294529d0
      iwe=iwe+1
      weightb( 27, 18,  3)=                  0.76995426744256001417d0
      iwe=iwe+1
      weightb( 28, 18,  3)=                 -0.67364033514771792799d0
      iwe=iwe+1
      weightb( 29, 18,  3)=                  0.34558689204971632103d0
      iwe=iwe+1
      weightb( 30, 18,  3)=                 -0.05824310147776809443d0
      iwe=iwe+1
      weightb( 31, 18,  3)=                 -0.30878309417442517670d0
      iwe=iwe+1
      weightb( 32, 18,  3)=                 -0.10003404599908051475d0
      iwe=iwe+1
      weightb( 33, 18,  3)=                 -0.40187058040413764504d0
      iwe=iwe+1
      weightb( 34, 18,  3)=                 -0.53874767899960052109d0
      iwe=iwe+1
      weightb( 35, 18,  3)=                  0.67347226507199120515d0
      iwe=iwe+1
      weightb( 36, 18,  3)=                 -0.09457845436454802301d0
      iwe=iwe+1
      weightb( 37, 18,  3)=                  0.58897181123584485540d0
      iwe=iwe+1
      weightb( 38, 18,  3)=                  0.65522044154399228244d0
      iwe=iwe+1
      weightb( 39, 18,  3)=                 -0.05463901203268756862d0
      iwe=iwe+1
      weightb( 40, 18,  3)=                 -0.04234229514380326298d0
      iwe=iwe+1
      weightb( 41, 18,  3)=                 -0.49433734504486243067d0
      iwe=iwe+1
      weightb( 42, 18,  3)=                 -0.04704216571103975869d0
      iwe=iwe+1
      weightb( 43, 18,  3)=                  0.04307586623497228207d0
      iwe=iwe+1
      weightb( 44, 18,  3)=                 -0.58565721737607723263d0
      iwe=iwe+1
      weightb( 45, 18,  3)=                 -0.01934862168526655518d0
      iwe=iwe+1
      weightb( 46, 18,  3)=                 -0.08179855016694714820d0
      iwe=iwe+1
      weightb( 47, 18,  3)=                  0.01941989461930580807d0
      iwe=iwe+1
      weightb( 48, 18,  3)=                 -0.02210199693883193456d0
      iwe=iwe+1
      weightb( 49, 18,  3)=                 -0.21573820314160363498d0
      iwe=iwe+1
      weightb( 50, 18,  3)=                 -0.52663429416858031917d0
      iwe=iwe+1
      biasb( 18,  3)=                 -0.68017871042184507857d0
      iwe=iwe+1
      weightb(  1, 19,  3)=                  0.18220576293550813651d0
      iwe=iwe+1
      weightb(  2, 19,  3)=                  0.16224661773006890386d0
      iwe=iwe+1
      weightb(  3, 19,  3)=                 -0.34316131149690276558d0
      iwe=iwe+1
      weightb(  4, 19,  3)=                 -0.10404262397719087063d0
      iwe=iwe+1
      weightb(  5, 19,  3)=                 -0.00458412682106103947d0
      iwe=iwe+1
      weightb(  6, 19,  3)=                 -0.35491485979911313597d0
      iwe=iwe+1
      weightb(  7, 19,  3)=                  0.25936758778260765590d0
      iwe=iwe+1
      weightb(  8, 19,  3)=                 -0.22922755996976762471d0
      iwe=iwe+1
      weightb(  9, 19,  3)=                  0.16437879154475609766d0
      iwe=iwe+1
      weightb( 10, 19,  3)=                  0.41347968348891639412d0
      iwe=iwe+1
      weightb( 11, 19,  3)=                  0.02364446300665763723d0
      iwe=iwe+1
      weightb( 12, 19,  3)=                  0.01631792721038446622d0
      iwe=iwe+1
      weightb( 13, 19,  3)=                  0.34255515243939493875d0
      iwe=iwe+1
      weightb( 14, 19,  3)=                  0.08620276071393420669d0
      iwe=iwe+1
      weightb( 15, 19,  3)=                  0.22197238369481381293d0
      iwe=iwe+1
      weightb( 16, 19,  3)=                 -0.36948603378512245854d0
      iwe=iwe+1
      weightb( 17, 19,  3)=                 -0.24186656258664193664d0
      iwe=iwe+1
      weightb( 18, 19,  3)=                  0.43201420618854508016d0
      iwe=iwe+1
      weightb( 19, 19,  3)=                 -0.47170425850191560757d0
      iwe=iwe+1
      weightb( 20, 19,  3)=                  0.41006742599468826160d0
      iwe=iwe+1
      weightb( 21, 19,  3)=                 -0.02069746599212004406d0
      iwe=iwe+1
      weightb( 22, 19,  3)=                  0.62997243063963492826d0
      iwe=iwe+1
      weightb( 23, 19,  3)=                  0.05945988066007303063d0
      iwe=iwe+1
      weightb( 24, 19,  3)=                 -0.16857121631876728629d0
      iwe=iwe+1
      weightb( 25, 19,  3)=                 -0.24436194740334310493d0
      iwe=iwe+1
      weightb( 26, 19,  3)=                  0.46541211984086761078d0
      iwe=iwe+1
      weightb( 27, 19,  3)=                  0.00167779720097120146d0
      iwe=iwe+1
      weightb( 28, 19,  3)=                 -0.11960687599344647924d0
      iwe=iwe+1
      weightb( 29, 19,  3)=                 -0.11876606717090143484d0
      iwe=iwe+1
      weightb( 30, 19,  3)=                  0.21206678614186882936d0
      iwe=iwe+1
      weightb( 31, 19,  3)=                 -0.13164070275480835304d0
      iwe=iwe+1
      weightb( 32, 19,  3)=                 -0.20789314385280754927d0
      iwe=iwe+1
      weightb( 33, 19,  3)=                 -0.21871895852104281111d0
      iwe=iwe+1
      weightb( 34, 19,  3)=                  0.36492135294009286905d0
      iwe=iwe+1
      weightb( 35, 19,  3)=                 -0.00984946729288018602d0
      iwe=iwe+1
      weightb( 36, 19,  3)=                 -0.04818469629477677152d0
      iwe=iwe+1
      weightb( 37, 19,  3)=                 -0.44354392417801147275d0
      iwe=iwe+1
      weightb( 38, 19,  3)=                 -0.07743562824832875280d0
      iwe=iwe+1
      weightb( 39, 19,  3)=                  0.27865640312996242667d0
      iwe=iwe+1
      weightb( 40, 19,  3)=                  0.16938221332072939118d0
      iwe=iwe+1
      weightb( 41, 19,  3)=                 -0.52204933055455982061d0
      iwe=iwe+1
      weightb( 42, 19,  3)=                 -0.20404089364201447032d0
      iwe=iwe+1
      weightb( 43, 19,  3)=                 -0.27006080230328244340d0
      iwe=iwe+1
      weightb( 44, 19,  3)=                  0.13898880314433106897d0
      iwe=iwe+1
      weightb( 45, 19,  3)=                  0.31150176772436155570d0
      iwe=iwe+1
      weightb( 46, 19,  3)=                 -0.59154910906115898417d0
      iwe=iwe+1
      weightb( 47, 19,  3)=                 -0.33581798725954514762d0
      iwe=iwe+1
      weightb( 48, 19,  3)=                 -0.38245205541112037295d0
      iwe=iwe+1
      weightb( 49, 19,  3)=                  0.13632658380482640115d0
      iwe=iwe+1
      weightb( 50, 19,  3)=                 -0.19345449615716667213d0
      iwe=iwe+1
      biasb( 19,  3)=                  0.61962225203908805060d0
      iwe=iwe+1
      weightb(  1, 20,  3)=                  0.19059556235921248923d0
      iwe=iwe+1
      weightb(  2, 20,  3)=                  0.64024178187706637377d0
      iwe=iwe+1
      weightb(  3, 20,  3)=                  0.22004123523527402417d0
      iwe=iwe+1
      weightb(  4, 20,  3)=                 -0.03589371871022450922d0
      iwe=iwe+1
      weightb(  5, 20,  3)=                 -0.42287192281606861277d0
      iwe=iwe+1
      weightb(  6, 20,  3)=                  0.01498383867834774882d0
      iwe=iwe+1
      weightb(  7, 20,  3)=                  0.13644849854276822065d0
      iwe=iwe+1
      weightb(  8, 20,  3)=                 -0.25493732878747776827d0
      iwe=iwe+1
      weightb(  9, 20,  3)=                  0.88339143430097555321d0
      iwe=iwe+1
      weightb( 10, 20,  3)=                 -0.00647456635231740546d0
      iwe=iwe+1
      weightb( 11, 20,  3)=                  0.01831927390469481609d0
      iwe=iwe+1
      weightb( 12, 20,  3)=                 -0.32837765977870259082d0
      iwe=iwe+1
      weightb( 13, 20,  3)=                  0.14636842341742073437d0
      iwe=iwe+1
      weightb( 14, 20,  3)=                  0.15821925808136660940d0
      iwe=iwe+1
      weightb( 15, 20,  3)=                  0.44792244284941967747d0
      iwe=iwe+1
      weightb( 16, 20,  3)=                 -0.10069236373172238408d0
      iwe=iwe+1
      weightb( 17, 20,  3)=                  0.25592158006452681018d0
      iwe=iwe+1
      weightb( 18, 20,  3)=                 -0.19857130754133170414d0
      iwe=iwe+1
      weightb( 19, 20,  3)=                  0.44476817957113262691d0
      iwe=iwe+1
      weightb( 20, 20,  3)=                  0.04582800632596713969d0
      iwe=iwe+1
      weightb( 21, 20,  3)=                 -0.65671523417978394654d0
      iwe=iwe+1
      weightb( 22, 20,  3)=                  0.16471276162782272356d0
      iwe=iwe+1
      weightb( 23, 20,  3)=                  0.07508503695364071584d0
      iwe=iwe+1
      weightb( 24, 20,  3)=                 -0.04179549678439060945d0
      iwe=iwe+1
      weightb( 25, 20,  3)=                  0.11785119411843053561d0
      iwe=iwe+1
      weightb( 26, 20,  3)=                  0.03207655120196621634d0
      iwe=iwe+1
      weightb( 27, 20,  3)=                  0.29457674420878965371d0
      iwe=iwe+1
      weightb( 28, 20,  3)=                 -0.57688399674667967254d0
      iwe=iwe+1
      weightb( 29, 20,  3)=                  0.15000553453790529956d0
      iwe=iwe+1
      weightb( 30, 20,  3)=                 -0.75145445265227095444d0
      iwe=iwe+1
      weightb( 31, 20,  3)=                 -0.04574760099084759779d0
      iwe=iwe+1
      weightb( 32, 20,  3)=                  0.09367025027120597092d0
      iwe=iwe+1
      weightb( 33, 20,  3)=                 -0.20018369906449975937d0
      iwe=iwe+1
      weightb( 34, 20,  3)=                  0.08077352129698867067d0
      iwe=iwe+1
      weightb( 35, 20,  3)=                 -0.09400391499823269881d0
      iwe=iwe+1
      weightb( 36, 20,  3)=                 -0.03982940173886352631d0
      iwe=iwe+1
      weightb( 37, 20,  3)=                  0.15981445155691609283d0
      iwe=iwe+1
      weightb( 38, 20,  3)=                  0.52427567147728815211d0
      iwe=iwe+1
      weightb( 39, 20,  3)=                 -0.43474244445565773942d0
      iwe=iwe+1
      weightb( 40, 20,  3)=                  0.12347579375942593916d0
      iwe=iwe+1
      weightb( 41, 20,  3)=                 -0.12739346911094773240d0
      iwe=iwe+1
      weightb( 42, 20,  3)=                  0.18329407324539342961d0
      iwe=iwe+1
      weightb( 43, 20,  3)=                 -0.14178102119389984770d0
      iwe=iwe+1
      weightb( 44, 20,  3)=                  0.46926455108637354918d0
      iwe=iwe+1
      weightb( 45, 20,  3)=                  0.06033414585457135687d0
      iwe=iwe+1
      weightb( 46, 20,  3)=                 -0.24624840500754954786d0
      iwe=iwe+1
      weightb( 47, 20,  3)=                 -0.01668938596814224795d0
      iwe=iwe+1
      weightb( 48, 20,  3)=                 -0.21372378940024958083d0
      iwe=iwe+1
      weightb( 49, 20,  3)=                  0.04852453214242968826d0
      iwe=iwe+1
      weightb( 50, 20,  3)=                 -0.32495660755089661453d0
      iwe=iwe+1
      biasb( 20,  3)=                  0.87297064888535957916d0
      iwe=iwe+1
      weightb(  1, 21,  3)=                  0.19793015284008985688d0
      iwe=iwe+1
      weightb(  2, 21,  3)=                  0.24794249283497551972d0
      iwe=iwe+1
      weightb(  3, 21,  3)=                  0.28570045984291864150d0
      iwe=iwe+1
      weightb(  4, 21,  3)=                 -0.14377991966818881586d0
      iwe=iwe+1
      weightb(  5, 21,  3)=                 -0.46572874570126915339d0
      iwe=iwe+1
      weightb(  6, 21,  3)=                  0.09147141960367724534d0
      iwe=iwe+1
      weightb(  7, 21,  3)=                 -0.02233740012861815463d0
      iwe=iwe+1
      weightb(  8, 21,  3)=                  0.00131413673321286936d0
      iwe=iwe+1
      weightb(  9, 21,  3)=                  0.12430856090475192466d0
      iwe=iwe+1
      weightb( 10, 21,  3)=                 -0.52468927036518564488d0
      iwe=iwe+1
      weightb( 11, 21,  3)=                 -0.00970265277678102923d0
      iwe=iwe+1
      weightb( 12, 21,  3)=                  0.14357588883270117064d0
      iwe=iwe+1
      weightb( 13, 21,  3)=                 -0.10705531669925293092d0
      iwe=iwe+1
      weightb( 14, 21,  3)=                  0.26463774849747262463d0
      iwe=iwe+1
      weightb( 15, 21,  3)=                  0.45891084646445179374d0
      iwe=iwe+1
      weightb( 16, 21,  3)=                 -0.29204550526219569262d0
      iwe=iwe+1
      weightb( 17, 21,  3)=                 -0.26355661491650922423d0
      iwe=iwe+1
      weightb( 18, 21,  3)=                  0.41734272403957295428d0
      iwe=iwe+1
      weightb( 19, 21,  3)=                 -0.03270212823735851870d0
      iwe=iwe+1
      weightb( 20, 21,  3)=                 -0.09244413201653611800d0
      iwe=iwe+1
      weightb( 21, 21,  3)=                 -0.43696771587656296765d0
      iwe=iwe+1
      weightb( 22, 21,  3)=                  0.01475334633242178853d0
      iwe=iwe+1
      weightb( 23, 21,  3)=                  0.43952567639051648429d0
      iwe=iwe+1
      weightb( 24, 21,  3)=                  0.91842437427071188516d0
      iwe=iwe+1
      weightb( 25, 21,  3)=                  0.67659725837756135025d0
      iwe=iwe+1
      weightb( 26, 21,  3)=                 -0.28657973051117308083d0
      iwe=iwe+1
      weightb( 27, 21,  3)=                 -0.08216711846644034201d0
      iwe=iwe+1
      weightb( 28, 21,  3)=                 -0.15451008342456540312d0
      iwe=iwe+1
      weightb( 29, 21,  3)=                  0.31633521243951429058d0
      iwe=iwe+1
      weightb( 30, 21,  3)=                  0.26358832676130344863d0
      iwe=iwe+1
      weightb( 31, 21,  3)=                  0.40944053886567621792d0
      iwe=iwe+1
      weightb( 32, 21,  3)=                  0.05953331218166608985d0
      iwe=iwe+1
      weightb( 33, 21,  3)=                 -0.12746985493311582816d0
      iwe=iwe+1
      weightb( 34, 21,  3)=                 -0.05451949651342656578d0
      iwe=iwe+1
      weightb( 35, 21,  3)=                 -0.13928409154116966340d0
      iwe=iwe+1
      weightb( 36, 21,  3)=                  0.29370922237814273137d0
      iwe=iwe+1
      weightb( 37, 21,  3)=                  0.63582900783542117829d0
      iwe=iwe+1
      weightb( 38, 21,  3)=                  0.21982882005992029906d0
      iwe=iwe+1
      weightb( 39, 21,  3)=                  0.46924991275875715946d0
      iwe=iwe+1
      weightb( 40, 21,  3)=                 -0.31541636428040981110d0
      iwe=iwe+1
      weightb( 41, 21,  3)=                 -0.12935814787604785203d0
      iwe=iwe+1
      weightb( 42, 21,  3)=                  0.20938880714908922331d0
      iwe=iwe+1
      weightb( 43, 21,  3)=                 -0.08617242744586524339d0
      iwe=iwe+1
      weightb( 44, 21,  3)=                 -0.39252797204770134565d0
      iwe=iwe+1
      weightb( 45, 21,  3)=                 -0.19018923687008795764d0
      iwe=iwe+1
      weightb( 46, 21,  3)=                  0.07546840266202228809d0
      iwe=iwe+1
      weightb( 47, 21,  3)=                 -0.00073682928904193323d0
      iwe=iwe+1
      weightb( 48, 21,  3)=                 -0.10439839072785717100d0
      iwe=iwe+1
      weightb( 49, 21,  3)=                 -0.56292587643893110538d0
      iwe=iwe+1
      weightb( 50, 21,  3)=                 -0.09661519745707802809d0
      iwe=iwe+1
      biasb( 21,  3)=                  0.79788213244639427657d0
      iwe=iwe+1
      weightb(  1, 22,  3)=                 -0.20090240139452492096d0
      iwe=iwe+1
      weightb(  2, 22,  3)=                  0.10196257636934455415d0
      iwe=iwe+1
      weightb(  3, 22,  3)=                  0.07905052834900631875d0
      iwe=iwe+1
      weightb(  4, 22,  3)=                 -0.45352447134496132186d0
      iwe=iwe+1
      weightb(  5, 22,  3)=                  0.02317550232087230849d0
      iwe=iwe+1
      weightb(  6, 22,  3)=                  0.25440904529292790448d0
      iwe=iwe+1
      weightb(  7, 22,  3)=                 -0.23231791055834755122d0
      iwe=iwe+1
      weightb(  8, 22,  3)=                  0.24071468893561456803d0
      iwe=iwe+1
      weightb(  9, 22,  3)=                  0.33766930352873641974d0
      iwe=iwe+1
      weightb( 10, 22,  3)=                 -0.16227201606233060405d0
      iwe=iwe+1
      weightb( 11, 22,  3)=                 -0.26157415482675505647d0
      iwe=iwe+1
      weightb( 12, 22,  3)=                 -0.16693997336302893175d0
      iwe=iwe+1
      weightb( 13, 22,  3)=                 -0.10310947497409994611d0
      iwe=iwe+1
      weightb( 14, 22,  3)=                  0.42449558374639523306d0
      iwe=iwe+1
      weightb( 15, 22,  3)=                  0.23957616395705313983d0
      iwe=iwe+1
      weightb( 16, 22,  3)=                  0.01622709717155847164d0
      iwe=iwe+1
      weightb( 17, 22,  3)=                 -0.18593535057225177298d0
      iwe=iwe+1
      weightb( 18, 22,  3)=                 -0.19511302718161557812d0
      iwe=iwe+1
      weightb( 19, 22,  3)=                  0.01910350334042705545d0
      iwe=iwe+1
      weightb( 20, 22,  3)=                  0.33755833748471369971d0
      iwe=iwe+1
      weightb( 21, 22,  3)=                  0.03328686786615510373d0
      iwe=iwe+1
      weightb( 22, 22,  3)=                 -0.49687770867906422279d0
      iwe=iwe+1
      weightb( 23, 22,  3)=                  0.20480991633054695944d0
      iwe=iwe+1
      weightb( 24, 22,  3)=                  0.02294758737235711582d0
      iwe=iwe+1
      weightb( 25, 22,  3)=                  0.17052625496023868235d0
      iwe=iwe+1
      weightb( 26, 22,  3)=                 -0.24546115001263799082d0
      iwe=iwe+1
      weightb( 27, 22,  3)=                 -0.11868772234919183761d0
      iwe=iwe+1
      weightb( 28, 22,  3)=                  0.09051092231031190871d0
      iwe=iwe+1
      weightb( 29, 22,  3)=                  0.00415913070722972924d0
      iwe=iwe+1
      weightb( 30, 22,  3)=                  0.14249217568381691845d0
      iwe=iwe+1
      weightb( 31, 22,  3)=                 -0.21519651586818455691d0
      iwe=iwe+1
      weightb( 32, 22,  3)=                 -0.34150855904352106496d0
      iwe=iwe+1
      weightb( 33, 22,  3)=                  0.32868524685760092119d0
      iwe=iwe+1
      weightb( 34, 22,  3)=                  0.04081724366170286916d0
      iwe=iwe+1
      weightb( 35, 22,  3)=                 -0.18886752959917563199d0
      iwe=iwe+1
      weightb( 36, 22,  3)=                 -0.45788121363073963632d0
      iwe=iwe+1
      weightb( 37, 22,  3)=                 -0.28764973614026001503d0
      iwe=iwe+1
      weightb( 38, 22,  3)=                  0.27273485335949021469d0
      iwe=iwe+1
      weightb( 39, 22,  3)=                  0.12630104933930186295d0
      iwe=iwe+1
      weightb( 40, 22,  3)=                  0.24865235549358816192d0
      iwe=iwe+1
      weightb( 41, 22,  3)=                 -0.01931836012856087692d0
      iwe=iwe+1
      weightb( 42, 22,  3)=                 -0.20256095454331640715d0
      iwe=iwe+1
      weightb( 43, 22,  3)=                 -0.01375570617998233061d0
      iwe=iwe+1
      weightb( 44, 22,  3)=                 -0.13018681660022204949d0
      iwe=iwe+1
      weightb( 45, 22,  3)=                  0.09837358718927527446d0
      iwe=iwe+1
      weightb( 46, 22,  3)=                 -0.09845714500441365979d0
      iwe=iwe+1
      weightb( 47, 22,  3)=                 -0.09834678746706576602d0
      iwe=iwe+1
      weightb( 48, 22,  3)=                 -0.30174469279800336663d0
      iwe=iwe+1
      weightb( 49, 22,  3)=                  0.37250576030466309163d0
      iwe=iwe+1
      weightb( 50, 22,  3)=                 -0.29624614682824401690d0
      iwe=iwe+1
      biasb( 22,  3)=                  0.67202131342361226540d0
      iwe=iwe+1
      weightb(  1, 23,  3)=                  0.05378228031672808301d0
      iwe=iwe+1
      weightb(  2, 23,  3)=                  0.25246365637860190834d0
      iwe=iwe+1
      weightb(  3, 23,  3)=                 -0.21400524365601147903d0
      iwe=iwe+1
      weightb(  4, 23,  3)=                 -0.21593633845642076774d0
      iwe=iwe+1
      weightb(  5, 23,  3)=                  0.46509249843282124415d0
      iwe=iwe+1
      weightb(  6, 23,  3)=                 -0.11805927673349736473d0
      iwe=iwe+1
      weightb(  7, 23,  3)=                 -0.00715928806293915799d0
      iwe=iwe+1
      weightb(  8, 23,  3)=                  0.02147195515350499781d0
      iwe=iwe+1
      weightb(  9, 23,  3)=                 -0.21330920473693365524d0
      iwe=iwe+1
      weightb( 10, 23,  3)=                 -0.04888444519241622044d0
      iwe=iwe+1
      weightb( 11, 23,  3)=                 -0.05874758806818482226d0
      iwe=iwe+1
      weightb( 12, 23,  3)=                  0.10654481900129066096d0
      iwe=iwe+1
      weightb( 13, 23,  3)=                  0.37412044007063899320d0
      iwe=iwe+1
      weightb( 14, 23,  3)=                  0.17316189477791821272d0
      iwe=iwe+1
      weightb( 15, 23,  3)=                  0.11766282513845380264d0
      iwe=iwe+1
      weightb( 16, 23,  3)=                 -0.10717551156950720637d0
      iwe=iwe+1
      weightb( 17, 23,  3)=                  0.31203037147319945266d0
      iwe=iwe+1
      weightb( 18, 23,  3)=                  0.22060922465113899649d0
      iwe=iwe+1
      weightb( 19, 23,  3)=                 -0.19055447019566204570d0
      iwe=iwe+1
      weightb( 20, 23,  3)=                  0.06543602720647852256d0
      iwe=iwe+1
      weightb( 21, 23,  3)=                 -0.32760425921671781913d0
      iwe=iwe+1
      weightb( 22, 23,  3)=                 -0.10458808783178610846d0
      iwe=iwe+1
      weightb( 23, 23,  3)=                 -0.20376494812216250363d0
      iwe=iwe+1
      weightb( 24, 23,  3)=                  0.16539919859219590070d0
      iwe=iwe+1
      weightb( 25, 23,  3)=                 -0.02697352835622243011d0
      iwe=iwe+1
      weightb( 26, 23,  3)=                 -0.21810131979410066205d0
      iwe=iwe+1
      weightb( 27, 23,  3)=                  0.41097545545216823681d0
      iwe=iwe+1
      weightb( 28, 23,  3)=                 -0.29767334163870762254d0
      iwe=iwe+1
      weightb( 29, 23,  3)=                 -0.11368064360110011202d0
      iwe=iwe+1
      weightb( 30, 23,  3)=                 -0.30374075356898277978d0
      iwe=iwe+1
      weightb( 31, 23,  3)=                  0.27325270260495038155d0
      iwe=iwe+1
      weightb( 32, 23,  3)=                  0.02305492681723242746d0
      iwe=iwe+1
      weightb( 33, 23,  3)=                  0.33120875860571413751d0
      iwe=iwe+1
      weightb( 34, 23,  3)=                  0.05653619045874125337d0
      iwe=iwe+1
      weightb( 35, 23,  3)=                  0.28530434184767378136d0
      iwe=iwe+1
      weightb( 36, 23,  3)=                 -0.27231062156997187795d0
      iwe=iwe+1
      weightb( 37, 23,  3)=                  0.19805501931447413999d0
      iwe=iwe+1
      weightb( 38, 23,  3)=                  0.46299288907651348079d0
      iwe=iwe+1
      weightb( 39, 23,  3)=                 -0.15926962618390885784d0
      iwe=iwe+1
      weightb( 40, 23,  3)=                 -0.01692745363616687468d0
      iwe=iwe+1
      weightb( 41, 23,  3)=                  0.08836533546951026719d0
      iwe=iwe+1
      weightb( 42, 23,  3)=                  0.00372419128559397811d0
      iwe=iwe+1
      weightb( 43, 23,  3)=                 -0.11858300538321764339d0
      iwe=iwe+1
      weightb( 44, 23,  3)=                 -0.34755544400306753738d0
      iwe=iwe+1
      weightb( 45, 23,  3)=                  0.22913155704206927821d0
      iwe=iwe+1
      weightb( 46, 23,  3)=                 -0.30996208656798507342d0
      iwe=iwe+1
      weightb( 47, 23,  3)=                  0.44056193448262753742d0
      iwe=iwe+1
      weightb( 48, 23,  3)=                 -0.34927961171295990317d0
      iwe=iwe+1
      weightb( 49, 23,  3)=                  0.33294441005504959996d0
      iwe=iwe+1
      weightb( 50, 23,  3)=                  0.07236410602130408098d0
      iwe=iwe+1
      biasb( 23,  3)=                 -0.63449774226358757190d0
      iwe=iwe+1
      weightb(  1, 24,  3)=                 -0.08132573441771367984d0
      iwe=iwe+1
      weightb(  2, 24,  3)=                 -0.25730793972455268115d0
      iwe=iwe+1
      weightb(  3, 24,  3)=                  0.19357662561179134197d0
      iwe=iwe+1
      weightb(  4, 24,  3)=                  0.06055584495318212107d0
      iwe=iwe+1
      weightb(  5, 24,  3)=                  0.60106728405741238763d0
      iwe=iwe+1
      weightb(  6, 24,  3)=                 -0.35016939793726425956d0
      iwe=iwe+1
      weightb(  7, 24,  3)=                 -0.19101993730154989692d0
      iwe=iwe+1
      weightb(  8, 24,  3)=                 -0.16651112657886354973d0
      iwe=iwe+1
      weightb(  9, 24,  3)=                  0.01479462233142495031d0
      iwe=iwe+1
      weightb( 10, 24,  3)=                 -0.14981690891666438192d0
      iwe=iwe+1
      weightb( 11, 24,  3)=                 -0.16011411095879798938d0
      iwe=iwe+1
      weightb( 12, 24,  3)=                  0.01695521265806767056d0
      iwe=iwe+1
      weightb( 13, 24,  3)=                  0.38342485284408539536d0
      iwe=iwe+1
      weightb( 14, 24,  3)=                  0.01677636285708034025d0
      iwe=iwe+1
      weightb( 15, 24,  3)=                  0.26259053813834903890d0
      iwe=iwe+1
      weightb( 16, 24,  3)=                  0.10574393274138556287d0
      iwe=iwe+1
      weightb( 17, 24,  3)=                 -0.36095248659603418329d0
      iwe=iwe+1
      weightb( 18, 24,  3)=                 -0.45822735776313139322d0
      iwe=iwe+1
      weightb( 19, 24,  3)=                  0.00973134418070499899d0
      iwe=iwe+1
      weightb( 20, 24,  3)=                 -0.70918072069282001024d0
      iwe=iwe+1
      weightb( 21, 24,  3)=                 -0.14994590222540193913d0
      iwe=iwe+1
      weightb( 22, 24,  3)=                 -0.37028730506104001741d0
      iwe=iwe+1
      weightb( 23, 24,  3)=                 -0.04605282610426357504d0
      iwe=iwe+1
      weightb( 24, 24,  3)=                  0.65830028191942291382d0
      iwe=iwe+1
      weightb( 25, 24,  3)=                  0.54503443516736682639d0
      iwe=iwe+1
      weightb( 26, 24,  3)=                 -0.04502467884350944138d0
      iwe=iwe+1
      weightb( 27, 24,  3)=                  0.35561008741390520704d0
      iwe=iwe+1
      weightb( 28, 24,  3)=                 -0.84946457880517667327d0
      iwe=iwe+1
      weightb( 29, 24,  3)=                 -0.10578874576838345756d0
      iwe=iwe+1
      weightb( 30, 24,  3)=                 -0.21074877673721228999d0
      iwe=iwe+1
      weightb( 31, 24,  3)=                 -0.14383560568177936045d0
      iwe=iwe+1
      weightb( 32, 24,  3)=                  0.08290566925991041392d0
      iwe=iwe+1
      weightb( 33, 24,  3)=                  0.39312638335594246586d0
      iwe=iwe+1
      weightb( 34, 24,  3)=                  0.11556320478840351185d0
      iwe=iwe+1
      weightb( 35, 24,  3)=                  0.00734225966944446109d0
      iwe=iwe+1
      weightb( 36, 24,  3)=                  0.01805679801129305567d0
      iwe=iwe+1
      weightb( 37, 24,  3)=                  0.31782849197893475734d0
      iwe=iwe+1
      weightb( 38, 24,  3)=                  0.07201219170232114886d0
      iwe=iwe+1
      weightb( 39, 24,  3)=                  0.05176694922662637005d0
      iwe=iwe+1
      weightb( 40, 24,  3)=                 -0.31156915354444914001d0
      iwe=iwe+1
      weightb( 41, 24,  3)=                  0.06101310326878137125d0
      iwe=iwe+1
      weightb( 42, 24,  3)=                  0.35801176497847164715d0
      iwe=iwe+1
      weightb( 43, 24,  3)=                  0.52461946293640671080d0
      iwe=iwe+1
      weightb( 44, 24,  3)=                  0.02054259153627797929d0
      iwe=iwe+1
      weightb( 45, 24,  3)=                 -0.11815854266714853615d0
      iwe=iwe+1
      weightb( 46, 24,  3)=                 -0.04719892363831087317d0
      iwe=iwe+1
      weightb( 47, 24,  3)=                  0.26925356054646554238d0
      iwe=iwe+1
      weightb( 48, 24,  3)=                  0.14649125467622856056d0
      iwe=iwe+1
      weightb( 49, 24,  3)=                 -0.03418920551092893834d0
      iwe=iwe+1
      weightb( 50, 24,  3)=                  0.10783726737664951767d0
      iwe=iwe+1
      biasb( 24,  3)=                 -0.63265304746802364377d0
      iwe=iwe+1
      weightb(  1, 25,  3)=                 -0.34714621992482241897d0
      iwe=iwe+1
      weightb(  2, 25,  3)=                 -0.12104856562025656519d0
      iwe=iwe+1
      weightb(  3, 25,  3)=                 -0.34482659167890933327d0
      iwe=iwe+1
      weightb(  4, 25,  3)=                  0.04691357134246715993d0
      iwe=iwe+1
      weightb(  5, 25,  3)=                  0.30154079816718409868d0
      iwe=iwe+1
      weightb(  6, 25,  3)=                  0.14054712157115700766d0
      iwe=iwe+1
      weightb(  7, 25,  3)=                 -0.28279992706035472771d0
      iwe=iwe+1
      weightb(  8, 25,  3)=                  0.30309411642993716596d0
      iwe=iwe+1
      weightb(  9, 25,  3)=                 -0.05498654639634482921d0
      iwe=iwe+1
      weightb( 10, 25,  3)=                 -0.20420488026224117850d0
      iwe=iwe+1
      weightb( 11, 25,  3)=                 -0.33523391462291302068d0
      iwe=iwe+1
      weightb( 12, 25,  3)=                 -0.29756346031980823730d0
      iwe=iwe+1
      weightb( 13, 25,  3)=                 -0.13782021759890894508d0
      iwe=iwe+1
      weightb( 14, 25,  3)=                  0.12526301830020017403d0
      iwe=iwe+1
      weightb( 15, 25,  3)=                 -0.23753456329545769021d0
      iwe=iwe+1
      weightb( 16, 25,  3)=                 -0.35760569352668375442d0
      iwe=iwe+1
      weightb( 17, 25,  3)=                  0.21649547079026196239d0
      iwe=iwe+1
      weightb( 18, 25,  3)=                  0.43103302394181286505d0
      iwe=iwe+1
      weightb( 19, 25,  3)=                  0.09071840903515028531d0
      iwe=iwe+1
      weightb( 20, 25,  3)=                 -0.02037629167795933227d0
      iwe=iwe+1
      weightb( 21, 25,  3)=                  0.17844019604178157357d0
      iwe=iwe+1
      weightb( 22, 25,  3)=                 -0.16477770450565301652d0
      iwe=iwe+1
      weightb( 23, 25,  3)=                 -0.17500653769094534629d0
      iwe=iwe+1
      weightb( 24, 25,  3)=                  0.26044367350662478433d0
      iwe=iwe+1
      weightb( 25, 25,  3)=                  0.04650127902583198886d0
      iwe=iwe+1
      weightb( 26, 25,  3)=                  0.24481060605875104574d0
      iwe=iwe+1
      weightb( 27, 25,  3)=                 -0.03462229911261713311d0
      iwe=iwe+1
      weightb( 28, 25,  3)=                  0.07599267654388190685d0
      iwe=iwe+1
      weightb( 29, 25,  3)=                 -0.12085136503847355993d0
      iwe=iwe+1
      weightb( 30, 25,  3)=                  0.21309623375652411714d0
      iwe=iwe+1
      weightb( 31, 25,  3)=                 -0.05389214542942561553d0
      iwe=iwe+1
      weightb( 32, 25,  3)=                 -0.09267196413752505635d0
      iwe=iwe+1
      weightb( 33, 25,  3)=                  0.24948520260761938849d0
      iwe=iwe+1
      weightb( 34, 25,  3)=                 -0.05422814215833164642d0
      iwe=iwe+1
      weightb( 35, 25,  3)=                  0.26174671011702377310d0
      iwe=iwe+1
      weightb( 36, 25,  3)=                 -0.09056181296454231255d0
      iwe=iwe+1
      weightb( 37, 25,  3)=                  0.33210000377496645685d0
      iwe=iwe+1
      weightb( 38, 25,  3)=                 -0.28597416040966677775d0
      iwe=iwe+1
      weightb( 39, 25,  3)=                  0.36246134080945324740d0
      iwe=iwe+1
      weightb( 40, 25,  3)=                 -0.20430912477153531648d0
      iwe=iwe+1
      weightb( 41, 25,  3)=                 -0.34731225821751121607d0
      iwe=iwe+1
      weightb( 42, 25,  3)=                  0.09664135997883202545d0
      iwe=iwe+1
      weightb( 43, 25,  3)=                  0.01945957564971854958d0
      iwe=iwe+1
      weightb( 44, 25,  3)=                  0.25304663010684164126d0
      iwe=iwe+1
      weightb( 45, 25,  3)=                 -0.18246039807585343051d0
      iwe=iwe+1
      weightb( 46, 25,  3)=                  0.03877486250520042338d0
      iwe=iwe+1
      weightb( 47, 25,  3)=                  0.32674971431573363034d0
      iwe=iwe+1
      weightb( 48, 25,  3)=                  0.16558935265074778420d0
      iwe=iwe+1
      weightb( 49, 25,  3)=                  0.07913846716368763690d0
      iwe=iwe+1
      weightb( 50, 25,  3)=                  0.25962771789990551907d0
      iwe=iwe+1
      biasb( 25,  3)=                  0.59997370887397616368d0
      iwe=iwe+1
      weightb(  1, 26,  3)=                  0.10298521065315008327d0
      iwe=iwe+1
      weightb(  2, 26,  3)=                  0.37611516310322368195d0
      iwe=iwe+1
      weightb(  3, 26,  3)=                  0.33699225374706287539d0
      iwe=iwe+1
      weightb(  4, 26,  3)=                  0.10103464080642678147d0
      iwe=iwe+1
      weightb(  5, 26,  3)=                 -0.57482528658161424762d0
      iwe=iwe+1
      weightb(  6, 26,  3)=                  0.44673197310930790049d0
      iwe=iwe+1
      weightb(  7, 26,  3)=                 -0.24364734529896392434d0
      iwe=iwe+1
      weightb(  8, 26,  3)=                  0.07298721254271971215d0
      iwe=iwe+1
      weightb(  9, 26,  3)=                  0.48951407800233798229d0
      iwe=iwe+1
      weightb( 10, 26,  3)=                  0.12439140311064694755d0
      iwe=iwe+1
      weightb( 11, 26,  3)=                 -0.09941773177035290177d0
      iwe=iwe+1
      weightb( 12, 26,  3)=                  0.03599170608956873962d0
      iwe=iwe+1
      weightb( 13, 26,  3)=                 -0.05998136368474580454d0
      iwe=iwe+1
      weightb( 14, 26,  3)=                  0.13059853805719631725d0
      iwe=iwe+1
      weightb( 15, 26,  3)=                  0.47822381248211848215d0
      iwe=iwe+1
      weightb( 16, 26,  3)=                 -0.11889318158155313954d0
      iwe=iwe+1
      weightb( 17, 26,  3)=                 -0.15152904447689802270d0
      iwe=iwe+1
      weightb( 18, 26,  3)=                 -0.03950937800835293418d0
      iwe=iwe+1
      weightb( 19, 26,  3)=                  0.13887604173751855186d0
      iwe=iwe+1
      weightb( 20, 26,  3)=                  0.18478329019019018586d0
      iwe=iwe+1
      weightb( 21, 26,  3)=                  0.01071757679905914820d0
      iwe=iwe+1
      weightb( 22, 26,  3)=                 -0.03044006289912330743d0
      iwe=iwe+1
      weightb( 23, 26,  3)=                 -0.22384939726316566144d0
      iwe=iwe+1
      weightb( 24, 26,  3)=                 -0.13898210579854763935d0
      iwe=iwe+1
      weightb( 25, 26,  3)=                  0.39950148036879451485d0
      iwe=iwe+1
      weightb( 26, 26,  3)=                  0.39490881432478713853d0
      iwe=iwe+1
      weightb( 27, 26,  3)=                 -0.07145696930452520579d0
      iwe=iwe+1
      weightb( 28, 26,  3)=                 -0.51876188431557224146d0
      iwe=iwe+1
      weightb( 29, 26,  3)=                 -0.26538323891197751481d0
      iwe=iwe+1
      weightb( 30, 26,  3)=                 -0.36638919255584412316d0
      iwe=iwe+1
      weightb( 31, 26,  3)=                  0.55847057840288361064d0
      iwe=iwe+1
      weightb( 32, 26,  3)=                 -0.45008027060218958049d0
      iwe=iwe+1
      weightb( 33, 26,  3)=                  0.13055207957399031504d0
      iwe=iwe+1
      weightb( 34, 26,  3)=                  0.03701337480052894341d0
      iwe=iwe+1
      weightb( 35, 26,  3)=                  0.65442142429625438371d0
      iwe=iwe+1
      weightb( 36, 26,  3)=                  0.10195432899976787644d0
      iwe=iwe+1
      weightb( 37, 26,  3)=                  0.14319973735512747659d0
      iwe=iwe+1
      weightb( 38, 26,  3)=                 -0.33431335282708618539d0
      iwe=iwe+1
      weightb( 39, 26,  3)=                  0.04331151869171213920d0
      iwe=iwe+1
      weightb( 40, 26,  3)=                 -0.38649295357252932970d0
      iwe=iwe+1
      weightb( 41, 26,  3)=                 -0.61936185463031312448d0
      iwe=iwe+1
      weightb( 42, 26,  3)=                 -0.31382773629616605993d0
      iwe=iwe+1
      weightb( 43, 26,  3)=                  0.06500413025677580225d0
      iwe=iwe+1
      weightb( 44, 26,  3)=                  0.02015293284176890645d0
      iwe=iwe+1
      weightb( 45, 26,  3)=                 -0.28750117927802482098d0
      iwe=iwe+1
      weightb( 46, 26,  3)=                  0.18666720238470618787d0
      iwe=iwe+1
      weightb( 47, 26,  3)=                 -0.09213705368252080030d0
      iwe=iwe+1
      weightb( 48, 26,  3)=                 -0.02991412537678751066d0
      iwe=iwe+1
      weightb( 49, 26,  3)=                 -0.31422950456100029459d0
      iwe=iwe+1
      weightb( 50, 26,  3)=                 -0.10319606818546525617d0
      iwe=iwe+1
      biasb( 26,  3)=                  0.72443565197716675019d0
      iwe=iwe+1
      weightb(  1, 27,  3)=                  0.06674408558817152004d0
      iwe=iwe+1
      weightb(  2, 27,  3)=                  0.47276082473232150516d0
      iwe=iwe+1
      weightb(  3, 27,  3)=                 -0.13666969818264229630d0
      iwe=iwe+1
      weightb(  4, 27,  3)=                 -0.33005903323038793262d0
      iwe=iwe+1
      weightb(  5, 27,  3)=                  0.27811398544611909411d0
      iwe=iwe+1
      weightb(  6, 27,  3)=                 -0.14653013224314212493d0
      iwe=iwe+1
      weightb(  7, 27,  3)=                  0.21009019256219474414d0
      iwe=iwe+1
      weightb(  8, 27,  3)=                  0.02693990511236265400d0
      iwe=iwe+1
      weightb(  9, 27,  3)=                  0.04508016128278678064d0
      iwe=iwe+1
      weightb( 10, 27,  3)=                  0.03841367145412422773d0
      iwe=iwe+1
      weightb( 11, 27,  3)=                 -0.13166910001095299965d0
      iwe=iwe+1
      weightb( 12, 27,  3)=                  0.82715385323949963681d0
      iwe=iwe+1
      weightb( 13, 27,  3)=                  0.25628053368098713261d0
      iwe=iwe+1
      weightb( 14, 27,  3)=                 -0.18652057874445265861d0
      iwe=iwe+1
      weightb( 15, 27,  3)=                 -0.36364793342125839581d0
      iwe=iwe+1
      weightb( 16, 27,  3)=                  0.03669352823659437213d0
      iwe=iwe+1
      weightb( 17, 27,  3)=                  0.50895590785121425093d0
      iwe=iwe+1
      weightb( 18, 27,  3)=                  0.53016621713263223370d0
      iwe=iwe+1
      weightb( 19, 27,  3)=                  0.33087653266522609741d0
      iwe=iwe+1
      weightb( 20, 27,  3)=                 -0.08991462476298255069d0
      iwe=iwe+1
      weightb( 21, 27,  3)=                 -0.09778285991371123143d0
      iwe=iwe+1
      weightb( 22, 27,  3)=                  0.17719633024080663763d0
      iwe=iwe+1
      weightb( 23, 27,  3)=                 -0.09118654448600586881d0
      iwe=iwe+1
      weightb( 24, 27,  3)=                  0.67385771867795563050d0
      iwe=iwe+1
      weightb( 25, 27,  3)=                 -0.40255357870694868927d0
      iwe=iwe+1
      weightb( 26, 27,  3)=                 -0.03071523598670534635d0
      iwe=iwe+1
      weightb( 27, 27,  3)=                  0.56940936497984273590d0
      iwe=iwe+1
      weightb( 28, 27,  3)=                  0.32887218323956762811d0
      iwe=iwe+1
      weightb( 29, 27,  3)=                  0.25748173790899059332d0
      iwe=iwe+1
      weightb( 30, 27,  3)=                 -0.14295557150209142749d0
      iwe=iwe+1
      weightb( 31, 27,  3)=                 -0.22284856488258575347d0
      iwe=iwe+1
      weightb( 32, 27,  3)=                  0.08854872979579812842d0
      iwe=iwe+1
      weightb( 33, 27,  3)=                 -0.11352695493478073829d0
      iwe=iwe+1
      weightb( 34, 27,  3)=                  0.48433527318633096126d0
      iwe=iwe+1
      weightb( 35, 27,  3)=                  0.37917574159268413458d0
      iwe=iwe+1
      weightb( 36, 27,  3)=                 -0.49638422726079728386d0
      iwe=iwe+1
      weightb( 37, 27,  3)=                 -0.01065101930544914803d0
      iwe=iwe+1
      weightb( 38, 27,  3)=                 -0.15826167320660419757d0
      iwe=iwe+1
      weightb( 39, 27,  3)=                 -0.12035418590819473017d0
      iwe=iwe+1
      weightb( 40, 27,  3)=                 -0.42441427395601782901d0
      iwe=iwe+1
      weightb( 41, 27,  3)=                  0.17315333038977340219d0
      iwe=iwe+1
      weightb( 42, 27,  3)=                 -0.13610890122556898452d0
      iwe=iwe+1
      weightb( 43, 27,  3)=                  0.03221612227648096294d0
      iwe=iwe+1
      weightb( 44, 27,  3)=                 -0.17544220955163891684d0
      iwe=iwe+1
      weightb( 45, 27,  3)=                 -0.07369116611443002340d0
      iwe=iwe+1
      weightb( 46, 27,  3)=                 -0.27307858119610234349d0
      iwe=iwe+1
      weightb( 47, 27,  3)=                 -0.09489167730493060227d0
      iwe=iwe+1
      weightb( 48, 27,  3)=                 -0.08921517039640160240d0
      iwe=iwe+1
      weightb( 49, 27,  3)=                  0.17556299379671327920d0
      iwe=iwe+1
      weightb( 50, 27,  3)=                 -0.02838096649461569615d0
      iwe=iwe+1
      biasb( 27,  3)=                 -0.48223336145205136782d0
      iwe=iwe+1
      weightb(  1, 28,  3)=                 -0.11687857674276826148d0
      iwe=iwe+1
      weightb(  2, 28,  3)=                 -0.21493776174375317511d0
      iwe=iwe+1
      weightb(  3, 28,  3)=                  0.37247329158221970102d0
      iwe=iwe+1
      weightb(  4, 28,  3)=                  0.22233880930696811595d0
      iwe=iwe+1
      weightb(  5, 28,  3)=                  0.10429056643892929690d0
      iwe=iwe+1
      weightb(  6, 28,  3)=                  0.09247503367430948140d0
      iwe=iwe+1
      weightb(  7, 28,  3)=                 -0.33781038637145299752d0
      iwe=iwe+1
      weightb(  8, 28,  3)=                 -0.05569013279937099631d0
      iwe=iwe+1
      weightb(  9, 28,  3)=                 -0.35704719101100607093d0
      iwe=iwe+1
      weightb( 10, 28,  3)=                  0.08014285247704398818d0
      iwe=iwe+1
      weightb( 11, 28,  3)=                 -0.23630591990541674474d0
      iwe=iwe+1
      weightb( 12, 28,  3)=                 -0.20808175394553615756d0
      iwe=iwe+1
      weightb( 13, 28,  3)=                  0.30531074396668556048d0
      iwe=iwe+1
      weightb( 14, 28,  3)=                  0.04837643340511557644d0
      iwe=iwe+1
      weightb( 15, 28,  3)=                  0.34789293737725462963d0
      iwe=iwe+1
      weightb( 16, 28,  3)=                 -0.26815032384826742451d0
      iwe=iwe+1
      weightb( 17, 28,  3)=                 -0.38666372490767253467d0
      iwe=iwe+1
      weightb( 18, 28,  3)=                  0.22944455111517966794d0
      iwe=iwe+1
      weightb( 19, 28,  3)=                  0.27548201917350467749d0
      iwe=iwe+1
      weightb( 20, 28,  3)=                 -0.14334247079381287615d0
      iwe=iwe+1
      weightb( 21, 28,  3)=                 -0.33029260559405748676d0
      iwe=iwe+1
      weightb( 22, 28,  3)=                 -0.23780012786883852893d0
      iwe=iwe+1
      weightb( 23, 28,  3)=                  0.00358183605284813963d0
      iwe=iwe+1
      weightb( 24, 28,  3)=                  0.05239457081131337901d0
      iwe=iwe+1
      weightb( 25, 28,  3)=                  0.25019048077379446582d0
      iwe=iwe+1
      weightb( 26, 28,  3)=                  0.05505748220050529773d0
      iwe=iwe+1
      weightb( 27, 28,  3)=                  0.34795101730012056862d0
      iwe=iwe+1
      weightb( 28, 28,  3)=                  0.39464704578579534733d0
      iwe=iwe+1
      weightb( 29, 28,  3)=                 -0.23124330897129966034d0
      iwe=iwe+1
      weightb( 30, 28,  3)=                 -0.02553636404740002724d0
      iwe=iwe+1
      weightb( 31, 28,  3)=                 -0.28021519824908069918d0
      iwe=iwe+1
      weightb( 32, 28,  3)=                  0.08171617304228000200d0
      iwe=iwe+1
      weightb( 33, 28,  3)=                  0.26910568480807550706d0
      iwe=iwe+1
      weightb( 34, 28,  3)=                 -0.28575408604006652391d0
      iwe=iwe+1
      weightb( 35, 28,  3)=                 -0.19606607977605169935d0
      iwe=iwe+1
      weightb( 36, 28,  3)=                 -0.15218580806365994418d0
      iwe=iwe+1
      weightb( 37, 28,  3)=                 -0.03898890247750518706d0
      iwe=iwe+1
      weightb( 38, 28,  3)=                 -0.00266497155715617875d0
      iwe=iwe+1
      weightb( 39, 28,  3)=                  0.06757007957656882557d0
      iwe=iwe+1
      weightb( 40, 28,  3)=                 -0.26883815483102674326d0
      iwe=iwe+1
      weightb( 41, 28,  3)=                 -0.17470162267183494964d0
      iwe=iwe+1
      weightb( 42, 28,  3)=                 -0.38454423351475092163d0
      iwe=iwe+1
      weightb( 43, 28,  3)=                 -0.02586702992433364753d0
      iwe=iwe+1
      weightb( 44, 28,  3)=                 -0.23407126071343842266d0
      iwe=iwe+1
      weightb( 45, 28,  3)=                 -0.25263279285498424498d0
      iwe=iwe+1
      weightb( 46, 28,  3)=                 -0.16689207246449327959d0
      iwe=iwe+1
      weightb( 47, 28,  3)=                  0.35131004397952608764d0
      iwe=iwe+1
      weightb( 48, 28,  3)=                  0.31913093440392675815d0
      iwe=iwe+1
      weightb( 49, 28,  3)=                 -0.29263703917609246163d0
      iwe=iwe+1
      weightb( 50, 28,  3)=                  0.06533309344390790530d0
      iwe=iwe+1
      biasb( 28,  3)=                  0.53643574456942277884d0
      iwe=iwe+1
      weightb(  1, 29,  3)=                 -0.30785108070527167357d0
      iwe=iwe+1
      weightb(  2, 29,  3)=                 -0.13628064609296072773d0
      iwe=iwe+1
      weightb(  3, 29,  3)=                  0.20603108132986233669d0
      iwe=iwe+1
      weightb(  4, 29,  3)=                 -0.10263701302903574519d0
      iwe=iwe+1
      weightb(  5, 29,  3)=                 -0.01838175432412916810d0
      iwe=iwe+1
      weightb(  6, 29,  3)=                  0.29265449965685502720d0
      iwe=iwe+1
      weightb(  7, 29,  3)=                 -0.24022405039562769180d0
      iwe=iwe+1
      weightb(  8, 29,  3)=                 -0.06153526024730322092d0
      iwe=iwe+1
      weightb(  9, 29,  3)=                 -0.39370703793688449634d0
      iwe=iwe+1
      weightb( 10, 29,  3)=                 -0.04259352364095096710d0
      iwe=iwe+1
      weightb( 11, 29,  3)=                 -0.44740095636705651261d0
      iwe=iwe+1
      weightb( 12, 29,  3)=                  0.78805527230578664710d0
      iwe=iwe+1
      weightb( 13, 29,  3)=                  0.16915248762474863198d0
      iwe=iwe+1
      weightb( 14, 29,  3)=                  0.80461459535892232431d0
      iwe=iwe+1
      weightb( 15, 29,  3)=                 -0.12547168830749000357d0
      iwe=iwe+1
      weightb( 16, 29,  3)=                  0.57007162153508528224d0
      iwe=iwe+1
      weightb( 17, 29,  3)=                 -0.07979431200317536887d0
      iwe=iwe+1
      weightb( 18, 29,  3)=                 -0.06332848706826994800d0
      iwe=iwe+1
      weightb( 19, 29,  3)=                 -0.46142782121652720084d0
      iwe=iwe+1
      weightb( 20, 29,  3)=                  0.18321361182071038698d0
      iwe=iwe+1
      weightb( 21, 29,  3)=                 -0.43445325190763040002d0
      iwe=iwe+1
      weightb( 22, 29,  3)=                  0.14869328276833942981d0
      iwe=iwe+1
      weightb( 23, 29,  3)=                  0.13272614712005736948d0
      iwe=iwe+1
      weightb( 24, 29,  3)=                  0.00419466180180427285d0
      iwe=iwe+1
      weightb( 25, 29,  3)=                 -0.65999389478709336032d0
      iwe=iwe+1
      weightb( 26, 29,  3)=                 -0.02509063350272801307d0
      iwe=iwe+1
      weightb( 27, 29,  3)=                 -0.07168167824897413165d0
      iwe=iwe+1
      weightb( 28, 29,  3)=                 -0.29858246615628369902d0
      iwe=iwe+1
      weightb( 29, 29,  3)=                  0.04541082054363675818d0
      iwe=iwe+1
      weightb( 30, 29,  3)=                  0.28161389884927690019d0
      iwe=iwe+1
      weightb( 31, 29,  3)=                  0.20507262032327758239d0
      iwe=iwe+1
      weightb( 32, 29,  3)=                 -0.55195585207418229601d0
      iwe=iwe+1
      weightb( 33, 29,  3)=                 -0.43289062304861303243d0
      iwe=iwe+1
      weightb( 34, 29,  3)=                  0.36707357618802721744d0
      iwe=iwe+1
      weightb( 35, 29,  3)=                 -0.01192311210484756426d0
      iwe=iwe+1
      weightb( 36, 29,  3)=                  0.15598133939973821138d0
      iwe=iwe+1
      weightb( 37, 29,  3)=                  0.34014479078899034770d0
      iwe=iwe+1
      weightb( 38, 29,  3)=                  0.09862979474768125698d0
      iwe=iwe+1
      weightb( 39, 29,  3)=                  0.52712241280194671589d0
      iwe=iwe+1
      weightb( 40, 29,  3)=                 -0.18128650132696935704d0
      iwe=iwe+1
      weightb( 41, 29,  3)=                 -0.15175250643456772437d0
      iwe=iwe+1
      weightb( 42, 29,  3)=                 -0.05001686901254668444d0
      iwe=iwe+1
      weightb( 43, 29,  3)=                  0.05198904933706500336d0
      iwe=iwe+1
      weightb( 44, 29,  3)=                  0.20700142126902476569d0
      iwe=iwe+1
      weightb( 45, 29,  3)=                  0.30006297589097236100d0
      iwe=iwe+1
      weightb( 46, 29,  3)=                 -0.40587407062161273696d0
      iwe=iwe+1
      weightb( 47, 29,  3)=                  0.31770879065830331944d0
      iwe=iwe+1
      weightb( 48, 29,  3)=                 -0.18519576944884230674d0
      iwe=iwe+1
      weightb( 49, 29,  3)=                 -0.34110205303602053606d0
      iwe=iwe+1
      weightb( 50, 29,  3)=                  0.29523644289070222202d0
      iwe=iwe+1
      biasb( 29,  3)=                 -0.35532320251516885667d0
      iwe=iwe+1
      weightb(  1, 30,  3)=                  0.51201794309232928626d0
      iwe=iwe+1
      weightb(  2, 30,  3)=                  0.08612518484021629284d0
      iwe=iwe+1
      weightb(  3, 30,  3)=                 -0.22391063745976852450d0
      iwe=iwe+1
      weightb(  4, 30,  3)=                 -0.00420181539193164970d0
      iwe=iwe+1
      weightb(  5, 30,  3)=                 -0.17040469716876216477d0
      iwe=iwe+1
      weightb(  6, 30,  3)=                  0.48687104627502342247d0
      iwe=iwe+1
      weightb(  7, 30,  3)=                  0.03057313707936144473d0
      iwe=iwe+1
      weightb(  8, 30,  3)=                  0.64939001410405039483d0
      iwe=iwe+1
      weightb(  9, 30,  3)=                  0.52668296642001810604d0
      iwe=iwe+1
      weightb( 10, 30,  3)=                 -0.73682046374428222801d0
      iwe=iwe+1
      weightb( 11, 30,  3)=                 -0.59368693762637037015d0
      iwe=iwe+1
      weightb( 12, 30,  3)=                 -0.33776358181977528261d0
      iwe=iwe+1
      weightb( 13, 30,  3)=                  0.16538733179631368020d0
      iwe=iwe+1
      weightb( 14, 30,  3)=                  0.30009473801612535082d0
      iwe=iwe+1
      weightb( 15, 30,  3)=                  0.08988576485055688181d0
      iwe=iwe+1
      weightb( 16, 30,  3)=                 -0.22270367954430619895d0
      iwe=iwe+1
      weightb( 17, 30,  3)=                 -0.16441741379368984832d0
      iwe=iwe+1
      weightb( 18, 30,  3)=                  0.08473118582046033909d0
      iwe=iwe+1
      weightb( 19, 30,  3)=                  0.35066407951200934123d0
      iwe=iwe+1
      weightb( 20, 30,  3)=                  0.14180512565302844097d0
      iwe=iwe+1
      weightb( 21, 30,  3)=                  0.13174518037678414895d0
      iwe=iwe+1
      weightb( 22, 30,  3)=                  0.32884653964905508072d0
      iwe=iwe+1
      weightb( 23, 30,  3)=                 -0.01552233640213903677d0
      iwe=iwe+1
      weightb( 24, 30,  3)=                  0.57229766226223210968d0
      iwe=iwe+1
      weightb( 25, 30,  3)=                  0.32368048714362956941d0
      iwe=iwe+1
      weightb( 26, 30,  3)=                 -0.10463530083670270765d0
      iwe=iwe+1
      weightb( 27, 30,  3)=                 -0.52426171143298927468d0
      iwe=iwe+1
      weightb( 28, 30,  3)=                 -0.06396827093010455656d0
      iwe=iwe+1
      weightb( 29, 30,  3)=                  0.55237838297476826721d0
      iwe=iwe+1
      weightb( 30, 30,  3)=                  0.11773172825199386404d0
      iwe=iwe+1
      weightb( 31, 30,  3)=                  0.37676462178326208807d0
      iwe=iwe+1
      weightb( 32, 30,  3)=                  0.10865630240861087752d0
      iwe=iwe+1
      weightb( 33, 30,  3)=                 -0.19140048779446941496d0
      iwe=iwe+1
      weightb( 34, 30,  3)=                  0.18024103168227792460d0
      iwe=iwe+1
      weightb( 35, 30,  3)=                 -0.53243946213535431333d0
      iwe=iwe+1
      weightb( 36, 30,  3)=                 -0.11164215063406257578d0
      iwe=iwe+1
      weightb( 37, 30,  3)=                  0.17795375626692080950d0
      iwe=iwe+1
      weightb( 38, 30,  3)=                 -0.71259370332536808856d0
      iwe=iwe+1
      weightb( 39, 30,  3)=                  0.10861597054027738452d0
      iwe=iwe+1
      weightb( 40, 30,  3)=                 -0.27477429416682175312d0
      iwe=iwe+1
      weightb( 41, 30,  3)=                 -0.15183895129767299714d0
      iwe=iwe+1
      weightb( 42, 30,  3)=                  0.10252807713295147840d0
      iwe=iwe+1
      weightb( 43, 30,  3)=                 -0.25526516692852974089d0
      iwe=iwe+1
      weightb( 44, 30,  3)=                 -0.16337388975862401908d0
      iwe=iwe+1
      weightb( 45, 30,  3)=                  0.18441335650120388445d0
      iwe=iwe+1
      weightb( 46, 30,  3)=                 -0.52868415517254163660d0
      iwe=iwe+1
      weightb( 47, 30,  3)=                 -0.70611324664540486840d0
      iwe=iwe+1
      weightb( 48, 30,  3)=                 -0.41129287591800151036d0
      iwe=iwe+1
      weightb( 49, 30,  3)=                  0.09429423325768727937d0
      iwe=iwe+1
      weightb( 50, 30,  3)=                  0.32683086465588251368d0
      iwe=iwe+1
      biasb( 30,  3)=                  0.20859634026702544851d0
      iwe=iwe+1
      weightb(  1, 31,  3)=                 -0.01986864065764860562d0
      iwe=iwe+1
      weightb(  2, 31,  3)=                  0.31574940787846222934d0
      iwe=iwe+1
      weightb(  3, 31,  3)=                  0.08109144280459383569d0
      iwe=iwe+1
      weightb(  4, 31,  3)=                 -0.00285058014396694310d0
      iwe=iwe+1
      weightb(  5, 31,  3)=                 -0.12508540566066503330d0
      iwe=iwe+1
      weightb(  6, 31,  3)=                  0.72966652579920177057d0
      iwe=iwe+1
      weightb(  7, 31,  3)=                  0.01120644705073881205d0
      iwe=iwe+1
      weightb(  8, 31,  3)=                  0.11184797291436132660d0
      iwe=iwe+1
      weightb(  9, 31,  3)=                 -0.22155648813490538829d0
      iwe=iwe+1
      weightb( 10, 31,  3)=                 -0.00903243507314069154d0
      iwe=iwe+1
      weightb( 11, 31,  3)=                  0.42490899728242026434d0
      iwe=iwe+1
      weightb( 12, 31,  3)=                  0.31857852882115256232d0
      iwe=iwe+1
      weightb( 13, 31,  3)=                  0.69658381794758139627d0
      iwe=iwe+1
      weightb( 14, 31,  3)=                  0.12658092828589909140d0
      iwe=iwe+1
      weightb( 15, 31,  3)=                  0.47474808576440424845d0
      iwe=iwe+1
      weightb( 16, 31,  3)=                 -0.05757930872416083118d0
      iwe=iwe+1
      weightb( 17, 31,  3)=                  0.19485984034589606817d0
      iwe=iwe+1
      weightb( 18, 31,  3)=                 -0.32234271777711276386d0
      iwe=iwe+1
      weightb( 19, 31,  3)=                  0.37211226381229789428d0
      iwe=iwe+1
      weightb( 20, 31,  3)=                  0.38653931583442679987d0
      iwe=iwe+1
      weightb( 21, 31,  3)=                  0.19521145884905910517d0
      iwe=iwe+1
      weightb( 22, 31,  3)=                  0.20589706249360648083d0
      iwe=iwe+1
      weightb( 23, 31,  3)=                  0.18398841190755288455d0
      iwe=iwe+1
      weightb( 24, 31,  3)=                 -0.01870937908149829937d0
      iwe=iwe+1
      weightb( 25, 31,  3)=                 -0.03633394781053200101d0
      iwe=iwe+1
      weightb( 26, 31,  3)=                  0.01222124965572432033d0
      iwe=iwe+1
      weightb( 27, 31,  3)=                 -0.11977689927952687998d0
      iwe=iwe+1
      weightb( 28, 31,  3)=                  0.24199837946617983042d0
      iwe=iwe+1
      weightb( 29, 31,  3)=                 -0.23275043389635596824d0
      iwe=iwe+1
      weightb( 30, 31,  3)=                  0.04915629331929653040d0
      iwe=iwe+1
      weightb( 31, 31,  3)=                  0.03528774158720807824d0
      iwe=iwe+1
      weightb( 32, 31,  3)=                 -0.17125616868786711078d0
      iwe=iwe+1
      weightb( 33, 31,  3)=                 -0.60014060279288139466d0
      iwe=iwe+1
      weightb( 34, 31,  3)=                 -0.31830551056273032051d0
      iwe=iwe+1
      weightb( 35, 31,  3)=                  0.19505258111313397706d0
      iwe=iwe+1
      weightb( 36, 31,  3)=                 -0.00670138111467067851d0
      iwe=iwe+1
      weightb( 37, 31,  3)=                 -0.06535517743615582020d0
      iwe=iwe+1
      weightb( 38, 31,  3)=                  0.04893425088429254055d0
      iwe=iwe+1
      weightb( 39, 31,  3)=                  0.03687165737468180854d0
      iwe=iwe+1
      weightb( 40, 31,  3)=                  0.00828756221021346474d0
      iwe=iwe+1
      weightb( 41, 31,  3)=                 -0.08257358219169967650d0
      iwe=iwe+1
      weightb( 42, 31,  3)=                  0.40865264456938560356d0
      iwe=iwe+1
      weightb( 43, 31,  3)=                 -0.11195027551531684662d0
      iwe=iwe+1
      weightb( 44, 31,  3)=                 -0.00657086026275745510d0
      iwe=iwe+1
      weightb( 45, 31,  3)=                  0.31924843733880869934d0
      iwe=iwe+1
      weightb( 46, 31,  3)=                  0.29576414155746238999d0
      iwe=iwe+1
      weightb( 47, 31,  3)=                  0.24849047554649411618d0
      iwe=iwe+1
      weightb( 48, 31,  3)=                 -0.38241324841117430022d0
      iwe=iwe+1
      weightb( 49, 31,  3)=                  0.70145224043473142217d0
      iwe=iwe+1
      weightb( 50, 31,  3)=                 -0.34840315679662858805d0
      iwe=iwe+1
      biasb( 31,  3)=                 -0.49991470322631165191d0
      iwe=iwe+1
      weightb(  1, 32,  3)=                 -0.08238128827706234225d0
      iwe=iwe+1
      weightb(  2, 32,  3)=                 -0.18379538963370214977d0
      iwe=iwe+1
      weightb(  3, 32,  3)=                  0.20515629718184780206d0
      iwe=iwe+1
      weightb(  4, 32,  3)=                 -0.41847868184097869459d0
      iwe=iwe+1
      weightb(  5, 32,  3)=                  0.20536378044514380647d0
      iwe=iwe+1
      weightb(  6, 32,  3)=                 -0.05991471455286530301d0
      iwe=iwe+1
      weightb(  7, 32,  3)=                 -0.05002699142824836021d0
      iwe=iwe+1
      weightb(  8, 32,  3)=                  0.09203049081430421385d0
      iwe=iwe+1
      weightb(  9, 32,  3)=                  0.15075230014520507593d0
      iwe=iwe+1
      weightb( 10, 32,  3)=                  0.15178660706836830108d0
      iwe=iwe+1
      weightb( 11, 32,  3)=                 -0.19515480653404301825d0
      iwe=iwe+1
      weightb( 12, 32,  3)=                  0.09701834189697947086d0
      iwe=iwe+1
      weightb( 13, 32,  3)=                 -0.01961417491322688805d0
      iwe=iwe+1
      weightb( 14, 32,  3)=                 -0.32222190314924281651d0
      iwe=iwe+1
      weightb( 15, 32,  3)=                 -0.39441117980682111055d0
      iwe=iwe+1
      weightb( 16, 32,  3)=                 -0.18296720579747596802d0
      iwe=iwe+1
      weightb( 17, 32,  3)=                 -0.21185466598691807261d0
      iwe=iwe+1
      weightb( 18, 32,  3)=                  0.38930447617565949736d0
      iwe=iwe+1
      weightb( 19, 32,  3)=                 -0.20248558498777077808d0
      iwe=iwe+1
      weightb( 20, 32,  3)=                  0.07016923669856856005d0
      iwe=iwe+1
      weightb( 21, 32,  3)=                 -0.52266898518239823801d0
      iwe=iwe+1
      weightb( 22, 32,  3)=                 -0.61991597996049052632d0
      iwe=iwe+1
      weightb( 23, 32,  3)=                  0.23374927650870575002d0
      iwe=iwe+1
      weightb( 24, 32,  3)=                  0.22155484471435873961d0
      iwe=iwe+1
      weightb( 25, 32,  3)=                  0.14375796030352161470d0
      iwe=iwe+1
      weightb( 26, 32,  3)=                 -0.18209926569789905426d0
      iwe=iwe+1
      weightb( 27, 32,  3)=                  0.10099301324560892856d0
      iwe=iwe+1
      weightb( 28, 32,  3)=                 -0.59077938748208314035d0
      iwe=iwe+1
      weightb( 29, 32,  3)=                  0.05770962260004708355d0
      iwe=iwe+1
      weightb( 30, 32,  3)=                 -0.02937132887509654247d0
      iwe=iwe+1
      weightb( 31, 32,  3)=                  0.10091728237254121714d0
      iwe=iwe+1
      weightb( 32, 32,  3)=                 -0.10312070359569516786d0
      iwe=iwe+1
      weightb( 33, 32,  3)=                 -0.10502448783756371253d0
      iwe=iwe+1
      weightb( 34, 32,  3)=                 -0.38391543792952548264d0
      iwe=iwe+1
      weightb( 35, 32,  3)=                  0.07036302328323948418d0
      iwe=iwe+1
      weightb( 36, 32,  3)=                  0.18795584984541616191d0
      iwe=iwe+1
      weightb( 37, 32,  3)=                 -0.13037916807054186763d0
      iwe=iwe+1
      weightb( 38, 32,  3)=                  0.32298426127614920933d0
      iwe=iwe+1
      weightb( 39, 32,  3)=                 -0.07241001615636963318d0
      iwe=iwe+1
      weightb( 40, 32,  3)=                 -0.06982157006973192803d0
      iwe=iwe+1
      weightb( 41, 32,  3)=                  0.04858355196075594268d0
      iwe=iwe+1
      weightb( 42, 32,  3)=                  0.12824986044026240317d0
      iwe=iwe+1
      weightb( 43, 32,  3)=                  0.11704205196321018634d0
      iwe=iwe+1
      weightb( 44, 32,  3)=                  0.13607664307437269957d0
      iwe=iwe+1
      weightb( 45, 32,  3)=                 -0.31648957019818069192d0
      iwe=iwe+1
      weightb( 46, 32,  3)=                 -0.18108686821186747995d0
      iwe=iwe+1
      weightb( 47, 32,  3)=                  0.43571121147309976873d0
      iwe=iwe+1
      weightb( 48, 32,  3)=                 -0.02904854682204126293d0
      iwe=iwe+1
      weightb( 49, 32,  3)=                  0.34034812356885452145d0
      iwe=iwe+1
      weightb( 50, 32,  3)=                 -0.00988002344022825656d0
      iwe=iwe+1
      biasb( 32,  3)=                  0.50846820133227910166d0
      iwe=iwe+1
      weightb(  1, 33,  3)=                  0.01028252216755096669d0
      iwe=iwe+1
      weightb(  2, 33,  3)=                  0.30151099029916722527d0
      iwe=iwe+1
      weightb(  3, 33,  3)=                  0.38802191841512900794d0
      iwe=iwe+1
      weightb(  4, 33,  3)=                 -0.04494087020848643033d0
      iwe=iwe+1
      weightb(  5, 33,  3)=                 -0.15638766625917271957d0
      iwe=iwe+1
      weightb(  6, 33,  3)=                  0.37034921136596099522d0
      iwe=iwe+1
      weightb(  7, 33,  3)=                 -0.14018875366827207585d0
      iwe=iwe+1
      weightb(  8, 33,  3)=                 -0.10396892146819024239d0
      iwe=iwe+1
      weightb(  9, 33,  3)=                  0.11487792447309121135d0
      iwe=iwe+1
      weightb( 10, 33,  3)=                 -0.09202781177430637005d0
      iwe=iwe+1
      weightb( 11, 33,  3)=                  0.14987833907397885014d0
      iwe=iwe+1
      weightb( 12, 33,  3)=                  0.28431906413547458623d0
      iwe=iwe+1
      weightb( 13, 33,  3)=                  0.06222516443813357750d0
      iwe=iwe+1
      weightb( 14, 33,  3)=                  0.05351733224700092051d0
      iwe=iwe+1
      weightb( 15, 33,  3)=                  0.01778482330390777563d0
      iwe=iwe+1
      weightb( 16, 33,  3)=                 -0.28837379504761900817d0
      iwe=iwe+1
      weightb( 17, 33,  3)=                 -0.37719923102868246900d0
      iwe=iwe+1
      weightb( 18, 33,  3)=                  0.04579376716268274139d0
      iwe=iwe+1
      weightb( 19, 33,  3)=                 -0.19875381856528162583d0
      iwe=iwe+1
      weightb( 20, 33,  3)=                  0.08760877920609036473d0
      iwe=iwe+1
      weightb( 21, 33,  3)=                  0.35679425215059695775d0
      iwe=iwe+1
      weightb( 22, 33,  3)=                 -0.28512435879710579245d0
      iwe=iwe+1
      weightb( 23, 33,  3)=                 -0.12378688546994486008d0
      iwe=iwe+1
      weightb( 24, 33,  3)=                 -0.02312337962050384221d0
      iwe=iwe+1
      weightb( 25, 33,  3)=                 -0.08065481166796263646d0
      iwe=iwe+1
      weightb( 26, 33,  3)=                 -0.23804501452141843543d0
      iwe=iwe+1
      weightb( 27, 33,  3)=                  0.28571593166205100367d0
      iwe=iwe+1
      weightb( 28, 33,  3)=                  0.13314707833085631661d0
      iwe=iwe+1
      weightb( 29, 33,  3)=                  0.14739183420366600008d0
      iwe=iwe+1
      weightb( 30, 33,  3)=                  0.07537515940145807225d0
      iwe=iwe+1
      weightb( 31, 33,  3)=                 -0.06583470753731908431d0
      iwe=iwe+1
      weightb( 32, 33,  3)=                  0.20959757993728286851d0
      iwe=iwe+1
      weightb( 33, 33,  3)=                  0.17263191785367443254d0
      iwe=iwe+1
      weightb( 34, 33,  3)=                  0.35107085397265891391d0
      iwe=iwe+1
      weightb( 35, 33,  3)=                  0.35974366187141093576d0
      iwe=iwe+1
      weightb( 36, 33,  3)=                  0.22886544708608697052d0
      iwe=iwe+1
      weightb( 37, 33,  3)=                 -0.09831141540248206079d0
      iwe=iwe+1
      weightb( 38, 33,  3)=                  0.17360467501557125258d0
      iwe=iwe+1
      weightb( 39, 33,  3)=                  0.34014516440844205780d0
      iwe=iwe+1
      weightb( 40, 33,  3)=                 -0.40338884771725336265d0
      iwe=iwe+1
      weightb( 41, 33,  3)=                 -0.29506175039278553784d0
      iwe=iwe+1
      weightb( 42, 33,  3)=                 -0.10386869489260294741d0
      iwe=iwe+1
      weightb( 43, 33,  3)=                 -0.24174944065586995157d0
      iwe=iwe+1
      weightb( 44, 33,  3)=                 -0.02963852563403135409d0
      iwe=iwe+1
      weightb( 45, 33,  3)=                 -0.29916006730467442631d0
      iwe=iwe+1
      weightb( 46, 33,  3)=                  0.19268222934640555355d0
      iwe=iwe+1
      weightb( 47, 33,  3)=                 -0.21613713915822574396d0
      iwe=iwe+1
      weightb( 48, 33,  3)=                 -0.17022794603926089119d0
      iwe=iwe+1
      weightb( 49, 33,  3)=                  0.33218367106845458903d0
      iwe=iwe+1
      weightb( 50, 33,  3)=                  0.02255793950171351703d0
      iwe=iwe+1
      biasb( 33,  3)=                  0.36052748804667111848d0
      iwe=iwe+1
      weightb(  1, 34,  3)=                  0.37137204700845172223d0
      iwe=iwe+1
      weightb(  2, 34,  3)=                 -0.58237964707260458930d0
      iwe=iwe+1
      weightb(  3, 34,  3)=                  0.04871023376676718308d0
      iwe=iwe+1
      weightb(  4, 34,  3)=                 -0.09387248731880715180d0
      iwe=iwe+1
      weightb(  5, 34,  3)=                  0.05698320094669913349d0
      iwe=iwe+1
      weightb(  6, 34,  3)=                 -0.37895880146109300890d0
      iwe=iwe+1
      weightb(  7, 34,  3)=                 -0.15093186030774824458d0
      iwe=iwe+1
      weightb(  8, 34,  3)=                 -0.26086927702624018721d0
      iwe=iwe+1
      weightb(  9, 34,  3)=                 -0.16677394889065250139d0
      iwe=iwe+1
      weightb( 10, 34,  3)=                 -0.06846109305102907050d0
      iwe=iwe+1
      weightb( 11, 34,  3)=                  0.05591239834615408660d0
      iwe=iwe+1
      weightb( 12, 34,  3)=                  0.31092061024041789397d0
      iwe=iwe+1
      weightb( 13, 34,  3)=                 -0.05228561288621835779d0
      iwe=iwe+1
      weightb( 14, 34,  3)=                 -0.34143685542784024678d0
      iwe=iwe+1
      weightb( 15, 34,  3)=                 -0.33713181344669562733d0
      iwe=iwe+1
      weightb( 16, 34,  3)=                  0.43701185808817266665d0
      iwe=iwe+1
      weightb( 17, 34,  3)=                  0.01508234359246270889d0
      iwe=iwe+1
      weightb( 18, 34,  3)=                  0.11682228331875223193d0
      iwe=iwe+1
      weightb( 19, 34,  3)=                 -0.09634102643171826852d0
      iwe=iwe+1
      weightb( 20, 34,  3)=                 -0.17947460761487193937d0
      iwe=iwe+1
      weightb( 21, 34,  3)=                 -0.21202352526774959074d0
      iwe=iwe+1
      weightb( 22, 34,  3)=                 -1.14548527230501284713d0
      iwe=iwe+1
      weightb( 23, 34,  3)=                  0.33357459248387766326d0
      iwe=iwe+1
      weightb( 24, 34,  3)=                  0.50575176390422282857d0
      iwe=iwe+1
      weightb( 25, 34,  3)=                  0.29032696240131183885d0
      iwe=iwe+1
      weightb( 26, 34,  3)=                 -0.29930752922072756395d0
      iwe=iwe+1
      weightb( 27, 34,  3)=                 -0.45046484878243842065d0
      iwe=iwe+1
      weightb( 28, 34,  3)=                 -0.36701579447704729686d0
      iwe=iwe+1
      weightb( 29, 34,  3)=                 -0.33195562779327947300d0
      iwe=iwe+1
      weightb( 30, 34,  3)=                 -0.15658584532369226872d0
      iwe=iwe+1
      weightb( 31, 34,  3)=                 -0.20204809423366826282d0
      iwe=iwe+1
      weightb( 32, 34,  3)=                 -0.01232470896892930330d0
      iwe=iwe+1
      weightb( 33, 34,  3)=                  0.01781950551146579617d0
      iwe=iwe+1
      weightb( 34, 34,  3)=                  0.06037402257844183551d0
      iwe=iwe+1
      weightb( 35, 34,  3)=                  0.49385289256435799254d0
      iwe=iwe+1
      weightb( 36, 34,  3)=                  0.74077579451882247241d0
      iwe=iwe+1
      weightb( 37, 34,  3)=                 -0.02629096073146620915d0
      iwe=iwe+1
      weightb( 38, 34,  3)=                  0.00289725228281642860d0
      iwe=iwe+1
      weightb( 39, 34,  3)=                 -0.39067419035418460282d0
      iwe=iwe+1
      weightb( 40, 34,  3)=                  0.17062104815290030091d0
      iwe=iwe+1
      weightb( 41, 34,  3)=                  0.06469512818031522561d0
      iwe=iwe+1
      weightb( 42, 34,  3)=                 -0.22989786839214704228d0
      iwe=iwe+1
      weightb( 43, 34,  3)=                  0.06335592147793428497d0
      iwe=iwe+1
      weightb( 44, 34,  3)=                 -0.07278498663855792472d0
      iwe=iwe+1
      weightb( 45, 34,  3)=                 -0.29873422225529244756d0
      iwe=iwe+1
      weightb( 46, 34,  3)=                 -0.10178429314626881441d0
      iwe=iwe+1
      weightb( 47, 34,  3)=                 -0.06765261135057436259d0
      iwe=iwe+1
      weightb( 48, 34,  3)=                  0.24367426052549920334d0
      iwe=iwe+1
      weightb( 49, 34,  3)=                  0.07580632658235046673d0
      iwe=iwe+1
      weightb( 50, 34,  3)=                 -0.23927658913745197822d0
      iwe=iwe+1
      biasb( 34,  3)=                  0.42307126193297461825d0
      iwe=iwe+1
      weightb(  1, 35,  3)=                 -0.15984750455434995620d0
      iwe=iwe+1
      weightb(  2, 35,  3)=                  0.11808209528842711356d0
      iwe=iwe+1
      weightb(  3, 35,  3)=                 -0.03091164613904450950d0
      iwe=iwe+1
      weightb(  4, 35,  3)=                 -0.60751387265127743120d0
      iwe=iwe+1
      weightb(  5, 35,  3)=                 -0.02933246899452102499d0
      iwe=iwe+1
      weightb(  6, 35,  3)=                 -0.02021352804433837469d0
      iwe=iwe+1
      weightb(  7, 35,  3)=                  0.40854572833407443166d0
      iwe=iwe+1
      weightb(  8, 35,  3)=                 -0.14875334808370355155d0
      iwe=iwe+1
      weightb(  9, 35,  3)=                 -0.77470421454761673186d0
      iwe=iwe+1
      weightb( 10, 35,  3)=                 -0.53350296322988333131d0
      iwe=iwe+1
      weightb( 11, 35,  3)=                 -0.43918848479246325178d0
      iwe=iwe+1
      weightb( 12, 35,  3)=                  0.00810523460037782147d0
      iwe=iwe+1
      weightb( 13, 35,  3)=                 -0.67932174178080284577d0
      iwe=iwe+1
      weightb( 14, 35,  3)=                  0.61162740479445809605d0
      iwe=iwe+1
      weightb( 15, 35,  3)=                 -0.42990069166147648616d0
      iwe=iwe+1
      weightb( 16, 35,  3)=                 -0.33824129033655930821d0
      iwe=iwe+1
      weightb( 17, 35,  3)=                  0.32136514181878378382d0
      iwe=iwe+1
      weightb( 18, 35,  3)=                 -0.31442187979111213547d0
      iwe=iwe+1
      weightb( 19, 35,  3)=                  0.04291206724682443407d0
      iwe=iwe+1
      weightb( 20, 35,  3)=                 -0.22885316143156372859d0
      iwe=iwe+1
      weightb( 21, 35,  3)=                 -0.24416539558173366853d0
      iwe=iwe+1
      weightb( 22, 35,  3)=                  0.26478937308005101592d0
      iwe=iwe+1
      weightb( 23, 35,  3)=                 -0.34356343424814000942d0
      iwe=iwe+1
      weightb( 24, 35,  3)=                  0.07787702954402156430d0
      iwe=iwe+1
      weightb( 25, 35,  3)=                 -0.17762432477367065542d0
      iwe=iwe+1
      weightb( 26, 35,  3)=                  0.05969706045074422984d0
      iwe=iwe+1
      weightb( 27, 35,  3)=                 -0.20647754285414771092d0
      iwe=iwe+1
      weightb( 28, 35,  3)=                  0.04123098941316060556d0
      iwe=iwe+1
      weightb( 29, 35,  3)=                  0.29988154139980688351d0
      iwe=iwe+1
      weightb( 30, 35,  3)=                  0.44047048554861650826d0
      iwe=iwe+1
      weightb( 31, 35,  3)=                  0.37493114786295633767d0
      iwe=iwe+1
      weightb( 32, 35,  3)=                  0.41657516622069018508d0
      iwe=iwe+1
      weightb( 33, 35,  3)=                 -0.30225057689723189291d0
      iwe=iwe+1
      weightb( 34, 35,  3)=                 -0.18635940910276432847d0
      iwe=iwe+1
      weightb( 35, 35,  3)=                 -0.09375390474483173697d0
      iwe=iwe+1
      weightb( 36, 35,  3)=                  0.01256744506077392583d0
      iwe=iwe+1
      weightb( 37, 35,  3)=                 -0.27380580370339463459d0
      iwe=iwe+1
      weightb( 38, 35,  3)=                 -0.07985266861320951259d0
      iwe=iwe+1
      weightb( 39, 35,  3)=                 -0.03053353396823357477d0
      iwe=iwe+1
      weightb( 40, 35,  3)=                 -0.47825523815486020718d0
      iwe=iwe+1
      weightb( 41, 35,  3)=                 -0.16585711448162882009d0
      iwe=iwe+1
      weightb( 42, 35,  3)=                  0.05536717367311597832d0
      iwe=iwe+1
      weightb( 43, 35,  3)=                  0.32722665977986886698d0
      iwe=iwe+1
      weightb( 44, 35,  3)=                  0.07163926226089026295d0
      iwe=iwe+1
      weightb( 45, 35,  3)=                 -0.26050019382418582170d0
      iwe=iwe+1
      weightb( 46, 35,  3)=                 -0.10198863342611609595d0
      iwe=iwe+1
      weightb( 47, 35,  3)=                 -0.21052797275557563750d0
      iwe=iwe+1
      weightb( 48, 35,  3)=                  0.32105134507114885256d0
      iwe=iwe+1
      weightb( 49, 35,  3)=                  0.15108369599928583860d0
      iwe=iwe+1
      weightb( 50, 35,  3)=                 -0.08257199021036883135d0
      iwe=iwe+1
      biasb( 35,  3)=                  0.00601045550020672028d0
      iwe=iwe+1
      weightb(  1, 36,  3)=                  0.22432172890012788691d0
      iwe=iwe+1
      weightb(  2, 36,  3)=                  0.22730280511538630828d0
      iwe=iwe+1
      weightb(  3, 36,  3)=                 -0.12093834422017453456d0
      iwe=iwe+1
      weightb(  4, 36,  3)=                  0.14605156756442133625d0
      iwe=iwe+1
      weightb(  5, 36,  3)=                 -0.05190831591315674121d0
      iwe=iwe+1
      weightb(  6, 36,  3)=                  0.18454931991996276208d0
      iwe=iwe+1
      weightb(  7, 36,  3)=                  0.04431322666861074733d0
      iwe=iwe+1
      weightb(  8, 36,  3)=                  0.07088470387879670931d0
      iwe=iwe+1
      weightb(  9, 36,  3)=                 -0.23210106861770302134d0
      iwe=iwe+1
      weightb( 10, 36,  3)=                 -0.31909734731675687414d0
      iwe=iwe+1
      weightb( 11, 36,  3)=                  0.00913754146162309294d0
      iwe=iwe+1
      weightb( 12, 36,  3)=                 -0.01204744678367319390d0
      iwe=iwe+1
      weightb( 13, 36,  3)=                 -0.33656870098225005750d0
      iwe=iwe+1
      weightb( 14, 36,  3)=                  0.26139429958923221520d0
      iwe=iwe+1
      weightb( 15, 36,  3)=                  0.20500426212291181227d0
      iwe=iwe+1
      weightb( 16, 36,  3)=                 -0.08329972109999457530d0
      iwe=iwe+1
      weightb( 17, 36,  3)=                 -0.40467598873699223150d0
      iwe=iwe+1
      weightb( 18, 36,  3)=                 -0.01784933203100521823d0
      iwe=iwe+1
      weightb( 19, 36,  3)=                 -0.16121564987373773747d0
      iwe=iwe+1
      weightb( 20, 36,  3)=                 -0.25686068148452928517d0
      iwe=iwe+1
      weightb( 21, 36,  3)=                 -0.32703524203328315778d0
      iwe=iwe+1
      weightb( 22, 36,  3)=                 -0.35055240416226851607d0
      iwe=iwe+1
      weightb( 23, 36,  3)=                  0.03823312763514301327d0
      iwe=iwe+1
      weightb( 24, 36,  3)=                 -0.22146054612297402797d0
      iwe=iwe+1
      weightb( 25, 36,  3)=                 -0.16648780307703139880d0
      iwe=iwe+1
      weightb( 26, 36,  3)=                 -0.18300638651246708966d0
      iwe=iwe+1
      weightb( 27, 36,  3)=                 -0.37151764729764746864d0
      iwe=iwe+1
      weightb( 28, 36,  3)=                 -0.43400356499188752490d0
      iwe=iwe+1
      weightb( 29, 36,  3)=                 -0.17771098268720658675d0
      iwe=iwe+1
      weightb( 30, 36,  3)=                  0.31529510695031554013d0
      iwe=iwe+1
      weightb( 31, 36,  3)=                  0.02674423628367511921d0
      iwe=iwe+1
      weightb( 32, 36,  3)=                  0.16722309720291067547d0
      iwe=iwe+1
      weightb( 33, 36,  3)=                 -0.08805394086141153653d0
      iwe=iwe+1
      weightb( 34, 36,  3)=                 -0.41420950670249823133d0
      iwe=iwe+1
      weightb( 35, 36,  3)=                  0.10144444653097089981d0
      iwe=iwe+1
      weightb( 36, 36,  3)=                 -0.33035023194869095331d0
      iwe=iwe+1
      weightb( 37, 36,  3)=                  0.37060627034961729498d0
      iwe=iwe+1
      weightb( 38, 36,  3)=                  0.23213561279679909011d0
      iwe=iwe+1
      weightb( 39, 36,  3)=                 -0.07616994810633349877d0
      iwe=iwe+1
      weightb( 40, 36,  3)=                 -0.26958206814126972617d0
      iwe=iwe+1
      weightb( 41, 36,  3)=                  0.09612164351192169220d0
      iwe=iwe+1
      weightb( 42, 36,  3)=                 -0.15931393720195993757d0
      iwe=iwe+1
      weightb( 43, 36,  3)=                  0.23920647370743053362d0
      iwe=iwe+1
      weightb( 44, 36,  3)=                 -0.22009481181760456869d0
      iwe=iwe+1
      weightb( 45, 36,  3)=                  0.16607623239783059210d0
      iwe=iwe+1
      weightb( 46, 36,  3)=                  0.27785052250692621190d0
      iwe=iwe+1
      weightb( 47, 36,  3)=                  0.10853653279781140528d0
      iwe=iwe+1
      weightb( 48, 36,  3)=                 -0.12661588111436763993d0
      iwe=iwe+1
      weightb( 49, 36,  3)=                 -0.03781323885186201744d0
      iwe=iwe+1
      weightb( 50, 36,  3)=                 -0.34391196884604774420d0
      iwe=iwe+1
      biasb( 36,  3)=                 -0.13740203162685704630d0
      iwe=iwe+1
      weightb(  1, 37,  3)=                 -0.43594156027850800017d0
      iwe=iwe+1
      weightb(  2, 37,  3)=                  0.17375780489639225390d0
      iwe=iwe+1
      weightb(  3, 37,  3)=                 -0.21109188067869677496d0
      iwe=iwe+1
      weightb(  4, 37,  3)=                  0.06603663035449572338d0
      iwe=iwe+1
      weightb(  5, 37,  3)=                  0.30279955350676607262d0
      iwe=iwe+1
      weightb(  6, 37,  3)=                  0.19739066631045609768d0
      iwe=iwe+1
      weightb(  7, 37,  3)=                 -0.39214101951470270446d0
      iwe=iwe+1
      weightb(  8, 37,  3)=                 -0.11218592826512616134d0
      iwe=iwe+1
      weightb(  9, 37,  3)=                 -0.35145809540227918033d0
      iwe=iwe+1
      weightb( 10, 37,  3)=                  0.28784008376758268843d0
      iwe=iwe+1
      weightb( 11, 37,  3)=                  0.29889264436163726080d0
      iwe=iwe+1
      weightb( 12, 37,  3)=                 -0.02160771299661429917d0
      iwe=iwe+1
      weightb( 13, 37,  3)=                  0.12715655460325922532d0
      iwe=iwe+1
      weightb( 14, 37,  3)=                 -0.37202688664746264013d0
      iwe=iwe+1
      weightb( 15, 37,  3)=                 -0.31847821305235168854d0
      iwe=iwe+1
      weightb( 16, 37,  3)=                 -0.14366708344467032932d0
      iwe=iwe+1
      weightb( 17, 37,  3)=                  0.51058484719132923857d0
      iwe=iwe+1
      weightb( 18, 37,  3)=                  0.25824799093446432208d0
      iwe=iwe+1
      weightb( 19, 37,  3)=                 -0.28601570910729312569d0
      iwe=iwe+1
      weightb( 20, 37,  3)=                  0.18756509108149335696d0
      iwe=iwe+1
      weightb( 21, 37,  3)=                 -0.01723506304077203344d0
      iwe=iwe+1
      weightb( 22, 37,  3)=                  0.49328428087729253582d0
      iwe=iwe+1
      weightb( 23, 37,  3)=                 -0.03968806060324253648d0
      iwe=iwe+1
      weightb( 24, 37,  3)=                 -0.39655046785748326865d0
      iwe=iwe+1
      weightb( 25, 37,  3)=                  0.03092224273161088902d0
      iwe=iwe+1
      weightb( 26, 37,  3)=                  0.15421780015264538455d0
      iwe=iwe+1
      weightb( 27, 37,  3)=                  0.49721357597294363329d0
      iwe=iwe+1
      weightb( 28, 37,  3)=                  0.10619802929408619918d0
      iwe=iwe+1
      weightb( 29, 37,  3)=                 -0.35539842081968614496d0
      iwe=iwe+1
      weightb( 30, 37,  3)=                 -0.34007552039771554719d0
      iwe=iwe+1
      weightb( 31, 37,  3)=                 -0.02790777823637438301d0
      iwe=iwe+1
      weightb( 32, 37,  3)=                  0.33228788141063358985d0
      iwe=iwe+1
      weightb( 33, 37,  3)=                 -0.29224594783462942704d0
      iwe=iwe+1
      weightb( 34, 37,  3)=                 -0.01494797890780500890d0
      iwe=iwe+1
      weightb( 35, 37,  3)=                 -0.18226317227204202887d0
      iwe=iwe+1
      weightb( 36, 37,  3)=                 -0.16309839439896739455d0
      iwe=iwe+1
      weightb( 37, 37,  3)=                 -0.12232118461067791049d0
      iwe=iwe+1
      weightb( 38, 37,  3)=                 -0.18922672410873031534d0
      iwe=iwe+1
      weightb( 39, 37,  3)=                 -0.64951741386560879477d0
      iwe=iwe+1
      weightb( 40, 37,  3)=                 -0.07498234755645596938d0
      iwe=iwe+1
      weightb( 41, 37,  3)=                  0.21351064696644639351d0
      iwe=iwe+1
      weightb( 42, 37,  3)=                  0.28387775903635620312d0
      iwe=iwe+1
      weightb( 43, 37,  3)=                 -0.36987800659951863835d0
      iwe=iwe+1
      weightb( 44, 37,  3)=                 -0.40765627383194719124d0
      iwe=iwe+1
      weightb( 45, 37,  3)=                  0.06006677536906716852d0
      iwe=iwe+1
      weightb( 46, 37,  3)=                 -0.38736272678054700647d0
      iwe=iwe+1
      weightb( 47, 37,  3)=                  0.18764570640765537712d0
      iwe=iwe+1
      weightb( 48, 37,  3)=                 -0.20553843093486770521d0
      iwe=iwe+1
      weightb( 49, 37,  3)=                  0.03446768061982634357d0
      iwe=iwe+1
      weightb( 50, 37,  3)=                 -0.07859348667263250932d0
      iwe=iwe+1
      biasb( 37,  3)=                  0.05332802727579896707d0
      iwe=iwe+1
      weightb(  1, 38,  3)=                 -0.15453577964516765353d0
      iwe=iwe+1
      weightb(  2, 38,  3)=                  0.07935742026671754878d0
      iwe=iwe+1
      weightb(  3, 38,  3)=                 -0.15821647957364190495d0
      iwe=iwe+1
      weightb(  4, 38,  3)=                 -0.12653779794635938716d0
      iwe=iwe+1
      weightb(  5, 38,  3)=                  0.21697168581470277493d0
      iwe=iwe+1
      weightb(  6, 38,  3)=                  0.33276341179468832410d0
      iwe=iwe+1
      weightb(  7, 38,  3)=                 -0.22845772307396527978d0
      iwe=iwe+1
      weightb(  8, 38,  3)=                  0.02617354250293092710d0
      iwe=iwe+1
      weightb(  9, 38,  3)=                  0.04045066133183673751d0
      iwe=iwe+1
      weightb( 10, 38,  3)=                  0.52864545521706207687d0
      iwe=iwe+1
      weightb( 11, 38,  3)=                 -0.10082276236324404228d0
      iwe=iwe+1
      weightb( 12, 38,  3)=                  0.04926227677405055350d0
      iwe=iwe+1
      weightb( 13, 38,  3)=                 -0.03690328211396740055d0
      iwe=iwe+1
      weightb( 14, 38,  3)=                 -0.12899962997503605644d0
      iwe=iwe+1
      weightb( 15, 38,  3)=                 -0.19127721231740527075d0
      iwe=iwe+1
      weightb( 16, 38,  3)=                 -0.19472709450720540603d0
      iwe=iwe+1
      weightb( 17, 38,  3)=                 -0.20417262096643129521d0
      iwe=iwe+1
      weightb( 18, 38,  3)=                 -0.19945069873533247118d0
      iwe=iwe+1
      weightb( 19, 38,  3)=                  0.05282251328481746971d0
      iwe=iwe+1
      weightb( 20, 38,  3)=                  0.30394555081254298612d0
      iwe=iwe+1
      weightb( 21, 38,  3)=                 -0.19361404574762197672d0
      iwe=iwe+1
      weightb( 22, 38,  3)=                 -0.32305191999859961260d0
      iwe=iwe+1
      weightb( 23, 38,  3)=                 -0.26184644423732761354d0
      iwe=iwe+1
      weightb( 24, 38,  3)=                 -0.17415367226443498327d0
      iwe=iwe+1
      weightb( 25, 38,  3)=                  0.46914742942293274908d0
      iwe=iwe+1
      weightb( 26, 38,  3)=                 -0.18048278590493266327d0
      iwe=iwe+1
      weightb( 27, 38,  3)=                 -0.48621986161801317161d0
      iwe=iwe+1
      weightb( 28, 38,  3)=                 -0.30991619306256690258d0
      iwe=iwe+1
      weightb( 29, 38,  3)=                  0.45908029164779201592d0
      iwe=iwe+1
      weightb( 30, 38,  3)=                  0.08496506367943987281d0
      iwe=iwe+1
      weightb( 31, 38,  3)=                  0.20366826323034198376d0
      iwe=iwe+1
      weightb( 32, 38,  3)=                  0.11765410193351064083d0
      iwe=iwe+1
      weightb( 33, 38,  3)=                 -0.10343164433483816034d0
      iwe=iwe+1
      weightb( 34, 38,  3)=                  0.03262576081004098932d0
      iwe=iwe+1
      weightb( 35, 38,  3)=                  0.11101537729569693758d0
      iwe=iwe+1
      weightb( 36, 38,  3)=                 -0.42751021051453408361d0
      iwe=iwe+1
      weightb( 37, 38,  3)=                 -0.43304056626269438190d0
      iwe=iwe+1
      weightb( 38, 38,  3)=                  0.01910817249791572914d0
      iwe=iwe+1
      weightb( 39, 38,  3)=                 -0.25824143533983007215d0
      iwe=iwe+1
      weightb( 40, 38,  3)=                  0.12088224342784877063d0
      iwe=iwe+1
      weightb( 41, 38,  3)=                 -0.10089436530388969093d0
      iwe=iwe+1
      weightb( 42, 38,  3)=                  0.15287616131869971592d0
      iwe=iwe+1
      weightb( 43, 38,  3)=                 -0.13882081252923800241d0
      iwe=iwe+1
      weightb( 44, 38,  3)=                  0.41872677849243572501d0
      iwe=iwe+1
      weightb( 45, 38,  3)=                 -0.28634652569231716646d0
      iwe=iwe+1
      weightb( 46, 38,  3)=                 -0.21032707875511572060d0
      iwe=iwe+1
      weightb( 47, 38,  3)=                 -0.18707397904692646406d0
      iwe=iwe+1
      weightb( 48, 38,  3)=                  0.18504891627454983505d0
      iwe=iwe+1
      weightb( 49, 38,  3)=                  0.09788046626746124690d0
      iwe=iwe+1
      weightb( 50, 38,  3)=                 -0.00275585654627680948d0
      iwe=iwe+1
      biasb( 38,  3)=                  0.08948909857194251027d0
      iwe=iwe+1
      weightb(  1, 39,  3)=                 -0.36853478153895175007d0
      iwe=iwe+1
      weightb(  2, 39,  3)=                  0.16085374619026374110d0
      iwe=iwe+1
      weightb(  3, 39,  3)=                 -0.01886504753078432906d0
      iwe=iwe+1
      weightb(  4, 39,  3)=                 -0.34935662814525758613d0
      iwe=iwe+1
      weightb(  5, 39,  3)=                 -0.07811276242821904581d0
      iwe=iwe+1
      weightb(  6, 39,  3)=                  0.01818534393703178861d0
      iwe=iwe+1
      weightb(  7, 39,  3)=                 -0.02816215869609127800d0
      iwe=iwe+1
      weightb(  8, 39,  3)=                  0.26181968277981360060d0
      iwe=iwe+1
      weightb(  9, 39,  3)=                 -0.09926354428950760755d0
      iwe=iwe+1
      weightb( 10, 39,  3)=                 -0.16373061338615607641d0
      iwe=iwe+1
      weightb( 11, 39,  3)=                 -0.42791547499987908632d0
      iwe=iwe+1
      weightb( 12, 39,  3)=                 -0.24260636855647066401d0
      iwe=iwe+1
      weightb( 13, 39,  3)=                 -0.08273590347307534232d0
      iwe=iwe+1
      weightb( 14, 39,  3)=                  0.17806633704322299971d0
      iwe=iwe+1
      weightb( 15, 39,  3)=                  0.10546030169828067569d0
      iwe=iwe+1
      weightb( 16, 39,  3)=                 -0.06256685962543584445d0
      iwe=iwe+1
      weightb( 17, 39,  3)=                 -0.07133638135462558316d0
      iwe=iwe+1
      weightb( 18, 39,  3)=                  0.23473396235166030244d0
      iwe=iwe+1
      weightb( 19, 39,  3)=                 -0.39818107341259945109d0
      iwe=iwe+1
      weightb( 20, 39,  3)=                 -0.14895428946249375524d0
      iwe=iwe+1
      weightb( 21, 39,  3)=                  0.07989443528099958447d0
      iwe=iwe+1
      weightb( 22, 39,  3)=                  0.53122949744791825299d0
      iwe=iwe+1
      weightb( 23, 39,  3)=                  0.34134509012583630350d0
      iwe=iwe+1
      weightb( 24, 39,  3)=                 -0.09109159268637012641d0
      iwe=iwe+1
      weightb( 25, 39,  3)=                 -0.05176672312936887732d0
      iwe=iwe+1
      weightb( 26, 39,  3)=                  0.21936449798398055533d0
      iwe=iwe+1
      weightb( 27, 39,  3)=                 -0.23020645933508002146d0
      iwe=iwe+1
      weightb( 28, 39,  3)=                 -0.28835095209604821864d0
      iwe=iwe+1
      weightb( 29, 39,  3)=                  0.05557334803723640304d0
      iwe=iwe+1
      weightb( 30, 39,  3)=                  0.05090940817384709965d0
      iwe=iwe+1
      weightb( 31, 39,  3)=                 -0.21127452485464914833d0
      iwe=iwe+1
      weightb( 32, 39,  3)=                  0.03267322906774943608d0
      iwe=iwe+1
      weightb( 33, 39,  3)=                  0.30560729986299517424d0
      iwe=iwe+1
      weightb( 34, 39,  3)=                 -0.06567343496829775029d0
      iwe=iwe+1
      weightb( 35, 39,  3)=                  0.17080385284568991300d0
      iwe=iwe+1
      weightb( 36, 39,  3)=                 -0.45431804452760710111d0
      iwe=iwe+1
      weightb( 37, 39,  3)=                  0.29118331848193201861d0
      iwe=iwe+1
      weightb( 38, 39,  3)=                 -0.24357951317196685492d0
      iwe=iwe+1
      weightb( 39, 39,  3)=                 -0.05148156599552888846d0
      iwe=iwe+1
      weightb( 40, 39,  3)=                 -0.08308644707599245616d0
      iwe=iwe+1
      weightb( 41, 39,  3)=                 -0.17028024117563994588d0
      iwe=iwe+1
      weightb( 42, 39,  3)=                 -0.02051144754444869656d0
      iwe=iwe+1
      weightb( 43, 39,  3)=                  0.34959390247586152878d0
      iwe=iwe+1
      weightb( 44, 39,  3)=                  0.39980514369507375028d0
      iwe=iwe+1
      weightb( 45, 39,  3)=                 -0.03342228576646228549d0
      iwe=iwe+1
      weightb( 46, 39,  3)=                  0.28196108822742482758d0
      iwe=iwe+1
      weightb( 47, 39,  3)=                  0.33481955264019253038d0
      iwe=iwe+1
      weightb( 48, 39,  3)=                 -0.49842918678441616720d0
      iwe=iwe+1
      weightb( 49, 39,  3)=                  0.17603100636288487868d0
      iwe=iwe+1
      weightb( 50, 39,  3)=                  0.34512792088049282224d0
      iwe=iwe+1
      biasb( 39,  3)=                 -0.06446452262789861831d0
      iwe=iwe+1
      weightb(  1, 40,  3)=                  0.50312704739848912450d0
      iwe=iwe+1
      weightb(  2, 40,  3)=                  0.51406685784130823347d0
      iwe=iwe+1
      weightb(  3, 40,  3)=                 -0.42276642525640512060d0
      iwe=iwe+1
      weightb(  4, 40,  3)=                 -0.26497612597136904755d0
      iwe=iwe+1
      weightb(  5, 40,  3)=                 -0.20232478979509779804d0
      iwe=iwe+1
      weightb(  6, 40,  3)=                 -0.17924186112525394843d0
      iwe=iwe+1
      weightb(  7, 40,  3)=                 -0.24223214415282817713d0
      iwe=iwe+1
      weightb(  8, 40,  3)=                 -0.23672220396966292544d0
      iwe=iwe+1
      weightb(  9, 40,  3)=                  0.29553306563318881839d0
      iwe=iwe+1
      weightb( 10, 40,  3)=                 -0.31527507120833120347d0
      iwe=iwe+1
      weightb( 11, 40,  3)=                 -0.41910481692534468090d0
      iwe=iwe+1
      weightb( 12, 40,  3)=                 -0.11244272793959028678d0
      iwe=iwe+1
      weightb( 13, 40,  3)=                 -0.12813926610701953379d0
      iwe=iwe+1
      weightb( 14, 40,  3)=                  0.20021102736938742317d0
      iwe=iwe+1
      weightb( 15, 40,  3)=                  0.42880449466838199690d0
      iwe=iwe+1
      weightb( 16, 40,  3)=                 -0.05337538638662486096d0
      iwe=iwe+1
      weightb( 17, 40,  3)=                 -0.28598392088142216005d0
      iwe=iwe+1
      weightb( 18, 40,  3)=                  0.05906070159739924136d0
      iwe=iwe+1
      weightb( 19, 40,  3)=                  0.06464752720719237067d0
      iwe=iwe+1
      weightb( 20, 40,  3)=                 -0.25600858458141001472d0
      iwe=iwe+1
      weightb( 21, 40,  3)=                 -0.19807610803217692852d0
      iwe=iwe+1
      weightb( 22, 40,  3)=                 -0.14842219231049330608d0
      iwe=iwe+1
      weightb( 23, 40,  3)=                 -0.04952067718923175432d0
      iwe=iwe+1
      weightb( 24, 40,  3)=                 -0.47027498969228681558d0
      iwe=iwe+1
      weightb( 25, 40,  3)=                  1.09681940445360437408d0
      iwe=iwe+1
      weightb( 26, 40,  3)=                  0.31203953185904287349d0
      iwe=iwe+1
      weightb( 27, 40,  3)=                  0.07103310472619092653d0
      iwe=iwe+1
      weightb( 28, 40,  3)=                  0.10249015790939426662d0
      iwe=iwe+1
      weightb( 29, 40,  3)=                 -0.62023293198588136388d0
      iwe=iwe+1
      weightb( 30, 40,  3)=                 -0.37157853722767880678d0
      iwe=iwe+1
      weightb( 31, 40,  3)=                 -0.50026514467043992074d0
      iwe=iwe+1
      weightb( 32, 40,  3)=                 -0.08188855329829203278d0
      iwe=iwe+1
      weightb( 33, 40,  3)=                  0.24245496645923272916d0
      iwe=iwe+1
      weightb( 34, 40,  3)=                  0.71915530676786321163d0
      iwe=iwe+1
      weightb( 35, 40,  3)=                  0.58227852524542500490d0
      iwe=iwe+1
      weightb( 36, 40,  3)=                  0.42483597960701668939d0
      iwe=iwe+1
      weightb( 37, 40,  3)=                  0.29444919818682913082d0
      iwe=iwe+1
      weightb( 38, 40,  3)=                  0.29113905407093026989d0
      iwe=iwe+1
      weightb( 39, 40,  3)=                  0.27413464745779958509d0
      iwe=iwe+1
      weightb( 40, 40,  3)=                  0.31190457100113638811d0
      iwe=iwe+1
      weightb( 41, 40,  3)=                 -0.33410249565467342592d0
      iwe=iwe+1
      weightb( 42, 40,  3)=                  0.32835518421053772053d0
      iwe=iwe+1
      weightb( 43, 40,  3)=                  0.15341136611762087871d0
      iwe=iwe+1
      weightb( 44, 40,  3)=                  0.02834627476682417477d0
      iwe=iwe+1
      weightb( 45, 40,  3)=                 -0.26216026663988778456d0
      iwe=iwe+1
      weightb( 46, 40,  3)=                  0.31162522676572357305d0
      iwe=iwe+1
      weightb( 47, 40,  3)=                  0.02511241517262582587d0
      iwe=iwe+1
      weightb( 48, 40,  3)=                  0.33646956812519496216d0
      iwe=iwe+1
      weightb( 49, 40,  3)=                 -0.17738411638745099630d0
      iwe=iwe+1
      weightb( 50, 40,  3)=                 -0.02443156610746139226d0
      iwe=iwe+1
      biasb( 40,  3)=                 -0.03733741723744939817d0
      iwe=iwe+1
      weightb(  1, 41,  3)=                 -0.08526120133581889526d0
      iwe=iwe+1
      weightb(  2, 41,  3)=                 -0.16434273386360129243d0
      iwe=iwe+1
      weightb(  3, 41,  3)=                 -0.17644396364022496559d0
      iwe=iwe+1
      weightb(  4, 41,  3)=                  0.40895607705405762067d0
      iwe=iwe+1
      weightb(  5, 41,  3)=                 -0.21737558582942115293d0
      iwe=iwe+1
      weightb(  6, 41,  3)=                 -0.06087832718339022953d0
      iwe=iwe+1
      weightb(  7, 41,  3)=                  0.77548329634290480428d0
      iwe=iwe+1
      weightb(  8, 41,  3)=                 -0.22762249910038784284d0
      iwe=iwe+1
      weightb(  9, 41,  3)=                  0.49225353732109428107d0
      iwe=iwe+1
      weightb( 10, 41,  3)=                 -0.39038933185866164788d0
      iwe=iwe+1
      weightb( 11, 41,  3)=                 -0.53497114160462255761d0
      iwe=iwe+1
      weightb( 12, 41,  3)=                 -0.00543238040295632683d0
      iwe=iwe+1
      weightb( 13, 41,  3)=                 -0.00019059506062029091d0
      iwe=iwe+1
      weightb( 14, 41,  3)=                 -0.18374069880280469169d0
      iwe=iwe+1
      weightb( 15, 41,  3)=                  0.14652352024845674561d0
      iwe=iwe+1
      weightb( 16, 41,  3)=                 -0.15743275517268867647d0
      iwe=iwe+1
      weightb( 17, 41,  3)=                 -0.06334022643793088547d0
      iwe=iwe+1
      weightb( 18, 41,  3)=                 -0.09526276831732713446d0
      iwe=iwe+1
      weightb( 19, 41,  3)=                  0.04854916980902975604d0
      iwe=iwe+1
      weightb( 20, 41,  3)=                 -0.30108351443154246496d0
      iwe=iwe+1
      weightb( 21, 41,  3)=                 -0.24106547339085923620d0
      iwe=iwe+1
      weightb( 22, 41,  3)=                 -0.46301592516811501676d0
      iwe=iwe+1
      weightb( 23, 41,  3)=                  0.04482282102556263415d0
      iwe=iwe+1
      weightb( 24, 41,  3)=                 -0.35512624710187667976d0
      iwe=iwe+1
      weightb( 25, 41,  3)=                 -0.04335075314892573167d0
      iwe=iwe+1
      weightb( 26, 41,  3)=                  0.46945702600923611136d0
      iwe=iwe+1
      weightb( 27, 41,  3)=                  0.33719025052170203960d0
      iwe=iwe+1
      weightb( 28, 41,  3)=                  0.22944261971840781977d0
      iwe=iwe+1
      weightb( 29, 41,  3)=                 -0.37627390062358062606d0
      iwe=iwe+1
      weightb( 30, 41,  3)=                  0.15903796548469914529d0
      iwe=iwe+1
      weightb( 31, 41,  3)=                 -0.15904136676950950124d0
      iwe=iwe+1
      weightb( 32, 41,  3)=                 -0.07184416761707453081d0
      iwe=iwe+1
      weightb( 33, 41,  3)=                  0.15050879090008517647d0
      iwe=iwe+1
      weightb( 34, 41,  3)=                  0.15488035731145965990d0
      iwe=iwe+1
      weightb( 35, 41,  3)=                 -0.07032598982075348448d0
      iwe=iwe+1
      weightb( 36, 41,  3)=                 -0.08648241944318048324d0
      iwe=iwe+1
      weightb( 37, 41,  3)=                  0.06690277213379181021d0
      iwe=iwe+1
      weightb( 38, 41,  3)=                  0.04044888950014809137d0
      iwe=iwe+1
      weightb( 39, 41,  3)=                 -0.43303287891704378421d0
      iwe=iwe+1
      weightb( 40, 41,  3)=                 -0.32108526152963062783d0
      iwe=iwe+1
      weightb( 41, 41,  3)=                 -0.41430546398509476846d0
      iwe=iwe+1
      weightb( 42, 41,  3)=                 -0.31050925730083756005d0
      iwe=iwe+1
      weightb( 43, 41,  3)=                  0.00121529308654838401d0
      iwe=iwe+1
      weightb( 44, 41,  3)=                  0.33615503156503317994d0
      iwe=iwe+1
      weightb( 45, 41,  3)=                  0.34914355503569277639d0
      iwe=iwe+1
      weightb( 46, 41,  3)=                 -0.10208847480286188658d0
      iwe=iwe+1
      weightb( 47, 41,  3)=                 -0.09854341475976924336d0
      iwe=iwe+1
      weightb( 48, 41,  3)=                 -0.25156599469206303299d0
      iwe=iwe+1
      weightb( 49, 41,  3)=                  0.09557954424720209452d0
      iwe=iwe+1
      weightb( 50, 41,  3)=                 -0.38687907004666366451d0
      iwe=iwe+1
      biasb( 41,  3)=                 -0.15365936855698408836d0
      iwe=iwe+1
      weightb(  1, 42,  3)=                  0.33661329735635847626d0
      iwe=iwe+1
      weightb(  2, 42,  3)=                 -0.18900612989247189688d0
      iwe=iwe+1
      weightb(  3, 42,  3)=                 -0.11356111094825294128d0
      iwe=iwe+1
      weightb(  4, 42,  3)=                  0.12258711962478238688d0
      iwe=iwe+1
      weightb(  5, 42,  3)=                  0.26243118431304218729d0
      iwe=iwe+1
      weightb(  6, 42,  3)=                  0.11014656557857119279d0
      iwe=iwe+1
      weightb(  7, 42,  3)=                  0.12722619791215261653d0
      iwe=iwe+1
      weightb(  8, 42,  3)=                 -0.33200563312293734919d0
      iwe=iwe+1
      weightb(  9, 42,  3)=                 -0.24432860113808516078d0
      iwe=iwe+1
      weightb( 10, 42,  3)=                 -0.26196384552434265336d0
      iwe=iwe+1
      weightb( 11, 42,  3)=                  0.08351134149234946957d0
      iwe=iwe+1
      weightb( 12, 42,  3)=                 -0.36499760543709064420d0
      iwe=iwe+1
      weightb( 13, 42,  3)=                 -0.03330170510300271836d0
      iwe=iwe+1
      weightb( 14, 42,  3)=                  0.24718778112259329194d0
      iwe=iwe+1
      weightb( 15, 42,  3)=                  0.06653584243980144308d0
      iwe=iwe+1
      weightb( 16, 42,  3)=                 -0.16393467401361996871d0
      iwe=iwe+1
      weightb( 17, 42,  3)=                 -0.17883181636663730840d0
      iwe=iwe+1
      weightb( 18, 42,  3)=                 -0.36560068789221072949d0
      iwe=iwe+1
      weightb( 19, 42,  3)=                  0.29536483919571326906d0
      iwe=iwe+1
      weightb( 20, 42,  3)=                  0.10394604544835914228d0
      iwe=iwe+1
      weightb( 21, 42,  3)=                 -0.02176995338835301455d0
      iwe=iwe+1
      weightb( 22, 42,  3)=                  0.04393315298428788346d0
      iwe=iwe+1
      weightb( 23, 42,  3)=                 -0.29279035989719159883d0
      iwe=iwe+1
      weightb( 24, 42,  3)=                 -0.13840724176654878308d0
      iwe=iwe+1
      weightb( 25, 42,  3)=                  0.26828685048605938057d0
      iwe=iwe+1
      weightb( 26, 42,  3)=                  0.04065265043328274153d0
      iwe=iwe+1
      weightb( 27, 42,  3)=                 -0.15044709328695596295d0
      iwe=iwe+1
      weightb( 28, 42,  3)=                 -0.08704209190675279983d0
      iwe=iwe+1
      weightb( 29, 42,  3)=                 -0.31571781684097283138d0
      iwe=iwe+1
      weightb( 30, 42,  3)=                  0.41054173596895410236d0
      iwe=iwe+1
      weightb( 31, 42,  3)=                 -0.04819930877288547411d0
      iwe=iwe+1
      weightb( 32, 42,  3)=                 -0.27511050743748716174d0
      iwe=iwe+1
      weightb( 33, 42,  3)=                 -0.28665463582239014695d0
      iwe=iwe+1
      weightb( 34, 42,  3)=                 -0.50362197677452191780d0
      iwe=iwe+1
      weightb( 35, 42,  3)=                 -0.22441714474485974229d0
      iwe=iwe+1
      weightb( 36, 42,  3)=                  0.02003694390065000053d0
      iwe=iwe+1
      weightb( 37, 42,  3)=                 -0.18824572579414020068d0
      iwe=iwe+1
      weightb( 38, 42,  3)=                 -0.33506021708139926973d0
      iwe=iwe+1
      weightb( 39, 42,  3)=                 -0.23612793755270619633d0
      iwe=iwe+1
      weightb( 40, 42,  3)=                 -0.29044666731617413413d0
      iwe=iwe+1
      weightb( 41, 42,  3)=                  0.05328048122146401833d0
      iwe=iwe+1
      weightb( 42, 42,  3)=                  0.20490084957896301243d0
      iwe=iwe+1
      weightb( 43, 42,  3)=                 -0.02514475692041492211d0
      iwe=iwe+1
      weightb( 44, 42,  3)=                 -0.35104316280021069518d0
      iwe=iwe+1
      weightb( 45, 42,  3)=                  0.35217256890298792582d0
      iwe=iwe+1
      weightb( 46, 42,  3)=                 -0.02328491863592213607d0
      iwe=iwe+1
      weightb( 47, 42,  3)=                 -0.08487894170688276008d0
      iwe=iwe+1
      weightb( 48, 42,  3)=                 -0.16496068080048342797d0
      iwe=iwe+1
      weightb( 49, 42,  3)=                  0.15407466305625250325d0
      iwe=iwe+1
      weightb( 50, 42,  3)=                  0.00032543447596611455d0
      iwe=iwe+1
      biasb( 42,  3)=                  0.04253868855788124625d0
      iwe=iwe+1
      weightb(  1, 43,  3)=                 -0.19180547062692429594d0
      iwe=iwe+1
      weightb(  2, 43,  3)=                  0.43984202740539962706d0
      iwe=iwe+1
      weightb(  3, 43,  3)=                 -0.03980548084420482136d0
      iwe=iwe+1
      weightb(  4, 43,  3)=                  0.21894003610526840964d0
      iwe=iwe+1
      weightb(  5, 43,  3)=                 -0.04007296417979352987d0
      iwe=iwe+1
      weightb(  6, 43,  3)=                  0.15973399301191110178d0
      iwe=iwe+1
      weightb(  7, 43,  3)=                  0.05234401243714329605d0
      iwe=iwe+1
      weightb(  8, 43,  3)=                  0.35934997290672415771d0
      iwe=iwe+1
      weightb(  9, 43,  3)=                 -0.20063841103683033307d0
      iwe=iwe+1
      weightb( 10, 43,  3)=                 -0.36370220777214562480d0
      iwe=iwe+1
      weightb( 11, 43,  3)=                 -0.42310237410638357192d0
      iwe=iwe+1
      weightb( 12, 43,  3)=                 -0.08167069570511183152d0
      iwe=iwe+1
      weightb( 13, 43,  3)=                 -0.08430980692863908332d0
      iwe=iwe+1
      weightb( 14, 43,  3)=                 -0.41299991054696588710d0
      iwe=iwe+1
      weightb( 15, 43,  3)=                 -0.28979438153749415008d0
      iwe=iwe+1
      weightb( 16, 43,  3)=                  0.25262448301044754251d0
      iwe=iwe+1
      weightb( 17, 43,  3)=                 -0.37033098909708300761d0
      iwe=iwe+1
      weightb( 18, 43,  3)=                  0.06749610409419444512d0
      iwe=iwe+1
      weightb( 19, 43,  3)=                  0.26225234064633323738d0
      iwe=iwe+1
      weightb( 20, 43,  3)=                  0.05822854224249171540d0
      iwe=iwe+1
      weightb( 21, 43,  3)=                 -0.05512088074446869906d0
      iwe=iwe+1
      weightb( 22, 43,  3)=                 -0.07177792799069998564d0
      iwe=iwe+1
      weightb( 23, 43,  3)=                  0.37931812630160494093d0
      iwe=iwe+1
      weightb( 24, 43,  3)=                  0.38529967168636675146d0
      iwe=iwe+1
      weightb( 25, 43,  3)=                  0.27598158215924212255d0
      iwe=iwe+1
      weightb( 26, 43,  3)=                 -0.10464060041278612501d0
      iwe=iwe+1
      weightb( 27, 43,  3)=                  0.29501382984373342167d0
      iwe=iwe+1
      weightb( 28, 43,  3)=                  0.26932374009439413731d0
      iwe=iwe+1
      weightb( 29, 43,  3)=                  0.35464981083267987927d0
      iwe=iwe+1
      weightb( 30, 43,  3)=                  0.51961670158062478464d0
      iwe=iwe+1
      weightb( 31, 43,  3)=                  0.16978099967102522339d0
      iwe=iwe+1
      weightb( 32, 43,  3)=                 -0.17587135730940203771d0
      iwe=iwe+1
      weightb( 33, 43,  3)=                 -0.08278871927934233765d0
      iwe=iwe+1
      weightb( 34, 43,  3)=                  0.09837442968818703448d0
      iwe=iwe+1
      weightb( 35, 43,  3)=                  0.32002836285555469331d0
      iwe=iwe+1
      weightb( 36, 43,  3)=                 -0.18293283810863214534d0
      iwe=iwe+1
      weightb( 37, 43,  3)=                  0.16726032253148606643d0
      iwe=iwe+1
      weightb( 38, 43,  3)=                 -0.21500010232286420608d0
      iwe=iwe+1
      weightb( 39, 43,  3)=                 -0.00235087697796130916d0
      iwe=iwe+1
      weightb( 40, 43,  3)=                  0.08907617053679706132d0
      iwe=iwe+1
      weightb( 41, 43,  3)=                  0.08648817849725506934d0
      iwe=iwe+1
      weightb( 42, 43,  3)=                 -0.05750682918483106948d0
      iwe=iwe+1
      weightb( 43, 43,  3)=                  0.35638389626948258071d0
      iwe=iwe+1
      weightb( 44, 43,  3)=                 -0.15234420306530879752d0
      iwe=iwe+1
      weightb( 45, 43,  3)=                 -0.46875072370152548462d0
      iwe=iwe+1
      weightb( 46, 43,  3)=                 -0.07891401516915980130d0
      iwe=iwe+1
      weightb( 47, 43,  3)=                  0.11618307698263759253d0
      iwe=iwe+1
      weightb( 48, 43,  3)=                  0.32673907818812136794d0
      iwe=iwe+1
      weightb( 49, 43,  3)=                 -0.12578903587058271052d0
      iwe=iwe+1
      weightb( 50, 43,  3)=                 -0.21690358325552483443d0
      iwe=iwe+1
      biasb( 43,  3)=                 -0.12209461919358738369d0
      iwe=iwe+1
      weightb(  1, 44,  3)=                 -0.11709052509346455639d0
      iwe=iwe+1
      weightb(  2, 44,  3)=                  0.35773083162976809790d0
      iwe=iwe+1
      weightb(  3, 44,  3)=                 -0.32573695797255075579d0
      iwe=iwe+1
      weightb(  4, 44,  3)=                  1.05329580860812344056d0
      iwe=iwe+1
      weightb(  5, 44,  3)=                 -0.05953550004374810051d0
      iwe=iwe+1
      weightb(  6, 44,  3)=                  0.66254239442615892042d0
      iwe=iwe+1
      weightb(  7, 44,  3)=                  0.07806633973026737283d0
      iwe=iwe+1
      weightb(  8, 44,  3)=                  0.68885202652753274588d0
      iwe=iwe+1
      weightb(  9, 44,  3)=                 -0.27067504161228367332d0
      iwe=iwe+1
      weightb( 10, 44,  3)=                  0.05051490948860028890d0
      iwe=iwe+1
      weightb( 11, 44,  3)=                 -0.98447836291662282893d0
      iwe=iwe+1
      weightb( 12, 44,  3)=                 -0.08817614981587448830d0
      iwe=iwe+1
      weightb( 13, 44,  3)=                  0.49520023245609506857d0
      iwe=iwe+1
      weightb( 14, 44,  3)=                 -0.28112446947686536847d0
      iwe=iwe+1
      weightb( 15, 44,  3)=                  0.55988093906633129571d0
      iwe=iwe+1
      weightb( 16, 44,  3)=                  0.00255208843850037717d0
      iwe=iwe+1
      weightb( 17, 44,  3)=                 -0.53911766007126071809d0
      iwe=iwe+1
      weightb( 18, 44,  3)=                  0.10667977754050105010d0
      iwe=iwe+1
      weightb( 19, 44,  3)=                 -0.02267607712883297835d0
      iwe=iwe+1
      weightb( 20, 44,  3)=                 -0.14813768860469342381d0
      iwe=iwe+1
      weightb( 21, 44,  3)=                  0.07282215914689203762d0
      iwe=iwe+1
      weightb( 22, 44,  3)=                 -0.50844718267106425724d0
      iwe=iwe+1
      weightb( 23, 44,  3)=                  0.01089475025929515645d0
      iwe=iwe+1
      weightb( 24, 44,  3)=                  0.41165517781242333406d0
      iwe=iwe+1
      weightb( 25, 44,  3)=                 -0.00287689171299129612d0
      iwe=iwe+1
      weightb( 26, 44,  3)=                  0.44462129030585489931d0
      iwe=iwe+1
      weightb( 27, 44,  3)=                  0.43155055032359518341d0
      iwe=iwe+1
      weightb( 28, 44,  3)=                 -0.28218350097562322487d0
      iwe=iwe+1
      weightb( 29, 44,  3)=                  0.07948174486909471981d0
      iwe=iwe+1
      weightb( 30, 44,  3)=                 -0.19575342250981062064d0
      iwe=iwe+1
      weightb( 31, 44,  3)=                  0.08988999272281429642d0
      iwe=iwe+1
      weightb( 32, 44,  3)=                 -0.06415882261567910916d0
      iwe=iwe+1
      weightb( 33, 44,  3)=                  0.33891221306894742105d0
      iwe=iwe+1
      weightb( 34, 44,  3)=                  0.37609478436871018880d0
      iwe=iwe+1
      weightb( 35, 44,  3)=                  0.34664689535929732456d0
      iwe=iwe+1
      weightb( 36, 44,  3)=                  0.22729701832558391050d0
      iwe=iwe+1
      weightb( 37, 44,  3)=                 -0.63512504567651562049d0
      iwe=iwe+1
      weightb( 38, 44,  3)=                 -0.13325129827312132136d0
      iwe=iwe+1
      weightb( 39, 44,  3)=                 -0.04218180468413709749d0
      iwe=iwe+1
      weightb( 40, 44,  3)=                  0.25144086872710963432d0
      iwe=iwe+1
      weightb( 41, 44,  3)=                 -0.24420244019730941165d0
      iwe=iwe+1
      weightb( 42, 44,  3)=                 -0.38289198339077018529d0
      iwe=iwe+1
      weightb( 43, 44,  3)=                  0.05912938525145880475d0
      iwe=iwe+1
      weightb( 44, 44,  3)=                  0.14373647035301018171d0
      iwe=iwe+1
      weightb( 45, 44,  3)=                 -0.18551874413027891197d0
      iwe=iwe+1
      weightb( 46, 44,  3)=                  0.01107614881394521945d0
      iwe=iwe+1
      weightb( 47, 44,  3)=                  0.06666190283453128640d0
      iwe=iwe+1
      weightb( 48, 44,  3)=                  0.12785258046605907367d0
      iwe=iwe+1
      weightb( 49, 44,  3)=                 -0.12389779698795788665d0
      iwe=iwe+1
      weightb( 50, 44,  3)=                 -0.04971530755352115971d0
      iwe=iwe+1
      biasb( 44,  3)=                  0.25574754646442099393d0
      iwe=iwe+1
      weightb(  1, 45,  3)=                  0.26252083100532630500d0
      iwe=iwe+1
      weightb(  2, 45,  3)=                  0.08268082701773753207d0
      iwe=iwe+1
      weightb(  3, 45,  3)=                  0.01146251017052047141d0
      iwe=iwe+1
      weightb(  4, 45,  3)=                  0.12882730692573624021d0
      iwe=iwe+1
      weightb(  5, 45,  3)=                  0.37389506316039261558d0
      iwe=iwe+1
      weightb(  6, 45,  3)=                  0.16650725090363349690d0
      iwe=iwe+1
      weightb(  7, 45,  3)=                  0.00832221432771837119d0
      iwe=iwe+1
      weightb(  8, 45,  3)=                 -0.11049341495513066713d0
      iwe=iwe+1
      weightb(  9, 45,  3)=                  0.06565890029152088303d0
      iwe=iwe+1
      weightb( 10, 45,  3)=                 -0.23639715334483002440d0
      iwe=iwe+1
      weightb( 11, 45,  3)=                 -0.06652995972981673445d0
      iwe=iwe+1
      weightb( 12, 45,  3)=                  0.34193506628945319337d0
      iwe=iwe+1
      weightb( 13, 45,  3)=                 -0.32560081773690152662d0
      iwe=iwe+1
      weightb( 14, 45,  3)=                 -0.18191313760263735921d0
      iwe=iwe+1
      weightb( 15, 45,  3)=                  0.16710133126054990682d0
      iwe=iwe+1
      weightb( 16, 45,  3)=                 -0.39158208176980296988d0
      iwe=iwe+1
      weightb( 17, 45,  3)=                 -0.08500223315528411538d0
      iwe=iwe+1
      weightb( 18, 45,  3)=                 -0.11779685102321700574d0
      iwe=iwe+1
      weightb( 19, 45,  3)=                 -0.30238231930283770987d0
      iwe=iwe+1
      weightb( 20, 45,  3)=                  0.45162795731738436533d0
      iwe=iwe+1
      weightb( 21, 45,  3)=                 -0.06771696792426189215d0
      iwe=iwe+1
      weightb( 22, 45,  3)=                  0.33434676874481050746d0
      iwe=iwe+1
      weightb( 23, 45,  3)=                 -0.06091247722769753403d0
      iwe=iwe+1
      weightb( 24, 45,  3)=                  0.15716076020970060068d0
      iwe=iwe+1
      weightb( 25, 45,  3)=                  0.02577332966122789989d0
      iwe=iwe+1
      weightb( 26, 45,  3)=                 -0.24244789171151287510d0
      iwe=iwe+1
      weightb( 27, 45,  3)=                 -0.10217818745948784032d0
      iwe=iwe+1
      weightb( 28, 45,  3)=                 -0.50997316047657315075d0
      iwe=iwe+1
      weightb( 29, 45,  3)=                 -0.39806120268491401726d0
      iwe=iwe+1
      weightb( 30, 45,  3)=                 -0.37657825737886202466d0
      iwe=iwe+1
      weightb( 31, 45,  3)=                 -0.25087217598636230020d0
      iwe=iwe+1
      weightb( 32, 45,  3)=                  0.22097562789311314679d0
      iwe=iwe+1
      weightb( 33, 45,  3)=                 -0.16081666820431475551d0
      iwe=iwe+1
      weightb( 34, 45,  3)=                 -0.39598613481911815182d0
      iwe=iwe+1
      weightb( 35, 45,  3)=                 -0.29380180522602439286d0
      iwe=iwe+1
      weightb( 36, 45,  3)=                 -0.34533023728723333257d0
      iwe=iwe+1
      weightb( 37, 45,  3)=                 -0.19325429070883298754d0
      iwe=iwe+1
      weightb( 38, 45,  3)=                  0.30742590416889176153d0
      iwe=iwe+1
      weightb( 39, 45,  3)=                 -0.08431188741536503606d0
      iwe=iwe+1
      weightb( 40, 45,  3)=                  0.32089883604217234181d0
      iwe=iwe+1
      weightb( 41, 45,  3)=                 -0.01238334962171711885d0
      iwe=iwe+1
      weightb( 42, 45,  3)=                  0.33007094956134191976d0
      iwe=iwe+1
      weightb( 43, 45,  3)=                  0.06274888839603277868d0
      iwe=iwe+1
      weightb( 44, 45,  3)=                 -0.14215241459111466193d0
      iwe=iwe+1
      weightb( 45, 45,  3)=                 -0.11729806433965170309d0
      iwe=iwe+1
      weightb( 46, 45,  3)=                 -0.24813179754213413042d0
      iwe=iwe+1
      weightb( 47, 45,  3)=                 -0.02009632999395466468d0
      iwe=iwe+1
      weightb( 48, 45,  3)=                  0.12891017157302042673d0
      iwe=iwe+1
      weightb( 49, 45,  3)=                 -0.33436641345093348621d0
      iwe=iwe+1
      weightb( 50, 45,  3)=                 -0.19612656372389336568d0
      iwe=iwe+1
      biasb( 45,  3)=                  0.09991924282213492103d0
      iwe=iwe+1
      weightb(  1, 46,  3)=                  0.23999004879670984836d0
      iwe=iwe+1
      weightb(  2, 46,  3)=                  0.21785539066701994915d0
      iwe=iwe+1
      weightb(  3, 46,  3)=                  0.66791373117011132443d0
      iwe=iwe+1
      weightb(  4, 46,  3)=                  0.12044151810748593423d0
      iwe=iwe+1
      weightb(  5, 46,  3)=                  0.27385725834532070877d0
      iwe=iwe+1
      weightb(  6, 46,  3)=                  0.26680668317263533940d0
      iwe=iwe+1
      weightb(  7, 46,  3)=                  0.43989294433528131067d0
      iwe=iwe+1
      weightb(  8, 46,  3)=                  0.09177643675468430406d0
      iwe=iwe+1
      weightb(  9, 46,  3)=                 -0.22634238012491314507d0
      iwe=iwe+1
      weightb( 10, 46,  3)=                  0.01251395915218305593d0
      iwe=iwe+1
      weightb( 11, 46,  3)=                  0.27869069385502948100d0
      iwe=iwe+1
      weightb( 12, 46,  3)=                  0.19145129189510659562d0
      iwe=iwe+1
      weightb( 13, 46,  3)=                  0.04115135847613250741d0
      iwe=iwe+1
      weightb( 14, 46,  3)=                  0.03648836123745773791d0
      iwe=iwe+1
      weightb( 15, 46,  3)=                 -0.43576937552168687473d0
      iwe=iwe+1
      weightb( 16, 46,  3)=                  0.01256942096920111301d0
      iwe=iwe+1
      weightb( 17, 46,  3)=                  0.26285095402907010520d0
      iwe=iwe+1
      weightb( 18, 46,  3)=                  0.23611599228728971656d0
      iwe=iwe+1
      weightb( 19, 46,  3)=                  0.02226552132140502752d0
      iwe=iwe+1
      weightb( 20, 46,  3)=                 -0.58757109289818654219d0
      iwe=iwe+1
      weightb( 21, 46,  3)=                  0.31770663320795511364d0
      iwe=iwe+1
      weightb( 22, 46,  3)=                  0.02273803670364062807d0
      iwe=iwe+1
      weightb( 23, 46,  3)=                 -0.40999390578124683682d0
      iwe=iwe+1
      weightb( 24, 46,  3)=                 -0.44224515266641634126d0
      iwe=iwe+1
      weightb( 25, 46,  3)=                 -0.19337281628505215147d0
      iwe=iwe+1
      weightb( 26, 46,  3)=                 -0.20895453399681720996d0
      iwe=iwe+1
      weightb( 27, 46,  3)=                 -0.03597549201221234005d0
      iwe=iwe+1
      weightb( 28, 46,  3)=                 -0.08132207891308476655d0
      iwe=iwe+1
      weightb( 29, 46,  3)=                  0.10326754653243222504d0
      iwe=iwe+1
      weightb( 30, 46,  3)=                 -0.13374989509355655892d0
      iwe=iwe+1
      weightb( 31, 46,  3)=                  0.22053740870171870125d0
      iwe=iwe+1
      weightb( 32, 46,  3)=                  0.05620307233761812765d0
      iwe=iwe+1
      weightb( 33, 46,  3)=                 -0.28331515519317745921d0
      iwe=iwe+1
      weightb( 34, 46,  3)=                 -0.00699190057798577784d0
      iwe=iwe+1
      weightb( 35, 46,  3)=                 -0.30460240251272924228d0
      iwe=iwe+1
      weightb( 36, 46,  3)=                  0.59852771651729663738d0
      iwe=iwe+1
      weightb( 37, 46,  3)=                 -0.07423376288711600046d0
      iwe=iwe+1
      weightb( 38, 46,  3)=                 -0.09634272018435313667d0
      iwe=iwe+1
      weightb( 39, 46,  3)=                 -0.03098033418944158568d0
      iwe=iwe+1
      weightb( 40, 46,  3)=                 -0.26265800199601108122d0
      iwe=iwe+1
      weightb( 41, 46,  3)=                  0.30484994650819963180d0
      iwe=iwe+1
      weightb( 42, 46,  3)=                  0.10461902386952370847d0
      iwe=iwe+1
      weightb( 43, 46,  3)=                  0.02875780225025268561d0
      iwe=iwe+1
      weightb( 44, 46,  3)=                  0.00811700574092955734d0
      iwe=iwe+1
      weightb( 45, 46,  3)=                  0.32032402279776589493d0
      iwe=iwe+1
      weightb( 46, 46,  3)=                 -0.36061903471808565147d0
      iwe=iwe+1
      weightb( 47, 46,  3)=                  0.17132071733615081288d0
      iwe=iwe+1
      weightb( 48, 46,  3)=                  0.23961593436839018212d0
      iwe=iwe+1
      weightb( 49, 46,  3)=                 -0.33010808083314663319d0
      iwe=iwe+1
      weightb( 50, 46,  3)=                  0.33143230442389215451d0
      iwe=iwe+1
      biasb( 46,  3)=                  0.18600539615135830429d0
      iwe=iwe+1
      weightb(  1, 47,  3)=                  0.05538710037757077487d0
      iwe=iwe+1
      weightb(  2, 47,  3)=                  0.30914459649831227406d0
      iwe=iwe+1
      weightb(  3, 47,  3)=                 -0.19924927517124862986d0
      iwe=iwe+1
      weightb(  4, 47,  3)=                  0.31879189527733514664d0
      iwe=iwe+1
      weightb(  5, 47,  3)=                  0.26840908212589614790d0
      iwe=iwe+1
      weightb(  6, 47,  3)=                  0.10543936342123398642d0
      iwe=iwe+1
      weightb(  7, 47,  3)=                 -0.07092345950260749154d0
      iwe=iwe+1
      weightb(  8, 47,  3)=                 -0.27898791829098240624d0
      iwe=iwe+1
      weightb(  9, 47,  3)=                 -0.25208255290055997522d0
      iwe=iwe+1
      weightb( 10, 47,  3)=                 -0.28459339000325778457d0
      iwe=iwe+1
      weightb( 11, 47,  3)=                  0.25019278678834616647d0
      iwe=iwe+1
      weightb( 12, 47,  3)=                 -0.01401932940016674053d0
      iwe=iwe+1
      weightb( 13, 47,  3)=                  0.18432018133107935798d0
      iwe=iwe+1
      weightb( 14, 47,  3)=                 -0.69744406316844742566d0
      iwe=iwe+1
      weightb( 15, 47,  3)=                  0.58771365197459657370d0
      iwe=iwe+1
      weightb( 16, 47,  3)=                  0.24779164290077679289d0
      iwe=iwe+1
      weightb( 17, 47,  3)=                  0.17401500928282140346d0
      iwe=iwe+1
      weightb( 18, 47,  3)=                  0.38207433771330590044d0
      iwe=iwe+1
      weightb( 19, 47,  3)=                 -0.02666356044752046447d0
      iwe=iwe+1
      weightb( 20, 47,  3)=                 -0.39350648044003050385d0
      iwe=iwe+1
      weightb( 21, 47,  3)=                  0.31542246454115108190d0
      iwe=iwe+1
      weightb( 22, 47,  3)=                  0.17792249946375834901d0
      iwe=iwe+1
      weightb( 23, 47,  3)=                  0.13634306755115851995d0
      iwe=iwe+1
      weightb( 24, 47,  3)=                 -0.17062613499680084894d0
      iwe=iwe+1
      weightb( 25, 47,  3)=                 -0.13224887770727677960d0
      iwe=iwe+1
      weightb( 26, 47,  3)=                  0.43220455779121130790d0
      iwe=iwe+1
      weightb( 27, 47,  3)=                  0.23399852052968936333d0
      iwe=iwe+1
      weightb( 28, 47,  3)=                 -0.66885730561190326338d0
      iwe=iwe+1
      weightb( 29, 47,  3)=                  0.06955501191405634442d0
      iwe=iwe+1
      weightb( 30, 47,  3)=                 -0.06461116974308844796d0
      iwe=iwe+1
      weightb( 31, 47,  3)=                 -0.01770575914845776491d0
      iwe=iwe+1
      weightb( 32, 47,  3)=                  0.39018580758272164433d0
      iwe=iwe+1
      weightb( 33, 47,  3)=                 -0.02726040933836032520d0
      iwe=iwe+1
      weightb( 34, 47,  3)=                 -0.89334252383700507583d0
      iwe=iwe+1
      weightb( 35, 47,  3)=                  0.18652705705958186333d0
      iwe=iwe+1
      weightb( 36, 47,  3)=                  0.32067576810940390253d0
      iwe=iwe+1
      weightb( 37, 47,  3)=                 -0.18867231157855574031d0
      iwe=iwe+1
      weightb( 38, 47,  3)=                  0.53186646172028517743d0
      iwe=iwe+1
      weightb( 39, 47,  3)=                 -0.05238284273356950960d0
      iwe=iwe+1
      weightb( 40, 47,  3)=                 -0.14478927825180631928d0
      iwe=iwe+1
      weightb( 41, 47,  3)=                 -0.26963276714004025258d0
      iwe=iwe+1
      weightb( 42, 47,  3)=                 -0.37136937660230812108d0
      iwe=iwe+1
      weightb( 43, 47,  3)=                 -0.14896831175777860978d0
      iwe=iwe+1
      weightb( 44, 47,  3)=                  0.30528947187074012559d0
      iwe=iwe+1
      weightb( 45, 47,  3)=                  0.35448966545697363495d0
      iwe=iwe+1
      weightb( 46, 47,  3)=                  0.02492863667292449792d0
      iwe=iwe+1
      weightb( 47, 47,  3)=                  0.11161631997161597374d0
      iwe=iwe+1
      weightb( 48, 47,  3)=                 -0.37270470427483942677d0
      iwe=iwe+1
      weightb( 49, 47,  3)=                  0.12702028006301871454d0
      iwe=iwe+1
      weightb( 50, 47,  3)=                  0.29914751845807746600d0
      iwe=iwe+1
      biasb( 47,  3)=                 -0.42193055350348651622d0
      iwe=iwe+1
      weightb(  1, 48,  3)=                  0.31205360927895681167d0
      iwe=iwe+1
      weightb(  2, 48,  3)=                 -0.02506578243236822282d0
      iwe=iwe+1
      weightb(  3, 48,  3)=                  0.06193472202967906931d0
      iwe=iwe+1
      weightb(  4, 48,  3)=                 -0.35201056585064277593d0
      iwe=iwe+1
      weightb(  5, 48,  3)=                  0.19246096719721469959d0
      iwe=iwe+1
      weightb(  6, 48,  3)=                 -0.24488833319754496620d0
      iwe=iwe+1
      weightb(  7, 48,  3)=                 -0.24050992054800174325d0
      iwe=iwe+1
      weightb(  8, 48,  3)=                 -0.28035260358381569601d0
      iwe=iwe+1
      weightb(  9, 48,  3)=                  0.19863213535022836154d0
      iwe=iwe+1
      weightb( 10, 48,  3)=                 -0.32254309645154249919d0
      iwe=iwe+1
      weightb( 11, 48,  3)=                 -0.13806678068296582285d0
      iwe=iwe+1
      weightb( 12, 48,  3)=                 -0.01685669029074867570d0
      iwe=iwe+1
      weightb( 13, 48,  3)=                  0.06490482336125512342d0
      iwe=iwe+1
      weightb( 14, 48,  3)=                 -0.16590105750383191130d0
      iwe=iwe+1
      weightb( 15, 48,  3)=                  0.30375999078633392214d0
      iwe=iwe+1
      weightb( 16, 48,  3)=                 -0.31785363540183020348d0
      iwe=iwe+1
      weightb( 17, 48,  3)=                  0.08067365207717534792d0
      iwe=iwe+1
      weightb( 18, 48,  3)=                  0.17721045893221043510d0
      iwe=iwe+1
      weightb( 19, 48,  3)=                  0.03368457821460377200d0
      iwe=iwe+1
      weightb( 20, 48,  3)=                  0.26480152034324794252d0
      iwe=iwe+1
      weightb( 21, 48,  3)=                 -0.27285008083511458343d0
      iwe=iwe+1
      weightb( 22, 48,  3)=                  0.20961350569817210898d0
      iwe=iwe+1
      weightb( 23, 48,  3)=                 -0.18889507839933566968d0
      iwe=iwe+1
      weightb( 24, 48,  3)=                 -0.05221429534010646467d0
      iwe=iwe+1
      weightb( 25, 48,  3)=                  0.07025029712347513611d0
      iwe=iwe+1
      weightb( 26, 48,  3)=                  0.25538540429898337614d0
      iwe=iwe+1
      weightb( 27, 48,  3)=                 -0.25476279771359455761d0
      iwe=iwe+1
      weightb( 28, 48,  3)=                  0.03983730701745592101d0
      iwe=iwe+1
      weightb( 29, 48,  3)=                  0.25488227611578201381d0
      iwe=iwe+1
      weightb( 30, 48,  3)=                  0.25862974496373891675d0
      iwe=iwe+1
      weightb( 31, 48,  3)=                  0.09192155759939578397d0
      iwe=iwe+1
      weightb( 32, 48,  3)=                  0.13795423017949143274d0
      iwe=iwe+1
      weightb( 33, 48,  3)=                 -0.14917172428095820669d0
      iwe=iwe+1
      weightb( 34, 48,  3)=                 -0.19730300423223071093d0
      iwe=iwe+1
      weightb( 35, 48,  3)=                 -0.27659681894410503844d0
      iwe=iwe+1
      weightb( 36, 48,  3)=                 -0.29388507566113547531d0
      iwe=iwe+1
      weightb( 37, 48,  3)=                 -0.01722282725105889895d0
      iwe=iwe+1
      weightb( 38, 48,  3)=                  0.31894044626160461542d0
      iwe=iwe+1
      weightb( 39, 48,  3)=                 -0.21594092060093236785d0
      iwe=iwe+1
      weightb( 40, 48,  3)=                  0.16364090295785016504d0
      iwe=iwe+1
      weightb( 41, 48,  3)=                 -0.30369687162263236946d0
      iwe=iwe+1
      weightb( 42, 48,  3)=                  0.22832352185463061778d0
      iwe=iwe+1
      weightb( 43, 48,  3)=                 -0.22536012989201312240d0
      iwe=iwe+1
      weightb( 44, 48,  3)=                 -0.24964329919333244634d0
      iwe=iwe+1
      weightb( 45, 48,  3)=                 -0.00166598687104156651d0
      iwe=iwe+1
      weightb( 46, 48,  3)=                  0.26113900872705525513d0
      iwe=iwe+1
      weightb( 47, 48,  3)=                  0.17525542751467471092d0
      iwe=iwe+1
      weightb( 48, 48,  3)=                  0.25480960915370226560d0
      iwe=iwe+1
      weightb( 49, 48,  3)=                  0.31848013011313591747d0
      iwe=iwe+1
      weightb( 50, 48,  3)=                 -0.17785390400388750853d0
      iwe=iwe+1
      biasb( 48,  3)=                  0.28202960796941822785d0
      iwe=iwe+1
      weightb(  1, 49,  3)=                  0.55375804151309071521d0
      iwe=iwe+1
      weightb(  2, 49,  3)=                 -0.11471868287409113518d0
      iwe=iwe+1
      weightb(  3, 49,  3)=                  0.11916355248579975357d0
      iwe=iwe+1
      weightb(  4, 49,  3)=                  0.28095708645417982741d0
      iwe=iwe+1
      weightb(  5, 49,  3)=                 -0.35733437490406866344d0
      iwe=iwe+1
      weightb(  6, 49,  3)=                  0.08576066434426585228d0
      iwe=iwe+1
      weightb(  7, 49,  3)=                 -0.12418911826656846287d0
      iwe=iwe+1
      weightb(  8, 49,  3)=                 -0.10293795851272163899d0
      iwe=iwe+1
      weightb(  9, 49,  3)=                  0.38030866377896238584d0
      iwe=iwe+1
      weightb( 10, 49,  3)=                 -0.29354374416373302248d0
      iwe=iwe+1
      weightb( 11, 49,  3)=                  0.23680620650208780709d0
      iwe=iwe+1
      weightb( 12, 49,  3)=                  0.06916525029289254112d0
      iwe=iwe+1
      weightb( 13, 49,  3)=                  0.92011027204106388133d0
      iwe=iwe+1
      weightb( 14, 49,  3)=                 -0.13901331153067195134d0
      iwe=iwe+1
      weightb( 15, 49,  3)=                 -0.00055832608366345815d0
      iwe=iwe+1
      weightb( 16, 49,  3)=                  0.33636144071247214837d0
      iwe=iwe+1
      weightb( 17, 49,  3)=                  0.05396830366208454910d0
      iwe=iwe+1
      weightb( 18, 49,  3)=                 -0.02567929190724404717d0
      iwe=iwe+1
      weightb( 19, 49,  3)=                  0.41778136818210992454d0
      iwe=iwe+1
      weightb( 20, 49,  3)=                  0.02507727537832136339d0
      iwe=iwe+1
      weightb( 21, 49,  3)=                  0.21952291592677411480d0
      iwe=iwe+1
      weightb( 22, 49,  3)=                 -0.20056947419475054661d0
      iwe=iwe+1
      weightb( 23, 49,  3)=                 -0.37116341533746066705d0
      iwe=iwe+1
      weightb( 24, 49,  3)=                  0.12840603688185103781d0
      iwe=iwe+1
      weightb( 25, 49,  3)=                  0.25114744064858407491d0
      iwe=iwe+1
      weightb( 26, 49,  3)=                 -0.26570461444813314733d0
      iwe=iwe+1
      weightb( 27, 49,  3)=                 -0.27311952638829140039d0
      iwe=iwe+1
      weightb( 28, 49,  3)=                  0.54803616975681468393d0
      iwe=iwe+1
      weightb( 29, 49,  3)=                 -0.14394360074387754778d0
      iwe=iwe+1
      weightb( 30, 49,  3)=                 -0.03242221630263235344d0
      iwe=iwe+1
      weightb( 31, 49,  3)=                  0.40082930046695913751d0
      iwe=iwe+1
      weightb( 32, 49,  3)=                  0.45419021734616410457d0
      iwe=iwe+1
      weightb( 33, 49,  3)=                 -0.37094991432869900416d0
      iwe=iwe+1
      weightb( 34, 49,  3)=                  0.63952971611064113322d0
      iwe=iwe+1
      weightb( 35, 49,  3)=                  0.16446682557580991069d0
      iwe=iwe+1
      weightb( 36, 49,  3)=                  0.22524759213210712727d0
      iwe=iwe+1
      weightb( 37, 49,  3)=                 -0.09031239770456560290d0
      iwe=iwe+1
      weightb( 38, 49,  3)=                  0.50822614897964968339d0
      iwe=iwe+1
      weightb( 39, 49,  3)=                  0.04793358783677047208d0
      iwe=iwe+1
      weightb( 40, 49,  3)=                  0.22551938016522132813d0
      iwe=iwe+1
      weightb( 41, 49,  3)=                 -0.32388974020774713436d0
      iwe=iwe+1
      weightb( 42, 49,  3)=                 -0.16447354437612135558d0
      iwe=iwe+1
      weightb( 43, 49,  3)=                 -0.02431208818020583542d0
      iwe=iwe+1
      weightb( 44, 49,  3)=                 -0.25548425607103375512d0
      iwe=iwe+1
      weightb( 45, 49,  3)=                  0.37946529435998793689d0
      iwe=iwe+1
      weightb( 46, 49,  3)=                 -0.04852392949530334038d0
      iwe=iwe+1
      weightb( 47, 49,  3)=                 -0.90314116054067250516d0
      iwe=iwe+1
      weightb( 48, 49,  3)=                 -0.23068233158450915377d0
      iwe=iwe+1
      weightb( 49, 49,  3)=                 -0.10336769821181585050d0
      iwe=iwe+1
      weightb( 50, 49,  3)=                  0.27646219184049020123d0
      iwe=iwe+1
      biasb( 49,  3)=                 -0.47503280077363368994d0
      iwe=iwe+1
      weightb(  1, 50,  3)=                 -0.54612155442391541182d0
      iwe=iwe+1
      weightb(  2, 50,  3)=                  0.23574062233655829202d0
      iwe=iwe+1
      weightb(  3, 50,  3)=                 -0.34550509821083896789d0
      iwe=iwe+1
      weightb(  4, 50,  3)=                 -0.15502754539101085141d0
      iwe=iwe+1
      weightb(  5, 50,  3)=                  0.00885377830004823591d0
      iwe=iwe+1
      weightb(  6, 50,  3)=                 -0.45344518068608702377d0
      iwe=iwe+1
      weightb(  7, 50,  3)=                  0.47498093543425723428d0
      iwe=iwe+1
      weightb(  8, 50,  3)=                  0.09664925471244084632d0
      iwe=iwe+1
      weightb(  9, 50,  3)=                 -0.52281182314588470206d0
      iwe=iwe+1
      weightb( 10, 50,  3)=                 -0.03723334657670080566d0
      iwe=iwe+1
      weightb( 11, 50,  3)=                 -0.29250033827750715476d0
      iwe=iwe+1
      weightb( 12, 50,  3)=                  0.25910764086070214862d0
      iwe=iwe+1
      weightb( 13, 50,  3)=                  0.13238086114298000528d0
      iwe=iwe+1
      weightb( 14, 50,  3)=                 -0.47373799677106159800d0
      iwe=iwe+1
      weightb( 15, 50,  3)=                 -0.09402630298283939925d0
      iwe=iwe+1
      weightb( 16, 50,  3)=                  0.16615665836573290104d0
      iwe=iwe+1
      weightb( 17, 50,  3)=                 -0.38317485825190322757d0
      iwe=iwe+1
      weightb( 18, 50,  3)=                 -0.32507341903076303335d0
      iwe=iwe+1
      weightb( 19, 50,  3)=                 -0.03151246709657507666d0
      iwe=iwe+1
      weightb( 20, 50,  3)=                  0.18115416967411054894d0
      iwe=iwe+1
      weightb( 21, 50,  3)=                 -0.16356994262174157084d0
      iwe=iwe+1
      weightb( 22, 50,  3)=                  0.23402661987954501144d0
      iwe=iwe+1
      weightb( 23, 50,  3)=                  0.18057943754658331570d0
      iwe=iwe+1
      weightb( 24, 50,  3)=                 -0.34212337055509384198d0
      iwe=iwe+1
      weightb( 25, 50,  3)=                 -0.51647396323641092675d0
      iwe=iwe+1
      weightb( 26, 50,  3)=                  0.12160909893482896305d0
      iwe=iwe+1
      weightb( 27, 50,  3)=                 -0.12669089390823584651d0
      iwe=iwe+1
      weightb( 28, 50,  3)=                 -0.01194947902862904775d0
      iwe=iwe+1
      weightb( 29, 50,  3)=                  0.00384204735393019713d0
      iwe=iwe+1
      weightb( 30, 50,  3)=                  0.10418920358483245436d0
      iwe=iwe+1
      weightb( 31, 50,  3)=                  0.35743672039327062384d0
      iwe=iwe+1
      weightb( 32, 50,  3)=                  0.32748603084074368041d0
      iwe=iwe+1
      weightb( 33, 50,  3)=                  0.00777227223256372543d0
      iwe=iwe+1
      weightb( 34, 50,  3)=                 -0.43077270555933339091d0
      iwe=iwe+1
      weightb( 35, 50,  3)=                 -0.29335031366926317409d0
      iwe=iwe+1
      weightb( 36, 50,  3)=                 -0.17406363606152294721d0
      iwe=iwe+1
      weightb( 37, 50,  3)=                  0.13612563463072860359d0
      iwe=iwe+1
      weightb( 38, 50,  3)=                 -0.17660565630109839597d0
      iwe=iwe+1
      weightb( 39, 50,  3)=                  0.22059809841567903921d0
      iwe=iwe+1
      weightb( 40, 50,  3)=                  0.08617268796446456158d0
      iwe=iwe+1
      weightb( 41, 50,  3)=                 -0.18544738069204946829d0
      iwe=iwe+1
      weightb( 42, 50,  3)=                 -0.06290568837931483082d0
      iwe=iwe+1
      weightb( 43, 50,  3)=                 -0.13280973187859396178d0
      iwe=iwe+1
      weightb( 44, 50,  3)=                 -0.18763761122656846814d0
      iwe=iwe+1
      weightb( 45, 50,  3)=                 -0.32641223191185647634d0
      iwe=iwe+1
      weightb( 46, 50,  3)=                 -0.29556047629510356911d0
      iwe=iwe+1
      weightb( 47, 50,  3)=                  0.05988289393314114029d0
      iwe=iwe+1
      weightb( 48, 50,  3)=                  0.04082315369872711180d0
      iwe=iwe+1
      weightb( 49, 50,  3)=                  0.04733220220249749477d0
      iwe=iwe+1
      weightb( 50, 50,  3)=                 -0.24266569933831444450d0
      iwe=iwe+1
      biasb( 50,  3)=                 -0.43313504269567981719d0
      iwe=iwe+1
      weightb(  1, 51,  3)=                  0.15781550857239115548d0
      iwe=iwe+1
      weightb(  2, 51,  3)=                 -0.23933246852590023268d0
      iwe=iwe+1
      weightb(  3, 51,  3)=                  0.10775505156379344696d0
      iwe=iwe+1
      weightb(  4, 51,  3)=                  0.25049467101888778231d0
      iwe=iwe+1
      weightb(  5, 51,  3)=                  0.16840736621974891629d0
      iwe=iwe+1
      weightb(  6, 51,  3)=                  0.18055023192675834220d0
      iwe=iwe+1
      weightb(  7, 51,  3)=                 -0.16504325280573386991d0
      iwe=iwe+1
      weightb(  8, 51,  3)=                  0.30133013329068025765d0
      iwe=iwe+1
      weightb(  9, 51,  3)=                  0.11982234195706781277d0
      iwe=iwe+1
      weightb( 10, 51,  3)=                  0.47243253230916243401d0
      iwe=iwe+1
      weightb( 11, 51,  3)=                  0.46123072394317432554d0
      iwe=iwe+1
      weightb( 12, 51,  3)=                  0.06291818295925033500d0
      iwe=iwe+1
      weightb( 13, 51,  3)=                 -0.24428852723879709852d0
      iwe=iwe+1
      weightb( 14, 51,  3)=                 -0.32350368119962558122d0
      iwe=iwe+1
      weightb( 15, 51,  3)=                 -0.56360624544681414694d0
      iwe=iwe+1
      weightb( 16, 51,  3)=                 -0.45937754238599570744d0
      iwe=iwe+1
      weightb( 17, 51,  3)=                 -0.20194448595891506537d0
      iwe=iwe+1
      weightb( 18, 51,  3)=                  0.20264713844853488034d0
      iwe=iwe+1
      weightb( 19, 51,  3)=                 -0.41834411671691335011d0
      iwe=iwe+1
      weightb( 20, 51,  3)=                  0.17681386942356003278d0
      iwe=iwe+1
      weightb( 21, 51,  3)=                 -0.06168161200689353807d0
      iwe=iwe+1
      weightb( 22, 51,  3)=                 -0.20311685389319203421d0
      iwe=iwe+1
      weightb( 23, 51,  3)=                  0.44097742475720402844d0
      iwe=iwe+1
      weightb( 24, 51,  3)=                  0.23992688375043125237d0
      iwe=iwe+1
      weightb( 25, 51,  3)=                  0.24278334133615914192d0
      iwe=iwe+1
      weightb( 26, 51,  3)=                  0.33886882743060608991d0
      iwe=iwe+1
      weightb( 27, 51,  3)=                  0.22016829956139491453d0
      iwe=iwe+1
      weightb( 28, 51,  3)=                 -0.49626529474108471707d0
      iwe=iwe+1
      weightb( 29, 51,  3)=                  0.46024733241954529639d0
      iwe=iwe+1
      weightb( 30, 51,  3)=                 -0.20642278206127240292d0
      iwe=iwe+1
      weightb( 31, 51,  3)=                 -0.22739619803162774980d0
      iwe=iwe+1
      weightb( 32, 51,  3)=                  0.26335593784206695611d0
      iwe=iwe+1
      weightb( 33, 51,  3)=                 -0.31888748113362319625d0
      iwe=iwe+1
      weightb( 34, 51,  3)=                 -0.37424027991862007791d0
      iwe=iwe+1
      weightb( 35, 51,  3)=                 -0.21220725922077290915d0
      iwe=iwe+1
      weightb( 36, 51,  3)=                 -0.04523073900458760704d0
      iwe=iwe+1
      weightb( 37, 51,  3)=                 -0.12672883170059479063d0
      iwe=iwe+1
      weightb( 38, 51,  3)=                 -0.08639950322452517872d0
      iwe=iwe+1
      weightb( 39, 51,  3)=                 -0.43041908664362382719d0
      iwe=iwe+1
      weightb( 40, 51,  3)=                  0.07034072731843352133d0
      iwe=iwe+1
      weightb( 41, 51,  3)=                 -0.35182490114680681215d0
      iwe=iwe+1
      weightb( 42, 51,  3)=                 -0.03007576648282466944d0
      iwe=iwe+1
      weightb( 43, 51,  3)=                  0.16249613591223177611d0
      iwe=iwe+1
      weightb( 44, 51,  3)=                  0.10534876021530791002d0
      iwe=iwe+1
      weightb( 45, 51,  3)=                  0.20286814585793017107d0
      iwe=iwe+1
      weightb( 46, 51,  3)=                 -0.17124395379114137894d0
      iwe=iwe+1
      weightb( 47, 51,  3)=                 -0.51551670583190900565d0
      iwe=iwe+1
      weightb( 48, 51,  3)=                  0.03609371890042906844d0
      iwe=iwe+1
      weightb( 49, 51,  3)=                 -0.28902205038717310170d0
      iwe=iwe+1
      weightb( 50, 51,  3)=                 -0.39392526850204362399d0
      iwe=iwe+1
      biasb( 51,  3)=                  0.22561971695822333195d0
      iwe=iwe+1
      weightb(  1, 52,  3)=                 -0.19655075086081993940d0
      iwe=iwe+1
      weightb(  2, 52,  3)=                  0.18079564156249319784d0
      iwe=iwe+1
      weightb(  3, 52,  3)=                 -0.21153188626624369606d0
      iwe=iwe+1
      weightb(  4, 52,  3)=                 -0.29728322155293451790d0
      iwe=iwe+1
      weightb(  5, 52,  3)=                  0.48931126199914659614d0
      iwe=iwe+1
      weightb(  6, 52,  3)=                 -0.37024426738459825792d0
      iwe=iwe+1
      weightb(  7, 52,  3)=                 -0.05217608467945469841d0
      iwe=iwe+1
      weightb(  8, 52,  3)=                 -0.17918715770398455089d0
      iwe=iwe+1
      weightb(  9, 52,  3)=                  0.11613864080303602788d0
      iwe=iwe+1
      weightb( 10, 52,  3)=                  0.08470401568394406167d0
      iwe=iwe+1
      weightb( 11, 52,  3)=                 -0.16542473369492255442d0
      iwe=iwe+1
      weightb( 12, 52,  3)=                 -0.18727959589832091081d0
      iwe=iwe+1
      weightb( 13, 52,  3)=                  0.45460484358546066064d0
      iwe=iwe+1
      weightb( 14, 52,  3)=                 -0.07809052165970466197d0
      iwe=iwe+1
      weightb( 15, 52,  3)=                 -0.05055776822569000434d0
      iwe=iwe+1
      weightb( 16, 52,  3)=                 -0.15366786612180025062d0
      iwe=iwe+1
      weightb( 17, 52,  3)=                 -0.37307877655284038543d0
      iwe=iwe+1
      weightb( 18, 52,  3)=                  0.28654066185937299149d0
      iwe=iwe+1
      weightb( 19, 52,  3)=                  0.46418933117738392369d0
      iwe=iwe+1
      weightb( 20, 52,  3)=                  0.02486297304248246201d0
      iwe=iwe+1
      weightb( 21, 52,  3)=                 -0.01638431955453197725d0
      iwe=iwe+1
      weightb( 22, 52,  3)=                 -0.60612773338562220271d0
      iwe=iwe+1
      weightb( 23, 52,  3)=                  0.24420755326556461973d0
      iwe=iwe+1
      weightb( 24, 52,  3)=                 -0.29296386728424750334d0
      iwe=iwe+1
      weightb( 25, 52,  3)=                 -0.01475905952956428971d0
      iwe=iwe+1
      weightb( 26, 52,  3)=                 -0.37555129664496905706d0
      iwe=iwe+1
      weightb( 27, 52,  3)=                  0.22021920538895206620d0
      iwe=iwe+1
      weightb( 28, 52,  3)=                  0.14167989939310404734d0
      iwe=iwe+1
      weightb( 29, 52,  3)=                 -0.43087807200038436006d0
      iwe=iwe+1
      weightb( 30, 52,  3)=                  0.00066748394514066015d0
      iwe=iwe+1
      weightb( 31, 52,  3)=                  0.24763398059434424403d0
      iwe=iwe+1
      weightb( 32, 52,  3)=                  0.16380230679203483524d0
      iwe=iwe+1
      weightb( 33, 52,  3)=                 -0.38321453719099402013d0
      iwe=iwe+1
      weightb( 34, 52,  3)=                  0.48363359513085635299d0
      iwe=iwe+1
      weightb( 35, 52,  3)=                  0.29024382570879514454d0
      iwe=iwe+1
      weightb( 36, 52,  3)=                  0.02797732004118271346d0
      iwe=iwe+1
      weightb( 37, 52,  3)=                 -0.17056853468561875009d0
      iwe=iwe+1
      weightb( 38, 52,  3)=                  0.07896003423515929320d0
      iwe=iwe+1
      weightb( 39, 52,  3)=                 -0.09332452030423278588d0
      iwe=iwe+1
      weightb( 40, 52,  3)=                  0.07568866526122575156d0
      iwe=iwe+1
      weightb( 41, 52,  3)=                  0.09777134165973451474d0
      iwe=iwe+1
      weightb( 42, 52,  3)=                 -0.27530321240659233473d0
      iwe=iwe+1
      weightb( 43, 52,  3)=                  0.24678008571986362329d0
      iwe=iwe+1
      weightb( 44, 52,  3)=                  0.06846620600724728778d0
      iwe=iwe+1
      weightb( 45, 52,  3)=                  0.17185053892674814757d0
      iwe=iwe+1
      weightb( 46, 52,  3)=                 -0.05810362974483419124d0
      iwe=iwe+1
      weightb( 47, 52,  3)=                  0.16983484851339536448d0
      iwe=iwe+1
      weightb( 48, 52,  3)=                 -0.13759422239387367193d0
      iwe=iwe+1
      weightb( 49, 52,  3)=                 -0.19261831610070048737d0
      iwe=iwe+1
      weightb( 50, 52,  3)=                 -0.16637350028777245226d0
      iwe=iwe+1
      biasb( 52,  3)=                 -0.36975788873121256950d0
      iwe=iwe+1
      weightb(  1, 53,  3)=                 -0.13331274516112906481d0
      iwe=iwe+1
      weightb(  2, 53,  3)=                 -0.15598373458639772093d0
      iwe=iwe+1
      weightb(  3, 53,  3)=                  0.06370250040854175122d0
      iwe=iwe+1
      weightb(  4, 53,  3)=                 -0.26072040619626335456d0
      iwe=iwe+1
      weightb(  5, 53,  3)=                 -0.38071844169066143548d0
      iwe=iwe+1
      weightb(  6, 53,  3)=                 -0.00492330896702818707d0
      iwe=iwe+1
      weightb(  7, 53,  3)=                 -0.41058950179430347971d0
      iwe=iwe+1
      weightb(  8, 53,  3)=                  0.37796706762033799309d0
      iwe=iwe+1
      weightb(  9, 53,  3)=                  0.09769270152219407255d0
      iwe=iwe+1
      weightb( 10, 53,  3)=                 -0.07725230988836198631d0
      iwe=iwe+1
      weightb( 11, 53,  3)=                  0.10474707767231682121d0
      iwe=iwe+1
      weightb( 12, 53,  3)=                  0.50919556089582496128d0
      iwe=iwe+1
      weightb( 13, 53,  3)=                 -0.60268990485298357118d0
      iwe=iwe+1
      weightb( 14, 53,  3)=                 -0.50430600709902029255d0
      iwe=iwe+1
      weightb( 15, 53,  3)=                  0.50132046025846987991d0
      iwe=iwe+1
      weightb( 16, 53,  3)=                  0.33561773543232137351d0
      iwe=iwe+1
      weightb( 17, 53,  3)=                 -0.37282899652625473008d0
      iwe=iwe+1
      weightb( 18, 53,  3)=                  0.15900665746248418553d0
      iwe=iwe+1
      weightb( 19, 53,  3)=                  0.18454527499464834506d0
      iwe=iwe+1
      weightb( 20, 53,  3)=                  0.47078007700668156321d0
      iwe=iwe+1
      weightb( 21, 53,  3)=                  0.54770148714153088498d0
      iwe=iwe+1
      weightb( 22, 53,  3)=                 -0.25791996240124615003d0
      iwe=iwe+1
      weightb( 23, 53,  3)=                 -0.37766855570808144371d0
      iwe=iwe+1
      weightb( 24, 53,  3)=                 -0.00591592843569058776d0
      iwe=iwe+1
      weightb( 25, 53,  3)=                  0.21712140272633137505d0
      iwe=iwe+1
      weightb( 26, 53,  3)=                  0.34341925304738618596d0
      iwe=iwe+1
      weightb( 27, 53,  3)=                  0.11215984195934668166d0
      iwe=iwe+1
      weightb( 28, 53,  3)=                  0.07404703877051557748d0
      iwe=iwe+1
      weightb( 29, 53,  3)=                 -0.50855549614470141329d0
      iwe=iwe+1
      weightb( 30, 53,  3)=                 -0.29247005963490746439d0
      iwe=iwe+1
      weightb( 31, 53,  3)=                  0.20190572012013621728d0
      iwe=iwe+1
      weightb( 32, 53,  3)=                 -0.21877425109540812875d0
      iwe=iwe+1
      weightb( 33, 53,  3)=                 -0.04142143858395881673d0
      iwe=iwe+1
      weightb( 34, 53,  3)=                 -0.03700743476934093695d0
      iwe=iwe+1
      weightb( 35, 53,  3)=                  0.02845038506758663585d0
      iwe=iwe+1
      weightb( 36, 53,  3)=                  0.04580844653975006675d0
      iwe=iwe+1
      weightb( 37, 53,  3)=                  0.13825202633725031109d0
      iwe=iwe+1
      weightb( 38, 53,  3)=                  0.09531828287766819230d0
      iwe=iwe+1
      weightb( 39, 53,  3)=                  0.39971624718160292389d0
      iwe=iwe+1
      weightb( 40, 53,  3)=                 -0.33368870058240446275d0
      iwe=iwe+1
      weightb( 41, 53,  3)=                  0.01735107406830415158d0
      iwe=iwe+1
      weightb( 42, 53,  3)=                 -0.33490332996391375397d0
      iwe=iwe+1
      weightb( 43, 53,  3)=                 -0.08494403151926958884d0
      iwe=iwe+1
      weightb( 44, 53,  3)=                 -0.11816688251879581273d0
      iwe=iwe+1
      weightb( 45, 53,  3)=                 -0.28249232444235639061d0
      iwe=iwe+1
      weightb( 46, 53,  3)=                 -0.00233945841296825593d0
      iwe=iwe+1
      weightb( 47, 53,  3)=                  0.35578425340662345189d0
      iwe=iwe+1
      weightb( 48, 53,  3)=                  0.03417624825558993051d0
      iwe=iwe+1
      weightb( 49, 53,  3)=                  0.03655951237568783041d0
      iwe=iwe+1
      weightb( 50, 53,  3)=                  0.18915538743464116456d0
      iwe=iwe+1
      biasb( 53,  3)=                 -0.56685290672667387746d0
      iwe=iwe+1
      weightb(  1, 54,  3)=                 -0.12292189331711773914d0
      iwe=iwe+1
      weightb(  2, 54,  3)=                 -0.17612814085158051691d0
      iwe=iwe+1
      weightb(  3, 54,  3)=                 -0.12003800772502155880d0
      iwe=iwe+1
      weightb(  4, 54,  3)=                 -0.19599391359460019424d0
      iwe=iwe+1
      weightb(  5, 54,  3)=                 -0.25825268389120797918d0
      iwe=iwe+1
      weightb(  6, 54,  3)=                  0.02997815944997641105d0
      iwe=iwe+1
      weightb(  7, 54,  3)=                 -0.10967116186746658779d0
      iwe=iwe+1
      weightb(  8, 54,  3)=                 -0.02951636499672873060d0
      iwe=iwe+1
      weightb(  9, 54,  3)=                 -0.30118006418117881928d0
      iwe=iwe+1
      weightb( 10, 54,  3)=                 -0.51654488196070813544d0
      iwe=iwe+1
      weightb( 11, 54,  3)=                 -0.18890001077410895070d0
      iwe=iwe+1
      weightb( 12, 54,  3)=                  0.05955441561107521764d0
      iwe=iwe+1
      weightb( 13, 54,  3)=                  0.08983177755703197764d0
      iwe=iwe+1
      weightb( 14, 54,  3)=                 -0.00093959606338778071d0
      iwe=iwe+1
      weightb( 15, 54,  3)=                 -0.48846333139712183602d0
      iwe=iwe+1
      weightb( 16, 54,  3)=                  0.08084595412191070141d0
      iwe=iwe+1
      weightb( 17, 54,  3)=                  0.11749037398269175647d0
      iwe=iwe+1
      weightb( 18, 54,  3)=                 -0.41397855954234058506d0
      iwe=iwe+1
      weightb( 19, 54,  3)=                  0.20182035975071765943d0
      iwe=iwe+1
      weightb( 20, 54,  3)=                  0.15509161901129422945d0
      iwe=iwe+1
      weightb( 21, 54,  3)=                  0.03201392162101208277d0
      iwe=iwe+1
      weightb( 22, 54,  3)=                 -0.11343205944013926012d0
      iwe=iwe+1
      weightb( 23, 54,  3)=                 -0.27819787692248670874d0
      iwe=iwe+1
      weightb( 24, 54,  3)=                  0.51680247504903076283d0
      iwe=iwe+1
      weightb( 25, 54,  3)=                 -0.64626445164843293600d0
      iwe=iwe+1
      weightb( 26, 54,  3)=                  0.07052594088320021659d0
      iwe=iwe+1
      weightb( 27, 54,  3)=                 -0.09500268582974698284d0
      iwe=iwe+1
      weightb( 28, 54,  3)=                  0.26034188968548782617d0
      iwe=iwe+1
      weightb( 29, 54,  3)=                  0.46633608770515100339d0
      iwe=iwe+1
      weightb( 30, 54,  3)=                  0.27586269826699955088d0
      iwe=iwe+1
      weightb( 31, 54,  3)=                  0.08260597933257228520d0
      iwe=iwe+1
      weightb( 32, 54,  3)=                  0.26773813753746877886d0
      iwe=iwe+1
      weightb( 33, 54,  3)=                 -0.11957057914429372603d0
      iwe=iwe+1
      weightb( 34, 54,  3)=                  0.64802914341433626166d0
      iwe=iwe+1
      weightb( 35, 54,  3)=                 -0.29333278426329251198d0
      iwe=iwe+1
      weightb( 36, 54,  3)=                 -0.00434163598564011460d0
      iwe=iwe+1
      weightb( 37, 54,  3)=                 -0.20471231671753437054d0
      iwe=iwe+1
      weightb( 38, 54,  3)=                 -0.05973396237566274553d0
      iwe=iwe+1
      weightb( 39, 54,  3)=                 -0.41869915319952549781d0
      iwe=iwe+1
      weightb( 40, 54,  3)=                  0.06213635191425791182d0
      iwe=iwe+1
      weightb( 41, 54,  3)=                  0.40043324265054447419d0
      iwe=iwe+1
      weightb( 42, 54,  3)=                 -0.57354329818865312784d0
      iwe=iwe+1
      weightb( 43, 54,  3)=                 -0.10525516431150656882d0
      iwe=iwe+1
      weightb( 44, 54,  3)=                  0.10033796756586219057d0
      iwe=iwe+1
      weightb( 45, 54,  3)=                 -0.17119179520009075723d0
      iwe=iwe+1
      weightb( 46, 54,  3)=                 -0.30979829745930181906d0
      iwe=iwe+1
      weightb( 47, 54,  3)=                  0.44656403161217900211d0
      iwe=iwe+1
      weightb( 48, 54,  3)=                  0.39126520358191307913d0
      iwe=iwe+1
      weightb( 49, 54,  3)=                 -0.11853732619459812769d0
      iwe=iwe+1
      weightb( 50, 54,  3)=                 -0.04238157017985404867d0
      iwe=iwe+1
      biasb( 54,  3)=                  0.69471605546278847321d0
      iwe=iwe+1
      weightb(  1, 55,  3)=                  0.40180023437464484903d0
      iwe=iwe+1
      weightb(  2, 55,  3)=                 -0.13382976288034051371d0
      iwe=iwe+1
      weightb(  3, 55,  3)=                  0.03464341563738078389d0
      iwe=iwe+1
      weightb(  4, 55,  3)=                 -0.25280541456261940159d0
      iwe=iwe+1
      weightb(  5, 55,  3)=                 -0.42432935123163278979d0
      iwe=iwe+1
      weightb(  6, 55,  3)=                  0.25069584354500823453d0
      iwe=iwe+1
      weightb(  7, 55,  3)=                 -0.18718055816217971099d0
      iwe=iwe+1
      weightb(  8, 55,  3)=                  0.23831749268920973672d0
      iwe=iwe+1
      weightb(  9, 55,  3)=                  0.11241113900361078548d0
      iwe=iwe+1
      weightb( 10, 55,  3)=                 -0.05725115924929759237d0
      iwe=iwe+1
      weightb( 11, 55,  3)=                 -0.39705576945051573867d0
      iwe=iwe+1
      weightb( 12, 55,  3)=                 -0.16324755137248184167d0
      iwe=iwe+1
      weightb( 13, 55,  3)=                  0.02245009853883189743d0
      iwe=iwe+1
      weightb( 14, 55,  3)=                  0.74212529120517956027d0
      iwe=iwe+1
      weightb( 15, 55,  3)=                  0.05831476003622348969d0
      iwe=iwe+1
      weightb( 16, 55,  3)=                 -0.96306738729983476510d0
      iwe=iwe+1
      weightb( 17, 55,  3)=                  0.07310509071783759250d0
      iwe=iwe+1
      weightb( 18, 55,  3)=                 -0.20036573663304163562d0
      iwe=iwe+1
      weightb( 19, 55,  3)=                 -0.14105489121214193071d0
      iwe=iwe+1
      weightb( 20, 55,  3)=                  0.10056905009561968589d0
      iwe=iwe+1
      weightb( 21, 55,  3)=                 -0.60477756056525322492d0
      iwe=iwe+1
      weightb( 22, 55,  3)=                 -0.58187627094184313226d0
      iwe=iwe+1
      weightb( 23, 55,  3)=                 -0.40626465602556161016d0
      iwe=iwe+1
      weightb( 24, 55,  3)=                 -0.21454741512789082813d0
      iwe=iwe+1
      weightb( 25, 55,  3)=                  1.10097243298626490393d0
      iwe=iwe+1
      weightb( 26, 55,  3)=                  0.47787452758842674516d0
      iwe=iwe+1
      weightb( 27, 55,  3)=                  0.26926002674116539248d0
      iwe=iwe+1
      weightb( 28, 55,  3)=                  0.21569923695752171722d0
      iwe=iwe+1
      weightb( 29, 55,  3)=                 -0.42093044250193439870d0
      iwe=iwe+1
      weightb( 30, 55,  3)=                  0.33908639747111701812d0
      iwe=iwe+1
      weightb( 31, 55,  3)=                  0.07135454112378350477d0
      iwe=iwe+1
      weightb( 32, 55,  3)=                  0.56083999852204213799d0
      iwe=iwe+1
      weightb( 33, 55,  3)=                  0.31775529312821293448d0
      iwe=iwe+1
      weightb( 34, 55,  3)=                  0.41979318016307043404d0
      iwe=iwe+1
      weightb( 35, 55,  3)=                  0.34432103001979841306d0
      iwe=iwe+1
      weightb( 36, 55,  3)=                 -0.02427772714175954749d0
      iwe=iwe+1
      weightb( 37, 55,  3)=                  0.58227092304905148090d0
      iwe=iwe+1
      weightb( 38, 55,  3)=                 -0.09523743261333694754d0
      iwe=iwe+1
      weightb( 39, 55,  3)=                 -0.27337133331252649882d0
      iwe=iwe+1
      weightb( 40, 55,  3)=                 -0.12514723196879448675d0
      iwe=iwe+1
      weightb( 41, 55,  3)=                  0.34452811222423501691d0
      iwe=iwe+1
      weightb( 42, 55,  3)=                 -0.01608426021191001684d0
      iwe=iwe+1
      weightb( 43, 55,  3)=                 -0.22704091561960032530d0
      iwe=iwe+1
      weightb( 44, 55,  3)=                  0.27739103500539979974d0
      iwe=iwe+1
      weightb( 45, 55,  3)=                  0.30980874278872722050d0
      iwe=iwe+1
      weightb( 46, 55,  3)=                  0.24226930477110067419d0
      iwe=iwe+1
      weightb( 47, 55,  3)=                 -0.33622522563472995172d0
      iwe=iwe+1
      weightb( 48, 55,  3)=                  0.34572135246035123890d0
      iwe=iwe+1
      weightb( 49, 55,  3)=                  0.14247571161367994508d0
      iwe=iwe+1
      weightb( 50, 55,  3)=                  0.02919283073430424189d0
      iwe=iwe+1
      biasb( 55,  3)=                  0.60831302787865793036d0
      iwe=iwe+1
      weightb(  1, 56,  3)=                  0.33555812348498925690d0
      iwe=iwe+1
      weightb(  2, 56,  3)=                  0.63150054952584966372d0
      iwe=iwe+1
      weightb(  3, 56,  3)=                 -0.18266280553242358886d0
      iwe=iwe+1
      weightb(  4, 56,  3)=                 -0.26100081895185045511d0
      iwe=iwe+1
      weightb(  5, 56,  3)=                  0.35939325111093922693d0
      iwe=iwe+1
      weightb(  6, 56,  3)=                 -0.31140079022724459490d0
      iwe=iwe+1
      weightb(  7, 56,  3)=                 -0.35464110817146676791d0
      iwe=iwe+1
      weightb(  8, 56,  3)=                 -0.26023826850356585050d0
      iwe=iwe+1
      weightb(  9, 56,  3)=                 -0.30964808974211105452d0
      iwe=iwe+1
      weightb( 10, 56,  3)=                 -0.19283454080306536293d0
      iwe=iwe+1
      weightb( 11, 56,  3)=                 -0.19329151986562462251d0
      iwe=iwe+1
      weightb( 12, 56,  3)=                 -0.08615398722145661825d0
      iwe=iwe+1
      weightb( 13, 56,  3)=                 -0.05406050480662467211d0
      iwe=iwe+1
      weightb( 14, 56,  3)=                 -0.01821840420201318450d0
      iwe=iwe+1
      weightb( 15, 56,  3)=                  0.00017161593697379973d0
      iwe=iwe+1
      weightb( 16, 56,  3)=                 -0.19237391403176526405d0
      iwe=iwe+1
      weightb( 17, 56,  3)=                 -0.19205971631585494475d0
      iwe=iwe+1
      weightb( 18, 56,  3)=                  0.50287887096607131188d0
      iwe=iwe+1
      weightb( 19, 56,  3)=                  0.02682735980043077229d0
      iwe=iwe+1
      weightb( 20, 56,  3)=                  0.13878122857011923608d0
      iwe=iwe+1
      weightb( 21, 56,  3)=                 -0.28537112529330455057d0
      iwe=iwe+1
      weightb( 22, 56,  3)=                 -0.31987578167809721519d0
      iwe=iwe+1
      weightb( 23, 56,  3)=                  0.04776887902609604220d0
      iwe=iwe+1
      weightb( 24, 56,  3)=                 -0.70729916493065869698d0
      iwe=iwe+1
      weightb( 25, 56,  3)=                 -0.42814162645273490249d0
      iwe=iwe+1
      weightb( 26, 56,  3)=                  0.42244929526470847980d0
      iwe=iwe+1
      weightb( 27, 56,  3)=                 -0.02358521155736117286d0
      iwe=iwe+1
      weightb( 28, 56,  3)=                  0.23576713943045968236d0
      iwe=iwe+1
      weightb( 29, 56,  3)=                 -0.51547910577829236800d0
      iwe=iwe+1
      weightb( 30, 56,  3)=                 -0.03785048169373249338d0
      iwe=iwe+1
      weightb( 31, 56,  3)=                  0.02232551716008967374d0
      iwe=iwe+1
      weightb( 32, 56,  3)=                  0.41917631154888790324d0
      iwe=iwe+1
      weightb( 33, 56,  3)=                 -0.34710462765325761358d0
      iwe=iwe+1
      weightb( 34, 56,  3)=                 -0.23708319829229262954d0
      iwe=iwe+1
      weightb( 35, 56,  3)=                  0.33516470667227032942d0
      iwe=iwe+1
      weightb( 36, 56,  3)=                 -0.36686493334243108766d0
      iwe=iwe+1
      weightb( 37, 56,  3)=                  0.31649981709124036522d0
      iwe=iwe+1
      weightb( 38, 56,  3)=                 -0.26183991938632839025d0
      iwe=iwe+1
      weightb( 39, 56,  3)=                 -0.10779357930238932239d0
      iwe=iwe+1
      weightb( 40, 56,  3)=                 -0.16050604057533446323d0
      iwe=iwe+1
      weightb( 41, 56,  3)=                 -0.40255347428853943681d0
      iwe=iwe+1
      weightb( 42, 56,  3)=                 -0.32509825158733990369d0
      iwe=iwe+1
      weightb( 43, 56,  3)=                  0.23910008044108241321d0
      iwe=iwe+1
      weightb( 44, 56,  3)=                  0.17401693414930630155d0
      iwe=iwe+1
      weightb( 45, 56,  3)=                  0.42340325658942462583d0
      iwe=iwe+1
      weightb( 46, 56,  3)=                  0.43105275931142039703d0
      iwe=iwe+1
      weightb( 47, 56,  3)=                 -0.21424478865722990095d0
      iwe=iwe+1
      weightb( 48, 56,  3)=                  0.27266459977169016371d0
      iwe=iwe+1
      weightb( 49, 56,  3)=                 -0.01113589330033377955d0
      iwe=iwe+1
      weightb( 50, 56,  3)=                 -0.00147913830792904192d0
      iwe=iwe+1
      biasb( 56,  3)=                  0.67398646674791862221d0
      iwe=iwe+1
      weightb(  1, 57,  3)=                  0.41183817234502717586d0
      iwe=iwe+1
      weightb(  2, 57,  3)=                  0.48070286033756431943d0
      iwe=iwe+1
      weightb(  3, 57,  3)=                 -0.08551288956167421573d0
      iwe=iwe+1
      weightb(  4, 57,  3)=                  0.07796903786188494334d0
      iwe=iwe+1
      weightb(  5, 57,  3)=                  0.12977868655491581196d0
      iwe=iwe+1
      weightb(  6, 57,  3)=                 -0.09543476158374621099d0
      iwe=iwe+1
      weightb(  7, 57,  3)=                 -0.00695932794065539078d0
      iwe=iwe+1
      weightb(  8, 57,  3)=                 -0.15175174698642049376d0
      iwe=iwe+1
      weightb(  9, 57,  3)=                  0.23081358675606578057d0
      iwe=iwe+1
      weightb( 10, 57,  3)=                  0.12736154690898052189d0
      iwe=iwe+1
      weightb( 11, 57,  3)=                 -0.26580353829983682790d0
      iwe=iwe+1
      weightb( 12, 57,  3)=                  0.49059102135595722416d0
      iwe=iwe+1
      weightb( 13, 57,  3)=                  0.30351507515018688599d0
      iwe=iwe+1
      weightb( 14, 57,  3)=                 -0.15735222435172230293d0
      iwe=iwe+1
      weightb( 15, 57,  3)=                 -0.05399659804252604500d0
      iwe=iwe+1
      weightb( 16, 57,  3)=                 -0.19688403928611267202d0
      iwe=iwe+1
      weightb( 17, 57,  3)=                 -0.11672471444730410373d0
      iwe=iwe+1
      weightb( 18, 57,  3)=                 -0.23932483939330423395d0
      iwe=iwe+1
      weightb( 19, 57,  3)=                  0.16913947589615946354d0
      iwe=iwe+1
      weightb( 20, 57,  3)=                 -0.15698793374174277448d0
      iwe=iwe+1
      weightb( 21, 57,  3)=                 -0.31669685819293286189d0
      iwe=iwe+1
      weightb( 22, 57,  3)=                  0.07392530644707138998d0
      iwe=iwe+1
      weightb( 23, 57,  3)=                  0.09931612839198510068d0
      iwe=iwe+1
      weightb( 24, 57,  3)=                 -0.13683284562587405553d0
      iwe=iwe+1
      weightb( 25, 57,  3)=                 -0.28410386399116360767d0
      iwe=iwe+1
      weightb( 26, 57,  3)=                  0.25132456176499184952d0
      iwe=iwe+1
      weightb( 27, 57,  3)=                  0.30013004196536746671d0
      iwe=iwe+1
      weightb( 28, 57,  3)=                 -0.21733170539162846580d0
      iwe=iwe+1
      weightb( 29, 57,  3)=                  0.38341906834303385310d0
      iwe=iwe+1
      weightb( 30, 57,  3)=                 -0.26055253292631369577d0
      iwe=iwe+1
      weightb( 31, 57,  3)=                  0.01266278555414841571d0
      iwe=iwe+1
      weightb( 32, 57,  3)=                 -0.23598297962597217237d0
      iwe=iwe+1
      weightb( 33, 57,  3)=                 -0.11796501063104695983d0
      iwe=iwe+1
      weightb( 34, 57,  3)=                  0.66166582683855479363d0
      iwe=iwe+1
      weightb( 35, 57,  3)=                 -0.29167201738549758394d0
      iwe=iwe+1
      weightb( 36, 57,  3)=                  0.02609928629665506095d0
      iwe=iwe+1
      weightb( 37, 57,  3)=                  0.31413081612310145285d0
      iwe=iwe+1
      weightb( 38, 57,  3)=                 -0.13323684447468592262d0
      iwe=iwe+1
      weightb( 39, 57,  3)=                 -0.07802059310457847008d0
      iwe=iwe+1
      weightb( 40, 57,  3)=                  0.08472794806226258135d0
      iwe=iwe+1
      weightb( 41, 57,  3)=                  0.25288427272211899677d0
      iwe=iwe+1
      weightb( 42, 57,  3)=                 -0.21745214185032976650d0
      iwe=iwe+1
      weightb( 43, 57,  3)=                 -0.21982535202024774956d0
      iwe=iwe+1
      weightb( 44, 57,  3)=                 -0.18088898030336209022d0
      iwe=iwe+1
      weightb( 45, 57,  3)=                  0.24333610272970948585d0
      iwe=iwe+1
      weightb( 46, 57,  3)=                 -0.28074340609667514101d0
      iwe=iwe+1
      weightb( 47, 57,  3)=                 -0.37932364336280743888d0
      iwe=iwe+1
      weightb( 48, 57,  3)=                  0.03562284898533719935d0
      iwe=iwe+1
      weightb( 49, 57,  3)=                 -0.22370077140908239954d0
      iwe=iwe+1
      weightb( 50, 57,  3)=                 -0.24769085572172588883d0
      iwe=iwe+1
      biasb( 57,  3)=                  0.60682072803928888138d0
      iwe=iwe+1
      weightb(  1, 58,  3)=                  0.30899389861648141054d0
      iwe=iwe+1
      weightb(  2, 58,  3)=                 -0.09438891896604709175d0
      iwe=iwe+1
      weightb(  3, 58,  3)=                 -0.08546031555427002768d0
      iwe=iwe+1
      weightb(  4, 58,  3)=                  0.07278897143633807076d0
      iwe=iwe+1
      weightb(  5, 58,  3)=                 -0.22749474736562680377d0
      iwe=iwe+1
      weightb(  6, 58,  3)=                 -0.29984367717233606498d0
      iwe=iwe+1
      weightb(  7, 58,  3)=                 -0.13773373629956522923d0
      iwe=iwe+1
      weightb(  8, 58,  3)=                  0.09557810878590598802d0
      iwe=iwe+1
      weightb(  9, 58,  3)=                 -0.17271492523146458886d0
      iwe=iwe+1
      weightb( 10, 58,  3)=                  0.17613911422858083422d0
      iwe=iwe+1
      weightb( 11, 58,  3)=                  0.06096963230484316043d0
      iwe=iwe+1
      weightb( 12, 58,  3)=                  0.18667620833322509655d0
      iwe=iwe+1
      weightb( 13, 58,  3)=                 -0.15712882475683215278d0
      iwe=iwe+1
      weightb( 14, 58,  3)=                 -0.22501936175429781972d0
      iwe=iwe+1
      weightb( 15, 58,  3)=                  0.08412136128950063740d0
      iwe=iwe+1
      weightb( 16, 58,  3)=                 -0.15690392616855031171d0
      iwe=iwe+1
      weightb( 17, 58,  3)=                  0.46215032656694254865d0
      iwe=iwe+1
      weightb( 18, 58,  3)=                  0.16376653264449861358d0
      iwe=iwe+1
      weightb( 19, 58,  3)=                  0.22899625339827778259d0
      iwe=iwe+1
      weightb( 20, 58,  3)=                  0.37855851289829989259d0
      iwe=iwe+1
      weightb( 21, 58,  3)=                  0.29169568433683762398d0
      iwe=iwe+1
      weightb( 22, 58,  3)=                 -0.16771109548384788290d0
      iwe=iwe+1
      weightb( 23, 58,  3)=                 -0.44693553065849078720d0
      iwe=iwe+1
      weightb( 24, 58,  3)=                 -0.48213559313367249093d0
      iwe=iwe+1
      weightb( 25, 58,  3)=                  0.03993462445636898617d0
      iwe=iwe+1
      weightb( 26, 58,  3)=                 -0.40282915051615597601d0
      iwe=iwe+1
      weightb( 27, 58,  3)=                  0.15138955641633661253d0
      iwe=iwe+1
      weightb( 28, 58,  3)=                 -0.29800076901172317667d0
      iwe=iwe+1
      weightb( 29, 58,  3)=                  0.27609264043721432058d0
      iwe=iwe+1
      weightb( 30, 58,  3)=                 -0.31456128622087764501d0
      iwe=iwe+1
      weightb( 31, 58,  3)=                 -0.00340506391669948179d0
      iwe=iwe+1
      weightb( 32, 58,  3)=                  0.33468822314386953432d0
      iwe=iwe+1
      weightb( 33, 58,  3)=                 -0.23913772692635820727d0
      iwe=iwe+1
      weightb( 34, 58,  3)=                 -0.24705769216646719655d0
      iwe=iwe+1
      weightb( 35, 58,  3)=                  0.25871714454400329686d0
      iwe=iwe+1
      weightb( 36, 58,  3)=                  0.24221759197732672941d0
      iwe=iwe+1
      weightb( 37, 58,  3)=                 -0.00533681078916286872d0
      iwe=iwe+1
      weightb( 38, 58,  3)=                 -0.22952378895993205687d0
      iwe=iwe+1
      weightb( 39, 58,  3)=                  0.05275062399131154323d0
      iwe=iwe+1
      weightb( 40, 58,  3)=                  0.19367424318045795006d0
      iwe=iwe+1
      weightb( 41, 58,  3)=                 -0.23502630424654455399d0
      iwe=iwe+1
      weightb( 42, 58,  3)=                  0.27817943115796439635d0
      iwe=iwe+1
      weightb( 43, 58,  3)=                  0.23918711399429262721d0
      iwe=iwe+1
      weightb( 44, 58,  3)=                 -0.12694449883131705969d0
      iwe=iwe+1
      weightb( 45, 58,  3)=                 -0.20891529919352189171d0
      iwe=iwe+1
      weightb( 46, 58,  3)=                 -0.22346662615084228465d0
      iwe=iwe+1
      weightb( 47, 58,  3)=                  0.25751783925779531126d0
      iwe=iwe+1
      weightb( 48, 58,  3)=                 -0.02948313394821553551d0
      iwe=iwe+1
      weightb( 49, 58,  3)=                 -0.14402286771009770172d0
      iwe=iwe+1
      weightb( 50, 58,  3)=                 -0.19593394258642021777d0
      iwe=iwe+1
      biasb( 58,  3)=                  0.68459675836174138652d0
      iwe=iwe+1
      weightb(  1, 59,  3)=                 -0.15347544116938802161d0
      iwe=iwe+1
      weightb(  2, 59,  3)=                  0.53361109003081697022d0
      iwe=iwe+1
      weightb(  3, 59,  3)=                 -0.14854301282696363851d0
      iwe=iwe+1
      weightb(  4, 59,  3)=                  0.17956482727043199255d0
      iwe=iwe+1
      weightb(  5, 59,  3)=                 -0.11755458246303765457d0
      iwe=iwe+1
      weightb(  6, 59,  3)=                  0.24511275777739019444d0
      iwe=iwe+1
      weightb(  7, 59,  3)=                 -0.03523014793758597746d0
      iwe=iwe+1
      weightb(  8, 59,  3)=                  0.27705423391947492373d0
      iwe=iwe+1
      weightb(  9, 59,  3)=                  0.05879472160719786955d0
      iwe=iwe+1
      weightb( 10, 59,  3)=                 -0.02083231427530313207d0
      iwe=iwe+1
      weightb( 11, 59,  3)=                  0.45624942690427766623d0
      iwe=iwe+1
      weightb( 12, 59,  3)=                 -0.36909454065035340875d0
      iwe=iwe+1
      weightb( 13, 59,  3)=                 -0.17781092210157004030d0
      iwe=iwe+1
      weightb( 14, 59,  3)=                 -0.22648906250258446504d0
      iwe=iwe+1
      weightb( 15, 59,  3)=                 -0.29715479383787513079d0
      iwe=iwe+1
      weightb( 16, 59,  3)=                 -0.36567214927216962206d0
      iwe=iwe+1
      weightb( 17, 59,  3)=                  0.25595663769741605620d0
      iwe=iwe+1
      weightb( 18, 59,  3)=                 -0.40235638956397612453d0
      iwe=iwe+1
      weightb( 19, 59,  3)=                  0.16801984839354650036d0
      iwe=iwe+1
      weightb( 20, 59,  3)=                  0.22520326370369750379d0
      iwe=iwe+1
      weightb( 21, 59,  3)=                 -0.41986659334139059263d0
      iwe=iwe+1
      weightb( 22, 59,  3)=                 -0.23412621369069111510d0
      iwe=iwe+1
      weightb( 23, 59,  3)=                  0.01808325479831651011d0
      iwe=iwe+1
      weightb( 24, 59,  3)=                 -0.29207733510369537910d0
      iwe=iwe+1
      weightb( 25, 59,  3)=                  0.05926902685970557999d0
      iwe=iwe+1
      weightb( 26, 59,  3)=                  0.03066125045581455724d0
      iwe=iwe+1
      weightb( 27, 59,  3)=                  0.20141329371314437013d0
      iwe=iwe+1
      weightb( 28, 59,  3)=                 -0.04662523055800383426d0
      iwe=iwe+1
      weightb( 29, 59,  3)=                 -0.36392592497214676373d0
      iwe=iwe+1
      weightb( 30, 59,  3)=                  0.11991569819490989490d0
      iwe=iwe+1
      weightb( 31, 59,  3)=                  0.64011196377510637401d0
      iwe=iwe+1
      weightb( 32, 59,  3)=                 -0.31040367416618869223d0
      iwe=iwe+1
      weightb( 33, 59,  3)=                 -0.23819314040893133089d0
      iwe=iwe+1
      weightb( 34, 59,  3)=                 -0.01710790039590171299d0
      iwe=iwe+1
      weightb( 35, 59,  3)=                 -0.46032596587609136973d0
      iwe=iwe+1
      weightb( 36, 59,  3)=                 -0.15162081862765855456d0
      iwe=iwe+1
      weightb( 37, 59,  3)=                  0.02802258297404919968d0
      iwe=iwe+1
      weightb( 38, 59,  3)=                  0.19226505627927803488d0
      iwe=iwe+1
      weightb( 39, 59,  3)=                 -0.33202411088800293237d0
      iwe=iwe+1
      weightb( 40, 59,  3)=                 -0.74575696114831757644d0
      iwe=iwe+1
      weightb( 41, 59,  3)=                  0.06874510709398051755d0
      iwe=iwe+1
      weightb( 42, 59,  3)=                 -0.29672571121814822481d0
      iwe=iwe+1
      weightb( 43, 59,  3)=                 -0.01039127863307381765d0
      iwe=iwe+1
      weightb( 44, 59,  3)=                 -0.21458722342414349171d0
      iwe=iwe+1
      weightb( 45, 59,  3)=                  0.04784620415311510028d0
      iwe=iwe+1
      weightb( 46, 59,  3)=                 -0.24539241378643508740d0
      iwe=iwe+1
      weightb( 47, 59,  3)=                  0.11340870552784086678d0
      iwe=iwe+1
      weightb( 48, 59,  3)=                 -0.02145072820025824972d0
      iwe=iwe+1
      weightb( 49, 59,  3)=                  0.22205686431474391807d0
      iwe=iwe+1
      weightb( 50, 59,  3)=                 -0.01305776680950222583d0
      iwe=iwe+1
      biasb( 59,  3)=                 -0.80442167967561661879d0
      iwe=iwe+1
      weightb(  1, 60,  3)=                  1.00100769035139269825d0
      iwe=iwe+1
      weightb(  2, 60,  3)=                  0.89504968636273407601d0
      iwe=iwe+1
      weightb(  3, 60,  3)=                  0.14240864221010596236d0
      iwe=iwe+1
      weightb(  4, 60,  3)=                 -0.92298372956461283145d0
      iwe=iwe+1
      weightb(  5, 60,  3)=                 -0.94053953254247280036d0
      iwe=iwe+1
      weightb(  6, 60,  3)=                 -0.00090845310572119919d0
      iwe=iwe+1
      weightb(  7, 60,  3)=                  0.49126548515058360289d0
      iwe=iwe+1
      weightb(  8, 60,  3)=                  0.07357468384068244216d0
      iwe=iwe+1
      weightb(  9, 60,  3)=                  0.01432703088301027182d0
      iwe=iwe+1
      weightb( 10, 60,  3)=                  0.21379969850524943586d0
      iwe=iwe+1
      weightb( 11, 60,  3)=                 -0.03793969904279281824d0
      iwe=iwe+1
      weightb( 12, 60,  3)=                  0.54386936306570687893d0
      iwe=iwe+1
      weightb( 13, 60,  3)=                  0.02387760995751909282d0
      iwe=iwe+1
      weightb( 14, 60,  3)=                  0.06148797216609763056d0
      iwe=iwe+1
      weightb( 15, 60,  3)=                  0.45384696846612287979d0
      iwe=iwe+1
      weightb( 16, 60,  3)=                  0.20070937877083774858d0
      iwe=iwe+1
      weightb( 17, 60,  3)=                 -0.12091118204621724430d0
      iwe=iwe+1
      weightb( 18, 60,  3)=                  0.68429210602901480165d0
      iwe=iwe+1
      weightb( 19, 60,  3)=                  0.16946909755045189150d0
      iwe=iwe+1
      weightb( 20, 60,  3)=                  0.58009646118697011374d0
      iwe=iwe+1
      weightb( 21, 60,  3)=                 -1.16335316461823445877d0
      iwe=iwe+1
      weightb( 22, 60,  3)=                 -0.33041292145302375571d0
      iwe=iwe+1
      weightb( 23, 60,  3)=                 -0.49109306777176042758d0
      iwe=iwe+1
      weightb( 24, 60,  3)=                  0.56540161505596076008d0
      iwe=iwe+1
      weightb( 25, 60,  3)=                 -0.10024275717813850572d0
      iwe=iwe+1
      weightb( 26, 60,  3)=                 -0.49864861387968545392d0
      iwe=iwe+1
      weightb( 27, 60,  3)=                  0.74186361499115527351d0
      iwe=iwe+1
      weightb( 28, 60,  3)=                 -0.39937858626477729107d0
      iwe=iwe+1
      weightb( 29, 60,  3)=                  0.24593986958197605608d0
      iwe=iwe+1
      weightb( 30, 60,  3)=                  0.02682735646818427272d0
      iwe=iwe+1
      weightb( 31, 60,  3)=                  0.13861994506511240988d0
      iwe=iwe+1
      weightb( 32, 60,  3)=                 -0.05849802970301803962d0
      iwe=iwe+1
      weightb( 33, 60,  3)=                 -0.27600888266057210796d0
      iwe=iwe+1
      weightb( 34, 60,  3)=                 -0.75062840111825857026d0
      iwe=iwe+1
      weightb( 35, 60,  3)=                  0.29497548090106551211d0
      iwe=iwe+1
      weightb( 36, 60,  3)=                 -0.07878922135747841449d0
      iwe=iwe+1
      weightb( 37, 60,  3)=                  0.56339880569306188818d0
      iwe=iwe+1
      weightb( 38, 60,  3)=                  0.97918033492614742208d0
      iwe=iwe+1
      weightb( 39, 60,  3)=                  0.21363263069774152125d0
      iwe=iwe+1
      weightb( 40, 60,  3)=                  0.34028588713416990652d0
      iwe=iwe+1
      weightb( 41, 60,  3)=                 -0.71324473979166813642d0
      iwe=iwe+1
      weightb( 42, 60,  3)=                  0.14837875340429187987d0
      iwe=iwe+1
      weightb( 43, 60,  3)=                 -0.12842835679377506697d0
      iwe=iwe+1
      weightb( 44, 60,  3)=                 -0.41151421539979038400d0
      iwe=iwe+1
      weightb( 45, 60,  3)=                 -0.31327777314140065057d0
      iwe=iwe+1
      weightb( 46, 60,  3)=                 -0.26114825738256103316d0
      iwe=iwe+1
      weightb( 47, 60,  3)=                  0.00451598178308580071d0
      iwe=iwe+1
      weightb( 48, 60,  3)=                 -0.36015869141305212331d0
      iwe=iwe+1
      weightb( 49, 60,  3)=                 -0.32930804854012851735d0
      iwe=iwe+1
      weightb( 50, 60,  3)=                 -0.66074087407142068074d0
      iwe=iwe+1
      biasb( 60,  3)=                  0.65833004837440711743d0
      iwe=iwe+1
      weightb(  1, 61,  3)=                  0.29706904846646936535d0
      iwe=iwe+1
      weightb(  2, 61,  3)=                  0.30499884946842070743d0
      iwe=iwe+1
      weightb(  3, 61,  3)=                 -0.32101803725523264665d0
      iwe=iwe+1
      weightb(  4, 61,  3)=                  0.39247243541411913625d0
      iwe=iwe+1
      weightb(  5, 61,  3)=                 -0.04347925922777834407d0
      iwe=iwe+1
      weightb(  6, 61,  3)=                  0.16941342211670060158d0
      iwe=iwe+1
      weightb(  7, 61,  3)=                  0.42406955240849525390d0
      iwe=iwe+1
      weightb(  8, 61,  3)=                  0.16428825749857020599d0
      iwe=iwe+1
      weightb(  9, 61,  3)=                  0.00298636425431996356d0
      iwe=iwe+1
      weightb( 10, 61,  3)=                 -0.33395574258572835458d0
      iwe=iwe+1
      weightb( 11, 61,  3)=                  0.29614224949036227486d0
      iwe=iwe+1
      weightb( 12, 61,  3)=                  0.09174707039438348422d0
      iwe=iwe+1
      weightb( 13, 61,  3)=                  0.08723626844749494957d0
      iwe=iwe+1
      weightb( 14, 61,  3)=                  0.24775237374750427866d0
      iwe=iwe+1
      weightb( 15, 61,  3)=                 -0.13214070851745290947d0
      iwe=iwe+1
      weightb( 16, 61,  3)=                  0.19967968674450967126d0
      iwe=iwe+1
      weightb( 17, 61,  3)=                 -0.04823749512589801947d0
      iwe=iwe+1
      weightb( 18, 61,  3)=                 -0.15148008445461541571d0
      iwe=iwe+1
      weightb( 19, 61,  3)=                 -0.22389166396032292305d0
      iwe=iwe+1
      weightb( 20, 61,  3)=                  0.05535609308362885589d0
      iwe=iwe+1
      weightb( 21, 61,  3)=                 -0.00581614548682000965d0
      iwe=iwe+1
      weightb( 22, 61,  3)=                  0.05526626939676772959d0
      iwe=iwe+1
      weightb( 23, 61,  3)=                 -0.23814866658090025342d0
      iwe=iwe+1
      weightb( 24, 61,  3)=                  0.00987487483355501024d0
      iwe=iwe+1
      weightb( 25, 61,  3)=                 -0.08882682045737815002d0
      iwe=iwe+1
      weightb( 26, 61,  3)=                 -0.22671498522709265799d0
      iwe=iwe+1
      weightb( 27, 61,  3)=                  0.01194915993008844983d0
      iwe=iwe+1
      weightb( 28, 61,  3)=                  0.24826266504027547088d0
      iwe=iwe+1
      weightb( 29, 61,  3)=                 -0.30277582262662389168d0
      iwe=iwe+1
      weightb( 30, 61,  3)=                 -0.24979077131595819883d0
      iwe=iwe+1
      weightb( 31, 61,  3)=                  0.39294860832082784130d0
      iwe=iwe+1
      weightb( 32, 61,  3)=                 -0.43657750211632440074d0
      iwe=iwe+1
      weightb( 33, 61,  3)=                  0.10027051063493901129d0
      iwe=iwe+1
      weightb( 34, 61,  3)=                  0.11651666979971932181d0
      iwe=iwe+1
      weightb( 35, 61,  3)=                 -0.34128438886261991403d0
      iwe=iwe+1
      weightb( 36, 61,  3)=                  0.38758044376557226895d0
      iwe=iwe+1
      weightb( 37, 61,  3)=                 -0.07441930428666233832d0
      iwe=iwe+1
      weightb( 38, 61,  3)=                  0.13604383297845842882d0
      iwe=iwe+1
      weightb( 39, 61,  3)=                 -0.13969195517898314041d0
      iwe=iwe+1
      weightb( 40, 61,  3)=                 -0.37175219794136710183d0
      iwe=iwe+1
      weightb( 41, 61,  3)=                 -0.30260774920308292080d0
      iwe=iwe+1
      weightb( 42, 61,  3)=                 -0.43312941854941183761d0
      iwe=iwe+1
      weightb( 43, 61,  3)=                  0.14610827250264524224d0
      iwe=iwe+1
      weightb( 44, 61,  3)=                  0.33232841675579177787d0
      iwe=iwe+1
      weightb( 45, 61,  3)=                  0.10113479536405230175d0
      iwe=iwe+1
      weightb( 46, 61,  3)=                 -0.01362015549775251466d0
      iwe=iwe+1
      weightb( 47, 61,  3)=                 -0.34918431411637795847d0
      iwe=iwe+1
      weightb( 48, 61,  3)=                 -0.12554402152032487217d0
      iwe=iwe+1
      weightb( 49, 61,  3)=                 -0.25708869662012601154d0
      iwe=iwe+1
      weightb( 50, 61,  3)=                 -0.15580306301295354654d0
      iwe=iwe+1
      biasb( 61,  3)=                  0.77709565226821475381d0
      iwe=iwe+1
      weightb(  1, 62,  3)=                 -0.39291905394362108828d0
      iwe=iwe+1
      weightb(  2, 62,  3)=                 -0.38407337461333751483d0
      iwe=iwe+1
      weightb(  3, 62,  3)=                 -0.01472872170360604339d0
      iwe=iwe+1
      weightb(  4, 62,  3)=                  0.08342668677001509325d0
      iwe=iwe+1
      weightb(  5, 62,  3)=                 -0.07874190506529211986d0
      iwe=iwe+1
      weightb(  6, 62,  3)=                  0.36579818950952974754d0
      iwe=iwe+1
      weightb(  7, 62,  3)=                  0.07553481325174654648d0
      iwe=iwe+1
      weightb(  8, 62,  3)=                 -0.06172001459965081177d0
      iwe=iwe+1
      weightb(  9, 62,  3)=                 -0.02577204241608846771d0
      iwe=iwe+1
      weightb( 10, 62,  3)=                 -0.03087116244876576127d0
      iwe=iwe+1
      weightb( 11, 62,  3)=                  0.27654096461946209295d0
      iwe=iwe+1
      weightb( 12, 62,  3)=                  0.23759579098843602862d0
      iwe=iwe+1
      weightb( 13, 62,  3)=                 -0.37200071339116547176d0
      iwe=iwe+1
      weightb( 14, 62,  3)=                  0.26561254937188139014d0
      iwe=iwe+1
      weightb( 15, 62,  3)=                 -0.06100968063884756876d0
      iwe=iwe+1
      weightb( 16, 62,  3)=                  0.10476433039851958118d0
      iwe=iwe+1
      weightb( 17, 62,  3)=                  0.11166383041824327893d0
      iwe=iwe+1
      weightb( 18, 62,  3)=                 -0.40044893156521776945d0
      iwe=iwe+1
      weightb( 19, 62,  3)=                 -0.14156836949985976415d0
      iwe=iwe+1
      weightb( 20, 62,  3)=                 -0.24101997346279369072d0
      iwe=iwe+1
      weightb( 21, 62,  3)=                  0.37897762375318155836d0
      iwe=iwe+1
      weightb( 22, 62,  3)=                  0.31494364020771575818d0
      iwe=iwe+1
      weightb( 23, 62,  3)=                  0.30130700493206774571d0
      iwe=iwe+1
      weightb( 24, 62,  3)=                 -0.25409899602957164433d0
      iwe=iwe+1
      weightb( 25, 62,  3)=                 -0.37107744308019080526d0
      iwe=iwe+1
      weightb( 26, 62,  3)=                 -0.31559428218277219003d0
      iwe=iwe+1
      weightb( 27, 62,  3)=                 -0.01296651425226486368d0
      iwe=iwe+1
      weightb( 28, 62,  3)=                 -0.31055749775446261918d0
      iwe=iwe+1
      weightb( 29, 62,  3)=                  0.13871977675937038899d0
      iwe=iwe+1
      weightb( 30, 62,  3)=                 -0.08120081094514224052d0
      iwe=iwe+1
      weightb( 31, 62,  3)=                  0.17879289401548334459d0
      iwe=iwe+1
      weightb( 32, 62,  3)=                  0.06510164942585337788d0
      iwe=iwe+1
      weightb( 33, 62,  3)=                 -0.18384441896894021529d0
      iwe=iwe+1
      weightb( 34, 62,  3)=                 -0.38833622874896078780d0
      iwe=iwe+1
      weightb( 35, 62,  3)=                  0.14810396021683808199d0
      iwe=iwe+1
      weightb( 36, 62,  3)=                 -0.21198638051497115109d0
      iwe=iwe+1
      weightb( 37, 62,  3)=                  0.16778410585717390413d0
      iwe=iwe+1
      weightb( 38, 62,  3)=                  0.21651568719196109813d0
      iwe=iwe+1
      weightb( 39, 62,  3)=                 -0.24517708072931543306d0
      iwe=iwe+1
      weightb( 40, 62,  3)=                  0.27763152256638146120d0
      iwe=iwe+1
      weightb( 41, 62,  3)=                 -0.26117748559156672705d0
      iwe=iwe+1
      weightb( 42, 62,  3)=                  0.05878247082165541371d0
      iwe=iwe+1
      weightb( 43, 62,  3)=                  0.11826639153705151286d0
      iwe=iwe+1
      weightb( 44, 62,  3)=                 -0.32434236661458049067d0
      iwe=iwe+1
      weightb( 45, 62,  3)=                  0.19039807570851235985d0
      iwe=iwe+1
      weightb( 46, 62,  3)=                  0.28003467229842460284d0
      iwe=iwe+1
      weightb( 47, 62,  3)=                 -0.27421956216599058243d0
      iwe=iwe+1
      weightb( 48, 62,  3)=                  0.28741142554215776128d0
      iwe=iwe+1
      weightb( 49, 62,  3)=                 -0.35079133188952715816d0
      iwe=iwe+1
      weightb( 50, 62,  3)=                 -0.09184451496367793122d0
      iwe=iwe+1
      biasb( 62,  3)=                 -0.85931704937600661420d0
      iwe=iwe+1
      weightb(  1, 63,  3)=                 -0.39629073999641473147d0
      iwe=iwe+1
      weightb(  2, 63,  3)=                 -0.33716485678932889281d0
      iwe=iwe+1
      weightb(  3, 63,  3)=                 -0.46215415919169622327d0
      iwe=iwe+1
      weightb(  4, 63,  3)=                 -0.17815327797399560517d0
      iwe=iwe+1
      weightb(  5, 63,  3)=                  0.19507085961168255106d0
      iwe=iwe+1
      weightb(  6, 63,  3)=                 -0.85108672909381910543d0
      iwe=iwe+1
      weightb(  7, 63,  3)=                 -0.30395682595672690596d0
      iwe=iwe+1
      weightb(  8, 63,  3)=                 -0.04577236959084718393d0
      iwe=iwe+1
      weightb(  9, 63,  3)=                 -0.03464451678305483645d0
      iwe=iwe+1
      weightb( 10, 63,  3)=                 -0.01497584188105744764d0
      iwe=iwe+1
      weightb( 11, 63,  3)=                  0.13786193311739364242d0
      iwe=iwe+1
      weightb( 12, 63,  3)=                 -0.25983197449264799905d0
      iwe=iwe+1
      weightb( 13, 63,  3)=                 -0.51885024548938796229d0
      iwe=iwe+1
      weightb( 14, 63,  3)=                 -0.10259217670329529026d0
      iwe=iwe+1
      weightb( 15, 63,  3)=                 -0.09161150845485781236d0
      iwe=iwe+1
      weightb( 16, 63,  3)=                  0.11549974515760354221d0
      iwe=iwe+1
      weightb( 17, 63,  3)=                 -0.39760475274988693606d0
      iwe=iwe+1
      weightb( 18, 63,  3)=                 -0.22044530455269009672d0
      iwe=iwe+1
      weightb( 19, 63,  3)=                  0.41071839378892399663d0
      iwe=iwe+1
      weightb( 20, 63,  3)=                  0.38615785408572050885d0
      iwe=iwe+1
      weightb( 21, 63,  3)=                 -0.15241033242272983284d0
      iwe=iwe+1
      weightb( 22, 63,  3)=                 -0.24501458627608055374d0
      iwe=iwe+1
      weightb( 23, 63,  3)=                 -0.08607974513786255388d0
      iwe=iwe+1
      weightb( 24, 63,  3)=                  0.02626854495935912470d0
      iwe=iwe+1
      weightb( 25, 63,  3)=                  0.05812257978236338996d0
      iwe=iwe+1
      weightb( 26, 63,  3)=                  0.18529876255459315493d0
      iwe=iwe+1
      weightb( 27, 63,  3)=                 -0.13698192383336085798d0
      iwe=iwe+1
      weightb( 28, 63,  3)=                  0.19126202300764472142d0
      iwe=iwe+1
      weightb( 29, 63,  3)=                  0.09397110210105151518d0
      iwe=iwe+1
      weightb( 30, 63,  3)=                  0.33496617541388745698d0
      iwe=iwe+1
      weightb( 31, 63,  3)=                 -0.17972138924027500351d0
      iwe=iwe+1
      weightb( 32, 63,  3)=                 -0.24171936282826536613d0
      iwe=iwe+1
      weightb( 33, 63,  3)=                 -0.43758025813887008182d0
      iwe=iwe+1
      weightb( 34, 63,  3)=                  0.12455160013431106070d0
      iwe=iwe+1
      weightb( 35, 63,  3)=                  0.04010988208838836555d0
      iwe=iwe+1
      weightb( 36, 63,  3)=                 -0.04572538249399894783d0
      iwe=iwe+1
      weightb( 37, 63,  3)=                 -0.30753711353802359874d0
      iwe=iwe+1
      weightb( 38, 63,  3)=                  0.08908235463157794520d0
      iwe=iwe+1
      weightb( 39, 63,  3)=                  0.24800129602262652173d0
      iwe=iwe+1
      weightb( 40, 63,  3)=                 -0.17182869477305162675d0
      iwe=iwe+1
      weightb( 41, 63,  3)=                 -0.25427677241332424796d0
      iwe=iwe+1
      weightb( 42, 63,  3)=                  0.02486344417384974553d0
      iwe=iwe+1
      weightb( 43, 63,  3)=                  0.22139709296075874012d0
      iwe=iwe+1
      weightb( 44, 63,  3)=                  0.41519681467186220214d0
      iwe=iwe+1
      weightb( 45, 63,  3)=                  0.13710139238495364089d0
      iwe=iwe+1
      weightb( 46, 63,  3)=                  0.36387296402661140071d0
      iwe=iwe+1
      weightb( 47, 63,  3)=                 -0.21062869163440034459d0
      iwe=iwe+1
      weightb( 48, 63,  3)=                 -0.12199679245337449740d0
      iwe=iwe+1
      weightb( 49, 63,  3)=                  0.35329711172182259871d0
      iwe=iwe+1
      weightb( 50, 63,  3)=                  0.19329944372300353339d0
      iwe=iwe+1
      biasb( 63,  3)=                 -0.87496663904840354942d0
      iwe=iwe+1
      weightb(  1, 64,  3)=                  0.41512079375812249715d0
      iwe=iwe+1
      weightb(  2, 64,  3)=                 -0.16569657734899992385d0
      iwe=iwe+1
      weightb(  3, 64,  3)=                 -0.13162980938149992927d0
      iwe=iwe+1
      weightb(  4, 64,  3)=                 -0.10155395233791654486d0
      iwe=iwe+1
      weightb(  5, 64,  3)=                  0.13644302862227336570d0
      iwe=iwe+1
      weightb(  6, 64,  3)=                 -0.09867349748576557944d0
      iwe=iwe+1
      weightb(  7, 64,  3)=                  0.01411381265165521058d0
      iwe=iwe+1
      weightb(  8, 64,  3)=                  0.31814687178151451752d0
      iwe=iwe+1
      weightb(  9, 64,  3)=                  0.31622250109519367545d0
      iwe=iwe+1
      weightb( 10, 64,  3)=                 -0.22986548820251817560d0
      iwe=iwe+1
      weightb( 11, 64,  3)=                  0.19323793354953985868d0
      iwe=iwe+1
      weightb( 12, 64,  3)=                  0.07273202368651310312d0
      iwe=iwe+1
      weightb( 13, 64,  3)=                 -0.03706109361551869485d0
      iwe=iwe+1
      weightb( 14, 64,  3)=                  0.45347048187252025908d0
      iwe=iwe+1
      weightb( 15, 64,  3)=                 -0.11739836791483901357d0
      iwe=iwe+1
      weightb( 16, 64,  3)=                 -0.32974949763161315319d0
      iwe=iwe+1
      weightb( 17, 64,  3)=                 -0.17129789984743534759d0
      iwe=iwe+1
      weightb( 18, 64,  3)=                 -0.30377540891620324892d0
      iwe=iwe+1
      weightb( 19, 64,  3)=                  0.11927865883159287363d0
      iwe=iwe+1
      weightb( 20, 64,  3)=                 -0.19658664963281621829d0
      iwe=iwe+1
      weightb( 21, 64,  3)=                 -0.23564319998770186237d0
      iwe=iwe+1
      weightb( 22, 64,  3)=                 -0.13766438697880550857d0
      iwe=iwe+1
      weightb( 23, 64,  3)=                  0.18441922978176567005d0
      iwe=iwe+1
      weightb( 24, 64,  3)=                 -0.27187046631056299706d0
      iwe=iwe+1
      weightb( 25, 64,  3)=                 -0.35495403058046010036d0
      iwe=iwe+1
      weightb( 26, 64,  3)=                  0.46206449408724425965d0
      iwe=iwe+1
      weightb( 27, 64,  3)=                 -0.68680322894543466283d0
      iwe=iwe+1
      weightb( 28, 64,  3)=                 -0.09278413165584079025d0
      iwe=iwe+1
      weightb( 29, 64,  3)=                 -0.54152004642404460988d0
      iwe=iwe+1
      weightb( 30, 64,  3)=                 -0.41648282426234300990d0
      iwe=iwe+1
      weightb( 31, 64,  3)=                 -0.04299279308880364636d0
      iwe=iwe+1
      weightb( 32, 64,  3)=                 -0.05003118394605100827d0
      iwe=iwe+1
      weightb( 33, 64,  3)=                 -0.12226189113896340777d0
      iwe=iwe+1
      weightb( 34, 64,  3)=                  0.03262779286487015040d0
      iwe=iwe+1
      weightb( 35, 64,  3)=                  0.21216492572834541597d0
      iwe=iwe+1
      weightb( 36, 64,  3)=                 -0.16703066140847064314d0
      iwe=iwe+1
      weightb( 37, 64,  3)=                 -0.00144729676979949567d0
      iwe=iwe+1
      weightb( 38, 64,  3)=                 -0.10920110017123360602d0
      iwe=iwe+1
      weightb( 39, 64,  3)=                  0.25590443240230764665d0
      iwe=iwe+1
      weightb( 40, 64,  3)=                 -0.22789095487541924379d0
      iwe=iwe+1
      weightb( 41, 64,  3)=                 -0.43639532904581229689d0
      iwe=iwe+1
      weightb( 42, 64,  3)=                  0.38506153240328533371d0
      iwe=iwe+1
      weightb( 43, 64,  3)=                  0.01349285805024770177d0
      iwe=iwe+1
      weightb( 44, 64,  3)=                  0.06850885913595539112d0
      iwe=iwe+1
      weightb( 45, 64,  3)=                 -0.32621144614974584286d0
      iwe=iwe+1
      weightb( 46, 64,  3)=                 -0.53043399413160097211d0
      iwe=iwe+1
      weightb( 47, 64,  3)=                 -0.45090207799740350536d0
      iwe=iwe+1
      weightb( 48, 64,  3)=                 -0.35808047753204158559d0
      iwe=iwe+1
      weightb( 49, 64,  3)=                  0.27303651081583579785d0
      iwe=iwe+1
      weightb( 50, 64,  3)=                 -0.40327016071795840357d0
      iwe=iwe+1
      biasb( 64,  3)=                  0.88380513142644723246d0
      iwe=iwe+1
      weightb(  1, 65,  3)=                 -0.15384692204677627436d0
      iwe=iwe+1
      weightb(  2, 65,  3)=                 -0.40101430603538462671d0
      iwe=iwe+1
      weightb(  3, 65,  3)=                  0.22727501596587657007d0
      iwe=iwe+1
      weightb(  4, 65,  3)=                 -0.02038818794374094856d0
      iwe=iwe+1
      weightb(  5, 65,  3)=                  0.53841002781398017429d0
      iwe=iwe+1
      weightb(  6, 65,  3)=                  0.27306950393518319986d0
      iwe=iwe+1
      weightb(  7, 65,  3)=                  0.49158453551434522222d0
      iwe=iwe+1
      weightb(  8, 65,  3)=                  0.12271375940932656434d0
      iwe=iwe+1
      weightb(  9, 65,  3)=                 -0.21241706336537438671d0
      iwe=iwe+1
      weightb( 10, 65,  3)=                  0.19434346288323409158d0
      iwe=iwe+1
      weightb( 11, 65,  3)=                  0.28515109601477173218d0
      iwe=iwe+1
      weightb( 12, 65,  3)=                  0.04625193333708294691d0
      iwe=iwe+1
      weightb( 13, 65,  3)=                 -0.00806331489617734265d0
      iwe=iwe+1
      weightb( 14, 65,  3)=                 -0.17749748223616179654d0
      iwe=iwe+1
      weightb( 15, 65,  3)=                 -0.52771442351629904710d0
      iwe=iwe+1
      weightb( 16, 65,  3)=                 -0.56990119317258758347d0
      iwe=iwe+1
      weightb( 17, 65,  3)=                 -0.14888280513492635482d0
      iwe=iwe+1
      weightb( 18, 65,  3)=                  0.57905254008247419861d0
      iwe=iwe+1
      weightb( 19, 65,  3)=                 -0.01536932993894076123d0
      iwe=iwe+1
      weightb( 20, 65,  3)=                 -0.19099982165465589912d0
      iwe=iwe+1
      weightb( 21, 65,  3)=                 -0.12863661065924825166d0
      iwe=iwe+1
      weightb( 22, 65,  3)=                  0.37657235118780452154d0
      iwe=iwe+1
      weightb( 23, 65,  3)=                 -0.15939669969324676835d0
      iwe=iwe+1
      weightb( 24, 65,  3)=                 -0.15701135896113538326d0
      iwe=iwe+1
      weightb( 25, 65,  3)=                  0.05209576267880051265d0
      iwe=iwe+1
      weightb( 26, 65,  3)=                  0.01399297629359187722d0
      iwe=iwe+1
      weightb( 27, 65,  3)=                  0.49430125930349683161d0
      iwe=iwe+1
      weightb( 28, 65,  3)=                  0.26946341103015175600d0
      iwe=iwe+1
      weightb( 29, 65,  3)=                 -0.46790284056668179913d0
      iwe=iwe+1
      weightb( 30, 65,  3)=                  0.21609859555030289102d0
      iwe=iwe+1
      weightb( 31, 65,  3)=                 -0.08591646977665597096d0
      iwe=iwe+1
      weightb( 32, 65,  3)=                  0.07293227457964775173d0
      iwe=iwe+1
      weightb( 33, 65,  3)=                  0.26010914534513213114d0
      iwe=iwe+1
      weightb( 34, 65,  3)=                  0.07160217644906312351d0
      iwe=iwe+1
      weightb( 35, 65,  3)=                  0.01167565764125294038d0
      iwe=iwe+1
      weightb( 36, 65,  3)=                  0.53301398644133335392d0
      iwe=iwe+1
      weightb( 37, 65,  3)=                  0.26247229223209250781d0
      iwe=iwe+1
      weightb( 38, 65,  3)=                  0.16900139778393899470d0
      iwe=iwe+1
      weightb( 39, 65,  3)=                 -0.43396480835959994060d0
      iwe=iwe+1
      weightb( 40, 65,  3)=                 -0.29508887213692464035d0
      iwe=iwe+1
      weightb( 41, 65,  3)=                  0.18201805553207139887d0
      iwe=iwe+1
      weightb( 42, 65,  3)=                 -0.23103419751881251742d0
      iwe=iwe+1
      weightb( 43, 65,  3)=                 -0.05754768740097539192d0
      iwe=iwe+1
      weightb( 44, 65,  3)=                  0.12860802525961698151d0
      iwe=iwe+1
      weightb( 45, 65,  3)=                 -0.37282943075963426161d0
      iwe=iwe+1
      weightb( 46, 65,  3)=                  0.01938802849998794500d0
      iwe=iwe+1
      weightb( 47, 65,  3)=                 -0.02751409542603229508d0
      iwe=iwe+1
      weightb( 48, 65,  3)=                  0.08458637949059968908d0
      iwe=iwe+1
      weightb( 49, 65,  3)=                  0.06139141180604771458d0
      iwe=iwe+1
      weightb( 50, 65,  3)=                  0.08091545839691410835d0
      iwe=iwe+1
      biasb( 65,  3)=                  1.00220974938694307177d0
      iwe=iwe+1
      weightb(  1, 66,  3)=                  0.07373869064067516133d0
      iwe=iwe+1
      weightb(  2, 66,  3)=                  0.46119517031688561648d0
      iwe=iwe+1
      weightb(  3, 66,  3)=                 -0.14594931909276623316d0
      iwe=iwe+1
      weightb(  4, 66,  3)=                 -0.21268044081649953303d0
      iwe=iwe+1
      weightb(  5, 66,  3)=                 -0.25152146609045378245d0
      iwe=iwe+1
      weightb(  6, 66,  3)=                 -0.20905318811970918791d0
      iwe=iwe+1
      weightb(  7, 66,  3)=                  0.22503138859006502348d0
      iwe=iwe+1
      weightb(  8, 66,  3)=                  0.14888997990919183856d0
      iwe=iwe+1
      weightb(  9, 66,  3)=                 -0.14346349921273068850d0
      iwe=iwe+1
      weightb( 10, 66,  3)=                  0.40459137282001927938d0
      iwe=iwe+1
      weightb( 11, 66,  3)=                 -0.03139928259753586165d0
      iwe=iwe+1
      weightb( 12, 66,  3)=                  0.26741612104086459611d0
      iwe=iwe+1
      weightb( 13, 66,  3)=                 -0.37637680868545120294d0
      iwe=iwe+1
      weightb( 14, 66,  3)=                  0.28501748392610387617d0
      iwe=iwe+1
      weightb( 15, 66,  3)=                 -0.34778004139626439439d0
      iwe=iwe+1
      weightb( 16, 66,  3)=                 -0.19399520650578697123d0
      iwe=iwe+1
      weightb( 17, 66,  3)=                  0.05250402652565217682d0
      iwe=iwe+1
      weightb( 18, 66,  3)=                  0.20130018600743435075d0
      iwe=iwe+1
      weightb( 19, 66,  3)=                 -0.37255726575809883228d0
      iwe=iwe+1
      weightb( 20, 66,  3)=                  0.09423398539053193246d0
      iwe=iwe+1
      weightb( 21, 66,  3)=                 -0.18106259235341443103d0
      iwe=iwe+1
      weightb( 22, 66,  3)=                  0.01158370878910949808d0
      iwe=iwe+1
      weightb( 23, 66,  3)=                 -0.07508623265908487276d0
      iwe=iwe+1
      weightb( 24, 66,  3)=                 -0.16227814987220112730d0
      iwe=iwe+1
      weightb( 25, 66,  3)=                  0.08517813878491216351d0
      iwe=iwe+1
      weightb( 26, 66,  3)=                  0.14299373439546420039d0
      iwe=iwe+1
      weightb( 27, 66,  3)=                 -0.09196696849967438137d0
      iwe=iwe+1
      weightb( 28, 66,  3)=                 -0.16172936576209617776d0
      iwe=iwe+1
      weightb( 29, 66,  3)=                 -0.35819819983002765262d0
      iwe=iwe+1
      weightb( 30, 66,  3)=                  0.34390793621116994006d0
      iwe=iwe+1
      weightb( 31, 66,  3)=                  0.06926405469615808108d0
      iwe=iwe+1
      weightb( 32, 66,  3)=                 -0.14425245409242096195d0
      iwe=iwe+1
      weightb( 33, 66,  3)=                 -0.24380194917857053727d0
      iwe=iwe+1
      weightb( 34, 66,  3)=                  0.09994405218686108761d0
      iwe=iwe+1
      weightb( 35, 66,  3)=                  0.29348299518199721936d0
      iwe=iwe+1
      weightb( 36, 66,  3)=                 -0.34504130729925019949d0
      iwe=iwe+1
      weightb( 37, 66,  3)=                  0.54519034100569152557d0
      iwe=iwe+1
      weightb( 38, 66,  3)=                  0.17681541814239570831d0
      iwe=iwe+1
      weightb( 39, 66,  3)=                 -0.15555385070349245225d0
      iwe=iwe+1
      weightb( 40, 66,  3)=                 -0.20138255096418711254d0
      iwe=iwe+1
      weightb( 41, 66,  3)=                 -0.38852078058025601992d0
      iwe=iwe+1
      weightb( 42, 66,  3)=                 -0.18988189403511820941d0
      iwe=iwe+1
      weightb( 43, 66,  3)=                  0.10367219574132295612d0
      iwe=iwe+1
      weightb( 44, 66,  3)=                  0.42457729552022088759d0
      iwe=iwe+1
      weightb( 45, 66,  3)=                  0.00841932133251831714d0
      iwe=iwe+1
      weightb( 46, 66,  3)=                 -0.04490090764794322370d0
      iwe=iwe+1
      weightb( 47, 66,  3)=                 -0.12878912388669164213d0
      iwe=iwe+1
      weightb( 48, 66,  3)=                 -0.15758210515631504434d0
      iwe=iwe+1
      weightb( 49, 66,  3)=                  0.00705419356681840325d0
      iwe=iwe+1
      weightb( 50, 66,  3)=                  0.03008950598578438371d0
      iwe=iwe+1
      biasb( 66,  3)=                  1.07408522087450997162d0
      iwe=iwe+1
      weightb(  1, 67,  3)=                 -0.10512679450504436307d0
      iwe=iwe+1
      weightb(  2, 67,  3)=                  0.57727825999796333889d0
      iwe=iwe+1
      weightb(  3, 67,  3)=                  0.26881544051787231719d0
      iwe=iwe+1
      weightb(  4, 67,  3)=                 -0.23002975349137710914d0
      iwe=iwe+1
      weightb(  5, 67,  3)=                  0.12954072389569665225d0
      iwe=iwe+1
      weightb(  6, 67,  3)=                  0.38213120513382842214d0
      iwe=iwe+1
      weightb(  7, 67,  3)=                  0.31441331050828774663d0
      iwe=iwe+1
      weightb(  8, 67,  3)=                 -0.00397506883859519416d0
      iwe=iwe+1
      weightb(  9, 67,  3)=                  0.43598058706384629213d0
      iwe=iwe+1
      weightb( 10, 67,  3)=                 -0.31788393501704026445d0
      iwe=iwe+1
      weightb( 11, 67,  3)=                  0.17711198043146059167d0
      iwe=iwe+1
      weightb( 12, 67,  3)=                  0.67488868609562135958d0
      iwe=iwe+1
      weightb( 13, 67,  3)=                 -0.22142846518270467571d0
      iwe=iwe+1
      weightb( 14, 67,  3)=                 -0.31806002192079024793d0
      iwe=iwe+1
      weightb( 15, 67,  3)=                 -0.03295831390874432582d0
      iwe=iwe+1
      weightb( 16, 67,  3)=                 -0.31362201361644570508d0
      iwe=iwe+1
      weightb( 17, 67,  3)=                 -0.04104865563855527449d0
      iwe=iwe+1
      weightb( 18, 67,  3)=                 -0.28467296340759329354d0
      iwe=iwe+1
      weightb( 19, 67,  3)=                 -0.44806881102009404882d0
      iwe=iwe+1
      weightb( 20, 67,  3)=                  0.01840928527915711849d0
      iwe=iwe+1
      weightb( 21, 67,  3)=                 -0.11633955851236221779d0
      iwe=iwe+1
      weightb( 22, 67,  3)=                 -0.20298953221571183758d0
      iwe=iwe+1
      weightb( 23, 67,  3)=                 -0.03042037122438227478d0
      iwe=iwe+1
      weightb( 24, 67,  3)=                  0.58043523981943057066d0
      iwe=iwe+1
      weightb( 25, 67,  3)=                  0.15480426197918659148d0
      iwe=iwe+1
      weightb( 26, 67,  3)=                  0.85775421597063250534d0
      iwe=iwe+1
      weightb( 27, 67,  3)=                 -0.29457417194532192761d0
      iwe=iwe+1
      weightb( 28, 67,  3)=                 -0.02958967584243651222d0
      iwe=iwe+1
      weightb( 29, 67,  3)=                  0.33087035288165866920d0
      iwe=iwe+1
      weightb( 30, 67,  3)=                 -0.05067984710324776459d0
      iwe=iwe+1
      weightb( 31, 67,  3)=                 -0.39614790811971534179d0
      iwe=iwe+1
      weightb( 32, 67,  3)=                 -0.02733236419438433290d0
      iwe=iwe+1
      weightb( 33, 67,  3)=                  0.08545098038217222025d0
      iwe=iwe+1
      weightb( 34, 67,  3)=                  0.09124599252586605702d0
      iwe=iwe+1
      weightb( 35, 67,  3)=                  0.22065726561447462917d0
      iwe=iwe+1
      weightb( 36, 67,  3)=                 -0.32090161967652197639d0
      iwe=iwe+1
      weightb( 37, 67,  3)=                 -0.38283663537641204888d0
      iwe=iwe+1
      weightb( 38, 67,  3)=                 -0.02695619064625308717d0
      iwe=iwe+1
      weightb( 39, 67,  3)=                 -0.22904936276082243918d0
      iwe=iwe+1
      weightb( 40, 67,  3)=                  0.08991133554607480538d0
      iwe=iwe+1
      weightb( 41, 67,  3)=                 -0.24032823132245945130d0
      iwe=iwe+1
      weightb( 42, 67,  3)=                 -0.14141296394991503815d0
      iwe=iwe+1
      weightb( 43, 67,  3)=                 -0.01850745202631627617d0
      iwe=iwe+1
      weightb( 44, 67,  3)=                 -0.41120226205874671477d0
      iwe=iwe+1
      weightb( 45, 67,  3)=                 -0.08242848952828774056d0
      iwe=iwe+1
      weightb( 46, 67,  3)=                 -0.10450533032379057119d0
      iwe=iwe+1
      weightb( 47, 67,  3)=                 -0.02143033022665169485d0
      iwe=iwe+1
      weightb( 48, 67,  3)=                  0.44168052261239371115d0
      iwe=iwe+1
      weightb( 49, 67,  3)=                 -0.29361649050924498727d0
      iwe=iwe+1
      weightb( 50, 67,  3)=                  0.36960961814759435429d0
      iwe=iwe+1
      biasb( 67,  3)=                  1.03358908801578452952d0
      iwe=iwe+1
      weightb(  1, 68,  3)=                 -0.25065679612344460292d0
      iwe=iwe+1
      weightb(  2, 68,  3)=                  0.50447756372005947423d0
      iwe=iwe+1
      weightb(  3, 68,  3)=                 -0.43491405623866008501d0
      iwe=iwe+1
      weightb(  4, 68,  3)=                  0.08317644040404663375d0
      iwe=iwe+1
      weightb(  5, 68,  3)=                  0.46244240121737834048d0
      iwe=iwe+1
      weightb(  6, 68,  3)=                 -0.26185486055524703763d0
      iwe=iwe+1
      weightb(  7, 68,  3)=                  0.30170345815912347209d0
      iwe=iwe+1
      weightb(  8, 68,  3)=                  0.19064691569581537767d0
      iwe=iwe+1
      weightb(  9, 68,  3)=                  0.34051982310721362612d0
      iwe=iwe+1
      weightb( 10, 68,  3)=                  0.07060897606437126217d0
      iwe=iwe+1
      weightb( 11, 68,  3)=                  0.12935604688027660392d0
      iwe=iwe+1
      weightb( 12, 68,  3)=                 -0.24890323123044125198d0
      iwe=iwe+1
      weightb( 13, 68,  3)=                 -0.06750596063683193815d0
      iwe=iwe+1
      weightb( 14, 68,  3)=                 -0.51162232706514954028d0
      iwe=iwe+1
      weightb( 15, 68,  3)=                 -0.13288413352333972028d0
      iwe=iwe+1
      weightb( 16, 68,  3)=                 -0.12881025558125322461d0
      iwe=iwe+1
      weightb( 17, 68,  3)=                 -0.20668917031931705042d0
      iwe=iwe+1
      weightb( 18, 68,  3)=                  0.25129553260613601839d0
      iwe=iwe+1
      weightb( 19, 68,  3)=                 -0.07135043969482310344d0
      iwe=iwe+1
      weightb( 20, 68,  3)=                  0.07891028604996914997d0
      iwe=iwe+1
      weightb( 21, 68,  3)=                 -0.09393833049462388396d0
      iwe=iwe+1
      weightb( 22, 68,  3)=                  0.12556031525415584094d0
      iwe=iwe+1
      weightb( 23, 68,  3)=                 -0.73719600203607471567d0
      iwe=iwe+1
      weightb( 24, 68,  3)=                 -0.66946802242026759444d0
      iwe=iwe+1
      weightb( 25, 68,  3)=                 -0.08983631334922138889d0
      iwe=iwe+1
      weightb( 26, 68,  3)=                  0.26763096088267951389d0
      iwe=iwe+1
      weightb( 27, 68,  3)=                  0.04634713296198117449d0
      iwe=iwe+1
      weightb( 28, 68,  3)=                  0.21912953337346097182d0
      iwe=iwe+1
      weightb( 29, 68,  3)=                  0.02814539438177685732d0
      iwe=iwe+1
      weightb( 30, 68,  3)=                 -0.05209380808630276194d0
      iwe=iwe+1
      weightb( 31, 68,  3)=                 -0.15069308416649057625d0
      iwe=iwe+1
      weightb( 32, 68,  3)=                  0.31810026606764513213d0
      iwe=iwe+1
      weightb( 33, 68,  3)=                  0.21369923598145540433d0
      iwe=iwe+1
      weightb( 34, 68,  3)=                  0.10535109959662225521d0
      iwe=iwe+1
      weightb( 35, 68,  3)=                  0.40314451345658369741d0
      iwe=iwe+1
      weightb( 36, 68,  3)=                 -0.10385945020140524564d0
      iwe=iwe+1
      weightb( 37, 68,  3)=                 -0.24584625529467088456d0
      iwe=iwe+1
      weightb( 38, 68,  3)=                  0.10074652139930415085d0
      iwe=iwe+1
      weightb( 39, 68,  3)=                  0.36554996554363744510d0
      iwe=iwe+1
      weightb( 40, 68,  3)=                 -0.06508634188951967214d0
      iwe=iwe+1
      weightb( 41, 68,  3)=                  0.45526760606536426090d0
      iwe=iwe+1
      weightb( 42, 68,  3)=                  0.28429072022670986986d0
      iwe=iwe+1
      weightb( 43, 68,  3)=                  0.04219226677747112131d0
      iwe=iwe+1
      weightb( 44, 68,  3)=                 -0.05389501410723822328d0
      iwe=iwe+1
      weightb( 45, 68,  3)=                 -0.24192717021646736875d0
      iwe=iwe+1
      weightb( 46, 68,  3)=                  0.18990972644697357019d0
      iwe=iwe+1
      weightb( 47, 68,  3)=                 -0.76158033740010833146d0
      iwe=iwe+1
      weightb( 48, 68,  3)=                 -0.46683166119915159298d0
      iwe=iwe+1
      weightb( 49, 68,  3)=                 -0.33838704216644938105d0
      iwe=iwe+1
      weightb( 50, 68,  3)=                 -0.14242124045865248161d0
      iwe=iwe+1
      biasb( 68,  3)=                  0.83189639265008319402d0
      iwe=iwe+1
      weightb(  1, 69,  3)=                  0.10818889740729256688d0
      iwe=iwe+1
      weightb(  2, 69,  3)=                 -0.09718844745228387427d0
      iwe=iwe+1
      weightb(  3, 69,  3)=                 -0.14078813174673163178d0
      iwe=iwe+1
      weightb(  4, 69,  3)=                 -0.04756147095448166190d0
      iwe=iwe+1
      weightb(  5, 69,  3)=                  0.00556438868823043876d0
      iwe=iwe+1
      weightb(  6, 69,  3)=                 -0.27251731143704194249d0
      iwe=iwe+1
      weightb(  7, 69,  3)=                  0.39891427641965082618d0
      iwe=iwe+1
      weightb(  8, 69,  3)=                 -0.17120152398204632749d0
      iwe=iwe+1
      weightb(  9, 69,  3)=                 -0.17536184711575975026d0
      iwe=iwe+1
      weightb( 10, 69,  3)=                 -0.26029319179569093690d0
      iwe=iwe+1
      weightb( 11, 69,  3)=                 -0.04892533454852135422d0
      iwe=iwe+1
      weightb( 12, 69,  3)=                 -0.07432031726213619849d0
      iwe=iwe+1
      weightb( 13, 69,  3)=                  0.14199193829368728093d0
      iwe=iwe+1
      weightb( 14, 69,  3)=                 -0.37314466035557586343d0
      iwe=iwe+1
      weightb( 15, 69,  3)=                 -0.09453307211545207422d0
      iwe=iwe+1
      weightb( 16, 69,  3)=                  0.13505019599451781320d0
      iwe=iwe+1
      weightb( 17, 69,  3)=                  0.15799405077908498796d0
      iwe=iwe+1
      weightb( 18, 69,  3)=                  0.11571802687833949996d0
      iwe=iwe+1
      weightb( 19, 69,  3)=                  0.34324502442905335808d0
      iwe=iwe+1
      weightb( 20, 69,  3)=                 -0.23861754509553223524d0
      iwe=iwe+1
      weightb( 21, 69,  3)=                 -0.34109536119796513010d0
      iwe=iwe+1
      weightb( 22, 69,  3)=                 -0.07592291999583133943d0
      iwe=iwe+1
      weightb( 23, 69,  3)=                 -0.31437132736485862150d0
      iwe=iwe+1
      weightb( 24, 69,  3)=                  0.22541159067824365070d0
      iwe=iwe+1
      weightb( 25, 69,  3)=                  0.11283363072872068522d0
      iwe=iwe+1
      weightb( 26, 69,  3)=                 -0.28019488929527908150d0
      iwe=iwe+1
      weightb( 27, 69,  3)=                 -0.29529500352775078786d0
      iwe=iwe+1
      weightb( 28, 69,  3)=                  0.18902143513175734268d0
      iwe=iwe+1
      weightb( 29, 69,  3)=                 -0.02313961848705847757d0
      iwe=iwe+1
      weightb( 30, 69,  3)=                 -0.06565689198469387700d0
      iwe=iwe+1
      weightb( 31, 69,  3)=                  0.47111491680853656572d0
      iwe=iwe+1
      weightb( 32, 69,  3)=                  0.48103646724318965822d0
      iwe=iwe+1
      weightb( 33, 69,  3)=                  0.01400312777998015401d0
      iwe=iwe+1
      weightb( 34, 69,  3)=                  0.25266924926231892901d0
      iwe=iwe+1
      weightb( 35, 69,  3)=                  0.27363900641997473961d0
      iwe=iwe+1
      weightb( 36, 69,  3)=                 -0.18365332442122958567d0
      iwe=iwe+1
      weightb( 37, 69,  3)=                 -0.09350727737567714193d0
      iwe=iwe+1
      weightb( 38, 69,  3)=                  0.14800719310665785833d0
      iwe=iwe+1
      weightb( 39, 69,  3)=                  0.26769098634080806809d0
      iwe=iwe+1
      weightb( 40, 69,  3)=                  0.37858510711455939379d0
      iwe=iwe+1
      weightb( 41, 69,  3)=                  0.25200624023858125833d0
      iwe=iwe+1
      weightb( 42, 69,  3)=                 -0.44816493054207479085d0
      iwe=iwe+1
      weightb( 43, 69,  3)=                 -0.28408535205551455061d0
      iwe=iwe+1
      weightb( 44, 69,  3)=                  0.16179674647331737658d0
      iwe=iwe+1
      weightb( 45, 69,  3)=                 -0.10237920235658179435d0
      iwe=iwe+1
      weightb( 46, 69,  3)=                 -0.21493424122614096516d0
      iwe=iwe+1
      weightb( 47, 69,  3)=                  0.22275407840948063809d0
      iwe=iwe+1
      weightb( 48, 69,  3)=                 -0.30743073272248372385d0
      iwe=iwe+1
      weightb( 49, 69,  3)=                  0.13649038081880898732d0
      iwe=iwe+1
      weightb( 50, 69,  3)=                 -0.38576190023405959595d0
      iwe=iwe+1
      biasb( 69,  3)=                  1.07800722280317962110d0
      iwe=iwe+1
      weightb(  1, 70,  3)=                 -0.00361359354842875511d0
      iwe=iwe+1
      weightb(  2, 70,  3)=                 -0.21804366161807051117d0
      iwe=iwe+1
      weightb(  3, 70,  3)=                  0.08226735767502454943d0
      iwe=iwe+1
      weightb(  4, 70,  3)=                 -0.39009119503324291012d0
      iwe=iwe+1
      weightb(  5, 70,  3)=                  0.55784970750483275914d0
      iwe=iwe+1
      weightb(  6, 70,  3)=                  0.11701179476052650519d0
      iwe=iwe+1
      weightb(  7, 70,  3)=                  0.10562731479344475427d0
      iwe=iwe+1
      weightb(  8, 70,  3)=                 -0.26720012578418522731d0
      iwe=iwe+1
      weightb(  9, 70,  3)=                 -0.48514118468920536253d0
      iwe=iwe+1
      weightb( 10, 70,  3)=                 -0.01884000099718694671d0
      iwe=iwe+1
      weightb( 11, 70,  3)=                 -0.06737553767731539744d0
      iwe=iwe+1
      weightb( 12, 70,  3)=                  0.48723647594362723412d0
      iwe=iwe+1
      weightb( 13, 70,  3)=                  0.04008370927941008049d0
      iwe=iwe+1
      weightb( 14, 70,  3)=                  0.10410502841454721823d0
      iwe=iwe+1
      weightb( 15, 70,  3)=                 -0.17635582666371885097d0
      iwe=iwe+1
      weightb( 16, 70,  3)=                 -0.09784260179260385881d0
      iwe=iwe+1
      weightb( 17, 70,  3)=                 -0.51628597892972494243d0
      iwe=iwe+1
      weightb( 18, 70,  3)=                 -0.46212349437410971120d0
      iwe=iwe+1
      weightb( 19, 70,  3)=                 -0.37946606602945481823d0
      iwe=iwe+1
      weightb( 20, 70,  3)=                 -0.19971307461443865705d0
      iwe=iwe+1
      weightb( 21, 70,  3)=                 -0.36094498788631673714d0
      iwe=iwe+1
      weightb( 22, 70,  3)=                  0.39082260656832862322d0
      iwe=iwe+1
      weightb( 23, 70,  3)=                  0.44903145731319055178d0
      iwe=iwe+1
      weightb( 24, 70,  3)=                  0.15151040815778185622d0
      iwe=iwe+1
      weightb( 25, 70,  3)=                 -0.30895300417592691522d0
      iwe=iwe+1
      weightb( 26, 70,  3)=                  0.72586353636853384597d0
      iwe=iwe+1
      weightb( 27, 70,  3)=                 -0.06682785168772681361d0
      iwe=iwe+1
      weightb( 28, 70,  3)=                  0.12559559357252758627d0
      iwe=iwe+1
      weightb( 29, 70,  3)=                 -0.08457095057406149863d0
      iwe=iwe+1
      weightb( 30, 70,  3)=                 -0.23364740305506098705d0
      iwe=iwe+1
      weightb( 31, 70,  3)=                 -0.17814298066957942601d0
      iwe=iwe+1
      weightb( 32, 70,  3)=                 -0.17058446556874526379d0
      iwe=iwe+1
      weightb( 33, 70,  3)=                 -0.00993343088763795970d0
      iwe=iwe+1
      weightb( 34, 70,  3)=                  0.22217700671237536336d0
      iwe=iwe+1
      weightb( 35, 70,  3)=                  0.30061330909384931243d0
      iwe=iwe+1
      weightb( 36, 70,  3)=                 -0.21163829799273575771d0
      iwe=iwe+1
      weightb( 37, 70,  3)=                  0.12189621900263114540d0
      iwe=iwe+1
      weightb( 38, 70,  3)=                  0.21494721382332285242d0
      iwe=iwe+1
      weightb( 39, 70,  3)=                  0.52737152558368061150d0
      iwe=iwe+1
      weightb( 40, 70,  3)=                 -0.07830903763620268576d0
      iwe=iwe+1
      weightb( 41, 70,  3)=                 -0.28910259451031938838d0
      iwe=iwe+1
      weightb( 42, 70,  3)=                  0.01224798986364905584d0
      iwe=iwe+1
      weightb( 43, 70,  3)=                 -0.25202328160784548405d0
      iwe=iwe+1
      weightb( 44, 70,  3)=                  0.20207385997159088564d0
      iwe=iwe+1
      weightb( 45, 70,  3)=                  0.38168820609830855783d0
      iwe=iwe+1
      weightb( 46, 70,  3)=                 -0.51788252390840605610d0
      iwe=iwe+1
      weightb( 47, 70,  3)=                  0.59011216458535298290d0
      iwe=iwe+1
      weightb( 48, 70,  3)=                 -0.03651555702272470116d0
      iwe=iwe+1
      weightb( 49, 70,  3)=                 -0.20367636780782361061d0
      iwe=iwe+1
      weightb( 50, 70,  3)=                 -0.10263023138336722917d0
      iwe=iwe+1
      biasb( 70,  3)=                  1.04697381726264771018d0
      iwe=iwe+1
      weightb(  1, 71,  3)=                 -0.22320209696204917904d0
      iwe=iwe+1
      weightb(  2, 71,  3)=                  0.43136672566766470771d0
      iwe=iwe+1
      weightb(  3, 71,  3)=                 -0.16001990651987560432d0
      iwe=iwe+1
      weightb(  4, 71,  3)=                 -0.17194880911401294599d0
      iwe=iwe+1
      weightb(  5, 71,  3)=                 -0.02087509686507603782d0
      iwe=iwe+1
      weightb(  6, 71,  3)=                 -0.29444111693258717688d0
      iwe=iwe+1
      weightb(  7, 71,  3)=                  0.10908552193433578015d0
      iwe=iwe+1
      weightb(  8, 71,  3)=                 -0.36126035521591193245d0
      iwe=iwe+1
      weightb(  9, 71,  3)=                 -0.24014711268023097857d0
      iwe=iwe+1
      weightb( 10, 71,  3)=                 -0.10827854472744866121d0
      iwe=iwe+1
      weightb( 11, 71,  3)=                 -0.24954116660887210033d0
      iwe=iwe+1
      weightb( 12, 71,  3)=                  0.39482220420785657522d0
      iwe=iwe+1
      weightb( 13, 71,  3)=                  0.21450434200960633024d0
      iwe=iwe+1
      weightb( 14, 71,  3)=                  0.09699314791943687564d0
      iwe=iwe+1
      weightb( 15, 71,  3)=                 -0.52144574364298146296d0
      iwe=iwe+1
      weightb( 16, 71,  3)=                 -0.01312587073869232908d0
      iwe=iwe+1
      weightb( 17, 71,  3)=                 -0.12971787594024422607d0
      iwe=iwe+1
      weightb( 18, 71,  3)=                  0.16249222808516647354d0
      iwe=iwe+1
      weightb( 19, 71,  3)=                 -0.29886306999763367909d0
      iwe=iwe+1
      weightb( 20, 71,  3)=                 -0.20792883838211709269d0
      iwe=iwe+1
      weightb( 21, 71,  3)=                  0.07331960559058491034d0
      iwe=iwe+1
      weightb( 22, 71,  3)=                  0.24775675197418903228d0
      iwe=iwe+1
      weightb( 23, 71,  3)=                  0.14956160363724602114d0
      iwe=iwe+1
      weightb( 24, 71,  3)=                 -0.05017569404379090131d0
      iwe=iwe+1
      weightb( 25, 71,  3)=                 -0.02997322345506977376d0
      iwe=iwe+1
      weightb( 26, 71,  3)=                  0.16225638627259589275d0
      iwe=iwe+1
      weightb( 27, 71,  3)=                  0.30925085834846710586d0
      iwe=iwe+1
      weightb( 28, 71,  3)=                 -0.00602015318973897484d0
      iwe=iwe+1
      weightb( 29, 71,  3)=                 -0.55777960825980776871d0
      iwe=iwe+1
      weightb( 30, 71,  3)=                  0.28058038204325214116d0
      iwe=iwe+1
      weightb( 31, 71,  3)=                  0.18842798393101747867d0
      iwe=iwe+1
      weightb( 32, 71,  3)=                  0.31727134734169787356d0
      iwe=iwe+1
      weightb( 33, 71,  3)=                 -0.10129500491069051704d0
      iwe=iwe+1
      weightb( 34, 71,  3)=                 -0.32721733678084663488d0
      iwe=iwe+1
      weightb( 35, 71,  3)=                  0.25708653626882899124d0
      iwe=iwe+1
      weightb( 36, 71,  3)=                  0.18902371901903852747d0
      iwe=iwe+1
      weightb( 37, 71,  3)=                 -0.34797860042097467081d0
      iwe=iwe+1
      weightb( 38, 71,  3)=                  0.00948725459320064884d0
      iwe=iwe+1
      weightb( 39, 71,  3)=                 -0.22770962906248926050d0
      iwe=iwe+1
      weightb( 40, 71,  3)=                 -0.14013992992632887113d0
      iwe=iwe+1
      weightb( 41, 71,  3)=                  0.33999590988677463876d0
      iwe=iwe+1
      weightb( 42, 71,  3)=                 -0.55608800927529022928d0
      iwe=iwe+1
      weightb( 43, 71,  3)=                  0.19482071273487983065d0
      iwe=iwe+1
      weightb( 44, 71,  3)=                 -0.23267842796675403116d0
      iwe=iwe+1
      weightb( 45, 71,  3)=                  0.17519261636341937338d0
      iwe=iwe+1
      weightb( 46, 71,  3)=                  0.36373493681176571890d0
      iwe=iwe+1
      weightb( 47, 71,  3)=                  0.18192594816113905054d0
      iwe=iwe+1
      weightb( 48, 71,  3)=                 -0.16314721280750996146d0
      iwe=iwe+1
      weightb( 49, 71,  3)=                  0.01775625567938920318d0
      iwe=iwe+1
      weightb( 50, 71,  3)=                  0.29568059922455491861d0
      iwe=iwe+1
      biasb( 71,  3)=                 -1.24209231075760029306d0
      iwe=iwe+1
      weightb(  1, 72,  3)=                  0.25598584107394489751d0
      iwe=iwe+1
      weightb(  2, 72,  3)=                  0.10586138953099791249d0
      iwe=iwe+1
      weightb(  3, 72,  3)=                 -0.14140473352200721990d0
      iwe=iwe+1
      weightb(  4, 72,  3)=                  0.19951217196763559869d0
      iwe=iwe+1
      weightb(  5, 72,  3)=                 -0.12619070697922621371d0
      iwe=iwe+1
      weightb(  6, 72,  3)=                 -0.19160885862608562080d0
      iwe=iwe+1
      weightb(  7, 72,  3)=                  0.22807876206143762321d0
      iwe=iwe+1
      weightb(  8, 72,  3)=                 -0.23756032823805134369d0
      iwe=iwe+1
      weightb(  9, 72,  3)=                 -0.32268725644901030680d0
      iwe=iwe+1
      weightb( 10, 72,  3)=                  0.38180449883804390421d0
      iwe=iwe+1
      weightb( 11, 72,  3)=                 -0.43236860793526948887d0
      iwe=iwe+1
      weightb( 12, 72,  3)=                  0.19548136618378886276d0
      iwe=iwe+1
      weightb( 13, 72,  3)=                  0.24866348862872983405d0
      iwe=iwe+1
      weightb( 14, 72,  3)=                  0.18320912008398515525d0
      iwe=iwe+1
      weightb( 15, 72,  3)=                  0.26355138933825772440d0
      iwe=iwe+1
      weightb( 16, 72,  3)=                  0.17850416948997624433d0
      iwe=iwe+1
      weightb( 17, 72,  3)=                  0.19915305171824204677d0
      iwe=iwe+1
      weightb( 18, 72,  3)=                  0.15927648044282471940d0
      iwe=iwe+1
      weightb( 19, 72,  3)=                  0.06474933663179077703d0
      iwe=iwe+1
      weightb( 20, 72,  3)=                 -0.21790781077236898167d0
      iwe=iwe+1
      weightb( 21, 72,  3)=                 -0.05850586781602858111d0
      iwe=iwe+1
      weightb( 22, 72,  3)=                  0.21826022350504847847d0
      iwe=iwe+1
      weightb( 23, 72,  3)=                  0.20133538946739212849d0
      iwe=iwe+1
      weightb( 24, 72,  3)=                  0.17186155462576341302d0
      iwe=iwe+1
      weightb( 25, 72,  3)=                  0.27170744334755481120d0
      iwe=iwe+1
      weightb( 26, 72,  3)=                 -0.11485525553406042421d0
      iwe=iwe+1
      weightb( 27, 72,  3)=                 -0.31363961810872292846d0
      iwe=iwe+1
      weightb( 28, 72,  3)=                 -0.13498352073993802325d0
      iwe=iwe+1
      weightb( 29, 72,  3)=                  0.15144616623061429861d0
      iwe=iwe+1
      weightb( 30, 72,  3)=                 -0.19366532786187096171d0
      iwe=iwe+1
      weightb( 31, 72,  3)=                 -0.06390934589387055331d0
      iwe=iwe+1
      weightb( 32, 72,  3)=                  0.18831657382946023760d0
      iwe=iwe+1
      weightb( 33, 72,  3)=                 -0.29587603553849822768d0
      iwe=iwe+1
      weightb( 34, 72,  3)=                 -0.22515268937504381852d0
      iwe=iwe+1
      weightb( 35, 72,  3)=                 -0.01907888655622797316d0
      iwe=iwe+1
      weightb( 36, 72,  3)=                 -0.02815634711826070502d0
      iwe=iwe+1
      weightb( 37, 72,  3)=                  0.18329568753578404094d0
      iwe=iwe+1
      weightb( 38, 72,  3)=                 -0.22881809330174701644d0
      iwe=iwe+1
      weightb( 39, 72,  3)=                  0.33069843332847120854d0
      iwe=iwe+1
      weightb( 40, 72,  3)=                  0.19332652704088978957d0
      iwe=iwe+1
      weightb( 41, 72,  3)=                 -0.07852503342511733819d0
      iwe=iwe+1
      weightb( 42, 72,  3)=                 -0.14651475778795497451d0
      iwe=iwe+1
      weightb( 43, 72,  3)=                  0.26088721887092064522d0
      iwe=iwe+1
      weightb( 44, 72,  3)=                  0.23097688272527888698d0
      iwe=iwe+1
      weightb( 45, 72,  3)=                 -0.23120093753197074049d0
      iwe=iwe+1
      weightb( 46, 72,  3)=                  0.38724345302027268767d0
      iwe=iwe+1
      weightb( 47, 72,  3)=                  0.09982875360747468785d0
      iwe=iwe+1
      weightb( 48, 72,  3)=                 -0.17872356254883739468d0
      iwe=iwe+1
      weightb( 49, 72,  3)=                 -0.09585972723329211354d0
      iwe=iwe+1
      weightb( 50, 72,  3)=                  0.14492579373178166025d0
      iwe=iwe+1
      biasb( 72,  3)=                  1.28023823051101137693d0
      iwe=iwe+1
      weightb(  1, 73,  3)=                  0.26262743794689047405d0
      iwe=iwe+1
      weightb(  2, 73,  3)=                  0.24515069635550634786d0
      iwe=iwe+1
      weightb(  3, 73,  3)=                 -0.04656126397664471506d0
      iwe=iwe+1
      weightb(  4, 73,  3)=                  0.39710748075008278635d0
      iwe=iwe+1
      weightb(  5, 73,  3)=                  0.20964260690102179407d0
      iwe=iwe+1
      weightb(  6, 73,  3)=                 -0.10978495362188463169d0
      iwe=iwe+1
      weightb(  7, 73,  3)=                  0.21158841169226688672d0
      iwe=iwe+1
      weightb(  8, 73,  3)=                 -0.20847423910944021253d0
      iwe=iwe+1
      weightb(  9, 73,  3)=                  0.56775879902027026613d0
      iwe=iwe+1
      weightb( 10, 73,  3)=                  0.05764938750441812171d0
      iwe=iwe+1
      weightb( 11, 73,  3)=                 -0.20323772303918993809d0
      iwe=iwe+1
      weightb( 12, 73,  3)=                  0.18450962822906225025d0
      iwe=iwe+1
      weightb( 13, 73,  3)=                  0.07372454991678410730d0
      iwe=iwe+1
      weightb( 14, 73,  3)=                 -0.00480024019447855641d0
      iwe=iwe+1
      weightb( 15, 73,  3)=                  0.28689711761675101842d0
      iwe=iwe+1
      weightb( 16, 73,  3)=                  0.03480530058231846857d0
      iwe=iwe+1
      weightb( 17, 73,  3)=                 -0.38939396966324862914d0
      iwe=iwe+1
      weightb( 18, 73,  3)=                 -0.31692761351651038693d0
      iwe=iwe+1
      weightb( 19, 73,  3)=                 -0.18514236004660561408d0
      iwe=iwe+1
      weightb( 20, 73,  3)=                 -0.43048871147906087042d0
      iwe=iwe+1
      weightb( 21, 73,  3)=                  0.14697757910915676405d0
      iwe=iwe+1
      weightb( 22, 73,  3)=                  0.24312078478790871694d0
      iwe=iwe+1
      weightb( 23, 73,  3)=                  0.36174900514634977799d0
      iwe=iwe+1
      weightb( 24, 73,  3)=                  0.43145792608504485166d0
      iwe=iwe+1
      weightb( 25, 73,  3)=                  0.09397947490435099027d0
      iwe=iwe+1
      weightb( 26, 73,  3)=                  0.24062664942393016676d0
      iwe=iwe+1
      weightb( 27, 73,  3)=                 -0.24047485955230316068d0
      iwe=iwe+1
      weightb( 28, 73,  3)=                  0.00834306201753100794d0
      iwe=iwe+1
      weightb( 29, 73,  3)=                  0.12211325226754650430d0
      iwe=iwe+1
      weightb( 30, 73,  3)=                  0.16384006619914423530d0
      iwe=iwe+1
      weightb( 31, 73,  3)=                 -0.17674001915426845732d0
      iwe=iwe+1
      weightb( 32, 73,  3)=                  0.40797549419337497678d0
      iwe=iwe+1
      weightb( 33, 73,  3)=                  0.11817550218431215059d0
      iwe=iwe+1
      weightb( 34, 73,  3)=                  0.16041851468944262615d0
      iwe=iwe+1
      weightb( 35, 73,  3)=                 -0.19203625392198356292d0
      iwe=iwe+1
      weightb( 36, 73,  3)=                 -0.20455804243248640328d0
      iwe=iwe+1
      weightb( 37, 73,  3)=                 -0.08005234273491355912d0
      iwe=iwe+1
      weightb( 38, 73,  3)=                  0.06723799866090897359d0
      iwe=iwe+1
      weightb( 39, 73,  3)=                  0.34925817276177029136d0
      iwe=iwe+1
      weightb( 40, 73,  3)=                 -0.28269514908030457523d0
      iwe=iwe+1
      weightb( 41, 73,  3)=                 -0.02699008283968259980d0
      iwe=iwe+1
      weightb( 42, 73,  3)=                  0.30041992569336467556d0
      iwe=iwe+1
      weightb( 43, 73,  3)=                 -0.28051297714257622529d0
      iwe=iwe+1
      weightb( 44, 73,  3)=                 -0.23828254315065783286d0
      iwe=iwe+1
      weightb( 45, 73,  3)=                  0.24672091409597038392d0
      iwe=iwe+1
      weightb( 46, 73,  3)=                  0.14291031061586867423d0
      iwe=iwe+1
      weightb( 47, 73,  3)=                  0.32195936304770372827d0
      iwe=iwe+1
      weightb( 48, 73,  3)=                 -0.10027884508359539983d0
      iwe=iwe+1
      weightb( 49, 73,  3)=                 -0.10188402117684801362d0
      iwe=iwe+1
      weightb( 50, 73,  3)=                  0.19700394829909129157d0
      iwe=iwe+1
      biasb( 73,  3)=                  1.19350055898894713557d0
      iwe=iwe+1
      weightb(  1, 74,  3)=                 -0.38759557446457854057d0
      iwe=iwe+1
      weightb(  2, 74,  3)=                 -0.46349000857071381843d0
      iwe=iwe+1
      weightb(  3, 74,  3)=                  0.01829930234306723080d0
      iwe=iwe+1
      weightb(  4, 74,  3)=                 -0.12229033936207003852d0
      iwe=iwe+1
      weightb(  5, 74,  3)=                  0.75609291928131794336d0
      iwe=iwe+1
      weightb(  6, 74,  3)=                 -0.40772627951323842099d0
      iwe=iwe+1
      weightb(  7, 74,  3)=                  0.02166913984654237138d0
      iwe=iwe+1
      weightb(  8, 74,  3)=                  0.21720979126780715074d0
      iwe=iwe+1
      weightb(  9, 74,  3)=                  0.24535144863077054667d0
      iwe=iwe+1
      weightb( 10, 74,  3)=                  0.48553685379588318316d0
      iwe=iwe+1
      weightb( 11, 74,  3)=                  0.16190098203480346450d0
      iwe=iwe+1
      weightb( 12, 74,  3)=                 -0.06659689717136095533d0
      iwe=iwe+1
      weightb( 13, 74,  3)=                  0.24064105416097142376d0
      iwe=iwe+1
      weightb( 14, 74,  3)=                  0.11150329961149463287d0
      iwe=iwe+1
      weightb( 15, 74,  3)=                 -0.09696976233588826266d0
      iwe=iwe+1
      weightb( 16, 74,  3)=                  0.04120685711223093239d0
      iwe=iwe+1
      weightb( 17, 74,  3)=                  0.12702074290168699489d0
      iwe=iwe+1
      weightb( 18, 74,  3)=                 -0.47257941660489588553d0
      iwe=iwe+1
      weightb( 19, 74,  3)=                  0.11260967466922930380d0
      iwe=iwe+1
      weightb( 20, 74,  3)=                 -0.28369752021575889156d0
      iwe=iwe+1
      weightb( 21, 74,  3)=                  0.56599023895165045950d0
      iwe=iwe+1
      weightb( 22, 74,  3)=                 -0.03475467100112944463d0
      iwe=iwe+1
      weightb( 23, 74,  3)=                 -0.21210397892256932506d0
      iwe=iwe+1
      weightb( 24, 74,  3)=                  0.16435318449092856108d0
      iwe=iwe+1
      weightb( 25, 74,  3)=                 -0.22414153855148294392d0
      iwe=iwe+1
      weightb( 26, 74,  3)=                 -0.10018068299063989657d0
      iwe=iwe+1
      weightb( 27, 74,  3)=                  0.05973765867146788727d0
      iwe=iwe+1
      weightb( 28, 74,  3)=                 -0.28510592317429583886d0
      iwe=iwe+1
      weightb( 29, 74,  3)=                  0.08934000093842171808d0
      iwe=iwe+1
      weightb( 30, 74,  3)=                  0.34441488439482881301d0
      iwe=iwe+1
      weightb( 31, 74,  3)=                 -0.14295009160558366790d0
      iwe=iwe+1
      weightb( 32, 74,  3)=                  0.00496996531672446937d0
      iwe=iwe+1
      weightb( 33, 74,  3)=                 -0.22266193611303500277d0
      iwe=iwe+1
      weightb( 34, 74,  3)=                  0.09745957693715585901d0
      iwe=iwe+1
      weightb( 35, 74,  3)=                 -0.10770092045754332821d0
      iwe=iwe+1
      weightb( 36, 74,  3)=                 -0.12639635806820725961d0
      iwe=iwe+1
      weightb( 37, 74,  3)=                 -0.05961118273280176239d0
      iwe=iwe+1
      weightb( 38, 74,  3)=                 -0.47785590885424739094d0
      iwe=iwe+1
      weightb( 39, 74,  3)=                 -0.30226238512875530651d0
      iwe=iwe+1
      weightb( 40, 74,  3)=                 -0.10044991754375341697d0
      iwe=iwe+1
      weightb( 41, 74,  3)=                  0.92060603916269279079d0
      iwe=iwe+1
      weightb( 42, 74,  3)=                  0.05420509237276156800d0
      iwe=iwe+1
      weightb( 43, 74,  3)=                 -0.43823498388391052272d0
      iwe=iwe+1
      weightb( 44, 74,  3)=                 -0.14776070826924037060d0
      iwe=iwe+1
      weightb( 45, 74,  3)=                 -0.05902144812128524293d0
      iwe=iwe+1
      weightb( 46, 74,  3)=                 -0.16556752077002795387d0
      iwe=iwe+1
      weightb( 47, 74,  3)=                  0.12721282164777841794d0
      iwe=iwe+1
      weightb( 48, 74,  3)=                  0.26930302921133414396d0
      iwe=iwe+1
      weightb( 49, 74,  3)=                  0.11080186271987532698d0
      iwe=iwe+1
      weightb( 50, 74,  3)=                  0.18013864580958408035d0
      iwe=iwe+1
      biasb( 74,  3)=                  1.41883902690939134317d0
      iwe=iwe+1
      weightb(  1, 75,  3)=                  0.12099354674827436651d0
      iwe=iwe+1
      weightb(  2, 75,  3)=                 -0.05546211553873272443d0
      iwe=iwe+1
      weightb(  3, 75,  3)=                 -0.07053070770749085561d0
      iwe=iwe+1
      weightb(  4, 75,  3)=                  0.16448307681499427235d0
      iwe=iwe+1
      weightb(  5, 75,  3)=                 -0.34636547081560381534d0
      iwe=iwe+1
      weightb(  6, 75,  3)=                  0.10472640900764967897d0
      iwe=iwe+1
      weightb(  7, 75,  3)=                  0.29204964605926514443d0
      iwe=iwe+1
      weightb(  8, 75,  3)=                  0.14979332931668926099d0
      iwe=iwe+1
      weightb(  9, 75,  3)=                 -0.20061435326233970078d0
      iwe=iwe+1
      weightb( 10, 75,  3)=                 -0.33619272736317296069d0
      iwe=iwe+1
      weightb( 11, 75,  3)=                  0.00332068065826395149d0
      iwe=iwe+1
      weightb( 12, 75,  3)=                  0.01046744437507141773d0
      iwe=iwe+1
      weightb( 13, 75,  3)=                 -0.18828539256442738958d0
      iwe=iwe+1
      weightb( 14, 75,  3)=                  0.27722450103733625726d0
      iwe=iwe+1
      weightb( 15, 75,  3)=                 -0.27126048373419614501d0
      iwe=iwe+1
      weightb( 16, 75,  3)=                 -0.02040718800641889291d0
      iwe=iwe+1
      weightb( 17, 75,  3)=                  0.24689555796885903627d0
      iwe=iwe+1
      weightb( 18, 75,  3)=                  0.29698159916648780854d0
      iwe=iwe+1
      weightb( 19, 75,  3)=                  0.07711871488091261162d0
      iwe=iwe+1
      weightb( 20, 75,  3)=                 -0.02695009469105618879d0
      iwe=iwe+1
      weightb( 21, 75,  3)=                  0.13598136241588390516d0
      iwe=iwe+1
      weightb( 22, 75,  3)=                  0.34400776916797171090d0
      iwe=iwe+1
      weightb( 23, 75,  3)=                 -0.20574916494185882532d0
      iwe=iwe+1
      weightb( 24, 75,  3)=                  0.02629241447305464760d0
      iwe=iwe+1
      weightb( 25, 75,  3)=                 -0.28758643084396579015d0
      iwe=iwe+1
      weightb( 26, 75,  3)=                  0.30974144213851584340d0
      iwe=iwe+1
      weightb( 27, 75,  3)=                 -0.14436661329596739423d0
      iwe=iwe+1
      weightb( 28, 75,  3)=                  0.06645336906281663902d0
      iwe=iwe+1
      weightb( 29, 75,  3)=                 -0.28259226583772473207d0
      iwe=iwe+1
      weightb( 30, 75,  3)=                 -0.14388849776294818095d0
      iwe=iwe+1
      weightb( 31, 75,  3)=                 -0.18228768440331694078d0
      iwe=iwe+1
      weightb( 32, 75,  3)=                 -0.01448736964610342938d0
      iwe=iwe+1
      weightb( 33, 75,  3)=                  0.08442671857923764178d0
      iwe=iwe+1
      weightb( 34, 75,  3)=                  0.14925549165376317262d0
      iwe=iwe+1
      weightb( 35, 75,  3)=                 -0.27362483513126634183d0
      iwe=iwe+1
      weightb( 36, 75,  3)=                 -0.22174057484895476344d0
      iwe=iwe+1
      weightb( 37, 75,  3)=                 -0.06298479127957418156d0
      iwe=iwe+1
      weightb( 38, 75,  3)=                  0.29708523914557249945d0
      iwe=iwe+1
      weightb( 39, 75,  3)=                  0.36138600142390242542d0
      iwe=iwe+1
      weightb( 40, 75,  3)=                 -0.32985784406547841163d0
      iwe=iwe+1
      weightb( 41, 75,  3)=                 -0.35143752216751916739d0
      iwe=iwe+1
      weightb( 42, 75,  3)=                 -0.07421518018923813076d0
      iwe=iwe+1
      weightb( 43, 75,  3)=                 -0.06645240160954439534d0
      iwe=iwe+1
      weightb( 44, 75,  3)=                  0.33034226599655858170d0
      iwe=iwe+1
      weightb( 45, 75,  3)=                 -0.34893262074938319328d0
      iwe=iwe+1
      weightb( 46, 75,  3)=                  0.04131568077296517844d0
      iwe=iwe+1
      weightb( 47, 75,  3)=                  0.25935507361424703365d0
      iwe=iwe+1
      weightb( 48, 75,  3)=                  0.11605891844656010536d0
      iwe=iwe+1
      weightb( 49, 75,  3)=                 -0.08640857288114196788d0
      iwe=iwe+1
      weightb( 50, 75,  3)=                  0.33279040890468536418d0
      iwe=iwe+1
      biasb( 75,  3)=                  1.37197429035731133240d0
      iwe=iwe+1
      weightb(  1, 76,  3)=                  0.02925318918025672510d0
      iwe=iwe+1
      weightb(  2, 76,  3)=                  0.27712901957531116404d0
      iwe=iwe+1
      weightb(  3, 76,  3)=                  0.22409168912312457667d0
      iwe=iwe+1
      weightb(  4, 76,  3)=                  0.15470606964655730931d0
      iwe=iwe+1
      weightb(  5, 76,  3)=                  0.01956767502261453143d0
      iwe=iwe+1
      weightb(  6, 76,  3)=                 -0.19012446424703036141d0
      iwe=iwe+1
      weightb(  7, 76,  3)=                 -0.25022579165073671748d0
      iwe=iwe+1
      weightb(  8, 76,  3)=                  0.31571953952052950187d0
      iwe=iwe+1
      weightb(  9, 76,  3)=                 -0.13773909038832998775d0
      iwe=iwe+1
      weightb( 10, 76,  3)=                  0.27648620799009726579d0
      iwe=iwe+1
      weightb( 11, 76,  3)=                 -0.21187513288928458421d0
      iwe=iwe+1
      weightb( 12, 76,  3)=                 -0.23680801275320295662d0
      iwe=iwe+1
      weightb( 13, 76,  3)=                 -0.03080507376043740975d0
      iwe=iwe+1
      weightb( 14, 76,  3)=                 -0.42342271404223674747d0
      iwe=iwe+1
      weightb( 15, 76,  3)=                  0.24321165489692220252d0
      iwe=iwe+1
      weightb( 16, 76,  3)=                 -0.29885483694591485904d0
      iwe=iwe+1
      weightb( 17, 76,  3)=                  0.13326648318114667213d0
      iwe=iwe+1
      weightb( 18, 76,  3)=                 -0.17316952854107497961d0
      iwe=iwe+1
      weightb( 19, 76,  3)=                  0.21852712548513936186d0
      iwe=iwe+1
      weightb( 20, 76,  3)=                 -0.01360558445633906245d0
      iwe=iwe+1
      weightb( 21, 76,  3)=                  0.24572373650327891670d0
      iwe=iwe+1
      weightb( 22, 76,  3)=                 -0.27688085766847131408d0
      iwe=iwe+1
      weightb( 23, 76,  3)=                 -0.10324948604354754200d0
      iwe=iwe+1
      weightb( 24, 76,  3)=                 -0.31195034855890169112d0
      iwe=iwe+1
      weightb( 25, 76,  3)=                 -0.22472680037705899947d0
      iwe=iwe+1
      weightb( 26, 76,  3)=                  0.01109824318386235485d0
      iwe=iwe+1
      weightb( 27, 76,  3)=                 -0.42597145013283360671d0
      iwe=iwe+1
      weightb( 28, 76,  3)=                 -0.04753290409777696790d0
      iwe=iwe+1
      weightb( 29, 76,  3)=                 -0.46375993211490867951d0
      iwe=iwe+1
      weightb( 30, 76,  3)=                 -0.07682316082398227275d0
      iwe=iwe+1
      weightb( 31, 76,  3)=                 -0.49980570360667786467d0
      iwe=iwe+1
      weightb( 32, 76,  3)=                  0.22937592004623566511d0
      iwe=iwe+1
      weightb( 33, 76,  3)=                 -0.25545670074192072807d0
      iwe=iwe+1
      weightb( 34, 76,  3)=                  0.16254916060275304002d0
      iwe=iwe+1
      weightb( 35, 76,  3)=                 -0.07809460672996916542d0
      iwe=iwe+1
      weightb( 36, 76,  3)=                 -0.54677612697382693696d0
      iwe=iwe+1
      weightb( 37, 76,  3)=                  0.20164168277867589030d0
      iwe=iwe+1
      weightb( 38, 76,  3)=                  0.27304996380622148511d0
      iwe=iwe+1
      weightb( 39, 76,  3)=                 -0.09685586941445552267d0
      iwe=iwe+1
      weightb( 40, 76,  3)=                 -0.05461164918057989648d0
      iwe=iwe+1
      weightb( 41, 76,  3)=                 -0.51020661342840400998d0
      iwe=iwe+1
      weightb( 42, 76,  3)=                  0.14200475528946174264d0
      iwe=iwe+1
      weightb( 43, 76,  3)=                  0.15710927891965653647d0
      iwe=iwe+1
      weightb( 44, 76,  3)=                 -0.46339971465079504709d0
      iwe=iwe+1
      weightb( 45, 76,  3)=                  0.29230112963628979150d0
      iwe=iwe+1
      weightb( 46, 76,  3)=                 -0.24288139715041465183d0
      iwe=iwe+1
      weightb( 47, 76,  3)=                  0.00752982819893266864d0
      iwe=iwe+1
      weightb( 48, 76,  3)=                 -0.14404369858424434514d0
      iwe=iwe+1
      weightb( 49, 76,  3)=                  0.02367672323710567905d0
      iwe=iwe+1
      weightb( 50, 76,  3)=                 -0.14673213288502204299d0
      iwe=iwe+1
      biasb( 76,  3)=                  1.23921492552885736949d0
      iwe=iwe+1
      weightb(  1, 77,  3)=                 -0.06166860442111303520d0
      iwe=iwe+1
      weightb(  2, 77,  3)=                  0.26137175449340660505d0
      iwe=iwe+1
      weightb(  3, 77,  3)=                  0.37108470192732639914d0
      iwe=iwe+1
      weightb(  4, 77,  3)=                  0.55927675605884308307d0
      iwe=iwe+1
      weightb(  5, 77,  3)=                 -0.02448976752124288822d0
      iwe=iwe+1
      weightb(  6, 77,  3)=                  0.27766251487562965128d0
      iwe=iwe+1
      weightb(  7, 77,  3)=                  0.16438572354061428693d0
      iwe=iwe+1
      weightb(  8, 77,  3)=                  0.13096985102546687685d0
      iwe=iwe+1
      weightb(  9, 77,  3)=                 -0.06702794848060018851d0
      iwe=iwe+1
      weightb( 10, 77,  3)=                 -0.23304187905308931805d0
      iwe=iwe+1
      weightb( 11, 77,  3)=                  0.35636776409159065526d0
      iwe=iwe+1
      weightb( 12, 77,  3)=                 -0.01847947293997710683d0
      iwe=iwe+1
      weightb( 13, 77,  3)=                  0.23194872955992942853d0
      iwe=iwe+1
      weightb( 14, 77,  3)=                 -0.03291003948998266759d0
      iwe=iwe+1
      weightb( 15, 77,  3)=                  0.02916872488302557631d0
      iwe=iwe+1
      weightb( 16, 77,  3)=                 -0.21806286461526205867d0
      iwe=iwe+1
      weightb( 17, 77,  3)=                 -0.27655890048779874224d0
      iwe=iwe+1
      weightb( 18, 77,  3)=                 -0.06264393276525495602d0
      iwe=iwe+1
      weightb( 19, 77,  3)=                  0.00256508130995977430d0
      iwe=iwe+1
      weightb( 20, 77,  3)=                  0.45390513764775819450d0
      iwe=iwe+1
      weightb( 21, 77,  3)=                 -0.33198066655794133961d0
      iwe=iwe+1
      weightb( 22, 77,  3)=                  0.54642908733687578504d0
      iwe=iwe+1
      weightb( 23, 77,  3)=                  0.21496313093205809963d0
      iwe=iwe+1
      weightb( 24, 77,  3)=                  0.89363565133651923222d0
      iwe=iwe+1
      weightb( 25, 77,  3)=                  0.42700209713368297848d0
      iwe=iwe+1
      weightb( 26, 77,  3)=                 -0.56714712934529232236d0
      iwe=iwe+1
      weightb( 27, 77,  3)=                  0.08170303278511829859d0
      iwe=iwe+1
      weightb( 28, 77,  3)=                 -0.18065705073789112278d0
      iwe=iwe+1
      weightb( 29, 77,  3)=                 -0.37986564804969347176d0
      iwe=iwe+1
      weightb( 30, 77,  3)=                 -0.03863727478441775220d0
      iwe=iwe+1
      weightb( 31, 77,  3)=                  0.54481421203543656251d0
      iwe=iwe+1
      weightb( 32, 77,  3)=                 -0.45690761820279107708d0
      iwe=iwe+1
      weightb( 33, 77,  3)=                  0.21594435641614082022d0
      iwe=iwe+1
      weightb( 34, 77,  3)=                 -0.00857815886108112373d0
      iwe=iwe+1
      weightb( 35, 77,  3)=                 -0.12523679110560914651d0
      iwe=iwe+1
      weightb( 36, 77,  3)=                  0.39288992193376715001d0
      iwe=iwe+1
      weightb( 37, 77,  3)=                  0.52051942130619099913d0
      iwe=iwe+1
      weightb( 38, 77,  3)=                  0.01804200384116908321d0
      iwe=iwe+1
      weightb( 39, 77,  3)=                  0.24486218791128142036d0
      iwe=iwe+1
      weightb( 40, 77,  3)=                 -0.34685322734845847048d0
      iwe=iwe+1
      weightb( 41, 77,  3)=                  0.24133137739583263026d0
      iwe=iwe+1
      weightb( 42, 77,  3)=                 -0.13173256986319856199d0
      iwe=iwe+1
      weightb( 43, 77,  3)=                 -0.05786105205581075495d0
      iwe=iwe+1
      weightb( 44, 77,  3)=                 -0.66062565050279586920d0
      iwe=iwe+1
      weightb( 45, 77,  3)=                 -0.43079414765945295285d0
      iwe=iwe+1
      weightb( 46, 77,  3)=                 -0.34825383498734191479d0
      iwe=iwe+1
      weightb( 47, 77,  3)=                  0.24458933813268032842d0
      iwe=iwe+1
      weightb( 48, 77,  3)=                  0.05293724445077043622d0
      iwe=iwe+1
      weightb( 49, 77,  3)=                  0.27409478217400001787d0
      iwe=iwe+1
      weightb( 50, 77,  3)=                 -0.18391608384267471576d0
      iwe=iwe+1
      biasb( 77,  3)=                 -1.14326486799855753240d0
      iwe=iwe+1
      weightb(  1, 78,  3)=                 -0.32497811786140229362d0
      iwe=iwe+1
      weightb(  2, 78,  3)=                  0.11541079301302804849d0
      iwe=iwe+1
      weightb(  3, 78,  3)=                  0.24831581346998538029d0
      iwe=iwe+1
      weightb(  4, 78,  3)=                 -0.35585430685299684894d0
      iwe=iwe+1
      weightb(  5, 78,  3)=                 -0.15203132412175038302d0
      iwe=iwe+1
      weightb(  6, 78,  3)=                  0.06359525491692068211d0
      iwe=iwe+1
      weightb(  7, 78,  3)=                 -0.15452809975722353597d0
      iwe=iwe+1
      weightb(  8, 78,  3)=                  0.07053813993042219732d0
      iwe=iwe+1
      weightb(  9, 78,  3)=                  0.07688541924198721844d0
      iwe=iwe+1
      weightb( 10, 78,  3)=                  0.34781872813445996462d0
      iwe=iwe+1
      weightb( 11, 78,  3)=                 -0.15508998420902853077d0
      iwe=iwe+1
      weightb( 12, 78,  3)=                  0.23844162932810172850d0
      iwe=iwe+1
      weightb( 13, 78,  3)=                 -0.01303459219945187625d0
      iwe=iwe+1
      weightb( 14, 78,  3)=                  0.12785895283124243393d0
      iwe=iwe+1
      weightb( 15, 78,  3)=                  0.07973428572715349216d0
      iwe=iwe+1
      weightb( 16, 78,  3)=                  0.18007648832096961877d0
      iwe=iwe+1
      weightb( 17, 78,  3)=                 -0.06958930249966822912d0
      iwe=iwe+1
      weightb( 18, 78,  3)=                 -0.00657502008010913547d0
      iwe=iwe+1
      weightb( 19, 78,  3)=                 -0.37411872513308791488d0
      iwe=iwe+1
      weightb( 20, 78,  3)=                  0.34449313573188306004d0
      iwe=iwe+1
      weightb( 21, 78,  3)=                 -0.08074025165142798000d0
      iwe=iwe+1
      weightb( 22, 78,  3)=                 -0.11926488674885858676d0
      iwe=iwe+1
      weightb( 23, 78,  3)=                 -0.64553834490697203918d0
      iwe=iwe+1
      weightb( 24, 78,  3)=                 -0.13287847616694808961d0
      iwe=iwe+1
      weightb( 25, 78,  3)=                  0.03035529272691955480d0
      iwe=iwe+1
      weightb( 26, 78,  3)=                  0.29075410882911134625d0
      iwe=iwe+1
      weightb( 27, 78,  3)=                  0.13061774680374702018d0
      iwe=iwe+1
      weightb( 28, 78,  3)=                 -0.22281109954551384100d0
      iwe=iwe+1
      weightb( 29, 78,  3)=                  0.00218009136391084926d0
      iwe=iwe+1
      weightb( 30, 78,  3)=                 -0.26675290397697476452d0
      iwe=iwe+1
      weightb( 31, 78,  3)=                 -0.28808824980599317955d0
      iwe=iwe+1
      weightb( 32, 78,  3)=                  0.43772204869828479357d0
      iwe=iwe+1
      weightb( 33, 78,  3)=                  0.26125876297273786797d0
      iwe=iwe+1
      weightb( 34, 78,  3)=                 -0.24216252780264266309d0
      iwe=iwe+1
      weightb( 35, 78,  3)=                 -0.18626268969757001082d0
      iwe=iwe+1
      weightb( 36, 78,  3)=                 -0.11358933733520336362d0
      iwe=iwe+1
      weightb( 37, 78,  3)=                  0.20449041985734187077d0
      iwe=iwe+1
      weightb( 38, 78,  3)=                 -0.29511898542624032116d0
      iwe=iwe+1
      weightb( 39, 78,  3)=                  0.25482169064277609971d0
      iwe=iwe+1
      weightb( 40, 78,  3)=                  0.02438945407656008951d0
      iwe=iwe+1
      weightb( 41, 78,  3)=                 -0.04907191983064568969d0
      iwe=iwe+1
      weightb( 42, 78,  3)=                  0.12029769396830661266d0
      iwe=iwe+1
      weightb( 43, 78,  3)=                  0.27466606071671523237d0
      iwe=iwe+1
      weightb( 44, 78,  3)=                 -0.04157290136434410588d0
      iwe=iwe+1
      weightb( 45, 78,  3)=                 -0.24386861531376941015d0
      iwe=iwe+1
      weightb( 46, 78,  3)=                 -0.28301335001482080811d0
      iwe=iwe+1
      weightb( 47, 78,  3)=                 -0.23909129502840784087d0
      iwe=iwe+1
      weightb( 48, 78,  3)=                 -0.33173604757143371202d0
      iwe=iwe+1
      weightb( 49, 78,  3)=                  0.23530496480597690168d0
      iwe=iwe+1
      weightb( 50, 78,  3)=                  0.37411910116022156769d0
      iwe=iwe+1
      biasb( 78,  3)=                 -1.46329072769939516618d0
      iwe=iwe+1
      weightb(  1, 79,  3)=                 -0.06687839468478763705d0
      iwe=iwe+1
      weightb(  2, 79,  3)=                  0.26030146100239720530d0
      iwe=iwe+1
      weightb(  3, 79,  3)=                  0.46983795674751094307d0
      iwe=iwe+1
      weightb(  4, 79,  3)=                 -0.58262258861684590450d0
      iwe=iwe+1
      weightb(  5, 79,  3)=                 -0.05285724275308263664d0
      iwe=iwe+1
      weightb(  6, 79,  3)=                 -0.36204320689429003721d0
      iwe=iwe+1
      weightb(  7, 79,  3)=                 -0.14761740562244807240d0
      iwe=iwe+1
      weightb(  8, 79,  3)=                  0.24690034402330154895d0
      iwe=iwe+1
      weightb(  9, 79,  3)=                 -0.13078010836551637319d0
      iwe=iwe+1
      weightb( 10, 79,  3)=                  0.25158475899119736585d0
      iwe=iwe+1
      weightb( 11, 79,  3)=                 -0.22353707967969946302d0
      iwe=iwe+1
      weightb( 12, 79,  3)=                 -0.06397034436867145291d0
      iwe=iwe+1
      weightb( 13, 79,  3)=                  0.16672274370667097831d0
      iwe=iwe+1
      weightb( 14, 79,  3)=                  0.01161713558426053124d0
      iwe=iwe+1
      weightb( 15, 79,  3)=                  0.27059331150313187253d0
      iwe=iwe+1
      weightb( 16, 79,  3)=                  0.14768276387227086133d0
      iwe=iwe+1
      weightb( 17, 79,  3)=                 -0.09452232164804739989d0
      iwe=iwe+1
      weightb( 18, 79,  3)=                  0.19987338598008891344d0
      iwe=iwe+1
      weightb( 19, 79,  3)=                 -0.10625120682738413425d0
      iwe=iwe+1
      weightb( 20, 79,  3)=                  0.20874331636955748004d0
      iwe=iwe+1
      weightb( 21, 79,  3)=                  0.17044735566186841602d0
      iwe=iwe+1
      weightb( 22, 79,  3)=                  0.17398067802575009622d0
      iwe=iwe+1
      weightb( 23, 79,  3)=                 -0.40679310191127360241d0
      iwe=iwe+1
      weightb( 24, 79,  3)=                 -0.03184824581316417214d0
      iwe=iwe+1
      weightb( 25, 79,  3)=                 -0.09921402017285695096d0
      iwe=iwe+1
      weightb( 26, 79,  3)=                 -0.23752612847444570798d0
      iwe=iwe+1
      weightb( 27, 79,  3)=                  0.08151462065285665359d0
      iwe=iwe+1
      weightb( 28, 79,  3)=                 -0.72246112344981383568d0
      iwe=iwe+1
      weightb( 29, 79,  3)=                  0.11779165917799172547d0
      iwe=iwe+1
      weightb( 30, 79,  3)=                 -0.12446785847285478377d0
      iwe=iwe+1
      weightb( 31, 79,  3)=                  0.28124171154910160286d0
      iwe=iwe+1
      weightb( 32, 79,  3)=                  0.31104282344148420636d0
      iwe=iwe+1
      weightb( 33, 79,  3)=                 -0.71285500736235019037d0
      iwe=iwe+1
      weightb( 34, 79,  3)=                 -0.13927738997528676945d0
      iwe=iwe+1
      weightb( 35, 79,  3)=                  0.58189534543289211932d0
      iwe=iwe+1
      weightb( 36, 79,  3)=                 -0.12162043206191230915d0
      iwe=iwe+1
      weightb( 37, 79,  3)=                  0.34211336591796392970d0
      iwe=iwe+1
      weightb( 38, 79,  3)=                  0.12355363400169558363d0
      iwe=iwe+1
      weightb( 39, 79,  3)=                  0.46049379043028432212d0
      iwe=iwe+1
      weightb( 40, 79,  3)=                 -0.12052849149528721551d0
      iwe=iwe+1
      weightb( 41, 79,  3)=                 -0.31609546504116881049d0
      iwe=iwe+1
      weightb( 42, 79,  3)=                  0.32564375306484516504d0
      iwe=iwe+1
      weightb( 43, 79,  3)=                  0.56463017788556202348d0
      iwe=iwe+1
      weightb( 44, 79,  3)=                 -0.25497804301624249490d0
      iwe=iwe+1
      weightb( 45, 79,  3)=                 -0.07790481452695294240d0
      iwe=iwe+1
      weightb( 46, 79,  3)=                 -0.12671321701727952802d0
      iwe=iwe+1
      weightb( 47, 79,  3)=                  0.05664656462868607883d0
      iwe=iwe+1
      weightb( 48, 79,  3)=                  0.14871961954393145278d0
      iwe=iwe+1
      weightb( 49, 79,  3)=                  0.03245922002835766734d0
      iwe=iwe+1
      weightb( 50, 79,  3)=                 -0.26457054242097077790d0
      iwe=iwe+1
      biasb( 79,  3)=                 -1.33805850814016147332d0
      iwe=iwe+1
      weightb(  1, 80,  3)=                 -0.20298938091447527032d0
      iwe=iwe+1
      weightb(  2, 80,  3)=                 -0.05450663709043491317d0
      iwe=iwe+1
      weightb(  3, 80,  3)=                  0.11915377152081338408d0
      iwe=iwe+1
      weightb(  4, 80,  3)=                  0.00913624673766604868d0
      iwe=iwe+1
      weightb(  5, 80,  3)=                  0.04542201848612698045d0
      iwe=iwe+1
      weightb(  6, 80,  3)=                 -0.10560527205405481621d0
      iwe=iwe+1
      weightb(  7, 80,  3)=                 -0.29516058416142815224d0
      iwe=iwe+1
      weightb(  8, 80,  3)=                 -0.21310617666031636541d0
      iwe=iwe+1
      weightb(  9, 80,  3)=                  0.11140973090464438566d0
      iwe=iwe+1
      weightb( 10, 80,  3)=                 -0.25149509286201904290d0
      iwe=iwe+1
      weightb( 11, 80,  3)=                  0.07865996239663344824d0
      iwe=iwe+1
      weightb( 12, 80,  3)=                 -0.38330997621863838187d0
      iwe=iwe+1
      weightb( 13, 80,  3)=                  0.03352511026748625222d0
      iwe=iwe+1
      weightb( 14, 80,  3)=                 -0.14327289322112868319d0
      iwe=iwe+1
      weightb( 15, 80,  3)=                  0.20121663520850557871d0
      iwe=iwe+1
      weightb( 16, 80,  3)=                 -0.30466589299964730309d0
      iwe=iwe+1
      weightb( 17, 80,  3)=                  0.27665941783558262168d0
      iwe=iwe+1
      weightb( 18, 80,  3)=                  0.33553965884230047001d0
      iwe=iwe+1
      weightb( 19, 80,  3)=                 -0.17594680541848214950d0
      iwe=iwe+1
      weightb( 20, 80,  3)=                 -0.33601096737659669200d0
      iwe=iwe+1
      weightb( 21, 80,  3)=                 -0.31572076448607483412d0
      iwe=iwe+1
      weightb( 22, 80,  3)=                  0.11725627714938491319d0
      iwe=iwe+1
      weightb( 23, 80,  3)=                 -0.08153668680839200322d0
      iwe=iwe+1
      weightb( 24, 80,  3)=                  0.01170349972793188059d0
      iwe=iwe+1
      weightb( 25, 80,  3)=                  0.14980439238117207457d0
      iwe=iwe+1
      weightb( 26, 80,  3)=                  0.00403119424565208644d0
      iwe=iwe+1
      weightb( 27, 80,  3)=                 -0.12541678037654954703d0
      iwe=iwe+1
      weightb( 28, 80,  3)=                 -0.21816185364728638008d0
      iwe=iwe+1
      weightb( 29, 80,  3)=                  0.14143679418196980491d0
      iwe=iwe+1
      weightb( 30, 80,  3)=                  0.30731629759331313689d0
      iwe=iwe+1
      weightb( 31, 80,  3)=                  0.10807230786939392431d0
      iwe=iwe+1
      weightb( 32, 80,  3)=                 -0.35996148325774174337d0
      iwe=iwe+1
      weightb( 33, 80,  3)=                 -0.18776839249260862674d0
      iwe=iwe+1
      weightb( 34, 80,  3)=                 -0.30578700193414348751d0
      iwe=iwe+1
      weightb( 35, 80,  3)=                  0.14812605878378912183d0
      iwe=iwe+1
      weightb( 36, 80,  3)=                  0.20039849681363619549d0
      iwe=iwe+1
      weightb( 37, 80,  3)=                 -0.01204766322841611774d0
      iwe=iwe+1
      weightb( 38, 80,  3)=                  0.32503199435271573625d0
      iwe=iwe+1
      weightb( 39, 80,  3)=                 -0.04290176875682173013d0
      iwe=iwe+1
      weightb( 40, 80,  3)=                 -0.33869622153945888599d0
      iwe=iwe+1
      weightb( 41, 80,  3)=                  0.31983780100288178305d0
      iwe=iwe+1
      weightb( 42, 80,  3)=                 -0.01504234902753378948d0
      iwe=iwe+1
      weightb( 43, 80,  3)=                 -0.26051698939230516494d0
      iwe=iwe+1
      weightb( 44, 80,  3)=                  0.31151794045933067778d0
      iwe=iwe+1
      weightb( 45, 80,  3)=                 -0.30467522689058207375d0
      iwe=iwe+1
      weightb( 46, 80,  3)=                 -0.28966515598691677802d0
      iwe=iwe+1
      weightb( 47, 80,  3)=                  0.17829279841180692423d0
      iwe=iwe+1
      weightb( 48, 80,  3)=                  0.14568975603800474183d0
      iwe=iwe+1
      weightb( 49, 80,  3)=                  0.09715127676964119274d0
      iwe=iwe+1
      weightb( 50, 80,  3)=                 -0.21412832800234329889d0
      iwe=iwe+1
      biasb( 80,  3)=                 -1.52115099892471938858d0
      iwe=iwe+1
      weightb(  1,  1,  4)=                  1.16032103895392402215d0
      iwe=iwe+1
      weightb(  2,  1,  4)=                 -1.39841836202147162815d0
      iwe=iwe+1
      weightb(  3,  1,  4)=                  0.76154620110082427153d0
      iwe=iwe+1
      weightb(  4,  1,  4)=                  0.96227767082960347089d0
      iwe=iwe+1
      weightb(  5,  1,  4)=                  0.57232840905477921911d0
      iwe=iwe+1
      weightb(  6,  1,  4)=                 -1.41846042514940706702d0
      iwe=iwe+1
      weightb(  7,  1,  4)=                 -0.64081688414012627497d0
      iwe=iwe+1
      weightb(  8,  1,  4)=                  0.84733203740800711046d0
      iwe=iwe+1
      weightb(  9,  1,  4)=                 -0.89081821773803582243d0
      iwe=iwe+1
      weightb( 10,  1,  4)=                  0.82744201232005509805d0
      iwe=iwe+1
      weightb( 11,  1,  4)=                 -0.62759062908647000878d0
      iwe=iwe+1
      weightb( 12,  1,  4)=                 -0.66719211708176451303d0
      iwe=iwe+1
      weightb( 13,  1,  4)=                 -0.71813115308639918766d0
      iwe=iwe+1
      weightb( 14,  1,  4)=                  1.02903343523628088008d0
      iwe=iwe+1
      weightb( 15,  1,  4)=                 -0.51983329052710436358d0
      iwe=iwe+1
      weightb( 16,  1,  4)=                  0.95704261794022726928d0
      iwe=iwe+1
      weightb( 17,  1,  4)=                  0.68133236970686139600d0
      iwe=iwe+1
      weightb( 18,  1,  4)=                 -1.65085227079994689703d0
      iwe=iwe+1
      weightb( 19,  1,  4)=                 -0.73648524915846946826d0
      iwe=iwe+1
      weightb( 20,  1,  4)=                  0.93506219193611384011d0
      iwe=iwe+1
      weightb( 21,  1,  4)=                 -1.53359310272247051365d0
      iwe=iwe+1
      weightb( 22,  1,  4)=                  0.41689884289512790794d0
      iwe=iwe+1
      weightb( 23,  1,  4)=                  0.55299741293193216407d0
      iwe=iwe+1
      weightb( 24,  1,  4)=                 -1.04662427650618750086d0
      iwe=iwe+1
      weightb( 25,  1,  4)=                 -0.22795512697600181506d0
      iwe=iwe+1
      weightb( 26,  1,  4)=                  1.39045861409067028625d0
      iwe=iwe+1
      weightb( 27,  1,  4)=                  1.20819105265318427200d0
      iwe=iwe+1
      weightb( 28,  1,  4)=                  0.43021238879022855039d0
      iwe=iwe+1
      weightb( 29,  1,  4)=                  0.62009063736357716845d0
      iwe=iwe+1
      weightb( 30,  1,  4)=                  1.13888796156899796408d0
      iwe=iwe+1
      weightb( 31,  1,  4)=                 -1.03799710977354520125d0
      iwe=iwe+1
      weightb( 32,  1,  4)=                  0.65314020670437245020d0
      iwe=iwe+1
      weightb( 33,  1,  4)=                  0.29895771547618443797d0
      iwe=iwe+1
      weightb( 34,  1,  4)=                  0.83726815808575494327d0
      iwe=iwe+1
      weightb( 35,  1,  4)=                  0.91898926625490928721d0
      iwe=iwe+1
      weightb( 36,  1,  4)=                 -0.26101618186487496320d0
      iwe=iwe+1
      weightb( 37,  1,  4)=                  0.55754829251999848960d0
      iwe=iwe+1
      weightb( 38,  1,  4)=                 -0.65939520932276773912d0
      iwe=iwe+1
      weightb( 39,  1,  4)=                 -0.89198221614663808499d0
      iwe=iwe+1
      weightb( 40,  1,  4)=                  1.14154692298285187491d0
      iwe=iwe+1
      weightb( 41,  1,  4)=                 -1.14916425410408051810d0
      iwe=iwe+1
      weightb( 42,  1,  4)=                 -0.38805534086438320251d0
      iwe=iwe+1
      weightb( 43,  1,  4)=                 -0.60864479882544153533d0
      iwe=iwe+1
      weightb( 44,  1,  4)=                  0.71738998770268369576d0
      iwe=iwe+1
      weightb( 45,  1,  4)=                  0.29675835940121597645d0
      iwe=iwe+1
      weightb( 46,  1,  4)=                 -1.21227798537097819498d0
      iwe=iwe+1
      weightb( 47,  1,  4)=                 -1.45402240012427497184d0
      iwe=iwe+1
      weightb( 48,  1,  4)=                  0.09518759284445152402d0
      iwe=iwe+1
      weightb( 49,  1,  4)=                 -0.68354327110058510364d0
      iwe=iwe+1
      weightb( 50,  1,  4)=                 -0.39451132509778946700d0
      iwe=iwe+1
      weightb( 51,  1,  4)=                 -1.10431286003364026449d0
      iwe=iwe+1
      weightb( 52,  1,  4)=                  0.81539788786197808790d0
      iwe=iwe+1
      weightb( 53,  1,  4)=                 -0.65137739625748092287d0
      iwe=iwe+1
      weightb( 54,  1,  4)=                  1.15045300882066658943d0
      iwe=iwe+1
      weightb( 55,  1,  4)=                 -0.41253188698988302319d0
      iwe=iwe+1
      weightb( 56,  1,  4)=                 -1.31276812112507501595d0
      iwe=iwe+1
      weightb( 57,  1,  4)=                 -0.70091861010100875440d0
      iwe=iwe+1
      weightb( 58,  1,  4)=                  0.43911886280224787793d0
      iwe=iwe+1
      weightb( 59,  1,  4)=                 -0.69083200634550512298d0
      iwe=iwe+1
      weightb( 60,  1,  4)=                  1.74662262363792875064d0
      iwe=iwe+1
      weightb( 61,  1,  4)=                  0.76227810510415228151d0
      iwe=iwe+1
      weightb( 62,  1,  4)=                 -0.59072826284199020375d0
      iwe=iwe+1
      weightb( 63,  1,  4)=                  0.74043717142700415934d0
      iwe=iwe+1
      weightb( 64,  1,  4)=                 -0.53964248930280345196d0
      iwe=iwe+1
      weightb( 65,  1,  4)=                  1.46545408613446026536d0
      iwe=iwe+1
      weightb( 66,  1,  4)=                  0.79706202883207477594d0
      iwe=iwe+1
      weightb( 67,  1,  4)=                 -1.12928096632991459281d0
      iwe=iwe+1
      weightb( 68,  1,  4)=                 -0.85764771740693679369d0
      iwe=iwe+1
      weightb( 69,  1,  4)=                 -0.26341036063464529082d0
      iwe=iwe+1
      weightb( 70,  1,  4)=                 -0.65427379189884093957d0
      iwe=iwe+1
      weightb( 71,  1,  4)=                 -0.53283688590268185603d0
      iwe=iwe+1
      weightb( 72,  1,  4)=                  0.43775575938925809227d0
      iwe=iwe+1
      weightb( 73,  1,  4)=                 -0.75004374539445661796d0
      iwe=iwe+1
      weightb( 74,  1,  4)=                  1.03327206401278970382d0
      iwe=iwe+1
      weightb( 75,  1,  4)=                  0.47666089156136948191d0
      iwe=iwe+1
      weightb( 76,  1,  4)=                 -0.69247691773235242607d0
      iwe=iwe+1
      weightb( 77,  1,  4)=                  1.44110721292964338858d0
      iwe=iwe+1
      weightb( 78,  1,  4)=                 -0.52092908538311188948d0
      iwe=iwe+1
      weightb( 79,  1,  4)=                  0.93631661542781041696d0
      iwe=iwe+1
      weightb( 80,  1,  4)=                  0.02923650933991115905d0
      iwe=iwe+1
      biasb(  1,  4)=                  0.55107003129224929605d0
      iwe=iwe+1
      iwe= 5061
      if (iwe.ne.nwe) then
      write(*,*)'provided number of parameters ',nwe
      write(*,*)'actual number of parameters ',iwe
      write(*,*)'nwe not equal to iwe, check inputfiles or code'
      stop
      endif
      nhid=  2;noutput=  1
      nscale=ninput+noutput
      nlayer=nhid+2
      allocate(pdelc(nscale),pavgc(nscale))
      nodes(1)=ninput
      nodes(nlayer)=noutput
      nodes( 2)=50
      nodes( 3)=80
      nodemax=0
      do i=1,nlayer
       nodemax=max(nodemax,nodes(i))
      enddo
      allocate(weightc(nodemax,nodemax,2:nlayer),&
     &biasc(nodemax,2:nlayer))
      ifunc=  1;nwe=  5061
      pdelc(  1)=  0.1067562850000000d0
      pavgc(  1)=  0.1067562850000000d0
      pdelc(  2)=  0.3584514100000000d0
      pavgc(  2)=  0.5815815700000000d0
      pdelc(  3)=  0.2995175250000000d0
      pavgc(  3)=  0.2995175250000000d0
      pdelc(  4)=  0.2568390200000000d0
      pavgc(  4)=  0.2568390200000000d0
      pdelc(  5)=  0.0795311450000000d0
      pavgc(  5)=  0.0795311450000000d0
      pdelc(  6)=  0.1104549900000000d0
      pavgc(  6)=  0.1104549900000000d0
      pdelc(  7)=  0.0412553110000000d0
      pavgc(  7)=  0.0412553110000000d0
      pdelc(  8)=  0.1001943800000000d0
      pavgc(  8)=  0.1001943800000000d0
      pdelc(  9)=  0.0447088400000000d0
      pavgc(  9)=  0.0447088400000000d0
      pdelc( 10)=  0.0963427050000000d0
      pavgc( 10)=  0.0963427050000000d0
      pdelc( 11)=  0.0380176695000000d0
      pavgc( 11)=  0.0380176695000000d0
      pdelc( 12)=  0.1950274550000000d0
      pavgc( 12)=  0.1950274550000000d0
      pdelc( 13)=  0.1168573000000000d0
      pavgc( 13)=  0.1168573000000000d0
      pdelc( 14)=  0.0227938090000000d0
      pavgc( 14)=  0.0227938090000000d0
      pdelc( 15)=  0.1960274905000000d0
      pavgc( 15)=  0.2458145595000000d0
      pdelc( 16)=  0.0900038150000000d0
      pavgc( 16)=  0.0900038150000000d0
      pdelc( 17)=  0.1319325650000000d0
      pavgc( 17)=  0.1319325650000000d0
      pdelc( 18)=  2.5885233649999999d0
      pavgc( 18)=  2.4110914349999999d0
      iwe=  0
      weightc(  1,  1,  2)=                  0.27333468906022179157d0
      iwe=iwe+1
      weightc(  2,  1,  2)=                  0.28584409210086220154d0
      iwe=iwe+1
      weightc(  3,  1,  2)=                 -1.01693916056416133742d0
      iwe=iwe+1
      weightc(  4,  1,  2)=                 -1.19377238582136335765d0
      iwe=iwe+1
      weightc(  5,  1,  2)=                  0.27058765345958640802d0
      iwe=iwe+1
      weightc(  6,  1,  2)=                  1.10672472406971911241d0
      iwe=iwe+1
      weightc(  7,  1,  2)=                  0.46976853807693463860d0
      iwe=iwe+1
      weightc(  8,  1,  2)=                 -0.84429488112417772072d0
      iwe=iwe+1
      weightc(  9,  1,  2)=                  0.70746698766867299746d0
      iwe=iwe+1
      weightc( 10,  1,  2)=                  0.78227981993071915578d0
      iwe=iwe+1
      weightc( 11,  1,  2)=                 -0.22123370835638089815d0
      iwe=iwe+1
      weightc( 12,  1,  2)=                 -1.02029252091595834528d0
      iwe=iwe+1
      weightc( 13,  1,  2)=                 -0.56631945920391046911d0
      iwe=iwe+1
      weightc( 14,  1,  2)=                 -0.08574274843295995319d0
      iwe=iwe+1
      weightc( 15,  1,  2)=                  0.68125007518090274772d0
      iwe=iwe+1
      weightc( 16,  1,  2)=                 -0.96845291366446095704d0
      iwe=iwe+1
      weightc( 17,  1,  2)=                 -0.00214882389422598862d0
      iwe=iwe+1
      biasc(  1,  2)=                 -2.32668795468248523761d0
      iwe=iwe+1
      weightc(  1,  2,  2)=                 -1.03479815175542855243d0
      iwe=iwe+1
      weightc(  2,  2,  2)=                 -0.22062642027544968060d0
      iwe=iwe+1
      weightc(  3,  2,  2)=                  0.79294571659051049650d0
      iwe=iwe+1
      weightc(  4,  2,  2)=                  0.49219948436595661878d0
      iwe=iwe+1
      weightc(  5,  2,  2)=                  0.22950689466695831098d0
      iwe=iwe+1
      weightc(  6,  2,  2)=                 -1.01217636955839385138d0
      iwe=iwe+1
      weightc(  7,  2,  2)=                 -0.42823558912955800304d0
      iwe=iwe+1
      weightc(  8,  2,  2)=                  0.71771359556013480940d0
      iwe=iwe+1
      weightc(  9,  2,  2)=                  2.40795043964638288969d0
      iwe=iwe+1
      weightc( 10,  2,  2)=                  1.03917572677723302199d0
      iwe=iwe+1
      weightc( 11,  2,  2)=                  0.74557936259345691798d0
      iwe=iwe+1
      weightc( 12,  2,  2)=                  0.12474234669468024783d0
      iwe=iwe+1
      weightc( 13,  2,  2)=                 -0.72646152699567112521d0
      iwe=iwe+1
      weightc( 14,  2,  2)=                 -0.11178442291396269159d0
      iwe=iwe+1
      weightc( 15,  2,  2)=                 -0.30570872381390490347d0
      iwe=iwe+1
      weightc( 16,  2,  2)=                 -0.48684945316362149281d0
      iwe=iwe+1
      weightc( 17,  2,  2)=                  0.04069795572235361536d0
      iwe=iwe+1
      biasc(  2,  2)=                  2.50159439011797424257d0
      iwe=iwe+1
      weightc(  1,  3,  2)=                  0.27920833914659065611d0
      iwe=iwe+1
      weightc(  2,  3,  2)=                 -0.17085484809380210858d0
      iwe=iwe+1
      weightc(  3,  3,  2)=                 -0.11559871351835558639d0
      iwe=iwe+1
      weightc(  4,  3,  2)=                  0.69911525807807572974d0
      iwe=iwe+1
      weightc(  5,  3,  2)=                 -0.12031730627763535801d0
      iwe=iwe+1
      weightc(  6,  3,  2)=                 -0.47720769517401107063d0
      iwe=iwe+1
      weightc(  7,  3,  2)=                  0.92090183045720563904d0
      iwe=iwe+1
      weightc(  8,  3,  2)=                  0.14166287761318505090d0
      iwe=iwe+1
      weightc(  9,  3,  2)=                  0.84258361475592014056d0
      iwe=iwe+1
      weightc( 10,  3,  2)=                 -1.17715192612226005053d0
      iwe=iwe+1
      weightc( 11,  3,  2)=                  0.02155204402010628406d0
      iwe=iwe+1
      weightc( 12,  3,  2)=                  0.07869405677388977005d0
      iwe=iwe+1
      weightc( 13,  3,  2)=                 -0.73291844699384012252d0
      iwe=iwe+1
      weightc( 14,  3,  2)=                  0.37691026731142840411d0
      iwe=iwe+1
      weightc( 15,  3,  2)=                 -0.29513461760746212414d0
      iwe=iwe+1
      weightc( 16,  3,  2)=                 -0.71045245060489914390d0
      iwe=iwe+1
      weightc( 17,  3,  2)=                  0.66949250251372027787d0
      iwe=iwe+1
      biasc(  3,  2)=                  1.79864186134077908008d0
      iwe=iwe+1
      weightc(  1,  4,  2)=                 -0.72869775348690801753d0
      iwe=iwe+1
      weightc(  2,  4,  2)=                 -0.55481356424504646441d0
      iwe=iwe+1
      weightc(  3,  4,  2)=                  0.62082654719870489224d0
      iwe=iwe+1
      weightc(  4,  4,  2)=                  0.58135494444921220758d0
      iwe=iwe+1
      weightc(  5,  4,  2)=                  0.00356958297075268003d0
      iwe=iwe+1
      weightc(  6,  4,  2)=                 -0.12357642904946294915d0
      iwe=iwe+1
      weightc(  7,  4,  2)=                  0.38076439391232569376d0
      iwe=iwe+1
      weightc(  8,  4,  2)=                  0.14835462883366770659d0
      iwe=iwe+1
      weightc(  9,  4,  2)=                 -0.16187426903765098074d0
      iwe=iwe+1
      weightc( 10,  4,  2)=                 -0.20467200710156310817d0
      iwe=iwe+1
      weightc( 11,  4,  2)=                  0.22615387193260461096d0
      iwe=iwe+1
      weightc( 12,  4,  2)=                  0.53114854021347446267d0
      iwe=iwe+1
      weightc( 13,  4,  2)=                 -0.54850202653324409141d0
      iwe=iwe+1
      weightc( 14,  4,  2)=                 -0.69872998450701218065d0
      iwe=iwe+1
      weightc( 15,  4,  2)=                 -0.14162024447835863672d0
      iwe=iwe+1
      weightc( 16,  4,  2)=                 -0.11711501651621471221d0
      iwe=iwe+1
      weightc( 17,  4,  2)=                 -0.63450488083134815032d0
      iwe=iwe+1
      biasc(  4,  2)=                  1.39796630501746554920d0
      iwe=iwe+1
      weightc(  1,  5,  2)=                 -0.46989214008182456084d0
      iwe=iwe+1
      weightc(  2,  5,  2)=                  0.84773322365094661013d0
      iwe=iwe+1
      weightc(  3,  5,  2)=                 -0.18026714792040893220d0
      iwe=iwe+1
      weightc(  4,  5,  2)=                  0.70568957214822614077d0
      iwe=iwe+1
      weightc(  5,  5,  2)=                 -0.32436510799817264150d0
      iwe=iwe+1
      weightc(  6,  5,  2)=                 -0.18140652683624847175d0
      iwe=iwe+1
      weightc(  7,  5,  2)=                 -0.29108084111119325588d0
      iwe=iwe+1
      weightc(  8,  5,  2)=                 -0.14072069596759570476d0
      iwe=iwe+1
      weightc(  9,  5,  2)=                  0.21205245368116013016d0
      iwe=iwe+1
      weightc( 10,  5,  2)=                  1.02237676047909475940d0
      iwe=iwe+1
      weightc( 11,  5,  2)=                 -0.77663669885447939034d0
      iwe=iwe+1
      weightc( 12,  5,  2)=                  0.41217306050399998840d0
      iwe=iwe+1
      weightc( 13,  5,  2)=                 -0.11929587122155009549d0
      iwe=iwe+1
      weightc( 14,  5,  2)=                 -0.07092459864812579451d0
      iwe=iwe+1
      weightc( 15,  5,  2)=                  0.83073467461858840899d0
      iwe=iwe+1
      weightc( 16,  5,  2)=                  0.32897266517335388425d0
      iwe=iwe+1
      weightc( 17,  5,  2)=                 -1.05646553631110706739d0
      iwe=iwe+1
      biasc(  5,  2)=                  1.19828664934047712798d0
      iwe=iwe+1
      weightc(  1,  6,  2)=                  0.00821926090925835170d0
      iwe=iwe+1
      weightc(  2,  6,  2)=                 -0.04934075478483090221d0
      iwe=iwe+1
      weightc(  3,  6,  2)=                 -0.06897645621594809817d0
      iwe=iwe+1
      weightc(  4,  6,  2)=                  0.45342730959219235132d0
      iwe=iwe+1
      weightc(  5,  6,  2)=                 -0.26732402196027332808d0
      iwe=iwe+1
      weightc(  6,  6,  2)=                  0.36783251221707791156d0
      iwe=iwe+1
      weightc(  7,  6,  2)=                 -0.12851548205305035610d0
      iwe=iwe+1
      weightc(  8,  6,  2)=                  0.63891834119875257070d0
      iwe=iwe+1
      weightc(  9,  6,  2)=                 -0.09726817755591701808d0
      iwe=iwe+1
      weightc( 10,  6,  2)=                 -0.63954660120643325172d0
      iwe=iwe+1
      weightc( 11,  6,  2)=                 -0.46313789987345288512d0
      iwe=iwe+1
      weightc( 12,  6,  2)=                 -0.16646277379025004040d0
      iwe=iwe+1
      weightc( 13,  6,  2)=                  0.62472267068071551943d0
      iwe=iwe+1
      weightc( 14,  6,  2)=                  0.00421155890939516487d0
      iwe=iwe+1
      weightc( 15,  6,  2)=                 -0.44405983027977297128d0
      iwe=iwe+1
      weightc( 16,  6,  2)=                 -0.40003264810761307579d0
      iwe=iwe+1
      weightc( 17,  6,  2)=                  0.26187267379891593366d0
      iwe=iwe+1
      biasc(  6,  2)=                  1.55224789183672884363d0
      iwe=iwe+1
      weightc(  1,  7,  2)=                 -0.59049915990393986309d0
      iwe=iwe+1
      weightc(  2,  7,  2)=                 -0.64671781294112506977d0
      iwe=iwe+1
      weightc(  3,  7,  2)=                 -0.16062500443185864785d0
      iwe=iwe+1
      weightc(  4,  7,  2)=                  0.48575424394592325861d0
      iwe=iwe+1
      weightc(  5,  7,  2)=                 -0.22446105828567181062d0
      iwe=iwe+1
      weightc(  6,  7,  2)=                 -0.09456809052709014285d0
      iwe=iwe+1
      weightc(  7,  7,  2)=                  0.02620780144384861690d0
      iwe=iwe+1
      weightc(  8,  7,  2)=                  0.48412413591900793630d0
      iwe=iwe+1
      weightc(  9,  7,  2)=                 -0.13866031341139223310d0
      iwe=iwe+1
      weightc( 10,  7,  2)=                 -0.62700276021491119227d0
      iwe=iwe+1
      weightc( 11,  7,  2)=                  0.08334591931887842808d0
      iwe=iwe+1
      weightc( 12,  7,  2)=                 -0.59403097465503940100d0
      iwe=iwe+1
      weightc( 13,  7,  2)=                  0.91266758505089506937d0
      iwe=iwe+1
      weightc( 14,  7,  2)=                  0.32576853993596038839d0
      iwe=iwe+1
      weightc( 15,  7,  2)=                 -1.23861497281589949537d0
      iwe=iwe+1
      weightc( 16,  7,  2)=                 -0.70294898638381453360d0
      iwe=iwe+1
      weightc( 17,  7,  2)=                 -0.04866718740138936683d0
      iwe=iwe+1
      biasc(  7,  2)=                  1.16706781964833794518d0
      iwe=iwe+1
      weightc(  1,  8,  2)=                  0.67586438001681026222d0
      iwe=iwe+1
      weightc(  2,  8,  2)=                 -0.47005397230460710389d0
      iwe=iwe+1
      weightc(  3,  8,  2)=                 -1.31317398742999302819d0
      iwe=iwe+1
      weightc(  4,  8,  2)=                 -0.18833538652506440214d0
      iwe=iwe+1
      weightc(  5,  8,  2)=                  0.23892041444469414024d0
      iwe=iwe+1
      weightc(  6,  8,  2)=                 -0.46898741916041142286d0
      iwe=iwe+1
      weightc(  7,  8,  2)=                  0.10779537762065846684d0
      iwe=iwe+1
      weightc(  8,  8,  2)=                  0.04232782014020171346d0
      iwe=iwe+1
      weightc(  9,  8,  2)=                 -2.64448529420712041826d0
      iwe=iwe+1
      weightc( 10,  8,  2)=                 -0.46114499737013975311d0
      iwe=iwe+1
      weightc( 11,  8,  2)=                  0.45391070530082716639d0
      iwe=iwe+1
      weightc( 12,  8,  2)=                  0.62823386794374780351d0
      iwe=iwe+1
      weightc( 13,  8,  2)=                  0.42883896825454898005d0
      iwe=iwe+1
      weightc( 14,  8,  2)=                 -0.10943552846529623623d0
      iwe=iwe+1
      weightc( 15,  8,  2)=                  0.75313372798919853146d0
      iwe=iwe+1
      weightc( 16,  8,  2)=                  0.99940451224571569266d0
      iwe=iwe+1
      weightc( 17,  8,  2)=                 -0.39312949202967728546d0
      iwe=iwe+1
      biasc(  8,  2)=                 -1.87979788147176662960d0
      iwe=iwe+1
      weightc(  1,  9,  2)=                 -0.67757589372947790718d0
      iwe=iwe+1
      weightc(  2,  9,  2)=                  0.64296000031686972864d0
      iwe=iwe+1
      weightc(  3,  9,  2)=                 -0.21338009518299941303d0
      iwe=iwe+1
      weightc(  4,  9,  2)=                  0.17659817351060028146d0
      iwe=iwe+1
      weightc(  5,  9,  2)=                  0.22177659486128423194d0
      iwe=iwe+1
      weightc(  6,  9,  2)=                 -0.27042090488135872572d0
      iwe=iwe+1
      weightc(  7,  9,  2)=                 -0.59998642957534298326d0
      iwe=iwe+1
      weightc(  8,  9,  2)=                 -0.08637411135010494845d0
      iwe=iwe+1
      weightc(  9,  9,  2)=                  0.64052464057179192558d0
      iwe=iwe+1
      weightc( 10,  9,  2)=                 -0.42387551049248506363d0
      iwe=iwe+1
      weightc( 11,  9,  2)=                 -0.19548152956942069225d0
      iwe=iwe+1
      weightc( 12,  9,  2)=                 -0.55582581459975144433d0
      iwe=iwe+1
      weightc( 13,  9,  2)=                  0.71607530082974268915d0
      iwe=iwe+1
      weightc( 14,  9,  2)=                  0.68753807143684508851d0
      iwe=iwe+1
      weightc( 15,  9,  2)=                  1.26753156645551579018d0
      iwe=iwe+1
      weightc( 16,  9,  2)=                  0.01651971886642256485d0
      iwe=iwe+1
      weightc( 17,  9,  2)=                 -0.26919294077044320090d0
      iwe=iwe+1
      biasc(  9,  2)=                  1.19964194151166059221d0
      iwe=iwe+1
      weightc(  1, 10,  2)=                  0.79490320781776813153d0
      iwe=iwe+1
      weightc(  2, 10,  2)=                 -0.00818774563003192915d0
      iwe=iwe+1
      weightc(  3, 10,  2)=                  0.04203004258080843270d0
      iwe=iwe+1
      weightc(  4, 10,  2)=                  0.11035729342659135466d0
      iwe=iwe+1
      weightc(  5, 10,  2)=                  0.09171417738776140027d0
      iwe=iwe+1
      weightc(  6, 10,  2)=                 -0.42963188465709573061d0
      iwe=iwe+1
      weightc(  7, 10,  2)=                  0.11995533092550741960d0
      iwe=iwe+1
      weightc(  8, 10,  2)=                 -0.65114028033311655008d0
      iwe=iwe+1
      weightc(  9, 10,  2)=                  0.27567087679097751485d0
      iwe=iwe+1
      weightc( 10, 10,  2)=                  0.90635869171509142461d0
      iwe=iwe+1
      weightc( 11, 10,  2)=                  0.40151988461261894914d0
      iwe=iwe+1
      weightc( 12, 10,  2)=                  0.10241504089224215401d0
      iwe=iwe+1
      weightc( 13, 10,  2)=                  0.34637624066755295926d0
      iwe=iwe+1
      weightc( 14, 10,  2)=                 -0.10601124028946172506d0
      iwe=iwe+1
      weightc( 15, 10,  2)=                 -0.78275729714232189504d0
      iwe=iwe+1
      weightc( 16, 10,  2)=                 -0.47213983490269961774d0
      iwe=iwe+1
      weightc( 17, 10,  2)=                 -1.13117281010556713916d0
      iwe=iwe+1
      biasc( 10,  2)=                 -1.10754967478484900312d0
      iwe=iwe+1
      weightc(  1, 11,  2)=                  0.21378680280923142987d0
      iwe=iwe+1
      weightc(  2, 11,  2)=                 -0.16815318159281775201d0
      iwe=iwe+1
      weightc(  3, 11,  2)=                  0.25197031838664407655d0
      iwe=iwe+1
      weightc(  4, 11,  2)=                 -0.36237076176100241343d0
      iwe=iwe+1
      weightc(  5, 11,  2)=                  0.09897618561613888422d0
      iwe=iwe+1
      weightc(  6, 11,  2)=                  0.65671257721474729507d0
      iwe=iwe+1
      weightc(  7, 11,  2)=                 -0.29412705181942266908d0
      iwe=iwe+1
      weightc(  8, 11,  2)=                 -0.58707515349375505309d0
      iwe=iwe+1
      weightc(  9, 11,  2)=                  0.10457269348671950626d0
      iwe=iwe+1
      weightc( 10, 11,  2)=                  0.19468803811880069921d0
      iwe=iwe+1
      weightc( 11, 11,  2)=                  0.11229479045300171103d0
      iwe=iwe+1
      weightc( 12, 11,  2)=                  0.85260644687255737750d0
      iwe=iwe+1
      weightc( 13, 11,  2)=                 -0.04064793365542623133d0
      iwe=iwe+1
      weightc( 14, 11,  2)=                 -0.20726396201736868585d0
      iwe=iwe+1
      weightc( 15, 11,  2)=                 -2.05493442539943327318d0
      iwe=iwe+1
      weightc( 16, 11,  2)=                  0.18849126679885080948d0
      iwe=iwe+1
      weightc( 17, 11,  2)=                 -0.98745878288397614941d0
      iwe=iwe+1
      biasc( 11,  2)=                  1.25688300921352635875d0
      iwe=iwe+1
      weightc(  1, 12,  2)=                  0.38572772657928283691d0
      iwe=iwe+1
      weightc(  2, 12,  2)=                 -0.26758591092117040011d0
      iwe=iwe+1
      weightc(  3, 12,  2)=                 -0.63045751420662621278d0
      iwe=iwe+1
      weightc(  4, 12,  2)=                  1.46368846504296001854d0
      iwe=iwe+1
      weightc(  5, 12,  2)=                  1.71451828695594676866d0
      iwe=iwe+1
      weightc(  6, 12,  2)=                 -0.74982254935785008776d0
      iwe=iwe+1
      weightc(  7, 12,  2)=                  0.61591109352695627699d0
      iwe=iwe+1
      weightc(  8, 12,  2)=                 -0.35299375931528820249d0
      iwe=iwe+1
      weightc(  9, 12,  2)=                 -0.36840377361230020048d0
      iwe=iwe+1
      weightc( 10, 12,  2)=                 -1.07596250989183372937d0
      iwe=iwe+1
      weightc( 11, 12,  2)=                  1.70063450750758193841d0
      iwe=iwe+1
      weightc( 12, 12,  2)=                  0.11267567601309232128d0
      iwe=iwe+1
      weightc( 13, 12,  2)=                  0.01286431200364680436d0
      iwe=iwe+1
      weightc( 14, 12,  2)=                 -0.83639816416777335029d0
      iwe=iwe+1
      weightc( 15, 12,  2)=                  0.07191285167922799315d0
      iwe=iwe+1
      weightc( 16, 12,  2)=                  0.07214975975789635065d0
      iwe=iwe+1
      weightc( 17, 12,  2)=                 -0.94933660490660598530d0
      iwe=iwe+1
      biasc( 12,  2)=                  1.46455894406486875070d0
      iwe=iwe+1
      weightc(  1, 13,  2)=                 -0.22810856187694439345d0
      iwe=iwe+1
      weightc(  2, 13,  2)=                  0.40418851672734712466d0
      iwe=iwe+1
      weightc(  3, 13,  2)=                  0.51951795859731408900d0
      iwe=iwe+1
      weightc(  4, 13,  2)=                 -0.81223916724306199910d0
      iwe=iwe+1
      weightc(  5, 13,  2)=                  0.17210768519107802477d0
      iwe=iwe+1
      weightc(  6, 13,  2)=                  0.44895196813603505115d0
      iwe=iwe+1
      weightc(  7, 13,  2)=                 -0.15111763091678526161d0
      iwe=iwe+1
      weightc(  8, 13,  2)=                 -0.43681899643212107609d0
      iwe=iwe+1
      weightc(  9, 13,  2)=                  0.21924043936488252227d0
      iwe=iwe+1
      weightc( 10, 13,  2)=                 -0.33835372074713204738d0
      iwe=iwe+1
      weightc( 11, 13,  2)=                 -0.70315050572607362689d0
      iwe=iwe+1
      weightc( 12, 13,  2)=                  0.48714640868876657454d0
      iwe=iwe+1
      weightc( 13, 13,  2)=                 -0.05691211058555963043d0
      iwe=iwe+1
      weightc( 14, 13,  2)=                  0.19599398456778890920d0
      iwe=iwe+1
      weightc( 15, 13,  2)=                 -0.05667111743562867204d0
      iwe=iwe+1
      weightc( 16, 13,  2)=                 -1.02972866322719958099d0
      iwe=iwe+1
      weightc( 17, 13,  2)=                  0.45902167608979876912d0
      iwe=iwe+1
      biasc( 13,  2)=                  1.08231656909385320908d0
      iwe=iwe+1
      weightc(  1, 14,  2)=                 -0.29558536543849145417d0
      iwe=iwe+1
      weightc(  2, 14,  2)=                  0.72471528960752207293d0
      iwe=iwe+1
      weightc(  3, 14,  2)=                 -0.26931037221652870395d0
      iwe=iwe+1
      weightc(  4, 14,  2)=                  0.16750958060165827002d0
      iwe=iwe+1
      weightc(  5, 14,  2)=                  0.69214465482280806974d0
      iwe=iwe+1
      weightc(  6, 14,  2)=                  0.61193338217701620518d0
      iwe=iwe+1
      weightc(  7, 14,  2)=                 -0.17942375541776539594d0
      iwe=iwe+1
      weightc(  8, 14,  2)=                  0.18890242716310420845d0
      iwe=iwe+1
      weightc(  9, 14,  2)=                 -0.61792800779549261758d0
      iwe=iwe+1
      weightc( 10, 14,  2)=                  0.00381026560847930705d0
      iwe=iwe+1
      weightc( 11, 14,  2)=                  0.40140910701690152296d0
      iwe=iwe+1
      weightc( 12, 14,  2)=                  0.32707073611905790322d0
      iwe=iwe+1
      weightc( 13, 14,  2)=                 -0.16774278102997899897d0
      iwe=iwe+1
      weightc( 14, 14,  2)=                  0.26747706891523753692d0
      iwe=iwe+1
      weightc( 15, 14,  2)=                 -0.49283467385414569950d0
      iwe=iwe+1
      weightc( 16, 14,  2)=                 -0.48069883739081564755d0
      iwe=iwe+1
      weightc( 17, 14,  2)=                  0.01103499186716475587d0
      iwe=iwe+1
      biasc( 14,  2)=                  1.25564436470624718467d0
      iwe=iwe+1
      weightc(  1, 15,  2)=                 -0.51280206410428386121d0
      iwe=iwe+1
      weightc(  2, 15,  2)=                  0.52123627764103674931d0
      iwe=iwe+1
      weightc(  3, 15,  2)=                 -0.75770194359464571043d0
      iwe=iwe+1
      weightc(  4, 15,  2)=                 -0.16949718531641191910d0
      iwe=iwe+1
      weightc(  5, 15,  2)=                  0.67959808766182505657d0
      iwe=iwe+1
      weightc(  6, 15,  2)=                  1.27440740003972252659d0
      iwe=iwe+1
      weightc(  7, 15,  2)=                 -0.94582140923746993444d0
      iwe=iwe+1
      weightc(  8, 15,  2)=                 -0.55703796062048061000d0
      iwe=iwe+1
      weightc(  9, 15,  2)=                 -0.83423494090567285042d0
      iwe=iwe+1
      weightc( 10, 15,  2)=                 -0.21951138515673393470d0
      iwe=iwe+1
      weightc( 11, 15,  2)=                  0.81576906740518140282d0
      iwe=iwe+1
      weightc( 12, 15,  2)=                  0.36015639898773044170d0
      iwe=iwe+1
      weightc( 13, 15,  2)=                  0.47063888404542991717d0
      iwe=iwe+1
      weightc( 14, 15,  2)=                 -0.25398330628264587094d0
      iwe=iwe+1
      weightc( 15, 15,  2)=                 -0.32249311881884090702d0
      iwe=iwe+1
      weightc( 16, 15,  2)=                  0.31784544400287217947d0
      iwe=iwe+1
      weightc( 17, 15,  2)=                 -0.44578709186954967869d0
      iwe=iwe+1
      biasc( 15,  2)=                 -1.40192196992220718954d0
      iwe=iwe+1
      weightc(  1, 16,  2)=                  0.20256511090054243884d0
      iwe=iwe+1
      weightc(  2, 16,  2)=                 -0.26175118417405457416d0
      iwe=iwe+1
      weightc(  3, 16,  2)=                 -0.46840753452929811962d0
      iwe=iwe+1
      weightc(  4, 16,  2)=                  0.63931024518681134339d0
      iwe=iwe+1
      weightc(  5, 16,  2)=                 -0.72328096034235334066d0
      iwe=iwe+1
      weightc(  6, 16,  2)=                  0.24281932125628680197d0
      iwe=iwe+1
      weightc(  7, 16,  2)=                  0.59708999181575039827d0
      iwe=iwe+1
      weightc(  8, 16,  2)=                 -0.25233990184315452376d0
      iwe=iwe+1
      weightc(  9, 16,  2)=                  0.20607467983679114698d0
      iwe=iwe+1
      weightc( 10, 16,  2)=                  0.89099196376999834079d0
      iwe=iwe+1
      weightc( 11, 16,  2)=                  0.43522789641513859316d0
      iwe=iwe+1
      weightc( 12, 16,  2)=                 -0.40140752519497657769d0
      iwe=iwe+1
      weightc( 13, 16,  2)=                 -0.00485860130376277941d0
      iwe=iwe+1
      weightc( 14, 16,  2)=                 -0.46025031453669273951d0
      iwe=iwe+1
      weightc( 15, 16,  2)=                 -0.03686747945055033476d0
      iwe=iwe+1
      weightc( 16, 16,  2)=                  0.31311836320706532000d0
      iwe=iwe+1
      weightc( 17, 16,  2)=                  0.29856915366199021644d0
      iwe=iwe+1
      biasc( 16,  2)=                 -0.47745252519655156931d0
      iwe=iwe+1
      weightc(  1, 17,  2)=                  0.25052013574346143621d0
      iwe=iwe+1
      weightc(  2, 17,  2)=                  0.22815028803374587385d0
      iwe=iwe+1
      weightc(  3, 17,  2)=                  0.02200982667425652878d0
      iwe=iwe+1
      weightc(  4, 17,  2)=                 -0.57633799055333334582d0
      iwe=iwe+1
      weightc(  5, 17,  2)=                 -0.28672876540142433477d0
      iwe=iwe+1
      weightc(  6, 17,  2)=                 -0.95388110406511772421d0
      iwe=iwe+1
      weightc(  7, 17,  2)=                 -0.78560750606650475714d0
      iwe=iwe+1
      weightc(  8, 17,  2)=                 -0.57526435851867474547d0
      iwe=iwe+1
      weightc(  9, 17,  2)=                  0.09940894968742894355d0
      iwe=iwe+1
      weightc( 10, 17,  2)=                  0.56585878171631331934d0
      iwe=iwe+1
      weightc( 11, 17,  2)=                  0.74817496404968253376d0
      iwe=iwe+1
      weightc( 12, 17,  2)=                 -0.28497311966416494222d0
      iwe=iwe+1
      weightc( 13, 17,  2)=                 -0.69974866989501383063d0
      iwe=iwe+1
      weightc( 14, 17,  2)=                  0.36741500684244920993d0
      iwe=iwe+1
      weightc( 15, 17,  2)=                  1.74113509268173283218d0
      iwe=iwe+1
      weightc( 16, 17,  2)=                  0.51243559190811138748d0
      iwe=iwe+1
      weightc( 17, 17,  2)=                  0.15513354240220095237d0
      iwe=iwe+1
      biasc( 17,  2)=                 -0.38517485267415296768d0
      iwe=iwe+1
      weightc(  1, 18,  2)=                 -0.17387871347405811639d0
      iwe=iwe+1
      weightc(  2, 18,  2)=                 -0.64767167452773299896d0
      iwe=iwe+1
      weightc(  3, 18,  2)=                  1.25061275704572771872d0
      iwe=iwe+1
      weightc(  4, 18,  2)=                  0.12515414345031136700d0
      iwe=iwe+1
      weightc(  5, 18,  2)=                 -1.27806974655950877917d0
      iwe=iwe+1
      weightc(  6, 18,  2)=                 -0.60652642602686912543d0
      iwe=iwe+1
      weightc(  7, 18,  2)=                 -1.24708603224585301561d0
      iwe=iwe+1
      weightc(  8, 18,  2)=                  0.96861762507666182564d0
      iwe=iwe+1
      weightc(  9, 18,  2)=                  0.07475938376236557215d0
      iwe=iwe+1
      weightc( 10, 18,  2)=                 -1.40083385549824024352d0
      iwe=iwe+1
      weightc( 11, 18,  2)=                  0.71065297142865035962d0
      iwe=iwe+1
      weightc( 12, 18,  2)=                  0.11610274605449176499d0
      iwe=iwe+1
      weightc( 13, 18,  2)=                 -0.70597356985026504805d0
      iwe=iwe+1
      weightc( 14, 18,  2)=                  0.08336667006711728778d0
      iwe=iwe+1
      weightc( 15, 18,  2)=                  0.20423355878254362272d0
      iwe=iwe+1
      weightc( 16, 18,  2)=                  0.42467290323843892574d0
      iwe=iwe+1
      weightc( 17, 18,  2)=                  0.35347811652677657568d0
      iwe=iwe+1
      biasc( 18,  2)=                 -1.37061234387919506084d0
      iwe=iwe+1
      weightc(  1, 19,  2)=                  0.54428347729260506682d0
      iwe=iwe+1
      weightc(  2, 19,  2)=                  0.29029299068321406940d0
      iwe=iwe+1
      weightc(  3, 19,  2)=                  0.12179329359708222780d0
      iwe=iwe+1
      weightc(  4, 19,  2)=                 -0.83247366785134113698d0
      iwe=iwe+1
      weightc(  5, 19,  2)=                 -0.55146276061346333197d0
      iwe=iwe+1
      weightc(  6, 19,  2)=                  1.32694608065774377614d0
      iwe=iwe+1
      weightc(  7, 19,  2)=                  0.31872536655351257906d0
      iwe=iwe+1
      weightc(  8, 19,  2)=                 -0.73092250266462721608d0
      iwe=iwe+1
      weightc(  9, 19,  2)=                 -0.68698394543945329183d0
      iwe=iwe+1
      weightc( 10, 19,  2)=                  0.93313580231423420841d0
      iwe=iwe+1
      weightc( 11, 19,  2)=                  0.01896631395196796827d0
      iwe=iwe+1
      weightc( 12, 19,  2)=                 -0.31517352795396269549d0
      iwe=iwe+1
      weightc( 13, 19,  2)=                 -0.31983680718744172955d0
      iwe=iwe+1
      weightc( 14, 19,  2)=                 -0.86004486590549944491d0
      iwe=iwe+1
      weightc( 15, 19,  2)=                  0.24286616997846657839d0
      iwe=iwe+1
      weightc( 16, 19,  2)=                  0.55129325895973491090d0
      iwe=iwe+1
      weightc( 17, 19,  2)=                  0.30136295543878705017d0
      iwe=iwe+1
      biasc( 19,  2)=                 -0.39979764424525227051d0
      iwe=iwe+1
      weightc(  1, 20,  2)=                 -0.38788972907368074461d0
      iwe=iwe+1
      weightc(  2, 20,  2)=                 -0.19499138466677468084d0
      iwe=iwe+1
      weightc(  3, 20,  2)=                  0.36228689129373026212d0
      iwe=iwe+1
      weightc(  4, 20,  2)=                 -0.42418096408524980090d0
      iwe=iwe+1
      weightc(  5, 20,  2)=                 -0.02912866112049434381d0
      iwe=iwe+1
      weightc(  6, 20,  2)=                  0.28415922366541129795d0
      iwe=iwe+1
      weightc(  7, 20,  2)=                 -0.26353263795239784129d0
      iwe=iwe+1
      weightc(  8, 20,  2)=                  1.18911611952336704334d0
      iwe=iwe+1
      weightc(  9, 20,  2)=                 -0.00126251310689731483d0
      iwe=iwe+1
      weightc( 10, 20,  2)=                  0.11064955081482398536d0
      iwe=iwe+1
      weightc( 11, 20,  2)=                  0.38308640550899708543d0
      iwe=iwe+1
      weightc( 12, 20,  2)=                 -0.32120598636465119702d0
      iwe=iwe+1
      weightc( 13, 20,  2)=                 -0.26562487564149223074d0
      iwe=iwe+1
      weightc( 14, 20,  2)=                  0.20463676228556948455d0
      iwe=iwe+1
      weightc( 15, 20,  2)=                 -0.56721612356083661588d0
      iwe=iwe+1
      weightc( 16, 20,  2)=                 -0.71471786614230992107d0
      iwe=iwe+1
      weightc( 17, 20,  2)=                 -0.69290020407844032935d0
      iwe=iwe+1
      biasc( 20,  2)=                  0.02725528634233199618d0
      iwe=iwe+1
      weightc(  1, 21,  2)=                  0.64821458964605005448d0
      iwe=iwe+1
      weightc(  2, 21,  2)=                  1.31866230177632837162d0
      iwe=iwe+1
      weightc(  3, 21,  2)=                 -0.60268218504954085279d0
      iwe=iwe+1
      weightc(  4, 21,  2)=                  0.53781219339831465298d0
      iwe=iwe+1
      weightc(  5, 21,  2)=                 -0.13053457377982968790d0
      iwe=iwe+1
      weightc(  6, 21,  2)=                  2.21977349202174734089d0
      iwe=iwe+1
      weightc(  7, 21,  2)=                  0.22012403312031811331d0
      iwe=iwe+1
      weightc(  8, 21,  2)=                 -2.22798332866904358340d0
      iwe=iwe+1
      weightc(  9, 21,  2)=                  0.56707062235193950173d0
      iwe=iwe+1
      weightc( 10, 21,  2)=                  1.47809398150840354269d0
      iwe=iwe+1
      weightc( 11, 21,  2)=                 -0.58245402946482049966d0
      iwe=iwe+1
      weightc( 12, 21,  2)=                  0.15241295473219673706d0
      iwe=iwe+1
      weightc( 13, 21,  2)=                 -0.39530778761227292062d0
      iwe=iwe+1
      weightc( 14, 21,  2)=                 -0.85958042327906147850d0
      iwe=iwe+1
      weightc( 15, 21,  2)=                 -0.78513693233630255097d0
      iwe=iwe+1
      weightc( 16, 21,  2)=                 -0.23401195456767723280d0
      iwe=iwe+1
      weightc( 17, 21,  2)=                 -0.21715995814089636418d0
      iwe=iwe+1
      biasc( 21,  2)=                 -0.29147921944193300181d0
      iwe=iwe+1
      weightc(  1, 22,  2)=                  0.00045454464534717704d0
      iwe=iwe+1
      weightc(  2, 22,  2)=                  0.32530685270493853167d0
      iwe=iwe+1
      weightc(  3, 22,  2)=                 -0.00980006144181169020d0
      iwe=iwe+1
      weightc(  4, 22,  2)=                 -1.30833218106835724726d0
      iwe=iwe+1
      weightc(  5, 22,  2)=                  0.18331224448039426522d0
      iwe=iwe+1
      weightc(  6, 22,  2)=                  0.03570609172595703984d0
      iwe=iwe+1
      weightc(  7, 22,  2)=                  0.16667190534012160663d0
      iwe=iwe+1
      weightc(  8, 22,  2)=                 -0.49503510044089110709d0
      iwe=iwe+1
      weightc(  9, 22,  2)=                  0.38054305520493147963d0
      iwe=iwe+1
      weightc( 10, 22,  2)=                  0.10567400093819527551d0
      iwe=iwe+1
      weightc( 11, 22,  2)=                 -0.44924938319346846560d0
      iwe=iwe+1
      weightc( 12, 22,  2)=                 -1.12785903733338765953d0
      iwe=iwe+1
      weightc( 13, 22,  2)=                  0.69271025770789607101d0
      iwe=iwe+1
      weightc( 14, 22,  2)=                  0.38115420870995381231d0
      iwe=iwe+1
      weightc( 15, 22,  2)=                 -0.97695290332753048634d0
      iwe=iwe+1
      weightc( 16, 22,  2)=                 -0.20736835944105561080d0
      iwe=iwe+1
      weightc( 17, 22,  2)=                  0.57135432367524596753d0
      iwe=iwe+1
      biasc( 22,  2)=                 -0.76001735803360059851d0
      iwe=iwe+1
      weightc(  1, 23,  2)=                 -0.02698129884673117901d0
      iwe=iwe+1
      weightc(  2, 23,  2)=                 -0.19480255385807568325d0
      iwe=iwe+1
      weightc(  3, 23,  2)=                  1.02351615673868767686d0
      iwe=iwe+1
      weightc(  4, 23,  2)=                 -1.75119157253075274916d0
      iwe=iwe+1
      weightc(  5, 23,  2)=                 -0.51179081534358006333d0
      iwe=iwe+1
      weightc(  6, 23,  2)=                 -0.75830150921849015511d0
      iwe=iwe+1
      weightc(  7, 23,  2)=                  0.32248985128113055731d0
      iwe=iwe+1
      weightc(  8, 23,  2)=                  1.75710027080528274901d0
      iwe=iwe+1
      weightc(  9, 23,  2)=                 -0.90299278829072682218d0
      iwe=iwe+1
      weightc( 10, 23,  2)=                  0.17909801363665120433d0
      iwe=iwe+1
      weightc( 11, 23,  2)=                 -0.53716860671619726109d0
      iwe=iwe+1
      weightc( 12, 23,  2)=                 -0.00750953307272972555d0
      iwe=iwe+1
      weightc( 13, 23,  2)=                  0.77958757521120203293d0
      iwe=iwe+1
      weightc( 14, 23,  2)=                 -0.38146959597529084274d0
      iwe=iwe+1
      weightc( 15, 23,  2)=                  0.14728951650958826969d0
      iwe=iwe+1
      weightc( 16, 23,  2)=                 -0.01070320528136353699d0
      iwe=iwe+1
      weightc( 17, 23,  2)=                  0.05295995836796948270d0
      iwe=iwe+1
      biasc( 23,  2)=                 -0.21192998959388562041d0
      iwe=iwe+1
      weightc(  1, 24,  2)=                  0.72346899346120407959d0
      iwe=iwe+1
      weightc(  2, 24,  2)=                 -0.59287144804000257992d0
      iwe=iwe+1
      weightc(  3, 24,  2)=                  0.43214285114034506341d0
      iwe=iwe+1
      weightc(  4, 24,  2)=                 -0.28000269980443054374d0
      iwe=iwe+1
      weightc(  5, 24,  2)=                  0.52584363020632163277d0
      iwe=iwe+1
      weightc(  6, 24,  2)=                  0.38268317452703048964d0
      iwe=iwe+1
      weightc(  7, 24,  2)=                  0.13181969110519636823d0
      iwe=iwe+1
      weightc(  8, 24,  2)=                 -0.60034434544541848133d0
      iwe=iwe+1
      weightc(  9, 24,  2)=                 -1.50339053442106962422d0
      iwe=iwe+1
      weightc( 10, 24,  2)=                 -0.82961330249689113625d0
      iwe=iwe+1
      weightc( 11, 24,  2)=                 -0.48856951201919918137d0
      iwe=iwe+1
      weightc( 12, 24,  2)=                  0.51755584151830791306d0
      iwe=iwe+1
      weightc( 13, 24,  2)=                  0.66029598499081176843d0
      iwe=iwe+1
      weightc( 14, 24,  2)=                  0.24734843217383226111d0
      iwe=iwe+1
      weightc( 15, 24,  2)=                  0.71682797065109782331d0
      iwe=iwe+1
      weightc( 16, 24,  2)=                  0.39002775079391632795d0
      iwe=iwe+1
      weightc( 17, 24,  2)=                 -0.34637059035588629863d0
      iwe=iwe+1
      biasc( 24,  2)=                 -0.84427668478795248053d0
      iwe=iwe+1
      weightc(  1, 25,  2)=                  0.49083489600570689992d0
      iwe=iwe+1
      weightc(  2, 25,  2)=                 -0.23790914395911408330d0
      iwe=iwe+1
      weightc(  3, 25,  2)=                  0.65197674296456187282d0
      iwe=iwe+1
      weightc(  4, 25,  2)=                 -0.39871207276160003374d0
      iwe=iwe+1
      weightc(  5, 25,  2)=                  0.49731994103144483432d0
      iwe=iwe+1
      weightc(  6, 25,  2)=                  0.60946820797734635455d0
      iwe=iwe+1
      weightc(  7, 25,  2)=                  0.81344126298006469433d0
      iwe=iwe+1
      weightc(  8, 25,  2)=                  0.39493690505174039451d0
      iwe=iwe+1
      weightc(  9, 25,  2)=                  0.04456223913200191289d0
      iwe=iwe+1
      weightc( 10, 25,  2)=                  0.60151310997541218573d0
      iwe=iwe+1
      weightc( 11, 25,  2)=                  0.22087740286910856335d0
      iwe=iwe+1
      weightc( 12, 25,  2)=                  0.18265820632600279771d0
      iwe=iwe+1
      weightc( 13, 25,  2)=                  0.21469332962651194174d0
      iwe=iwe+1
      weightc( 14, 25,  2)=                 -0.26582762233531698204d0
      iwe=iwe+1
      weightc( 15, 25,  2)=                 -0.63563463887937632357d0
      iwe=iwe+1
      weightc( 16, 25,  2)=                 -0.33902592867998970760d0
      iwe=iwe+1
      weightc( 17, 25,  2)=                 -0.57582218458443645837d0
      iwe=iwe+1
      biasc( 25,  2)=                  0.16538944210258638146d0
      iwe=iwe+1
      weightc(  1, 26,  2)=                 -0.54291034900735146707d0
      iwe=iwe+1
      weightc(  2, 26,  2)=                 -0.46046127521767382662d0
      iwe=iwe+1
      weightc(  3, 26,  2)=                  0.00295691851254228401d0
      iwe=iwe+1
      weightc(  4, 26,  2)=                 -0.29466962033874144478d0
      iwe=iwe+1
      weightc(  5, 26,  2)=                  0.22388654224946386018d0
      iwe=iwe+1
      weightc(  6, 26,  2)=                 -0.66010018595806752018d0
      iwe=iwe+1
      weightc(  7, 26,  2)=                 -1.07749947622088515509d0
      iwe=iwe+1
      weightc(  8, 26,  2)=                 -0.48523887117149455683d0
      iwe=iwe+1
      weightc(  9, 26,  2)=                 -0.47432883664741698482d0
      iwe=iwe+1
      weightc( 10, 26,  2)=                 -0.28524623503783397283d0
      iwe=iwe+1
      weightc( 11, 26,  2)=                 -0.38295828043491420001d0
      iwe=iwe+1
      weightc( 12, 26,  2)=                 -0.00664317642689899422d0
      iwe=iwe+1
      weightc( 13, 26,  2)=                  0.24201612054097115800d0
      iwe=iwe+1
      weightc( 14, 26,  2)=                 -0.62125190149936171391d0
      iwe=iwe+1
      weightc( 15, 26,  2)=                  0.64430814194879726386d0
      iwe=iwe+1
      weightc( 16, 26,  2)=                  1.11832486574736944540d0
      iwe=iwe+1
      weightc( 17, 26,  2)=                  0.25445368161311521238d0
      iwe=iwe+1
      biasc( 26,  2)=                 -0.63906410302825167324d0
      iwe=iwe+1
      weightc(  1, 27,  2)=                 -0.63878587471535408504d0
      iwe=iwe+1
      weightc(  2, 27,  2)=                  0.28243190757411601455d0
      iwe=iwe+1
      weightc(  3, 27,  2)=                  1.13638787277220254524d0
      iwe=iwe+1
      weightc(  4, 27,  2)=                  0.87558184842524366953d0
      iwe=iwe+1
      weightc(  5, 27,  2)=                 -0.23160325518326513317d0
      iwe=iwe+1
      weightc(  6, 27,  2)=                 -0.40995270895128882449d0
      iwe=iwe+1
      weightc(  7, 27,  2)=                  0.99063373394295994867d0
      iwe=iwe+1
      weightc(  8, 27,  2)=                  0.08476377850832696181d0
      iwe=iwe+1
      weightc(  9, 27,  2)=                 -1.15856259651693394019d0
      iwe=iwe+1
      weightc( 10, 27,  2)=                  0.35359086681606299862d0
      iwe=iwe+1
      weightc( 11, 27,  2)=                  0.68271928731140130164d0
      iwe=iwe+1
      weightc( 12, 27,  2)=                  0.43981148580663537162d0
      iwe=iwe+1
      weightc( 13, 27,  2)=                  0.75020125944509830074d0
      iwe=iwe+1
      weightc( 14, 27,  2)=                 -0.58314150318970270348d0
      iwe=iwe+1
      weightc( 15, 27,  2)=                  0.04764088226322656106d0
      iwe=iwe+1
      weightc( 16, 27,  2)=                 -0.72551425721155071713d0
      iwe=iwe+1
      weightc( 17, 27,  2)=                 -1.26265861547140878507d0
      iwe=iwe+1
      biasc( 27,  2)=                  0.28717316278599153145d0
      iwe=iwe+1
      weightc(  1, 28,  2)=                  0.55062811676014156159d0
      iwe=iwe+1
      weightc(  2, 28,  2)=                 -0.13460187343509510960d0
      iwe=iwe+1
      weightc(  3, 28,  2)=                  0.33905753114214282062d0
      iwe=iwe+1
      weightc(  4, 28,  2)=                  0.60523251371573782986d0
      iwe=iwe+1
      weightc(  5, 28,  2)=                 -0.49607150114906861660d0
      iwe=iwe+1
      weightc(  6, 28,  2)=                 -0.56430727149240367257d0
      iwe=iwe+1
      weightc(  7, 28,  2)=                  0.63615284545190819987d0
      iwe=iwe+1
      weightc(  8, 28,  2)=                  0.74284012393635767690d0
      iwe=iwe+1
      weightc(  9, 28,  2)=                 -0.39917192854122551804d0
      iwe=iwe+1
      weightc( 10, 28,  2)=                 -0.34868111873092744180d0
      iwe=iwe+1
      weightc( 11, 28,  2)=                 -0.40019006225722753012d0
      iwe=iwe+1
      weightc( 12, 28,  2)=                 -0.47213236488106752331d0
      iwe=iwe+1
      weightc( 13, 28,  2)=                  0.45953406588578105119d0
      iwe=iwe+1
      weightc( 14, 28,  2)=                 -0.29080475070595251941d0
      iwe=iwe+1
      weightc( 15, 28,  2)=                  0.34422875090633364703d0
      iwe=iwe+1
      weightc( 16, 28,  2)=                 -0.20548988533652284838d0
      iwe=iwe+1
      weightc( 17, 28,  2)=                  0.61511972820538740603d0
      iwe=iwe+1
      biasc( 28,  2)=                 -0.08535520399512154521d0
      iwe=iwe+1
      weightc(  1, 29,  2)=                 -0.28663739237683688588d0
      iwe=iwe+1
      weightc(  2, 29,  2)=                 -0.39710073495117775844d0
      iwe=iwe+1
      weightc(  3, 29,  2)=                  0.47542988854158457768d0
      iwe=iwe+1
      weightc(  4, 29,  2)=                 -0.20235339498701246375d0
      iwe=iwe+1
      weightc(  5, 29,  2)=                 -0.37555983430534733980d0
      iwe=iwe+1
      weightc(  6, 29,  2)=                 -0.48808008426791399392d0
      iwe=iwe+1
      weightc(  7, 29,  2)=                 -0.77592942155709543339d0
      iwe=iwe+1
      weightc(  8, 29,  2)=                  0.38432218184650873694d0
      iwe=iwe+1
      weightc(  9, 29,  2)=                  0.15876732986734762298d0
      iwe=iwe+1
      weightc( 10, 29,  2)=                 -1.06375703582345049192d0
      iwe=iwe+1
      weightc( 11, 29,  2)=                 -0.72389766276540257195d0
      iwe=iwe+1
      weightc( 12, 29,  2)=                  0.58096760620116294493d0
      iwe=iwe+1
      weightc( 13, 29,  2)=                  0.07290651103346328099d0
      iwe=iwe+1
      weightc( 14, 29,  2)=                  0.18144044298422062900d0
      iwe=iwe+1
      weightc( 15, 29,  2)=                  0.70790765119900378455d0
      iwe=iwe+1
      weightc( 16, 29,  2)=                  0.02976788152380849609d0
      iwe=iwe+1
      weightc( 17, 29,  2)=                 -0.01307477657321544709d0
      iwe=iwe+1
      biasc( 29,  2)=                 -0.20465944767071880817d0
      iwe=iwe+1
      weightc(  1, 30,  2)=                  0.25110443789806713433d0
      iwe=iwe+1
      weightc(  2, 30,  2)=                 -0.13572950400559555262d0
      iwe=iwe+1
      weightc(  3, 30,  2)=                 -0.40574537163529522665d0
      iwe=iwe+1
      weightc(  4, 30,  2)=                  1.12619258403911581823d0
      iwe=iwe+1
      weightc(  5, 30,  2)=                 -0.29671448614859430304d0
      iwe=iwe+1
      weightc(  6, 30,  2)=                  0.17512733917965073172d0
      iwe=iwe+1
      weightc(  7, 30,  2)=                 -0.23978480489200912351d0
      iwe=iwe+1
      weightc(  8, 30,  2)=                  0.07690069392012328919d0
      iwe=iwe+1
      weightc(  9, 30,  2)=                 -1.12587232685785720854d0
      iwe=iwe+1
      weightc( 10, 30,  2)=                 -0.26604344732822843289d0
      iwe=iwe+1
      weightc( 11, 30,  2)=                 -0.08746521982637711634d0
      iwe=iwe+1
      weightc( 12, 30,  2)=                  0.29770048557858197480d0
      iwe=iwe+1
      weightc( 13, 30,  2)=                  0.66454591912851690427d0
      iwe=iwe+1
      weightc( 14, 30,  2)=                  0.61242153359363404874d0
      iwe=iwe+1
      weightc( 15, 30,  2)=                 -0.65114875481213063679d0
      iwe=iwe+1
      weightc( 16, 30,  2)=                  0.56529706515228439478d0
      iwe=iwe+1
      weightc( 17, 30,  2)=                 -0.38736633662757063989d0
      iwe=iwe+1
      biasc( 30,  2)=                  0.06030462745674974173d0
      iwe=iwe+1
      weightc(  1, 31,  2)=                 -0.42587173559700558512d0
      iwe=iwe+1
      weightc(  2, 31,  2)=                  0.84064896285886336891d0
      iwe=iwe+1
      weightc(  3, 31,  2)=                  0.25561683415920499751d0
      iwe=iwe+1
      weightc(  4, 31,  2)=                  0.51749343482704623920d0
      iwe=iwe+1
      weightc(  5, 31,  2)=                 -0.72897667121788178868d0
      iwe=iwe+1
      weightc(  6, 31,  2)=                  1.26135730961963044017d0
      iwe=iwe+1
      weightc(  7, 31,  2)=                 -0.21733163699951157932d0
      iwe=iwe+1
      weightc(  8, 31,  2)=                  1.20503568900738278202d0
      iwe=iwe+1
      weightc(  9, 31,  2)=                  0.10844012336595595936d0
      iwe=iwe+1
      weightc( 10, 31,  2)=                 -0.52349941405971545105d0
      iwe=iwe+1
      weightc( 11, 31,  2)=                 -0.02659625829343461798d0
      iwe=iwe+1
      weightc( 12, 31,  2)=                 -0.58373733827945650798d0
      iwe=iwe+1
      weightc( 13, 31,  2)=                 -0.25813311419897766452d0
      iwe=iwe+1
      weightc( 14, 31,  2)=                 -0.81971095011908945427d0
      iwe=iwe+1
      weightc( 15, 31,  2)=                 -0.35177474831970295677d0
      iwe=iwe+1
      weightc( 16, 31,  2)=                 -0.52813032616964661337d0
      iwe=iwe+1
      weightc( 17, 31,  2)=                 -0.83230744878446616397d0
      iwe=iwe+1
      biasc( 31,  2)=                 -0.25139687213210143435d0
      iwe=iwe+1
      weightc(  1, 32,  2)=                  1.10710640963907414047d0
      iwe=iwe+1
      weightc(  2, 32,  2)=                  0.71791522984384936734d0
      iwe=iwe+1
      weightc(  3, 32,  2)=                  0.56619283031439349152d0
      iwe=iwe+1
      weightc(  4, 32,  2)=                 -0.86807246866504994554d0
      iwe=iwe+1
      weightc(  5, 32,  2)=                 -0.54621279674994727138d0
      iwe=iwe+1
      weightc(  6, 32,  2)=                 -0.02118425827639446035d0
      iwe=iwe+1
      weightc(  7, 32,  2)=                  0.47793889026046471047d0
      iwe=iwe+1
      weightc(  8, 32,  2)=                  1.30824663782459693628d0
      iwe=iwe+1
      weightc(  9, 32,  2)=                  1.45131346169397756896d0
      iwe=iwe+1
      weightc( 10, 32,  2)=                 -0.77037585665259600276d0
      iwe=iwe+1
      weightc( 11, 32,  2)=                 -0.30675340442803189500d0
      iwe=iwe+1
      weightc( 12, 32,  2)=                 -0.81229918709249127051d0
      iwe=iwe+1
      weightc( 13, 32,  2)=                 -0.06100164731800712670d0
      iwe=iwe+1
      weightc( 14, 32,  2)=                 -0.09200637381397765158d0
      iwe=iwe+1
      weightc( 15, 32,  2)=                  0.17807485125262792480d0
      iwe=iwe+1
      weightc( 16, 32,  2)=                 -1.22530472143394120188d0
      iwe=iwe+1
      weightc( 17, 32,  2)=                  0.07178502247639485800d0
      iwe=iwe+1
      biasc( 32,  2)=                  0.25342943308530913038d0
      iwe=iwe+1
      weightc(  1, 33,  2)=                 -0.51407724161278645081d0
      iwe=iwe+1
      weightc(  2, 33,  2)=                  0.47214040777662902304d0
      iwe=iwe+1
      weightc(  3, 33,  2)=                 -0.43243666927466162253d0
      iwe=iwe+1
      weightc(  4, 33,  2)=                 -0.05891937205179135356d0
      iwe=iwe+1
      weightc(  5, 33,  2)=                 -0.00520860453953701959d0
      iwe=iwe+1
      weightc(  6, 33,  2)=                 -0.00235239801090301320d0
      iwe=iwe+1
      weightc(  7, 33,  2)=                 -0.09410793476558786119d0
      iwe=iwe+1
      weightc(  8, 33,  2)=                  0.27187380368779145989d0
      iwe=iwe+1
      weightc(  9, 33,  2)=                  0.49649939507532692140d0
      iwe=iwe+1
      weightc( 10, 33,  2)=                  0.31318948358884574068d0
      iwe=iwe+1
      weightc( 11, 33,  2)=                  0.18241044887980475964d0
      iwe=iwe+1
      weightc( 12, 33,  2)=                 -0.07901825999763194275d0
      iwe=iwe+1
      weightc( 13, 33,  2)=                  0.18697592925055878110d0
      iwe=iwe+1
      weightc( 14, 33,  2)=                  0.30975588605243642437d0
      iwe=iwe+1
      weightc( 15, 33,  2)=                  0.50898670223711328653d0
      iwe=iwe+1
      weightc( 16, 33,  2)=                  0.50663860859022036287d0
      iwe=iwe+1
      weightc( 17, 33,  2)=                  0.45346316776345546584d0
      iwe=iwe+1
      biasc( 33,  2)=                 -0.25651473965942223066d0
      iwe=iwe+1
      weightc(  1, 34,  2)=                 -0.88644832018280095287d0
      iwe=iwe+1
      weightc(  2, 34,  2)=                 -0.35616429870183996531d0
      iwe=iwe+1
      weightc(  3, 34,  2)=                 -0.31254525624757495406d0
      iwe=iwe+1
      weightc(  4, 34,  2)=                  0.08387208647790818372d0
      iwe=iwe+1
      weightc(  5, 34,  2)=                  0.84385057526943774153d0
      iwe=iwe+1
      weightc(  6, 34,  2)=                  0.89132214697132883252d0
      iwe=iwe+1
      weightc(  7, 34,  2)=                  0.33561960496244175323d0
      iwe=iwe+1
      weightc(  8, 34,  2)=                  0.58745755569925328654d0
      iwe=iwe+1
      weightc(  9, 34,  2)=                 -0.15089266858410496641d0
      iwe=iwe+1
      weightc( 10, 34,  2)=                 -0.25203227582965626041d0
      iwe=iwe+1
      weightc( 11, 34,  2)=                  0.61310104638242979291d0
      iwe=iwe+1
      weightc( 12, 34,  2)=                 -0.84165771474524064821d0
      iwe=iwe+1
      weightc( 13, 34,  2)=                 -0.35932324438182150494d0
      iwe=iwe+1
      weightc( 14, 34,  2)=                 -0.28285964935879509552d0
      iwe=iwe+1
      weightc( 15, 34,  2)=                  0.40814998423434928343d0
      iwe=iwe+1
      weightc( 16, 34,  2)=                 -0.16581460911363452015d0
      iwe=iwe+1
      weightc( 17, 34,  2)=                 -0.73632465269218894122d0
      iwe=iwe+1
      biasc( 34,  2)=                 -0.88030915874540804911d0
      iwe=iwe+1
      weightc(  1, 35,  2)=                  0.64546741263508067288d0
      iwe=iwe+1
      weightc(  2, 35,  2)=                  0.51981965464317303471d0
      iwe=iwe+1
      weightc(  3, 35,  2)=                 -0.13820279199927093527d0
      iwe=iwe+1
      weightc(  4, 35,  2)=                 -0.64152359845984174846d0
      iwe=iwe+1
      weightc(  5, 35,  2)=                  0.11766555708549554515d0
      iwe=iwe+1
      weightc(  6, 35,  2)=                  0.32138469651759443702d0
      iwe=iwe+1
      weightc(  7, 35,  2)=                 -0.95606490260549048532d0
      iwe=iwe+1
      weightc(  8, 35,  2)=                 -0.40486617020407761336d0
      iwe=iwe+1
      weightc(  9, 35,  2)=                  0.82036698428677690131d0
      iwe=iwe+1
      weightc( 10, 35,  2)=                 -0.03553416475105780625d0
      iwe=iwe+1
      weightc( 11, 35,  2)=                 -0.46878914094055584849d0
      iwe=iwe+1
      weightc( 12, 35,  2)=                 -0.40932028121601227166d0
      iwe=iwe+1
      weightc( 13, 35,  2)=                  0.21264574562428498194d0
      iwe=iwe+1
      weightc( 14, 35,  2)=                 -0.43011751199086450947d0
      iwe=iwe+1
      weightc( 15, 35,  2)=                 -0.55895612866934585306d0
      iwe=iwe+1
      weightc( 16, 35,  2)=                 -0.11927353755850082784d0
      iwe=iwe+1
      weightc( 17, 35,  2)=                  0.75935702403906979452d0
      iwe=iwe+1
      biasc( 35,  2)=                  0.28936378252073369222d0
      iwe=iwe+1
      weightc(  1, 36,  2)=                 -0.02261076358428849159d0
      iwe=iwe+1
      weightc(  2, 36,  2)=                  0.59259270542894437739d0
      iwe=iwe+1
      weightc(  3, 36,  2)=                 -0.86390599975167337021d0
      iwe=iwe+1
      weightc(  4, 36,  2)=                  0.19684243241310195316d0
      iwe=iwe+1
      weightc(  5, 36,  2)=                  0.20548079187839310422d0
      iwe=iwe+1
      weightc(  6, 36,  2)=                  1.03089197414790190166d0
      iwe=iwe+1
      weightc(  7, 36,  2)=                 -0.37676992889710436696d0
      iwe=iwe+1
      weightc(  8, 36,  2)=                 -0.98051564855489170558d0
      iwe=iwe+1
      weightc(  9, 36,  2)=                  0.34351214529514145779d0
      iwe=iwe+1
      weightc( 10, 36,  2)=                  1.25355439335901075459d0
      iwe=iwe+1
      weightc( 11, 36,  2)=                 -0.03727090901669930650d0
      iwe=iwe+1
      weightc( 12, 36,  2)=                 -0.17518564328435143329d0
      iwe=iwe+1
      weightc( 13, 36,  2)=                 -0.18114363322552728963d0
      iwe=iwe+1
      weightc( 14, 36,  2)=                  0.86032097479985147892d0
      iwe=iwe+1
      weightc( 15, 36,  2)=                 -0.61901183566140682846d0
      iwe=iwe+1
      weightc( 16, 36,  2)=                 -0.66652790311940424139d0
      iwe=iwe+1
      weightc( 17, 36,  2)=                  0.35488260401589005744d0
      iwe=iwe+1
      biasc( 36,  2)=                 -0.73064088644723201860d0
      iwe=iwe+1
      weightc(  1, 37,  2)=                  0.47123223313636453113d0
      iwe=iwe+1
      weightc(  2, 37,  2)=                 -0.53098213005953853738d0
      iwe=iwe+1
      weightc(  3, 37,  2)=                  0.15520711686779234406d0
      iwe=iwe+1
      weightc(  4, 37,  2)=                 -0.57014026228601588642d0
      iwe=iwe+1
      weightc(  5, 37,  2)=                  0.14326061681639495893d0
      iwe=iwe+1
      weightc(  6, 37,  2)=                  0.71891449957802766590d0
      iwe=iwe+1
      weightc(  7, 37,  2)=                  0.43095932362005506810d0
      iwe=iwe+1
      weightc(  8, 37,  2)=                  0.53151816945264140912d0
      iwe=iwe+1
      weightc(  9, 37,  2)=                 -0.50893382478056992113d0
      iwe=iwe+1
      weightc( 10, 37,  2)=                  0.64848959827078078710d0
      iwe=iwe+1
      weightc( 11, 37,  2)=                 -0.52291947447104691893d0
      iwe=iwe+1
      weightc( 12, 37,  2)=                  0.61654331717076349406d0
      iwe=iwe+1
      weightc( 13, 37,  2)=                  0.87953115330848696818d0
      iwe=iwe+1
      weightc( 14, 37,  2)=                  0.37429820297410587582d0
      iwe=iwe+1
      weightc( 15, 37,  2)=                 -0.55680192617979373804d0
      iwe=iwe+1
      weightc( 16, 37,  2)=                 -0.51666813689744106597d0
      iwe=iwe+1
      weightc( 17, 37,  2)=                  0.43855943269707231558d0
      iwe=iwe+1
      biasc( 37,  2)=                  1.10526754063602283829d0
      iwe=iwe+1
      weightc(  1, 38,  2)=                  0.33755576674141313243d0
      iwe=iwe+1
      weightc(  2, 38,  2)=                 -0.07173698228556107948d0
      iwe=iwe+1
      weightc(  3, 38,  2)=                 -0.16345804314761494536d0
      iwe=iwe+1
      weightc(  4, 38,  2)=                  0.37932610690982698776d0
      iwe=iwe+1
      weightc(  5, 38,  2)=                  0.29512921075158249362d0
      iwe=iwe+1
      weightc(  6, 38,  2)=                 -1.13818036114352016952d0
      iwe=iwe+1
      weightc(  7, 38,  2)=                 -0.23209818582791852393d0
      iwe=iwe+1
      weightc(  8, 38,  2)=                 -0.51934486312732264235d0
      iwe=iwe+1
      weightc(  9, 38,  2)=                 -0.30022801498509049667d0
      iwe=iwe+1
      weightc( 10, 38,  2)=                  0.43965150028688654293d0
      iwe=iwe+1
      weightc( 11, 38,  2)=                 -0.22416713162492302169d0
      iwe=iwe+1
      weightc( 12, 38,  2)=                 -0.60264242999909523046d0
      iwe=iwe+1
      weightc( 13, 38,  2)=                  0.29980489783600272613d0
      iwe=iwe+1
      weightc( 14, 38,  2)=                 -0.14468141708653226019d0
      iwe=iwe+1
      weightc( 15, 38,  2)=                  0.17028836287670190419d0
      iwe=iwe+1
      weightc( 16, 38,  2)=                 -0.02205734463178050594d0
      iwe=iwe+1
      weightc( 17, 38,  2)=                 -0.46338190766574655077d0
      iwe=iwe+1
      biasc( 38,  2)=                  1.02281015893885074419d0
      iwe=iwe+1
      weightc(  1, 39,  2)=                  0.09234681683652655459d0
      iwe=iwe+1
      weightc(  2, 39,  2)=                  0.73602225094905415759d0
      iwe=iwe+1
      weightc(  3, 39,  2)=                  0.18448759449202326022d0
      iwe=iwe+1
      weightc(  4, 39,  2)=                 -0.15562919130982366678d0
      iwe=iwe+1
      weightc(  5, 39,  2)=                  0.09894478248210340776d0
      iwe=iwe+1
      weightc(  6, 39,  2)=                 -0.17338669723447572291d0
      iwe=iwe+1
      weightc(  7, 39,  2)=                 -0.65417695889575455670d0
      iwe=iwe+1
      weightc(  8, 39,  2)=                 -0.07783356757906613466d0
      iwe=iwe+1
      weightc(  9, 39,  2)=                 -0.75859480306934545801d0
      iwe=iwe+1
      weightc( 10, 39,  2)=                 -1.17573854739409378034d0
      iwe=iwe+1
      weightc( 11, 39,  2)=                 -0.23621641226241729683d0
      iwe=iwe+1
      weightc( 12, 39,  2)=                 -0.87430335277730075738d0
      iwe=iwe+1
      weightc( 13, 39,  2)=                  0.54338624615247899108d0
      iwe=iwe+1
      weightc( 14, 39,  2)=                 -0.45059388583639548020d0
      iwe=iwe+1
      weightc( 15, 39,  2)=                  0.08708277567856605172d0
      iwe=iwe+1
      weightc( 16, 39,  2)=                  0.57374931166055553877d0
      iwe=iwe+1
      weightc( 17, 39,  2)=                 -0.37347468616715190359d0
      iwe=iwe+1
      biasc( 39,  2)=                 -1.57674848598523276166d0
      iwe=iwe+1
      weightc(  1, 40,  2)=                  0.20426546153033928177d0
      iwe=iwe+1
      weightc(  2, 40,  2)=                 -0.05786912387361838744d0
      iwe=iwe+1
      weightc(  3, 40,  2)=                 -0.03409311886452465190d0
      iwe=iwe+1
      weightc(  4, 40,  2)=                 -0.71507274584654934024d0
      iwe=iwe+1
      weightc(  5, 40,  2)=                 -0.49797342379556625014d0
      iwe=iwe+1
      weightc(  6, 40,  2)=                  0.98489766490728591908d0
      iwe=iwe+1
      weightc(  7, 40,  2)=                 -0.08059240706616802030d0
      iwe=iwe+1
      weightc(  8, 40,  2)=                  0.23794954963622000355d0
      iwe=iwe+1
      weightc(  9, 40,  2)=                 -0.06351928157992231538d0
      iwe=iwe+1
      weightc( 10, 40,  2)=                  0.64969711398269691660d0
      iwe=iwe+1
      weightc( 11, 40,  2)=                 -0.17500706596537479731d0
      iwe=iwe+1
      weightc( 12, 40,  2)=                  0.66228789902614404461d0
      iwe=iwe+1
      weightc( 13, 40,  2)=                 -0.26721878305154334043d0
      iwe=iwe+1
      weightc( 14, 40,  2)=                  0.66072452412931192978d0
      iwe=iwe+1
      weightc( 15, 40,  2)=                  0.67842317330498691508d0
      iwe=iwe+1
      weightc( 16, 40,  2)=                  0.09037661111283830373d0
      iwe=iwe+1
      weightc( 17, 40,  2)=                 -0.25738019939821404902d0
      iwe=iwe+1
      biasc( 40,  2)=                  1.04354193119282512292d0
      iwe=iwe+1
      weightc(  1, 41,  2)=                 -0.33229644800282387429d0
      iwe=iwe+1
      weightc(  2, 41,  2)=                 -0.12866423005535029822d0
      iwe=iwe+1
      weightc(  3, 41,  2)=                  0.42253079412065436271d0
      iwe=iwe+1
      weightc(  4, 41,  2)=                 -0.52867756601576854081d0
      iwe=iwe+1
      weightc(  5, 41,  2)=                  0.03151155142766491613d0
      iwe=iwe+1
      weightc(  6, 41,  2)=                  0.12508855041284774878d0
      iwe=iwe+1
      weightc(  7, 41,  2)=                  0.57924157062652381622d0
      iwe=iwe+1
      weightc(  8, 41,  2)=                 -0.64631076886351446209d0
      iwe=iwe+1
      weightc(  9, 41,  2)=                 -0.23631625065503708560d0
      iwe=iwe+1
      weightc( 10, 41,  2)=                  0.39723154540874411333d0
      iwe=iwe+1
      weightc( 11, 41,  2)=                  0.65927881309069746862d0
      iwe=iwe+1
      weightc( 12, 41,  2)=                 -0.33311117155311187332d0
      iwe=iwe+1
      weightc( 13, 41,  2)=                  0.15117196688211453903d0
      iwe=iwe+1
      weightc( 14, 41,  2)=                  0.52061335909138972688d0
      iwe=iwe+1
      weightc( 15, 41,  2)=                  0.21429048317379864597d0
      iwe=iwe+1
      weightc( 16, 41,  2)=                 -0.17096657952554480953d0
      iwe=iwe+1
      weightc( 17, 41,  2)=                  0.77229058314916998462d0
      iwe=iwe+1
      biasc( 41,  2)=                 -1.22854875472043989504d0
      iwe=iwe+1
      weightc(  1, 42,  2)=                  0.14817525734021724793d0
      iwe=iwe+1
      weightc(  2, 42,  2)=                  0.35699810430522760374d0
      iwe=iwe+1
      weightc(  3, 42,  2)=                  0.29992392872772355439d0
      iwe=iwe+1
      weightc(  4, 42,  2)=                 -0.17527885424110495327d0
      iwe=iwe+1
      weightc(  5, 42,  2)=                 -0.40759272806717788962d0
      iwe=iwe+1
      weightc(  6, 42,  2)=                  1.00289803083544759588d0
      iwe=iwe+1
      weightc(  7, 42,  2)=                  0.20068686391093534804d0
      iwe=iwe+1
      weightc(  8, 42,  2)=                 -0.33728766011541000402d0
      iwe=iwe+1
      weightc(  9, 42,  2)=                  0.34773930691718968333d0
      iwe=iwe+1
      weightc( 10, 42,  2)=                  0.88347812852359841607d0
      iwe=iwe+1
      weightc( 11, 42,  2)=                  0.72406950384487656081d0
      iwe=iwe+1
      weightc( 12, 42,  2)=                  0.38573959937405788434d0
      iwe=iwe+1
      weightc( 13, 42,  2)=                 -1.19083745945112307041d0
      iwe=iwe+1
      weightc( 14, 42,  2)=                 -0.87764460628610430071d0
      iwe=iwe+1
      weightc( 15, 42,  2)=                 -0.50529427572291829573d0
      iwe=iwe+1
      weightc( 16, 42,  2)=                  0.18688167290905366436d0
      iwe=iwe+1
      weightc( 17, 42,  2)=                 -0.65626560246423903955d0
      iwe=iwe+1
      biasc( 42,  2)=                 -1.37859298186189560553d0
      iwe=iwe+1
      weightc(  1, 43,  2)=                  0.63217429610462205769d0
      iwe=iwe+1
      weightc(  2, 43,  2)=                  0.53609481249679347137d0
      iwe=iwe+1
      weightc(  3, 43,  2)=                  0.00511441847021780211d0
      iwe=iwe+1
      weightc(  4, 43,  2)=                 -0.08987773548351005171d0
      iwe=iwe+1
      weightc(  5, 43,  2)=                  0.70344389312360089406d0
      iwe=iwe+1
      weightc(  6, 43,  2)=                 -0.49076426077308099583d0
      iwe=iwe+1
      weightc(  7, 43,  2)=                 -0.50513328638229915146d0
      iwe=iwe+1
      weightc(  8, 43,  2)=                  0.34982024453603632885d0
      iwe=iwe+1
      weightc(  9, 43,  2)=                  0.27835783339541897430d0
      iwe=iwe+1
      weightc( 10, 43,  2)=                 -0.25339237933918046242d0
      iwe=iwe+1
      weightc( 11, 43,  2)=                 -0.36701814888107719970d0
      iwe=iwe+1
      weightc( 12, 43,  2)=                 -0.18175994935516198714d0
      iwe=iwe+1
      weightc( 13, 43,  2)=                  0.33010328881424050307d0
      iwe=iwe+1
      weightc( 14, 43,  2)=                  0.58587886599879546168d0
      iwe=iwe+1
      weightc( 15, 43,  2)=                  0.10377878326264090847d0
      iwe=iwe+1
      weightc( 16, 43,  2)=                 -1.12292607557646295646d0
      iwe=iwe+1
      weightc( 17, 43,  2)=                  0.11299571532106474081d0
      iwe=iwe+1
      biasc( 43,  2)=                  1.36829681505185329904d0
      iwe=iwe+1
      weightc(  1, 44,  2)=                 -0.47357127902783885398d0
      iwe=iwe+1
      weightc(  2, 44,  2)=                  0.41468266978538986800d0
      iwe=iwe+1
      weightc(  3, 44,  2)=                  0.92163220597927753008d0
      iwe=iwe+1
      weightc(  4, 44,  2)=                 -0.65445827600622474840d0
      iwe=iwe+1
      weightc(  5, 44,  2)=                  0.86007319984995422857d0
      iwe=iwe+1
      weightc(  6, 44,  2)=                  0.77211371825372787647d0
      iwe=iwe+1
      weightc(  7, 44,  2)=                 -0.43923104418386843539d0
      iwe=iwe+1
      weightc(  8, 44,  2)=                  0.58978199942641973408d0
      iwe=iwe+1
      weightc(  9, 44,  2)=                 -0.77225527608151178782d0
      iwe=iwe+1
      weightc( 10, 44,  2)=                  0.36911937380767972927d0
      iwe=iwe+1
      weightc( 11, 44,  2)=                 -0.13889739771506071087d0
      iwe=iwe+1
      weightc( 12, 44,  2)=                  0.25585808770803203371d0
      iwe=iwe+1
      weightc( 13, 44,  2)=                 -0.48396083766048569874d0
      iwe=iwe+1
      weightc( 14, 44,  2)=                 -1.06225735641199747761d0
      iwe=iwe+1
      weightc( 15, 44,  2)=                 -0.63732075679650312949d0
      iwe=iwe+1
      weightc( 16, 44,  2)=                  0.03403157752979928119d0
      iwe=iwe+1
      weightc( 17, 44,  2)=                 -0.79783693075414363616d0
      iwe=iwe+1
      biasc( 44,  2)=                 -1.71040404142374380392d0
      iwe=iwe+1
      weightc(  1, 45,  2)=                 -0.31015538316752738757d0
      iwe=iwe+1
      weightc(  2, 45,  2)=                  0.66724501449981921120d0
      iwe=iwe+1
      weightc(  3, 45,  2)=                 -0.33932106764354846851d0
      iwe=iwe+1
      weightc(  4, 45,  2)=                 -0.27609985592464580950d0
      iwe=iwe+1
      weightc(  5, 45,  2)=                 -0.19174584366485186715d0
      iwe=iwe+1
      weightc(  6, 45,  2)=                 -0.02345463259953419616d0
      iwe=iwe+1
      weightc(  7, 45,  2)=                 -1.23008188783827221435d0
      iwe=iwe+1
      weightc(  8, 45,  2)=                 -0.45429471072208893467d0
      iwe=iwe+1
      weightc(  9, 45,  2)=                  0.85331959859988937289d0
      iwe=iwe+1
      weightc( 10, 45,  2)=                  0.13527340924286040957d0
      iwe=iwe+1
      weightc( 11, 45,  2)=                  0.00178598620014005886d0
      iwe=iwe+1
      weightc( 12, 45,  2)=                 -0.07377394884712654144d0
      iwe=iwe+1
      weightc( 13, 45,  2)=                  0.24274161131617019715d0
      iwe=iwe+1
      weightc( 14, 45,  2)=                 -0.83018231112275153727d0
      iwe=iwe+1
      weightc( 15, 45,  2)=                 -0.50294121285960968759d0
      iwe=iwe+1
      weightc( 16, 45,  2)=                  0.31757156478774373198d0
      iwe=iwe+1
      weightc( 17, 45,  2)=                 -0.80633303050389881772d0
      iwe=iwe+1
      biasc( 45,  2)=                 -1.50666267348960647432d0
      iwe=iwe+1
      weightc(  1, 46,  2)=                 -0.61488385505552467514d0
      iwe=iwe+1
      weightc(  2, 46,  2)=                  0.27206723880292982276d0
      iwe=iwe+1
      weightc(  3, 46,  2)=                  0.01839162067321031477d0
      iwe=iwe+1
      weightc(  4, 46,  2)=                 -0.10291467631340765754d0
      iwe=iwe+1
      weightc(  5, 46,  2)=                  0.27388161736523108925d0
      iwe=iwe+1
      weightc(  6, 46,  2)=                  0.62627687080801364150d0
      iwe=iwe+1
      weightc(  7, 46,  2)=                 -0.76135095611177694419d0
      iwe=iwe+1
      weightc(  8, 46,  2)=                  0.38146670726444931177d0
      iwe=iwe+1
      weightc(  9, 46,  2)=                  1.17992146304783762645d0
      iwe=iwe+1
      weightc( 10, 46,  2)=                 -0.99414152288493007337d0
      iwe=iwe+1
      weightc( 11, 46,  2)=                  0.70499050701787124851d0
      iwe=iwe+1
      weightc( 12, 46,  2)=                  0.59488984449696213908d0
      iwe=iwe+1
      weightc( 13, 46,  2)=                 -0.69759239534714501119d0
      iwe=iwe+1
      weightc( 14, 46,  2)=                 -0.34337150194071852649d0
      iwe=iwe+1
      weightc( 15, 46,  2)=                  0.47682697296680925936d0
      iwe=iwe+1
      weightc( 16, 46,  2)=                 -1.12967204566678125488d0
      iwe=iwe+1
      weightc( 17, 46,  2)=                 -0.40971147533201135449d0
      iwe=iwe+1
      biasc( 46,  2)=                 -1.66254526890582288168d0
      iwe=iwe+1
      weightc(  1, 47,  2)=                 -0.61261300782281613575d0
      iwe=iwe+1
      weightc(  2, 47,  2)=                  0.39784688756570352197d0
      iwe=iwe+1
      weightc(  3, 47,  2)=                  0.53322567932249342881d0
      iwe=iwe+1
      weightc(  4, 47,  2)=                 -0.53564668230341438981d0
      iwe=iwe+1
      weightc(  5, 47,  2)=                 -0.72778760888801918849d0
      iwe=iwe+1
      weightc(  6, 47,  2)=                  0.48265938911327310734d0
      iwe=iwe+1
      weightc(  7, 47,  2)=                 -0.23533757804024979521d0
      iwe=iwe+1
      weightc(  8, 47,  2)=                 -0.84673875125344644221d0
      iwe=iwe+1
      weightc(  9, 47,  2)=                 -0.15704937952350819796d0
      iwe=iwe+1
      weightc( 10, 47,  2)=                  1.33185485711151163635d0
      iwe=iwe+1
      weightc( 11, 47,  2)=                 -0.25621809407971740669d0
      iwe=iwe+1
      weightc( 12, 47,  2)=                  0.52532772114152292975d0
      iwe=iwe+1
      weightc( 13, 47,  2)=                  0.30979296022364910534d0
      iwe=iwe+1
      weightc( 14, 47,  2)=                 -0.56713902637625590586d0
      iwe=iwe+1
      weightc( 15, 47,  2)=                 -0.10049236068450366488d0
      iwe=iwe+1
      weightc( 16, 47,  2)=                 -0.71479298601667107249d0
      iwe=iwe+1
      weightc( 17, 47,  2)=                 -0.34862387914663794941d0
      iwe=iwe+1
      biasc( 47,  2)=                 -1.69540104694970672483d0
      iwe=iwe+1
      weightc(  1, 48,  2)=                 -0.31401425737000204785d0
      iwe=iwe+1
      weightc(  2, 48,  2)=                  0.77893177436544902559d0
      iwe=iwe+1
      weightc(  3, 48,  2)=                 -0.02834414612090899871d0
      iwe=iwe+1
      weightc(  4, 48,  2)=                 -0.32625283542026306538d0
      iwe=iwe+1
      weightc(  5, 48,  2)=                  0.58746555678057166272d0
      iwe=iwe+1
      weightc(  6, 48,  2)=                  0.26269943959648384135d0
      iwe=iwe+1
      weightc(  7, 48,  2)=                  0.95142784140228409129d0
      iwe=iwe+1
      weightc(  8, 48,  2)=                  0.57056811040911770139d0
      iwe=iwe+1
      weightc(  9, 48,  2)=                 -1.40181537939204914345d0
      iwe=iwe+1
      weightc( 10, 48,  2)=                 -1.03785072952969259497d0
      iwe=iwe+1
      weightc( 11, 48,  2)=                 -0.26585388295703532568d0
      iwe=iwe+1
      weightc( 12, 48,  2)=                 -0.44290890459218223985d0
      iwe=iwe+1
      weightc( 13, 48,  2)=                  0.09819995314881881099d0
      iwe=iwe+1
      weightc( 14, 48,  2)=                  0.58996118959892029920d0
      iwe=iwe+1
      weightc( 15, 48,  2)=                  0.80820181014636860439d0
      iwe=iwe+1
      weightc( 16, 48,  2)=                  0.28230269840664706793d0
      iwe=iwe+1
      weightc( 17, 48,  2)=                  0.38640326209641506772d0
      iwe=iwe+1
      biasc( 48,  2)=                 -1.65125485175094111057d0
      iwe=iwe+1
      weightc(  1, 49,  2)=                  0.12074051347116065980d0
      iwe=iwe+1
      weightc(  2, 49,  2)=                  0.15146878477514419403d0
      iwe=iwe+1
      weightc(  3, 49,  2)=                  0.93550516680682938020d0
      iwe=iwe+1
      weightc(  4, 49,  2)=                 -0.72061375729464105522d0
      iwe=iwe+1
      weightc(  5, 49,  2)=                 -1.07028629999000490791d0
      iwe=iwe+1
      weightc(  6, 49,  2)=                 -1.59729146436202307235d0
      iwe=iwe+1
      weightc(  7, 49,  2)=                  0.02276711820712404993d0
      iwe=iwe+1
      weightc(  8, 49,  2)=                  0.95713111189107635823d0
      iwe=iwe+1
      weightc(  9, 49,  2)=                 -0.64046789184433350339d0
      iwe=iwe+1
      weightc( 10, 49,  2)=                  1.42015185399428478519d0
      iwe=iwe+1
      weightc( 11, 49,  2)=                 -0.25732377431785335986d0
      iwe=iwe+1
      weightc( 12, 49,  2)=                 -0.19489962859467827028d0
      iwe=iwe+1
      weightc( 13, 49,  2)=                  0.42886147330603785477d0
      iwe=iwe+1
      weightc( 14, 49,  2)=                  0.55871946901130953300d0
      iwe=iwe+1
      weightc( 15, 49,  2)=                 -0.16907437826595950181d0
      iwe=iwe+1
      weightc( 16, 49,  2)=                  0.68402763512506448151d0
      iwe=iwe+1
      weightc( 17, 49,  2)=                  0.51226030549454593110d0
      iwe=iwe+1
      biasc( 49,  2)=                  2.47185429055772631912d0
      iwe=iwe+1
      weightc(  1, 50,  2)=                 -0.61463034923008197374d0
      iwe=iwe+1
      weightc(  2, 50,  2)=                  0.16705187856397182844d0
      iwe=iwe+1
      weightc(  3, 50,  2)=                 -0.95829907354159626909d0
      iwe=iwe+1
      weightc(  4, 50,  2)=                  0.10321836944994007557d0
      iwe=iwe+1
      weightc(  5, 50,  2)=                  0.02585209741582039297d0
      iwe=iwe+1
      weightc(  6, 50,  2)=                 -0.54305472472501548076d0
      iwe=iwe+1
      weightc(  7, 50,  2)=                 -1.05970220760362376922d0
      iwe=iwe+1
      weightc(  8, 50,  2)=                  0.00718615301913189640d0
      iwe=iwe+1
      weightc(  9, 50,  2)=                 -2.14423528057194667795d0
      iwe=iwe+1
      weightc( 10, 50,  2)=                 -0.52063981858426156002d0
      iwe=iwe+1
      weightc( 11, 50,  2)=                  0.33431890719604906437d0
      iwe=iwe+1
      weightc( 12, 50,  2)=                 -1.25528322867933672669d0
      iwe=iwe+1
      weightc( 13, 50,  2)=                  1.26896694248516239689d0
      iwe=iwe+1
      weightc( 14, 50,  2)=                  0.03023432600415430077d0
      iwe=iwe+1
      weightc( 15, 50,  2)=                  0.86016809314427944422d0
      iwe=iwe+1
      weightc( 16, 50,  2)=                  2.09238961467254291904d0
      iwe=iwe+1
      weightc( 17, 50,  2)=                 -0.29794523597876260146d0
      iwe=iwe+1
      biasc( 50,  2)=                 -1.86421126517172353054d0
      iwe=iwe+1
      weightc(  1,  1,  3)=                 -0.31223788965489102099d0
      iwe=iwe+1
      weightc(  2,  1,  3)=                  0.15081669060818558847d0
      iwe=iwe+1
      weightc(  3,  1,  3)=                  0.18970074940668960051d0
      iwe=iwe+1
      weightc(  4,  1,  3)=                  0.35446505224349278418d0
      iwe=iwe+1
      weightc(  5,  1,  3)=                 -0.11252707421881875949d0
      iwe=iwe+1
      weightc(  6,  1,  3)=                  0.24517861124791409666d0
      iwe=iwe+1
      weightc(  7,  1,  3)=                 -0.21178046723623805692d0
      iwe=iwe+1
      weightc(  8,  1,  3)=                  0.20497013181612347421d0
      iwe=iwe+1
      weightc(  9,  1,  3)=                  0.28515671617149668249d0
      iwe=iwe+1
      weightc( 10,  1,  3)=                 -0.27615231599136069729d0
      iwe=iwe+1
      weightc( 11,  1,  3)=                  0.24946330608320160804d0
      iwe=iwe+1
      weightc( 12,  1,  3)=                  0.12836894826422301508d0
      iwe=iwe+1
      weightc( 13,  1,  3)=                  0.31928333090529392724d0
      iwe=iwe+1
      weightc( 14,  1,  3)=                  0.36455690806688473282d0
      iwe=iwe+1
      weightc( 15,  1,  3)=                 -0.08934103963771902746d0
      iwe=iwe+1
      weightc( 16,  1,  3)=                 -0.13659815935272040521d0
      iwe=iwe+1
      weightc( 17,  1,  3)=                  0.31557916172408706501d0
      iwe=iwe+1
      weightc( 18,  1,  3)=                 -0.22798630035825553919d0
      iwe=iwe+1
      weightc( 19,  1,  3)=                 -0.18023733081465928563d0
      iwe=iwe+1
      weightc( 20,  1,  3)=                 -0.08794553420560952128d0
      iwe=iwe+1
      weightc( 21,  1,  3)=                  0.27421264612456980325d0
      iwe=iwe+1
      weightc( 22,  1,  3)=                 -0.31874532471966832148d0
      iwe=iwe+1
      weightc( 23,  1,  3)=                 -0.12684658116480140855d0
      iwe=iwe+1
      weightc( 24,  1,  3)=                  0.21822980731629285089d0
      iwe=iwe+1
      weightc( 25,  1,  3)=                  0.03821119075781442137d0
      iwe=iwe+1
      weightc( 26,  1,  3)=                 -0.38143563679254027798d0
      iwe=iwe+1
      weightc( 27,  1,  3)=                  0.36011167717185910142d0
      iwe=iwe+1
      weightc( 28,  1,  3)=                  0.19017020110937191135d0
      iwe=iwe+1
      weightc( 29,  1,  3)=                  0.18911943567789651910d0
      iwe=iwe+1
      weightc( 30,  1,  3)=                 -0.09864038482915855888d0
      iwe=iwe+1
      weightc( 31,  1,  3)=                 -0.22523824578359566417d0
      iwe=iwe+1
      weightc( 32,  1,  3)=                 -0.09006432616342092967d0
      iwe=iwe+1
      weightc( 33,  1,  3)=                 -0.08590110347277020442d0
      iwe=iwe+1
      weightc( 34,  1,  3)=                  0.04906897858759209224d0
      iwe=iwe+1
      weightc( 35,  1,  3)=                 -0.13084994560349608173d0
      iwe=iwe+1
      weightc( 36,  1,  3)=                  0.02009048585287550454d0
      iwe=iwe+1
      weightc( 37,  1,  3)=                  0.02863008381881795156d0
      iwe=iwe+1
      weightc( 38,  1,  3)=                  0.00240216638126374091d0
      iwe=iwe+1
      weightc( 39,  1,  3)=                  0.03106083086736989921d0
      iwe=iwe+1
      weightc( 40,  1,  3)=                  0.05929680408735514552d0
      iwe=iwe+1
      weightc( 41,  1,  3)=                  0.38988175938801711284d0
      iwe=iwe+1
      weightc( 42,  1,  3)=                  0.00716784608057780166d0
      iwe=iwe+1
      weightc( 43,  1,  3)=                  0.02702663538224723758d0
      iwe=iwe+1
      weightc( 44,  1,  3)=                  0.29172396713380288613d0
      iwe=iwe+1
      weightc( 45,  1,  3)=                  0.20311833949306315472d0
      iwe=iwe+1
      weightc( 46,  1,  3)=                 -0.15192713075269997924d0
      iwe=iwe+1
      weightc( 47,  1,  3)=                  0.12588805594328264514d0
      iwe=iwe+1
      weightc( 48,  1,  3)=                  0.10949948542637590043d0
      iwe=iwe+1
      weightc( 49,  1,  3)=                  0.09035471626684962732d0
      iwe=iwe+1
      weightc( 50,  1,  3)=                 -0.41552043001297167546d0
      iwe=iwe+1
      biasc(  1,  3)=                  1.52877677808126732906d0
      iwe=iwe+1
      weightc(  1,  2,  3)=                  0.03870703947260238642d0
      iwe=iwe+1
      weightc(  2,  2,  3)=                  0.03358395443261649738d0
      iwe=iwe+1
      weightc(  3,  2,  3)=                 -0.15034365120186188314d0
      iwe=iwe+1
      weightc(  4,  2,  3)=                  0.31515146743276511998d0
      iwe=iwe+1
      weightc(  5,  2,  3)=                  0.34450029528884906771d0
      iwe=iwe+1
      weightc(  6,  2,  3)=                  0.16133913639166269638d0
      iwe=iwe+1
      weightc(  7,  2,  3)=                 -0.06910973714622414832d0
      iwe=iwe+1
      weightc(  8,  2,  3)=                 -0.02203646795728072746d0
      iwe=iwe+1
      weightc(  9,  2,  3)=                 -0.32491803271086877603d0
      iwe=iwe+1
      weightc( 10,  2,  3)=                 -0.20947789884932799254d0
      iwe=iwe+1
      weightc( 11,  2,  3)=                 -0.18096755236251713117d0
      iwe=iwe+1
      weightc( 12,  2,  3)=                  0.21080417255382022379d0
      iwe=iwe+1
      weightc( 13,  2,  3)=                 -0.09249122761449080077d0
      iwe=iwe+1
      weightc( 14,  2,  3)=                  0.01310354429440258039d0
      iwe=iwe+1
      weightc( 15,  2,  3)=                 -0.11945184156506455375d0
      iwe=iwe+1
      weightc( 16,  2,  3)=                  0.19801477432915223775d0
      iwe=iwe+1
      weightc( 17,  2,  3)=                 -0.18911945357980028404d0
      iwe=iwe+1
      weightc( 18,  2,  3)=                  0.01440750764020006999d0
      iwe=iwe+1
      weightc( 19,  2,  3)=                  0.40960585526044257509d0
      iwe=iwe+1
      weightc( 20,  2,  3)=                  0.16041893971743190206d0
      iwe=iwe+1
      weightc( 21,  2,  3)=                 -0.31954719083249261136d0
      iwe=iwe+1
      weightc( 22,  2,  3)=                 -0.17695738012196635114d0
      iwe=iwe+1
      weightc( 23,  2,  3)=                 -0.35969004097001799902d0
      iwe=iwe+1
      weightc( 24,  2,  3)=                 -0.24546328179319348850d0
      iwe=iwe+1
      weightc( 25,  2,  3)=                  0.27917930449382172275d0
      iwe=iwe+1
      weightc( 26,  2,  3)=                 -0.36993328297247701775d0
      iwe=iwe+1
      weightc( 27,  2,  3)=                 -0.12082221291912526029d0
      iwe=iwe+1
      weightc( 28,  2,  3)=                  0.06169361305016272945d0
      iwe=iwe+1
      weightc( 29,  2,  3)=                  0.16544868244055285778d0
      iwe=iwe+1
      weightc( 30,  2,  3)=                 -0.26623523849512609196d0
      iwe=iwe+1
      weightc( 31,  2,  3)=                  0.16267849873313497411d0
      iwe=iwe+1
      weightc( 32,  2,  3)=                 -0.32987653156858653958d0
      iwe=iwe+1
      weightc( 33,  2,  3)=                 -0.01452175408225546242d0
      iwe=iwe+1
      weightc( 34,  2,  3)=                  0.17195737165245592037d0
      iwe=iwe+1
      weightc( 35,  2,  3)=                  0.31153835254092859808d0
      iwe=iwe+1
      weightc( 36,  2,  3)=                 -0.17872401753238476019d0
      iwe=iwe+1
      weightc( 37,  2,  3)=                  0.19151444514110155248d0
      iwe=iwe+1
      weightc( 38,  2,  3)=                  0.26119095878769499341d0
      iwe=iwe+1
      weightc( 39,  2,  3)=                 -0.19005705282370397025d0
      iwe=iwe+1
      weightc( 40,  2,  3)=                  0.29763766104815347902d0
      iwe=iwe+1
      weightc( 41,  2,  3)=                  0.07688852079757590996d0
      iwe=iwe+1
      weightc( 42,  2,  3)=                 -0.17984183704712353169d0
      iwe=iwe+1
      weightc( 43,  2,  3)=                 -0.30467594256337870995d0
      iwe=iwe+1
      weightc( 44,  2,  3)=                  0.24425380609018101929d0
      iwe=iwe+1
      weightc( 45,  2,  3)=                 -0.00875363025289841931d0
      iwe=iwe+1
      weightc( 46,  2,  3)=                  0.40486946274876478569d0
      iwe=iwe+1
      weightc( 47,  2,  3)=                 -0.14721461766307111785d0
      iwe=iwe+1
      weightc( 48,  2,  3)=                  0.14712870804978694927d0
      iwe=iwe+1
      weightc( 49,  2,  3)=                 -0.05741962956477834196d0
      iwe=iwe+1
      weightc( 50,  2,  3)=                  0.14699864348926669488d0
      iwe=iwe+1
      biasc(  2,  3)=                  1.47633797395565147248d0
      iwe=iwe+1
      weightc(  1,  3,  3)=                  0.04813608642499319495d0
      iwe=iwe+1
      weightc(  2,  3,  3)=                 -0.38489377736745927772d0
      iwe=iwe+1
      weightc(  3,  3,  3)=                 -0.01311127975323066706d0
      iwe=iwe+1
      weightc(  4,  3,  3)=                  0.23243669290605400990d0
      iwe=iwe+1
      weightc(  5,  3,  3)=                 -0.18482001663561115068d0
      iwe=iwe+1
      weightc(  6,  3,  3)=                 -0.24464736535612136015d0
      iwe=iwe+1
      weightc(  7,  3,  3)=                  0.13790925256546715527d0
      iwe=iwe+1
      weightc(  8,  3,  3)=                  0.46681821500362452593d0
      iwe=iwe+1
      weightc(  9,  3,  3)=                 -0.25812134758702692805d0
      iwe=iwe+1
      weightc( 10,  3,  3)=                 -0.18719248165048038568d0
      iwe=iwe+1
      weightc( 11,  3,  3)=                 -0.65381832647840931738d0
      iwe=iwe+1
      weightc( 12,  3,  3)=                  0.01129677145319981854d0
      iwe=iwe+1
      weightc( 13,  3,  3)=                  0.20378980497232163094d0
      iwe=iwe+1
      weightc( 14,  3,  3)=                  0.08919021446069844150d0
      iwe=iwe+1
      weightc( 15,  3,  3)=                  0.51671147324558819314d0
      iwe=iwe+1
      weightc( 16,  3,  3)=                  0.03609552519240917523d0
      iwe=iwe+1
      weightc( 17,  3,  3)=                 -0.19673013141370152002d0
      iwe=iwe+1
      weightc( 18,  3,  3)=                 -0.36986007911799206882d0
      iwe=iwe+1
      weightc( 19,  3,  3)=                 -0.15964027958539667162d0
      iwe=iwe+1
      weightc( 20,  3,  3)=                  0.53834642783013886280d0
      iwe=iwe+1
      weightc( 21,  3,  3)=                  0.22467762217381634371d0
      iwe=iwe+1
      weightc( 22,  3,  3)=                  0.42229338416672140832d0
      iwe=iwe+1
      weightc( 23,  3,  3)=                  0.34444958030676559035d0
      iwe=iwe+1
      weightc( 24,  3,  3)=                  0.37031945863559279086d0
      iwe=iwe+1
      weightc( 25,  3,  3)=                 -0.18533422477246605520d0
      iwe=iwe+1
      weightc( 26,  3,  3)=                 -0.04836504605750729935d0
      iwe=iwe+1
      weightc( 27,  3,  3)=                  0.19605674583509960507d0
      iwe=iwe+1
      weightc( 28,  3,  3)=                 -0.33755882714257967603d0
      iwe=iwe+1
      weightc( 29,  3,  3)=                 -0.51562690824678492074d0
      iwe=iwe+1
      weightc( 30,  3,  3)=                  0.49950688954519040230d0
      iwe=iwe+1
      weightc( 31,  3,  3)=                  0.32769439780321329980d0
      iwe=iwe+1
      weightc( 32,  3,  3)=                  0.10696256999103839758d0
      iwe=iwe+1
      weightc( 33,  3,  3)=                 -0.05143101558953384889d0
      iwe=iwe+1
      weightc( 34,  3,  3)=                  0.36605118311493234362d0
      iwe=iwe+1
      weightc( 35,  3,  3)=                 -0.26019811908385198640d0
      iwe=iwe+1
      weightc( 36,  3,  3)=                 -0.34431397793484297409d0
      iwe=iwe+1
      weightc( 37,  3,  3)=                 -0.06159462793568971223d0
      iwe=iwe+1
      weightc( 38,  3,  3)=                  0.35573705523071524892d0
      iwe=iwe+1
      weightc( 39,  3,  3)=                  0.20251695125977442480d0
      iwe=iwe+1
      weightc( 40,  3,  3)=                 -0.15539763483185770054d0
      iwe=iwe+1
      weightc( 41,  3,  3)=                 -0.31620986401419060030d0
      iwe=iwe+1
      weightc( 42,  3,  3)=                 -0.55129469694221955312d0
      iwe=iwe+1
      weightc( 43,  3,  3)=                 -0.05045156069695962142d0
      iwe=iwe+1
      weightc( 44,  3,  3)=                  0.38725976431117020704d0
      iwe=iwe+1
      weightc( 45,  3,  3)=                 -0.51428198935486957311d0
      iwe=iwe+1
      weightc( 46,  3,  3)=                 -0.33206702556804473803d0
      iwe=iwe+1
      weightc( 47,  3,  3)=                  0.58941615837300564973d0
      iwe=iwe+1
      weightc( 48,  3,  3)=                  0.33889287328538181265d0
      iwe=iwe+1
      weightc( 49,  3,  3)=                 -0.13462374454207495789d0
      iwe=iwe+1
      weightc( 50,  3,  3)=                  0.18756619581616434944d0
      iwe=iwe+1
      biasc(  3,  3)=                 -1.35816279585455190748d0
      iwe=iwe+1
      weightc(  1,  4,  3)=                 -0.29745350265173414739d0
      iwe=iwe+1
      weightc(  2,  4,  3)=                  0.30395335853487120970d0
      iwe=iwe+1
      weightc(  3,  4,  3)=                 -0.19972119868319854197d0
      iwe=iwe+1
      weightc(  4,  4,  3)=                 -0.25864152278543245389d0
      iwe=iwe+1
      weightc(  5,  4,  3)=                  0.30541637116424302789d0
      iwe=iwe+1
      weightc(  6,  4,  3)=                  0.12657492864287320233d0
      iwe=iwe+1
      weightc(  7,  4,  3)=                 -0.11847885419702544607d0
      iwe=iwe+1
      weightc(  8,  4,  3)=                 -0.07416001511212627628d0
      iwe=iwe+1
      weightc(  9,  4,  3)=                 -0.12800452445162988080d0
      iwe=iwe+1
      weightc( 10,  4,  3)=                  0.31378756334502116987d0
      iwe=iwe+1
      weightc( 11,  4,  3)=                 -0.12483332044523282045d0
      iwe=iwe+1
      weightc( 12,  4,  3)=                  0.16623656335674266704d0
      iwe=iwe+1
      weightc( 13,  4,  3)=                  0.39065797232743998402d0
      iwe=iwe+1
      weightc( 14,  4,  3)=                  0.67521039504589097646d0
      iwe=iwe+1
      weightc( 15,  4,  3)=                 -0.39496727169621331788d0
      iwe=iwe+1
      weightc( 16,  4,  3)=                 -0.21009148119740203575d0
      iwe=iwe+1
      weightc( 17,  4,  3)=                 -0.15449169125386838508d0
      iwe=iwe+1
      weightc( 18,  4,  3)=                 -0.71908100185835410745d0
      iwe=iwe+1
      weightc( 19,  4,  3)=                  0.45685774394832195933d0
      iwe=iwe+1
      weightc( 20,  4,  3)=                 -0.07777467647259554695d0
      iwe=iwe+1
      weightc( 21,  4,  3)=                 -0.04147438015437437259d0
      iwe=iwe+1
      weightc( 22,  4,  3)=                  0.30686180218570763278d0
      iwe=iwe+1
      weightc( 23,  4,  3)=                  0.04781956035541250899d0
      iwe=iwe+1
      weightc( 24,  4,  3)=                 -0.60069136907485454202d0
      iwe=iwe+1
      weightc( 25,  4,  3)=                  0.18053322552989217731d0
      iwe=iwe+1
      weightc( 26,  4,  3)=                 -0.22086516285576560104d0
      iwe=iwe+1
      weightc( 27,  4,  3)=                  0.59449472542128123376d0
      iwe=iwe+1
      weightc( 28,  4,  3)=                  0.14306504996823640741d0
      iwe=iwe+1
      weightc( 29,  4,  3)=                  0.36089035946324993231d0
      iwe=iwe+1
      weightc( 30,  4,  3)=                 -0.08576776732579406703d0
      iwe=iwe+1
      weightc( 31,  4,  3)=                 -0.03833675508439302743d0
      iwe=iwe+1
      weightc( 32,  4,  3)=                 -0.35262677762427147021d0
      iwe=iwe+1
      weightc( 33,  4,  3)=                 -0.22660150714173141195d0
      iwe=iwe+1
      weightc( 34,  4,  3)=                  0.12888277559295746588d0
      iwe=iwe+1
      weightc( 35,  4,  3)=                  0.01899454324293998672d0
      iwe=iwe+1
      weightc( 36,  4,  3)=                 -0.13936659632047523893d0
      iwe=iwe+1
      weightc( 37,  4,  3)=                 -0.28153432252690707704d0
      iwe=iwe+1
      weightc( 38,  4,  3)=                 -0.30770743732265826154d0
      iwe=iwe+1
      weightc( 39,  4,  3)=                  0.26862076004292889664d0
      iwe=iwe+1
      weightc( 40,  4,  3)=                  0.04916139837734470608d0
      iwe=iwe+1
      weightc( 41,  4,  3)=                  0.16353999248755587970d0
      iwe=iwe+1
      weightc( 42,  4,  3)=                  0.78072059524429782140d0
      iwe=iwe+1
      weightc( 43,  4,  3)=                 -0.09453167960587541274d0
      iwe=iwe+1
      weightc( 44,  4,  3)=                  0.42187922660617444004d0
      iwe=iwe+1
      weightc( 45,  4,  3)=                  0.21857688455547716333d0
      iwe=iwe+1
      weightc( 46,  4,  3)=                  0.80333277529095215019d0
      iwe=iwe+1
      weightc( 47,  4,  3)=                  0.10081543614317764468d0
      iwe=iwe+1
      weightc( 48,  4,  3)=                  0.03842553523297971563d0
      iwe=iwe+1
      weightc( 49,  4,  3)=                 -0.11678980987769736755d0
      iwe=iwe+1
      weightc( 50,  4,  3)=                 -0.33702610611309091748d0
      iwe=iwe+1
      biasc(  4,  3)=                  1.50846538436423127649d0
      iwe=iwe+1
      weightc(  1,  5,  3)=                 -0.23040174896191334408d0
      iwe=iwe+1
      weightc(  2,  5,  3)=                  0.00777157384279711892d0
      iwe=iwe+1
      weightc(  3,  5,  3)=                  0.39017516263777868302d0
      iwe=iwe+1
      weightc(  4,  5,  3)=                  0.22385231330908100800d0
      iwe=iwe+1
      weightc(  5,  5,  3)=                 -0.12170649337289396463d0
      iwe=iwe+1
      weightc(  6,  5,  3)=                 -0.15376683111399766513d0
      iwe=iwe+1
      weightc(  7,  5,  3)=                 -0.12125794451917121242d0
      iwe=iwe+1
      weightc(  8,  5,  3)=                  0.08181990383435883141d0
      iwe=iwe+1
      weightc(  9,  5,  3)=                  0.15037521389520272508d0
      iwe=iwe+1
      weightc( 10,  5,  3)=                 -0.37629311190285108513d0
      iwe=iwe+1
      weightc( 11,  5,  3)=                  0.00625728770840906431d0
      iwe=iwe+1
      weightc( 12,  5,  3)=                 -0.04825723118518221444d0
      iwe=iwe+1
      weightc( 13,  5,  3)=                  0.23474842322446748399d0
      iwe=iwe+1
      weightc( 14,  5,  3)=                  0.34329700938085178086d0
      iwe=iwe+1
      weightc( 15,  5,  3)=                 -0.28146821118897652481d0
      iwe=iwe+1
      weightc( 16,  5,  3)=                 -0.13471162122401547645d0
      iwe=iwe+1
      weightc( 17,  5,  3)=                  0.17744540909300987597d0
      iwe=iwe+1
      weightc( 18,  5,  3)=                 -0.15766180102899235438d0
      iwe=iwe+1
      weightc( 19,  5,  3)=                 -0.50794760598285182418d0
      iwe=iwe+1
      weightc( 20,  5,  3)=                 -0.25654441299048474923d0
      iwe=iwe+1
      weightc( 21,  5,  3)=                  0.01813241916641214480d0
      iwe=iwe+1
      weightc( 22,  5,  3)=                  0.29584430741289713396d0
      iwe=iwe+1
      weightc( 23,  5,  3)=                 -0.35617780916266689184d0
      iwe=iwe+1
      weightc( 24,  5,  3)=                  0.19723450393035540928d0
      iwe=iwe+1
      weightc( 25,  5,  3)=                  0.01391992229149124037d0
      iwe=iwe+1
      weightc( 26,  5,  3)=                 -0.35571686650989997602d0
      iwe=iwe+1
      weightc( 27,  5,  3)=                  0.14583515742450736674d0
      iwe=iwe+1
      weightc( 28,  5,  3)=                  0.00539279369249238104d0
      iwe=iwe+1
      weightc( 29,  5,  3)=                 -0.05642670529900652154d0
      iwe=iwe+1
      weightc( 30,  5,  3)=                  0.20000939475617046659d0
      iwe=iwe+1
      weightc( 31,  5,  3)=                  0.01284580811640493279d0
      iwe=iwe+1
      weightc( 32,  5,  3)=                  0.02715588252171960426d0
      iwe=iwe+1
      weightc( 33,  5,  3)=                 -0.00834372211330052828d0
      iwe=iwe+1
      weightc( 34,  5,  3)=                 -0.42064576720013929778d0
      iwe=iwe+1
      weightc( 35,  5,  3)=                 -0.00880703919492714649d0
      iwe=iwe+1
      weightc( 36,  5,  3)=                  0.42595779083098422868d0
      iwe=iwe+1
      weightc( 37,  5,  3)=                  0.05708288516549429870d0
      iwe=iwe+1
      weightc( 38,  5,  3)=                  0.24268247568962356131d0
      iwe=iwe+1
      weightc( 39,  5,  3)=                  0.11616958042376006321d0
      iwe=iwe+1
      weightc( 40,  5,  3)=                 -0.31326791907827672423d0
      iwe=iwe+1
      weightc( 41,  5,  3)=                 -0.27131641215329116434d0
      iwe=iwe+1
      weightc( 42,  5,  3)=                  0.40311383516333387789d0
      iwe=iwe+1
      weightc( 43,  5,  3)=                 -0.32214436238466753748d0
      iwe=iwe+1
      weightc( 44,  5,  3)=                 -0.24903249671288185674d0
      iwe=iwe+1
      weightc( 45,  5,  3)=                 -0.47121132279019567468d0
      iwe=iwe+1
      weightc( 46,  5,  3)=                  0.01738521820532071618d0
      iwe=iwe+1
      weightc( 47,  5,  3)=                 -0.10117823845798083748d0
      iwe=iwe+1
      weightc( 48,  5,  3)=                 -0.34879097611982695648d0
      iwe=iwe+1
      weightc( 49,  5,  3)=                  0.12100697280908537246d0
      iwe=iwe+1
      weightc( 50,  5,  3)=                 -0.60003198081720365842d0
      iwe=iwe+1
      biasc(  5,  3)=                  1.39393851531489998408d0
      iwe=iwe+1
      weightc(  1,  6,  3)=                 -0.21439720771622597373d0
      iwe=iwe+1
      weightc(  2,  6,  3)=                  0.32202639422485862530d0
      iwe=iwe+1
      weightc(  3,  6,  3)=                 -0.03120020754702253554d0
      iwe=iwe+1
      weightc(  4,  6,  3)=                  0.31704997325976891354d0
      iwe=iwe+1
      weightc(  5,  6,  3)=                 -0.38743237231258609299d0
      iwe=iwe+1
      weightc(  6,  6,  3)=                  0.08823256733945614161d0
      iwe=iwe+1
      weightc(  7,  6,  3)=                  0.22811070089470655842d0
      iwe=iwe+1
      weightc(  8,  6,  3)=                  0.43492531520876998030d0
      iwe=iwe+1
      weightc(  9,  6,  3)=                 -0.10429379060064267182d0
      iwe=iwe+1
      weightc( 10,  6,  3)=                 -0.35986804481842854520d0
      iwe=iwe+1
      weightc( 11,  6,  3)=                 -0.49958061869241815467d0
      iwe=iwe+1
      weightc( 12,  6,  3)=                 -0.24947222076774872024d0
      iwe=iwe+1
      weightc( 13,  6,  3)=                 -0.14158692875068223938d0
      iwe=iwe+1
      weightc( 14,  6,  3)=                  0.14814177828185728925d0
      iwe=iwe+1
      weightc( 15,  6,  3)=                  0.43893521186786943478d0
      iwe=iwe+1
      weightc( 16,  6,  3)=                 -0.18877663209728157145d0
      iwe=iwe+1
      weightc( 17,  6,  3)=                 -0.51021183476526621448d0
      iwe=iwe+1
      weightc( 18,  6,  3)=                  0.00087503644001750815d0
      iwe=iwe+1
      weightc( 19,  6,  3)=                  0.06337462945616638421d0
      iwe=iwe+1
      weightc( 20,  6,  3)=                 -0.06102196957643271635d0
      iwe=iwe+1
      weightc( 21,  6,  3)=                 -0.07006305877875428079d0
      iwe=iwe+1
      weightc( 22,  6,  3)=                 -0.13836648587658265108d0
      iwe=iwe+1
      weightc( 23,  6,  3)=                  0.71049945882915888085d0
      iwe=iwe+1
      weightc( 24,  6,  3)=                  0.03704891541375272823d0
      iwe=iwe+1
      weightc( 25,  6,  3)=                 -0.19521567291256169963d0
      iwe=iwe+1
      weightc( 26,  6,  3)=                 -0.34494084077387532350d0
      iwe=iwe+1
      weightc( 27,  6,  3)=                 -0.32507229217545680067d0
      iwe=iwe+1
      weightc( 28,  6,  3)=                  0.04745823117486474424d0
      iwe=iwe+1
      weightc( 29,  6,  3)=                 -0.12011946640362933247d0
      iwe=iwe+1
      weightc( 30,  6,  3)=                 -0.06018442335097367452d0
      iwe=iwe+1
      weightc( 31,  6,  3)=                 -0.23522860915016899352d0
      iwe=iwe+1
      weightc( 32,  6,  3)=                  0.07291521145561731532d0
      iwe=iwe+1
      weightc( 33,  6,  3)=                  0.40049595876288862639d0
      iwe=iwe+1
      weightc( 34,  6,  3)=                  0.46692544293910431819d0
      iwe=iwe+1
      weightc( 35,  6,  3)=                  0.51779449246445430344d0
      iwe=iwe+1
      weightc( 36,  6,  3)=                 -0.39674992777069817418d0
      iwe=iwe+1
      weightc( 37,  6,  3)=                  0.58227246285817946259d0
      iwe=iwe+1
      weightc( 38,  6,  3)=                 -0.13629132911820446283d0
      iwe=iwe+1
      weightc( 39,  6,  3)=                 -0.24046423465545563314d0
      iwe=iwe+1
      weightc( 40,  6,  3)=                 -0.16966918186383161959d0
      iwe=iwe+1
      weightc( 41,  6,  3)=                  0.18593607074153228886d0
      iwe=iwe+1
      weightc( 42,  6,  3)=                 -0.38512718673947660131d0
      iwe=iwe+1
      weightc( 43,  6,  3)=                  0.00335080530413563475d0
      iwe=iwe+1
      weightc( 44,  6,  3)=                  0.07713615855171121471d0
      iwe=iwe+1
      weightc( 45,  6,  3)=                 -0.28285803122113423180d0
      iwe=iwe+1
      weightc( 46,  6,  3)=                  0.06363168787537706872d0
      iwe=iwe+1
      weightc( 47,  6,  3)=                  0.02263819391011315588d0
      iwe=iwe+1
      weightc( 48,  6,  3)=                  0.09737814716287981898d0
      iwe=iwe+1
      weightc( 49,  6,  3)=                 -0.37678648818771715012d0
      iwe=iwe+1
      weightc( 50,  6,  3)=                  0.37848285890345539917d0
      iwe=iwe+1
      biasc(  6,  3)=                  1.45125861719513404857d0
      iwe=iwe+1
      weightc(  1,  7,  3)=                  0.39969595755317499641d0
      iwe=iwe+1
      weightc(  2,  7,  3)=                  0.19028143378814613151d0
      iwe=iwe+1
      weightc(  3,  7,  3)=                  0.26190564557894535636d0
      iwe=iwe+1
      weightc(  4,  7,  3)=                 -0.05156142461837415203d0
      iwe=iwe+1
      weightc(  5,  7,  3)=                 -0.43387302746232631057d0
      iwe=iwe+1
      weightc(  6,  7,  3)=                 -0.07175106970984417021d0
      iwe=iwe+1
      weightc(  7,  7,  3)=                  0.38060710198082847722d0
      iwe=iwe+1
      weightc(  8,  7,  3)=                 -0.54530903487734816437d0
      iwe=iwe+1
      weightc(  9,  7,  3)=                 -0.49521875760364819641d0
      iwe=iwe+1
      weightc( 10,  7,  3)=                  0.15232295574072252098d0
      iwe=iwe+1
      weightc( 11,  7,  3)=                  0.70782093913294419352d0
      iwe=iwe+1
      weightc( 12,  7,  3)=                 -0.21624213655118296185d0
      iwe=iwe+1
      weightc( 13,  7,  3)=                 -0.03058344595160649576d0
      iwe=iwe+1
      weightc( 14,  7,  3)=                 -0.13268773237249478769d0
      iwe=iwe+1
      weightc( 15,  7,  3)=                 -0.07712044850218965908d0
      iwe=iwe+1
      weightc( 16,  7,  3)=                  0.03944807417644256159d0
      iwe=iwe+1
      weightc( 17,  7,  3)=                 -0.36140974435896050521d0
      iwe=iwe+1
      weightc( 18,  7,  3)=                  0.11375985180264948371d0
      iwe=iwe+1
      weightc( 19,  7,  3)=                  0.34628353954380991508d0
      iwe=iwe+1
      weightc( 20,  7,  3)=                  0.29466392013568187824d0
      iwe=iwe+1
      weightc( 21,  7,  3)=                 -0.20569111938218737068d0
      iwe=iwe+1
      weightc( 22,  7,  3)=                  0.13856023446360221651d0
      iwe=iwe+1
      weightc( 23,  7,  3)=                 -0.03205824462084433391d0
      iwe=iwe+1
      weightc( 24,  7,  3)=                 -0.11426607760624039878d0
      iwe=iwe+1
      weightc( 25,  7,  3)=                 -0.19140633041165594497d0
      iwe=iwe+1
      weightc( 26,  7,  3)=                 -0.27055966430303718395d0
      iwe=iwe+1
      weightc( 27,  7,  3)=                 -0.01990196010866429957d0
      iwe=iwe+1
      weightc( 28,  7,  3)=                 -0.10585632926821787747d0
      iwe=iwe+1
      weightc( 29,  7,  3)=                 -0.26208466787888762273d0
      iwe=iwe+1
      weightc( 30,  7,  3)=                  0.16536418549152384627d0
      iwe=iwe+1
      weightc( 31,  7,  3)=                  0.04024651438363110317d0
      iwe=iwe+1
      weightc( 32,  7,  3)=                 -0.03115257405038274197d0
      iwe=iwe+1
      weightc( 33,  7,  3)=                  0.18735434893753291630d0
      iwe=iwe+1
      weightc( 34,  7,  3)=                  0.44115035378309058745d0
      iwe=iwe+1
      weightc( 35,  7,  3)=                 -0.13297296464443505992d0
      iwe=iwe+1
      weightc( 36,  7,  3)=                  0.63574873036046830599d0
      iwe=iwe+1
      weightc( 37,  7,  3)=                 -0.51331556876795092492d0
      iwe=iwe+1
      weightc( 38,  7,  3)=                 -0.19159175047999274510d0
      iwe=iwe+1
      weightc( 39,  7,  3)=                  0.06778393829112598634d0
      iwe=iwe+1
      weightc( 40,  7,  3)=                 -0.37911997379572875966d0
      iwe=iwe+1
      weightc( 41,  7,  3)=                  0.36892395236160119287d0
      iwe=iwe+1
      weightc( 42,  7,  3)=                  0.04812025802192280988d0
      iwe=iwe+1
      weightc( 43,  7,  3)=                  0.29308695494475484056d0
      iwe=iwe+1
      weightc( 44,  7,  3)=                 -0.12123482594861616224d0
      iwe=iwe+1
      weightc( 45,  7,  3)=                  0.10926125343278610125d0
      iwe=iwe+1
      weightc( 46,  7,  3)=                  0.11257633629804328357d0
      iwe=iwe+1
      weightc( 47,  7,  3)=                 -0.08803290666393795427d0
      iwe=iwe+1
      weightc( 48,  7,  3)=                 -0.01961220948908289768d0
      iwe=iwe+1
      weightc( 49,  7,  3)=                  0.14770993168429871756d0
      iwe=iwe+1
      weightc( 50,  7,  3)=                  0.07640816161543592666d0
      iwe=iwe+1
      biasc(  7,  3)=                  1.34366089715543490790d0
      iwe=iwe+1
      weightc(  1,  8,  3)=                  0.00631852345884555914d0
      iwe=iwe+1
      weightc(  2,  8,  3)=                  0.40073495814822424066d0
      iwe=iwe+1
      weightc(  3,  8,  3)=                 -0.25530295298030308837d0
      iwe=iwe+1
      weightc(  4,  8,  3)=                  0.07094565425082832721d0
      iwe=iwe+1
      weightc(  5,  8,  3)=                  0.02207770642556154683d0
      iwe=iwe+1
      weightc(  6,  8,  3)=                  0.00279859949043393102d0
      iwe=iwe+1
      weightc(  7,  8,  3)=                  0.16314616030980472194d0
      iwe=iwe+1
      weightc(  8,  8,  3)=                  0.31038390920193470457d0
      iwe=iwe+1
      weightc(  9,  8,  3)=                 -0.07608079025418934549d0
      iwe=iwe+1
      weightc( 10,  8,  3)=                  0.15882450885253393547d0
      iwe=iwe+1
      weightc( 11,  8,  3)=                  0.00360893520254260526d0
      iwe=iwe+1
      weightc( 12,  8,  3)=                 -0.37420102610434913259d0
      iwe=iwe+1
      weightc( 13,  8,  3)=                  0.11295248170555212408d0
      iwe=iwe+1
      weightc( 14,  8,  3)=                 -0.44342566289560725323d0
      iwe=iwe+1
      weightc( 15,  8,  3)=                 -0.40366061123883634210d0
      iwe=iwe+1
      weightc( 16,  8,  3)=                 -0.08445324721513282340d0
      iwe=iwe+1
      weightc( 17,  8,  3)=                  0.15507073727109221828d0
      iwe=iwe+1
      weightc( 18,  8,  3)=                  0.27754656659600912549d0
      iwe=iwe+1
      weightc( 19,  8,  3)=                  0.65558291840578442056d0
      iwe=iwe+1
      weightc( 20,  8,  3)=                 -0.41205215776190795562d0
      iwe=iwe+1
      weightc( 21,  8,  3)=                 -0.10907844814695674684d0
      iwe=iwe+1
      weightc( 22,  8,  3)=                 -0.63447863443958485430d0
      iwe=iwe+1
      weightc( 23,  8,  3)=                 -0.21873932787934571853d0
      iwe=iwe+1
      weightc( 24,  8,  3)=                  0.00083349852436813508d0
      iwe=iwe+1
      weightc( 25,  8,  3)=                 -0.06683047219342080902d0
      iwe=iwe+1
      weightc( 26,  8,  3)=                  0.00041703830253823990d0
      iwe=iwe+1
      weightc( 27,  8,  3)=                 -0.69384089838105356129d0
      iwe=iwe+1
      weightc( 28,  8,  3)=                 -0.06441181648259447501d0
      iwe=iwe+1
      weightc( 29,  8,  3)=                  0.14233492282926435424d0
      iwe=iwe+1
      weightc( 30,  8,  3)=                 -0.27892686943780103936d0
      iwe=iwe+1
      weightc( 31,  8,  3)=                 -0.23236558830152734267d0
      iwe=iwe+1
      weightc( 32,  8,  3)=                 -0.01240853139626110074d0
      iwe=iwe+1
      weightc( 33,  8,  3)=                  0.36615826267434414820d0
      iwe=iwe+1
      weightc( 34,  8,  3)=                 -0.59455028219612204854d0
      iwe=iwe+1
      weightc( 35,  8,  3)=                  0.44108818640670677258d0
      iwe=iwe+1
      weightc( 36,  8,  3)=                  0.49189607400759688405d0
      iwe=iwe+1
      weightc( 37,  8,  3)=                  0.14360969652285190956d0
      iwe=iwe+1
      weightc( 38,  8,  3)=                 -0.47509130236068447539d0
      iwe=iwe+1
      weightc( 39,  8,  3)=                 -0.28491894735634987201d0
      iwe=iwe+1
      weightc( 40,  8,  3)=                 -0.33563717854379493399d0
      iwe=iwe+1
      weightc( 41,  8,  3)=                  0.05114544510023405488d0
      iwe=iwe+1
      weightc( 42,  8,  3)=                  0.48480257230835405169d0
      iwe=iwe+1
      weightc( 43,  8,  3)=                  0.03862576102946256584d0
      iwe=iwe+1
      weightc( 44,  8,  3)=                  0.12786030322762956257d0
      iwe=iwe+1
      weightc( 45,  8,  3)=                  0.19839255836390415344d0
      iwe=iwe+1
      weightc( 46,  8,  3)=                 -0.24217618751083810902d0
      iwe=iwe+1
      weightc( 47,  8,  3)=                  0.31142789145665422668d0
      iwe=iwe+1
      weightc( 48,  8,  3)=                 -0.45712084144212544734d0
      iwe=iwe+1
      weightc( 49,  8,  3)=                  0.32227377603604090428d0
      iwe=iwe+1
      weightc( 50,  8,  3)=                  0.50033964900763228112d0
      iwe=iwe+1
      biasc(  8,  3)=                  1.17380386448611839789d0
      iwe=iwe+1
      weightc(  1,  9,  3)=                 -0.33504615713853014292d0
      iwe=iwe+1
      weightc(  2,  9,  3)=                  0.02295758198336447439d0
      iwe=iwe+1
      weightc(  3,  9,  3)=                  0.08475757919031523535d0
      iwe=iwe+1
      weightc(  4,  9,  3)=                  0.16564674010217053657d0
      iwe=iwe+1
      weightc(  5,  9,  3)=                  0.16615121175806973897d0
      iwe=iwe+1
      weightc(  6,  9,  3)=                  0.28707848849309758332d0
      iwe=iwe+1
      weightc(  7,  9,  3)=                  0.11400955518048168369d0
      iwe=iwe+1
      weightc(  8,  9,  3)=                  0.14768450546267825052d0
      iwe=iwe+1
      weightc(  9,  9,  3)=                 -0.26307216872896171944d0
      iwe=iwe+1
      weightc( 10,  9,  3)=                 -0.24983959222908463937d0
      iwe=iwe+1
      weightc( 11,  9,  3)=                 -0.29364328280801982318d0
      iwe=iwe+1
      weightc( 12,  9,  3)=                  0.02570257493506349078d0
      iwe=iwe+1
      weightc( 13,  9,  3)=                  0.14592754015084896668d0
      iwe=iwe+1
      weightc( 14,  9,  3)=                  0.07967672838970991933d0
      iwe=iwe+1
      weightc( 15,  9,  3)=                 -0.02331207513623421990d0
      iwe=iwe+1
      weightc( 16,  9,  3)=                  0.07251110940141168582d0
      iwe=iwe+1
      weightc( 17,  9,  3)=                  0.40445190319259638478d0
      iwe=iwe+1
      weightc( 18,  9,  3)=                  0.09031181480780972604d0
      iwe=iwe+1
      weightc( 19,  9,  3)=                  0.02330766612786897007d0
      iwe=iwe+1
      weightc( 20,  9,  3)=                  0.18026703650052189332d0
      iwe=iwe+1
      weightc( 21,  9,  3)=                  0.25037296929057212269d0
      iwe=iwe+1
      weightc( 22,  9,  3)=                 -0.32518952205702644775d0
      iwe=iwe+1
      weightc( 23,  9,  3)=                 -0.45326622715379877304d0
      iwe=iwe+1
      weightc( 24,  9,  3)=                  0.09173100501629255499d0
      iwe=iwe+1
      weightc( 25,  9,  3)=                 -0.20824440382383249681d0
      iwe=iwe+1
      weightc( 26,  9,  3)=                  0.07953148987198412068d0
      iwe=iwe+1
      weightc( 27,  9,  3)=                  0.31868314058325747373d0
      iwe=iwe+1
      weightc( 28,  9,  3)=                 -0.36858566799268582814d0
      iwe=iwe+1
      weightc( 29,  9,  3)=                 -0.26681700934623764354d0
      iwe=iwe+1
      weightc( 30,  9,  3)=                  0.18284867542164703891d0
      iwe=iwe+1
      weightc( 31,  9,  3)=                 -0.24141065005148321099d0
      iwe=iwe+1
      weightc( 32,  9,  3)=                  0.24609829762333179648d0
      iwe=iwe+1
      weightc( 33,  9,  3)=                 -0.36032327859313023621d0
      iwe=iwe+1
      weightc( 34,  9,  3)=                  0.18828901490485749903d0
      iwe=iwe+1
      weightc( 35,  9,  3)=                 -0.19407145395162739288d0
      iwe=iwe+1
      weightc( 36,  9,  3)=                  0.28038806002275895590d0
      iwe=iwe+1
      weightc( 37,  9,  3)=                 -0.31842574517050958871d0
      iwe=iwe+1
      weightc( 38,  9,  3)=                 -0.12568906244972810615d0
      iwe=iwe+1
      weightc( 39,  9,  3)=                  0.00297083220478248401d0
      iwe=iwe+1
      weightc( 40,  9,  3)=                  0.49616949796037884690d0
      iwe=iwe+1
      weightc( 41,  9,  3)=                  0.02420613731266207588d0
      iwe=iwe+1
      weightc( 42,  9,  3)=                 -0.21948735187222737086d0
      iwe=iwe+1
      weightc( 43,  9,  3)=                  0.25151465648928716945d0
      iwe=iwe+1
      weightc( 44,  9,  3)=                  0.33791753951339037476d0
      iwe=iwe+1
      weightc( 45,  9,  3)=                  0.00941935805425627576d0
      iwe=iwe+1
      weightc( 46,  9,  3)=                  0.21006239424261355375d0
      iwe=iwe+1
      weightc( 47,  9,  3)=                 -0.01066345769777924356d0
      iwe=iwe+1
      weightc( 48,  9,  3)=                  0.36127593366030935629d0
      iwe=iwe+1
      weightc( 49,  9,  3)=                  0.30653972783216670850d0
      iwe=iwe+1
      weightc( 50,  9,  3)=                  0.05393463157661634866d0
      iwe=iwe+1
      biasc(  9,  3)=                  1.19940268251739978744d0
      iwe=iwe+1
      weightc(  1, 10,  3)=                 -0.52099251075510188969d0
      iwe=iwe+1
      weightc(  2, 10,  3)=                 -0.07621316722809123867d0
      iwe=iwe+1
      weightc(  3, 10,  3)=                  0.27742099470644732140d0
      iwe=iwe+1
      weightc(  4, 10,  3)=                 -0.04235697273512283728d0
      iwe=iwe+1
      weightc(  5, 10,  3)=                  0.27379485436471628912d0
      iwe=iwe+1
      weightc(  6, 10,  3)=                  0.07682864473649154979d0
      iwe=iwe+1
      weightc(  7, 10,  3)=                  0.11306172489870351672d0
      iwe=iwe+1
      weightc(  8, 10,  3)=                 -0.01581645854859439412d0
      iwe=iwe+1
      weightc(  9, 10,  3)=                 -0.33554514155494408190d0
      iwe=iwe+1
      weightc( 10, 10,  3)=                 -0.51373974464719840416d0
      iwe=iwe+1
      weightc( 11, 10,  3)=                 -0.58827170152514507429d0
      iwe=iwe+1
      weightc( 12, 10,  3)=                 -0.08006720962871635705d0
      iwe=iwe+1
      weightc( 13, 10,  3)=                  0.05635068496272603589d0
      iwe=iwe+1
      weightc( 14, 10,  3)=                 -0.12299976899316089618d0
      iwe=iwe+1
      weightc( 15, 10,  3)=                 -0.10173510833192418723d0
      iwe=iwe+1
      weightc( 16, 10,  3)=                  0.29645313826020880388d0
      iwe=iwe+1
      weightc( 17, 10,  3)=                  0.71235613268334341264d0
      iwe=iwe+1
      weightc( 18, 10,  3)=                 -0.19244070805557900172d0
      iwe=iwe+1
      weightc( 19, 10,  3)=                  0.53068861244678566802d0
      iwe=iwe+1
      weightc( 20, 10,  3)=                 -0.34263636801980124069d0
      iwe=iwe+1
      weightc( 21, 10,  3)=                 -0.50062898065822969418d0
      iwe=iwe+1
      weightc( 22, 10,  3)=                  0.34658957740318685481d0
      iwe=iwe+1
      weightc( 23, 10,  3)=                  0.38546242815518411140d0
      iwe=iwe+1
      weightc( 24, 10,  3)=                 -0.20797278962535273306d0
      iwe=iwe+1
      weightc( 25, 10,  3)=                 -0.37307253683159979918d0
      iwe=iwe+1
      weightc( 26, 10,  3)=                  0.02930119850446156332d0
      iwe=iwe+1
      weightc( 27, 10,  3)=                  0.04559029061148751200d0
      iwe=iwe+1
      weightc( 28, 10,  3)=                  0.06388988352328754672d0
      iwe=iwe+1
      weightc( 29, 10,  3)=                 -0.40035757532990667862d0
      iwe=iwe+1
      weightc( 30, 10,  3)=                 -0.35649771964206661279d0
      iwe=iwe+1
      weightc( 31, 10,  3)=                 -0.19937269056740397621d0
      iwe=iwe+1
      weightc( 32, 10,  3)=                  0.40203045570021767041d0
      iwe=iwe+1
      weightc( 33, 10,  3)=                  0.15144836193843927430d0
      iwe=iwe+1
      weightc( 34, 10,  3)=                  0.03522336258279092081d0
      iwe=iwe+1
      weightc( 35, 10,  3)=                 -0.15165779185953864872d0
      iwe=iwe+1
      weightc( 36, 10,  3)=                 -0.37442707372388950304d0
      iwe=iwe+1
      weightc( 37, 10,  3)=                 -0.20645625064458783537d0
      iwe=iwe+1
      weightc( 38, 10,  3)=                 -0.18719671136273316470d0
      iwe=iwe+1
      weightc( 39, 10,  3)=                  0.22043910545287773162d0
      iwe=iwe+1
      weightc( 40, 10,  3)=                 -0.28316170629673076409d0
      iwe=iwe+1
      weightc( 41, 10,  3)=                  0.20218734429332671509d0
      iwe=iwe+1
      weightc( 42, 10,  3)=                 -0.81728454810991768564d0
      iwe=iwe+1
      weightc( 43, 10,  3)=                  0.37457926351546122490d0
      iwe=iwe+1
      weightc( 44, 10,  3)=                 -0.12898174711831081329d0
      iwe=iwe+1
      weightc( 45, 10,  3)=                 -0.19610065154640704543d0
      iwe=iwe+1
      weightc( 46, 10,  3)=                  0.10983632616365139600d0
      iwe=iwe+1
      weightc( 47, 10,  3)=                 -0.48034847463768820530d0
      iwe=iwe+1
      weightc( 48, 10,  3)=                 -0.07567051949321645932d0
      iwe=iwe+1
      weightc( 49, 10,  3)=                  0.23667301746966309950d0
      iwe=iwe+1
      weightc( 50, 10,  3)=                  0.52825621599916716686d0
      iwe=iwe+1
      biasc( 10,  3)=                  1.45912047920050746974d0
      iwe=iwe+1
      weightc(  1, 11,  3)=                  0.23736836281574916208d0
      iwe=iwe+1
      weightc(  2, 11,  3)=                  0.80368793862995835386d0
      iwe=iwe+1
      weightc(  3, 11,  3)=                  0.26152142909428871542d0
      iwe=iwe+1
      weightc(  4, 11,  3)=                 -0.10638767335765386690d0
      iwe=iwe+1
      weightc(  5, 11,  3)=                 -0.45170563031488786265d0
      iwe=iwe+1
      weightc(  6, 11,  3)=                  0.00697958088346907479d0
      iwe=iwe+1
      weightc(  7, 11,  3)=                  0.25176175549161944334d0
      iwe=iwe+1
      weightc(  8, 11,  3)=                 -0.96680534335218215602d0
      iwe=iwe+1
      weightc(  9, 11,  3)=                  0.35121984568163244766d0
      iwe=iwe+1
      weightc( 10, 11,  3)=                  0.17968411625230656936d0
      iwe=iwe+1
      weightc( 11, 11,  3)=                  0.05402278698849812683d0
      iwe=iwe+1
      weightc( 12, 11,  3)=                 -0.37377895298644220334d0
      iwe=iwe+1
      weightc( 13, 11,  3)=                 -0.09226504260884382802d0
      iwe=iwe+1
      weightc( 14, 11,  3)=                  0.31157075814313450746d0
      iwe=iwe+1
      weightc( 15, 11,  3)=                  0.07807109131123175783d0
      iwe=iwe+1
      weightc( 16, 11,  3)=                 -0.02390231416352287322d0
      iwe=iwe+1
      weightc( 17, 11,  3)=                 -0.17087400373707320456d0
      iwe=iwe+1
      weightc( 18, 11,  3)=                  0.04523790508925033815d0
      iwe=iwe+1
      weightc( 19, 11,  3)=                 -0.35613986894016641527d0
      iwe=iwe+1
      weightc( 20, 11,  3)=                  0.05428878559838286322d0
      iwe=iwe+1
      weightc( 21, 11,  3)=                 -0.21242038404945420837d0
      iwe=iwe+1
      weightc( 22, 11,  3)=                  0.08360524346655150152d0
      iwe=iwe+1
      weightc( 23, 11,  3)=                 -0.64785564096743519791d0
      iwe=iwe+1
      weightc( 24, 11,  3)=                 -0.24552594342865460830d0
      iwe=iwe+1
      weightc( 25, 11,  3)=                 -0.06934483151111778265d0
      iwe=iwe+1
      weightc( 26, 11,  3)=                 -0.18485536485521122940d0
      iwe=iwe+1
      weightc( 27, 11,  3)=                  0.47402863410968132385d0
      iwe=iwe+1
      weightc( 28, 11,  3)=                 -0.12243443327185238312d0
      iwe=iwe+1
      weightc( 29, 11,  3)=                  0.12167632564161566522d0
      iwe=iwe+1
      weightc( 30, 11,  3)=                 -0.54541537503764658812d0
      iwe=iwe+1
      weightc( 31, 11,  3)=                  0.08995591419428064506d0
      iwe=iwe+1
      weightc( 32, 11,  3)=                  0.52869395496848103910d0
      iwe=iwe+1
      weightc( 33, 11,  3)=                 -0.33807227269510220502d0
      iwe=iwe+1
      weightc( 34, 11,  3)=                 -0.37213353819736827433d0
      iwe=iwe+1
      weightc( 35, 11,  3)=                 -0.05101243717979479092d0
      iwe=iwe+1
      weightc( 36, 11,  3)=                  0.29039502390440902202d0
      iwe=iwe+1
      weightc( 37, 11,  3)=                 -0.19846097583125565933d0
      iwe=iwe+1
      weightc( 38, 11,  3)=                  0.02590736827086181221d0
      iwe=iwe+1
      weightc( 39, 11,  3)=                 -0.50147104223921701305d0
      iwe=iwe+1
      weightc( 40, 11,  3)=                 -0.04362189283163326464d0
      iwe=iwe+1
      weightc( 41, 11,  3)=                  0.19102223701425058433d0
      iwe=iwe+1
      weightc( 42, 11,  3)=                  0.21934452169358092943d0
      iwe=iwe+1
      weightc( 43, 11,  3)=                 -0.31412032851427673652d0
      iwe=iwe+1
      weightc( 44, 11,  3)=                 -0.48434999715712073742d0
      iwe=iwe+1
      weightc( 45, 11,  3)=                  0.08606196546470047670d0
      iwe=iwe+1
      weightc( 46, 11,  3)=                  0.79236061909199007047d0
      iwe=iwe+1
      weightc( 47, 11,  3)=                  0.12839355056811596612d0
      iwe=iwe+1
      weightc( 48, 11,  3)=                 -0.19600691233101411037d0
      iwe=iwe+1
      weightc( 49, 11,  3)=                 -0.10065025840725230766d0
      iwe=iwe+1
      weightc( 50, 11,  3)=                 -0.37448588099503948845d0
      iwe=iwe+1
      biasc( 11,  3)=                  1.02765825539646349362d0
      iwe=iwe+1
      weightc(  1, 12,  3)=                  0.14714211108662464400d0
      iwe=iwe+1
      weightc(  2, 12,  3)=                  0.05708747909575394297d0
      iwe=iwe+1
      weightc(  3, 12,  3)=                  0.28721927290071003203d0
      iwe=iwe+1
      weightc(  4, 12,  3)=                 -0.24482052271922666309d0
      iwe=iwe+1
      weightc(  5, 12,  3)=                 -0.18113179021944755820d0
      iwe=iwe+1
      weightc(  6, 12,  3)=                 -0.15175992705710775188d0
      iwe=iwe+1
      weightc(  7, 12,  3)=                  0.12054900685309037633d0
      iwe=iwe+1
      weightc(  8, 12,  3)=                  0.01609199953569153893d0
      iwe=iwe+1
      weightc(  9, 12,  3)=                 -0.11140090403696403798d0
      iwe=iwe+1
      weightc( 10, 12,  3)=                 -0.56366851155930497441d0
      iwe=iwe+1
      weightc( 11, 12,  3)=                  0.05598314785049747500d0
      iwe=iwe+1
      weightc( 12, 12,  3)=                  0.35523439691493330361d0
      iwe=iwe+1
      weightc( 13, 12,  3)=                  0.37265538445716134275d0
      iwe=iwe+1
      weightc( 14, 12,  3)=                 -0.35720209126206692307d0
      iwe=iwe+1
      weightc( 15, 12,  3)=                 -0.05785734735774753640d0
      iwe=iwe+1
      weightc( 16, 12,  3)=                  0.26982370964270618874d0
      iwe=iwe+1
      weightc( 17, 12,  3)=                 -0.05488552826845165267d0
      iwe=iwe+1
      weightc( 18, 12,  3)=                 -0.45889307150295577387d0
      iwe=iwe+1
      weightc( 19, 12,  3)=                  0.15714790336839126739d0
      iwe=iwe+1
      weightc( 20, 12,  3)=                  0.23239306517737923219d0
      iwe=iwe+1
      weightc( 21, 12,  3)=                 -0.23166975340077988754d0
      iwe=iwe+1
      weightc( 22, 12,  3)=                 -0.08940673367470380883d0
      iwe=iwe+1
      weightc( 23, 12,  3)=                  0.48424031635958558750d0
      iwe=iwe+1
      weightc( 24, 12,  3)=                  0.36013823575181275194d0
      iwe=iwe+1
      weightc( 25, 12,  3)=                  0.05125290151411153461d0
      iwe=iwe+1
      weightc( 26, 12,  3)=                  0.08136337903944784733d0
      iwe=iwe+1
      weightc( 27, 12,  3)=                 -0.55744322057948514360d0
      iwe=iwe+1
      weightc( 28, 12,  3)=                 -0.37879625529400795525d0
      iwe=iwe+1
      weightc( 29, 12,  3)=                 -0.31158982497358822528d0
      iwe=iwe+1
      weightc( 30, 12,  3)=                  0.14887891573801570466d0
      iwe=iwe+1
      weightc( 31, 12,  3)=                 -0.04511022892779170679d0
      iwe=iwe+1
      weightc( 32, 12,  3)=                  0.32848366001030343542d0
      iwe=iwe+1
      weightc( 33, 12,  3)=                  0.13211004750490662474d0
      iwe=iwe+1
      weightc( 34, 12,  3)=                  0.25495718337394868147d0
      iwe=iwe+1
      weightc( 35, 12,  3)=                  0.27695049323295772847d0
      iwe=iwe+1
      weightc( 36, 12,  3)=                  0.19018847771951458148d0
      iwe=iwe+1
      weightc( 37, 12,  3)=                  0.37148056211319901987d0
      iwe=iwe+1
      weightc( 38, 12,  3)=                  0.08982114953962064274d0
      iwe=iwe+1
      weightc( 39, 12,  3)=                 -0.40357162878664987193d0
      iwe=iwe+1
      weightc( 40, 12,  3)=                 -0.03120427059590717353d0
      iwe=iwe+1
      weightc( 41, 12,  3)=                  0.03933859531023237155d0
      iwe=iwe+1
      weightc( 42, 12,  3)=                  0.13815166577722121088d0
      iwe=iwe+1
      weightc( 43, 12,  3)=                  0.00816919598497150429d0
      iwe=iwe+1
      weightc( 44, 12,  3)=                  0.11053596888691341604d0
      iwe=iwe+1
      weightc( 45, 12,  3)=                 -0.16394422631202740237d0
      iwe=iwe+1
      weightc( 46, 12,  3)=                 -0.02081831869747425429d0
      iwe=iwe+1
      weightc( 47, 12,  3)=                  0.21610237841074342313d0
      iwe=iwe+1
      weightc( 48, 12,  3)=                  0.38502476700993532033d0
      iwe=iwe+1
      weightc( 49, 12,  3)=                  0.04455900885251147525d0
      iwe=iwe+1
      weightc( 50, 12,  3)=                 -0.61985376408093362244d0
      iwe=iwe+1
      biasc( 12,  3)=                 -1.24566064007725896268d0
      iwe=iwe+1
      weightc(  1, 13,  3)=                 -0.18476581116368676061d0
      iwe=iwe+1
      weightc(  2, 13,  3)=                  0.56167577812106539437d0
      iwe=iwe+1
      weightc(  3, 13,  3)=                 -0.17202473881209312534d0
      iwe=iwe+1
      weightc(  4, 13,  3)=                 -0.14761233471566628794d0
      iwe=iwe+1
      weightc(  5, 13,  3)=                  0.13571414130221282068d0
      iwe=iwe+1
      weightc(  6, 13,  3)=                  0.21943812049138680664d0
      iwe=iwe+1
      weightc(  7, 13,  3)=                  0.27041475469436682122d0
      iwe=iwe+1
      weightc(  8, 13,  3)=                 -0.67365957719711322405d0
      iwe=iwe+1
      weightc(  9, 13,  3)=                 -0.26285980884275794711d0
      iwe=iwe+1
      weightc( 10, 13,  3)=                 -0.16650599078544847664d0
      iwe=iwe+1
      weightc( 11, 13,  3)=                 -0.05408868704309772318d0
      iwe=iwe+1
      weightc( 12, 13,  3)=                 -0.32770519745045184612d0
      iwe=iwe+1
      weightc( 13, 13,  3)=                 -0.14742924067617407813d0
      iwe=iwe+1
      weightc( 14, 13,  3)=                 -0.16253381807092801004d0
      iwe=iwe+1
      weightc( 15, 13,  3)=                  0.55694679711200034689d0
      iwe=iwe+1
      weightc( 16, 13,  3)=                 -0.41339734495224378374d0
      iwe=iwe+1
      weightc( 17, 13,  3)=                  0.03705012600472191303d0
      iwe=iwe+1
      weightc( 18, 13,  3)=                  0.11719172184539883297d0
      iwe=iwe+1
      weightc( 19, 13,  3)=                  0.16079239429516464788d0
      iwe=iwe+1
      weightc( 20, 13,  3)=                 -0.00034791061512506394d0
      iwe=iwe+1
      weightc( 21, 13,  3)=                  0.26316243540055866967d0
      iwe=iwe+1
      weightc( 22, 13,  3)=                 -0.33631546769548803510d0
      iwe=iwe+1
      weightc( 23, 13,  3)=                 -0.07017674482100021149d0
      iwe=iwe+1
      weightc( 24, 13,  3)=                 -0.67932576751335427279d0
      iwe=iwe+1
      weightc( 25, 13,  3)=                  0.47421767342249943056d0
      iwe=iwe+1
      weightc( 26, 13,  3)=                 -0.01953985302272232341d0
      iwe=iwe+1
      weightc( 27, 13,  3)=                 -0.16139816412853405514d0
      iwe=iwe+1
      weightc( 28, 13,  3)=                 -0.23410764673222703158d0
      iwe=iwe+1
      weightc( 29, 13,  3)=                 -0.51683388824112286297d0
      iwe=iwe+1
      weightc( 30, 13,  3)=                  0.07416080168456487542d0
      iwe=iwe+1
      weightc( 31, 13,  3)=                 -0.03642957161626501905d0
      iwe=iwe+1
      weightc( 32, 13,  3)=                 -0.49361345217185881307d0
      iwe=iwe+1
      weightc( 33, 13,  3)=                 -0.16206172957837378101d0
      iwe=iwe+1
      weightc( 34, 13,  3)=                  0.06214318061560895889d0
      iwe=iwe+1
      weightc( 35, 13,  3)=                  0.00455083892985290971d0
      iwe=iwe+1
      weightc( 36, 13,  3)=                  0.21763595902805757398d0
      iwe=iwe+1
      weightc( 37, 13,  3)=                 -0.11733522765752930905d0
      iwe=iwe+1
      weightc( 38, 13,  3)=                  0.32179989850936535634d0
      iwe=iwe+1
      weightc( 39, 13,  3)=                 -0.62203865715962602945d0
      iwe=iwe+1
      weightc( 40, 13,  3)=                  0.35709247860703091648d0
      iwe=iwe+1
      weightc( 41, 13,  3)=                 -0.43240265844762754144d0
      iwe=iwe+1
      weightc( 42, 13,  3)=                  0.33383582425248203851d0
      iwe=iwe+1
      weightc( 43, 13,  3)=                  0.08167625090976438074d0
      iwe=iwe+1
      weightc( 44, 13,  3)=                 -0.19816229485566944080d0
      iwe=iwe+1
      weightc( 45, 13,  3)=                  0.06186622036686863224d0
      iwe=iwe+1
      weightc( 46, 13,  3)=                  0.15268161551142389598d0
      iwe=iwe+1
      weightc( 47, 13,  3)=                  0.19904300867985352808d0
      iwe=iwe+1
      weightc( 48, 13,  3)=                 -0.47313007931471345868d0
      iwe=iwe+1
      weightc( 49, 13,  3)=                 -0.20089564017746844304d0
      iwe=iwe+1
      weightc( 50, 13,  3)=                  0.05867664267918914350d0
      iwe=iwe+1
      biasc( 13,  3)=                  1.11597122680966420738d0
      iwe=iwe+1
      weightc(  1, 14,  3)=                 -0.48541176517994211181d0
      iwe=iwe+1
      weightc(  2, 14,  3)=                 -0.39670289794048074761d0
      iwe=iwe+1
      weightc(  3, 14,  3)=                  0.25402939078078867752d0
      iwe=iwe+1
      weightc(  4, 14,  3)=                  0.13911634713612996972d0
      iwe=iwe+1
      weightc(  5, 14,  3)=                 -0.01059085712690463130d0
      iwe=iwe+1
      weightc(  6, 14,  3)=                 -0.29290453348422318403d0
      iwe=iwe+1
      weightc(  7, 14,  3)=                  0.45521263407417544844d0
      iwe=iwe+1
      weightc(  8, 14,  3)=                  1.03890886073197541428d0
      iwe=iwe+1
      weightc(  9, 14,  3)=                  0.18870354517619311596d0
      iwe=iwe+1
      weightc( 10, 14,  3)=                  0.11139694673433053751d0
      iwe=iwe+1
      weightc( 11, 14,  3)=                 -0.68445347290626334935d0
      iwe=iwe+1
      weightc( 12, 14,  3)=                  0.91153667460718446058d0
      iwe=iwe+1
      weightc( 13, 14,  3)=                 -0.26830004558054654229d0
      iwe=iwe+1
      weightc( 14, 14,  3)=                  0.23794058704662313097d0
      iwe=iwe+1
      weightc( 15, 14,  3)=                 -0.26329847970807279678d0
      iwe=iwe+1
      weightc( 16, 14,  3)=                 -0.33958038456640821101d0
      iwe=iwe+1
      weightc( 17, 14,  3)=                 -0.24801869447439420235d0
      iwe=iwe+1
      weightc( 18, 14,  3)=                  0.31410751213091014922d0
      iwe=iwe+1
      weightc( 19, 14,  3)=                  0.10044237050832810487d0
      iwe=iwe+1
      weightc( 20, 14,  3)=                 -0.01447637401487733566d0
      iwe=iwe+1
      weightc( 21, 14,  3)=                 -0.10632660306648029913d0
      iwe=iwe+1
      weightc( 22, 14,  3)=                  0.17694052328562021037d0
      iwe=iwe+1
      weightc( 23, 14,  3)=                 -0.25109619131187016494d0
      iwe=iwe+1
      weightc( 24, 14,  3)=                  0.29121726132866737613d0
      iwe=iwe+1
      weightc( 25, 14,  3)=                 -0.20354360227287818241d0
      iwe=iwe+1
      weightc( 26, 14,  3)=                 -0.14522560152250663101d0
      iwe=iwe+1
      weightc( 27, 14,  3)=                  0.79937989582922519549d0
      iwe=iwe+1
      weightc( 28, 14,  3)=                  0.12839527418845292361d0
      iwe=iwe+1
      weightc( 29, 14,  3)=                 -0.06777896896118545955d0
      iwe=iwe+1
      weightc( 30, 14,  3)=                  0.03770773326898324562d0
      iwe=iwe+1
      weightc( 31, 14,  3)=                  0.59144283302420808113d0
      iwe=iwe+1
      weightc( 32, 14,  3)=                 -0.20651065392812478771d0
      iwe=iwe+1
      weightc( 33, 14,  3)=                  0.05103770343046797053d0
      iwe=iwe+1
      weightc( 34, 14,  3)=                 -0.42466354771530118173d0
      iwe=iwe+1
      weightc( 35, 14,  3)=                 -0.55801970209408602308d0
      iwe=iwe+1
      weightc( 36, 14,  3)=                 -0.19952978197479742661d0
      iwe=iwe+1
      weightc( 37, 14,  3)=                  0.43476703976310343558d0
      iwe=iwe+1
      weightc( 38, 14,  3)=                 -0.56126188667520382491d0
      iwe=iwe+1
      weightc( 39, 14,  3)=                  0.27671344048245538616d0
      iwe=iwe+1
      weightc( 40, 14,  3)=                 -0.07376900571643833782d0
      iwe=iwe+1
      weightc( 41, 14,  3)=                  0.03024325331723363985d0
      iwe=iwe+1
      weightc( 42, 14,  3)=                  0.01590217112279437850d0
      iwe=iwe+1
      weightc( 43, 14,  3)=                  0.13421385890251538719d0
      iwe=iwe+1
      weightc( 44, 14,  3)=                  0.61026383157510200039d0
      iwe=iwe+1
      weightc( 45, 14,  3)=                  0.17011815236522850880d0
      iwe=iwe+1
      weightc( 46, 14,  3)=                  0.01553434845866207697d0
      iwe=iwe+1
      weightc( 47, 14,  3)=                 -0.10780095320502454392d0
      iwe=iwe+1
      weightc( 48, 14,  3)=                  0.26598618105431137693d0
      iwe=iwe+1
      weightc( 49, 14,  3)=                 -0.62887660526068378530d0
      iwe=iwe+1
      weightc( 50, 14,  3)=                  0.18310822240324076127d0
      iwe=iwe+1
      biasc( 14,  3)=                  0.98202431694347003255d0
      iwe=iwe+1
      weightc(  1, 15,  3)=                 -0.51883031022058656578d0
      iwe=iwe+1
      weightc(  2, 15,  3)=                  0.16282119169214701038d0
      iwe=iwe+1
      weightc(  3, 15,  3)=                  0.00301694765540409761d0
      iwe=iwe+1
      weightc(  4, 15,  3)=                 -0.16947886119281185824d0
      iwe=iwe+1
      weightc(  5, 15,  3)=                 -0.12030351956074046560d0
      iwe=iwe+1
      weightc(  6, 15,  3)=                 -0.34666218285021227485d0
      iwe=iwe+1
      weightc(  7, 15,  3)=                  0.11179879727211648743d0
      iwe=iwe+1
      weightc(  8, 15,  3)=                  0.53619117294899620862d0
      iwe=iwe+1
      weightc(  9, 15,  3)=                  0.16693890304662686863d0
      iwe=iwe+1
      weightc( 10, 15,  3)=                 -0.10946366383801364730d0
      iwe=iwe+1
      weightc( 11, 15,  3)=                 -0.18273303367599552649d0
      iwe=iwe+1
      weightc( 12, 15,  3)=                  0.09555774759177615429d0
      iwe=iwe+1
      weightc( 13, 15,  3)=                 -0.31607639079782778868d0
      iwe=iwe+1
      weightc( 14, 15,  3)=                 -0.23661386680053211884d0
      iwe=iwe+1
      weightc( 15, 15,  3)=                 -0.21294873313529846803d0
      iwe=iwe+1
      weightc( 16, 15,  3)=                  0.21912014468564702807d0
      iwe=iwe+1
      weightc( 17, 15,  3)=                  0.06193035082095661031d0
      iwe=iwe+1
      weightc( 18, 15,  3)=                 -0.10566194289078952029d0
      iwe=iwe+1
      weightc( 19, 15,  3)=                 -0.09107527224736190752d0
      iwe=iwe+1
      weightc( 20, 15,  3)=                  0.35921002256653694618d0
      iwe=iwe+1
      weightc( 21, 15,  3)=                  0.00718401665940401890d0
      iwe=iwe+1
      weightc( 22, 15,  3)=                  0.17479572553918565347d0
      iwe=iwe+1
      weightc( 23, 15,  3)=                 -0.03105440582227237539d0
      iwe=iwe+1
      weightc( 24, 15,  3)=                  0.26102889564232351072d0
      iwe=iwe+1
      weightc( 25, 15,  3)=                  0.41625137226712632943d0
      iwe=iwe+1
      weightc( 26, 15,  3)=                 -0.22359143276488213647d0
      iwe=iwe+1
      weightc( 27, 15,  3)=                 -0.17395455737622669834d0
      iwe=iwe+1
      weightc( 28, 15,  3)=                  0.04371721997592997039d0
      iwe=iwe+1
      weightc( 29, 15,  3)=                 -0.19287953651883932293d0
      iwe=iwe+1
      weightc( 30, 15,  3)=                 -0.08356725790282193422d0
      iwe=iwe+1
      weightc( 31, 15,  3)=                 -0.18981996740579837324d0
      iwe=iwe+1
      weightc( 32, 15,  3)=                  0.43532101426768882169d0
      iwe=iwe+1
      weightc( 33, 15,  3)=                 -0.29549405257990102314d0
      iwe=iwe+1
      weightc( 34, 15,  3)=                 -0.08628425285488225405d0
      iwe=iwe+1
      weightc( 35, 15,  3)=                 -0.16473191229959108228d0
      iwe=iwe+1
      weightc( 36, 15,  3)=                 -0.24397872151967450738d0
      iwe=iwe+1
      weightc( 37, 15,  3)=                  0.49927222699338852374d0
      iwe=iwe+1
      weightc( 38, 15,  3)=                 -0.13570223625831542846d0
      iwe=iwe+1
      weightc( 39, 15,  3)=                  0.11445551892869984534d0
      iwe=iwe+1
      weightc( 40, 15,  3)=                 -0.37075984615081414297d0
      iwe=iwe+1
      weightc( 41, 15,  3)=                 -0.13257164511162156106d0
      iwe=iwe+1
      weightc( 42, 15,  3)=                  0.10161967589770568021d0
      iwe=iwe+1
      weightc( 43, 15,  3)=                 -0.01716630779249593911d0
      iwe=iwe+1
      weightc( 44, 15,  3)=                 -0.18095090259266960464d0
      iwe=iwe+1
      weightc( 45, 15,  3)=                 -0.28562513950793194661d0
      iwe=iwe+1
      weightc( 46, 15,  3)=                 -0.20373824104396229262d0
      iwe=iwe+1
      weightc( 47, 15,  3)=                  0.47607634251878866438d0
      iwe=iwe+1
      weightc( 48, 15,  3)=                  0.54037140787409965181d0
      iwe=iwe+1
      weightc( 49, 15,  3)=                  0.58109652474846018588d0
      iwe=iwe+1
      weightc( 50, 15,  3)=                 -0.39537013955241423480d0
      iwe=iwe+1
      biasc( 15,  3)=                  0.94807099227843272260d0
      iwe=iwe+1
      weightc(  1, 16,  3)=                 -0.15071053382217147742d0
      iwe=iwe+1
      weightc(  2, 16,  3)=                 -0.38693929744149763161d0
      iwe=iwe+1
      weightc(  3, 16,  3)=                  0.22496644222621609011d0
      iwe=iwe+1
      weightc(  4, 16,  3)=                  0.22714592722437590422d0
      iwe=iwe+1
      weightc(  5, 16,  3)=                 -0.06543016913310899241d0
      iwe=iwe+1
      weightc(  6, 16,  3)=                  0.56345841251059924915d0
      iwe=iwe+1
      weightc(  7, 16,  3)=                 -0.27554195857757096677d0
      iwe=iwe+1
      weightc(  8, 16,  3)=                 -0.17581150761896979784d0
      iwe=iwe+1
      weightc(  9, 16,  3)=                 -0.31400895292189273666d0
      iwe=iwe+1
      weightc( 10, 16,  3)=                 -0.22427775867355026485d0
      iwe=iwe+1
      weightc( 11, 16,  3)=                 -0.29826225458493671461d0
      iwe=iwe+1
      weightc( 12, 16,  3)=                  0.45043059973630183990d0
      iwe=iwe+1
      weightc( 13, 16,  3)=                  0.23994801682593289160d0
      iwe=iwe+1
      weightc( 14, 16,  3)=                  0.14634317534750601597d0
      iwe=iwe+1
      weightc( 15, 16,  3)=                  0.38844876733000560654d0
      iwe=iwe+1
      weightc( 16, 16,  3)=                 -0.12322981108506399217d0
      iwe=iwe+1
      weightc( 17, 16,  3)=                  0.08411567146151764651d0
      iwe=iwe+1
      weightc( 18, 16,  3)=                 -0.66830297966897567186d0
      iwe=iwe+1
      weightc( 19, 16,  3)=                 -0.09843465773313413159d0
      iwe=iwe+1
      weightc( 20, 16,  3)=                 -0.26743763682514637425d0
      iwe=iwe+1
      weightc( 21, 16,  3)=                  0.07895957999111076486d0
      iwe=iwe+1
      weightc( 22, 16,  3)=                 -0.01138970291236271123d0
      iwe=iwe+1
      weightc( 23, 16,  3)=                 -0.05650006894584969075d0
      iwe=iwe+1
      weightc( 24, 16,  3)=                  0.13747341874906149339d0
      iwe=iwe+1
      weightc( 25, 16,  3)=                  0.67820331230928410093d0
      iwe=iwe+1
      weightc( 26, 16,  3)=                 -0.00952059276125589299d0
      iwe=iwe+1
      weightc( 27, 16,  3)=                 -0.08290547090089611659d0
      iwe=iwe+1
      weightc( 28, 16,  3)=                 -0.01966680617469265466d0
      iwe=iwe+1
      weightc( 29, 16,  3)=                 -0.62104679449138011638d0
      iwe=iwe+1
      weightc( 30, 16,  3)=                 -0.55739709474178300574d0
      iwe=iwe+1
      weightc( 31, 16,  3)=                  0.15674104346978276481d0
      iwe=iwe+1
      weightc( 32, 16,  3)=                  0.10308203780100017033d0
      iwe=iwe+1
      weightc( 33, 16,  3)=                 -0.18618205144005578466d0
      iwe=iwe+1
      weightc( 34, 16,  3)=                  0.11610665319815428875d0
      iwe=iwe+1
      weightc( 35, 16,  3)=                  0.27010540168436625308d0
      iwe=iwe+1
      weightc( 36, 16,  3)=                  0.31428814872335575359d0
      iwe=iwe+1
      weightc( 37, 16,  3)=                  0.48686994928783483561d0
      iwe=iwe+1
      weightc( 38, 16,  3)=                 -0.01778470649097257938d0
      iwe=iwe+1
      weightc( 39, 16,  3)=                 -0.24414443421398820955d0
      iwe=iwe+1
      weightc( 40, 16,  3)=                 -0.01096150318710934456d0
      iwe=iwe+1
      weightc( 41, 16,  3)=                 -0.34358330405039960720d0
      iwe=iwe+1
      weightc( 42, 16,  3)=                  0.10576304726030137660d0
      iwe=iwe+1
      weightc( 43, 16,  3)=                  0.17986591379885097375d0
      iwe=iwe+1
      weightc( 44, 16,  3)=                 -0.05301583728502996806d0
      iwe=iwe+1
      weightc( 45, 16,  3)=                 -0.42390536166264963791d0
      iwe=iwe+1
      weightc( 46, 16,  3)=                 -0.04308610254105017107d0
      iwe=iwe+1
      weightc( 47, 16,  3)=                  0.16701349497674819466d0
      iwe=iwe+1
      weightc( 48, 16,  3)=                 -0.19795664694007064632d0
      iwe=iwe+1
      weightc( 49, 16,  3)=                  0.62372791528934290461d0
      iwe=iwe+1
      weightc( 50, 16,  3)=                 -0.34151000758418620373d0
      iwe=iwe+1
      biasc( 16,  3)=                 -0.72398338292658737103d0
      iwe=iwe+1
      weightc(  1, 17,  3)=                 -0.09377569319197009978d0
      iwe=iwe+1
      weightc(  2, 17,  3)=                 -0.07230134535132250184d0
      iwe=iwe+1
      weightc(  3, 17,  3)=                  0.16753882719465290618d0
      iwe=iwe+1
      weightc(  4, 17,  3)=                 -0.22893587259763678587d0
      iwe=iwe+1
      weightc(  5, 17,  3)=                  0.28652332151465442767d0
      iwe=iwe+1
      weightc(  6, 17,  3)=                  0.28308688129698533764d0
      iwe=iwe+1
      weightc(  7, 17,  3)=                 -0.12224145572590504327d0
      iwe=iwe+1
      weightc(  8, 17,  3)=                 -0.58468572393817053179d0
      iwe=iwe+1
      weightc(  9, 17,  3)=                  0.38114803324069557178d0
      iwe=iwe+1
      weightc( 10, 17,  3)=                 -0.23604050981807292442d0
      iwe=iwe+1
      weightc( 11, 17,  3)=                  0.06697611595760395720d0
      iwe=iwe+1
      weightc( 12, 17,  3)=                  0.08570884092958991340d0
      iwe=iwe+1
      weightc( 13, 17,  3)=                 -0.11829279197964652492d0
      iwe=iwe+1
      weightc( 14, 17,  3)=                 -0.39643159401275246401d0
      iwe=iwe+1
      weightc( 15, 17,  3)=                 -0.06480107491913349171d0
      iwe=iwe+1
      weightc( 16, 17,  3)=                  0.03638996562424890585d0
      iwe=iwe+1
      weightc( 17, 17,  3)=                 -0.38194550080095368561d0
      iwe=iwe+1
      weightc( 18, 17,  3)=                 -0.11641107627945580794d0
      iwe=iwe+1
      weightc( 19, 17,  3)=                  0.22758144755232700973d0
      iwe=iwe+1
      weightc( 20, 17,  3)=                  0.08238244469336553077d0
      iwe=iwe+1
      weightc( 21, 17,  3)=                  0.06780417860958080911d0
      iwe=iwe+1
      weightc( 22, 17,  3)=                 -0.25913597241509050972d0
      iwe=iwe+1
      weightc( 23, 17,  3)=                  0.34049401353460362341d0
      iwe=iwe+1
      weightc( 24, 17,  3)=                 -0.16011980844500298127d0
      iwe=iwe+1
      weightc( 25, 17,  3)=                 -0.27118381003008112939d0
      iwe=iwe+1
      weightc( 26, 17,  3)=                 -0.33159573181036278156d0
      iwe=iwe+1
      weightc( 27, 17,  3)=                  0.30728220759336782875d0
      iwe=iwe+1
      weightc( 28, 17,  3)=                 -0.15134644335888317035d0
      iwe=iwe+1
      weightc( 29, 17,  3)=                 -0.38093811308572711471d0
      iwe=iwe+1
      weightc( 30, 17,  3)=                  0.19368179623084391672d0
      iwe=iwe+1
      weightc( 31, 17,  3)=                  0.62469665207061053636d0
      iwe=iwe+1
      weightc( 32, 17,  3)=                 -0.12345167466083596663d0
      iwe=iwe+1
      weightc( 33, 17,  3)=                  0.29232097891125746747d0
      iwe=iwe+1
      weightc( 34, 17,  3)=                  0.41701207158388375884d0
      iwe=iwe+1
      weightc( 35, 17,  3)=                 -0.06223068961682232114d0
      iwe=iwe+1
      weightc( 36, 17,  3)=                  0.16802116905548503123d0
      iwe=iwe+1
      weightc( 37, 17,  3)=                  0.01637298836375583946d0
      iwe=iwe+1
      weightc( 38, 17,  3)=                 -0.23986128978853227256d0
      iwe=iwe+1
      weightc( 39, 17,  3)=                  0.16536462902131671138d0
      iwe=iwe+1
      weightc( 40, 17,  3)=                  0.27620758398926065214d0
      iwe=iwe+1
      weightc( 41, 17,  3)=                  0.10966227974803575973d0
      iwe=iwe+1
      weightc( 42, 17,  3)=                  0.14346595778002871335d0
      iwe=iwe+1
      weightc( 43, 17,  3)=                 -0.17293037760546292603d0
      iwe=iwe+1
      weightc( 44, 17,  3)=                  0.22480177192662365027d0
      iwe=iwe+1
      weightc( 45, 17,  3)=                 -0.11007880423331563302d0
      iwe=iwe+1
      weightc( 46, 17,  3)=                 -0.20852954148977867477d0
      iwe=iwe+1
      weightc( 47, 17,  3)=                 -0.41076929545008744604d0
      iwe=iwe+1
      weightc( 48, 17,  3)=                 -0.09172600873595779247d0
      iwe=iwe+1
      weightc( 49, 17,  3)=                 -0.12568395758250261451d0
      iwe=iwe+1
      weightc( 50, 17,  3)=                 -0.19356283758927819716d0
      iwe=iwe+1
      biasc( 17,  3)=                  0.92241504531877605011d0
      iwe=iwe+1
      weightc(  1, 18,  3)=                 -0.12669341125354394162d0
      iwe=iwe+1
      weightc(  2, 18,  3)=                  0.02855942569391457103d0
      iwe=iwe+1
      weightc(  3, 18,  3)=                 -0.20307680398501390395d0
      iwe=iwe+1
      weightc(  4, 18,  3)=                 -0.05872440106079828553d0
      iwe=iwe+1
      weightc(  5, 18,  3)=                 -0.21505129776149412013d0
      iwe=iwe+1
      weightc(  6, 18,  3)=                 -0.12237035216084297951d0
      iwe=iwe+1
      weightc(  7, 18,  3)=                 -0.27357463982149060611d0
      iwe=iwe+1
      weightc(  8, 18,  3)=                  0.22122631268494122314d0
      iwe=iwe+1
      weightc(  9, 18,  3)=                  0.24287122722381726536d0
      iwe=iwe+1
      weightc( 10, 18,  3)=                  0.21820948319024890960d0
      iwe=iwe+1
      weightc( 11, 18,  3)=                 -0.27072167627482862651d0
      iwe=iwe+1
      weightc( 12, 18,  3)=                  0.13316103443437313225d0
      iwe=iwe+1
      weightc( 13, 18,  3)=                 -0.10313677911215453353d0
      iwe=iwe+1
      weightc( 14, 18,  3)=                  0.40012919597688323403d0
      iwe=iwe+1
      weightc( 15, 18,  3)=                 -0.17007709814282409577d0
      iwe=iwe+1
      weightc( 16, 18,  3)=                 -0.43436210935859342896d0
      iwe=iwe+1
      weightc( 17, 18,  3)=                 -0.52405845160715147646d0
      iwe=iwe+1
      weightc( 18, 18,  3)=                 -0.25837894739460542937d0
      iwe=iwe+1
      weightc( 19, 18,  3)=                 -0.09947219246609408094d0
      iwe=iwe+1
      weightc( 20, 18,  3)=                 -0.29982485678746517710d0
      iwe=iwe+1
      weightc( 21, 18,  3)=                  0.11550781140363994282d0
      iwe=iwe+1
      weightc( 22, 18,  3)=                  0.17309327184045875114d0
      iwe=iwe+1
      weightc( 23, 18,  3)=                  0.10103004552769700997d0
      iwe=iwe+1
      weightc( 24, 18,  3)=                 -0.47643990309693073915d0
      iwe=iwe+1
      weightc( 25, 18,  3)=                  0.23287101002457707977d0
      iwe=iwe+1
      weightc( 26, 18,  3)=                 -0.21104544568697447549d0
      iwe=iwe+1
      weightc( 27, 18,  3)=                 -0.39795976941330146737d0
      iwe=iwe+1
      weightc( 28, 18,  3)=                 -0.19918560103377011550d0
      iwe=iwe+1
      weightc( 29, 18,  3)=                  0.42227903007749667541d0
      iwe=iwe+1
      weightc( 30, 18,  3)=                  0.07649505691064288626d0
      iwe=iwe+1
      weightc( 31, 18,  3)=                  0.47012194264957296586d0
      iwe=iwe+1
      weightc( 32, 18,  3)=                 -0.06920058925993452514d0
      iwe=iwe+1
      weightc( 33, 18,  3)=                  0.37621108737608671690d0
      iwe=iwe+1
      weightc( 34, 18,  3)=                 -0.92414952705928687937d0
      iwe=iwe+1
      weightc( 35, 18,  3)=                 -0.18731647763862616096d0
      iwe=iwe+1
      weightc( 36, 18,  3)=                 -0.05157168218355596273d0
      iwe=iwe+1
      weightc( 37, 18,  3)=                 -0.08888701553235808794d0
      iwe=iwe+1
      weightc( 38, 18,  3)=                  0.48587043349342751153d0
      iwe=iwe+1
      weightc( 39, 18,  3)=                 -0.19709006254966696114d0
      iwe=iwe+1
      weightc( 40, 18,  3)=                  0.58142974031028515913d0
      iwe=iwe+1
      weightc( 41, 18,  3)=                  0.16588635394660158906d0
      iwe=iwe+1
      weightc( 42, 18,  3)=                  0.22623524771928196775d0
      iwe=iwe+1
      weightc( 43, 18,  3)=                 -0.60764553576167579241d0
      iwe=iwe+1
      weightc( 44, 18,  3)=                 -0.29961512230454934169d0
      iwe=iwe+1
      weightc( 45, 18,  3)=                  0.08835989759586697356d0
      iwe=iwe+1
      weightc( 46, 18,  3)=                  0.11393778839645117562d0
      iwe=iwe+1
      weightc( 47, 18,  3)=                 -0.18863218048686447581d0
      iwe=iwe+1
      weightc( 48, 18,  3)=                  0.27226758820334390210d0
      iwe=iwe+1
      weightc( 49, 18,  3)=                 -0.49581768918975882565d0
      iwe=iwe+1
      weightc( 50, 18,  3)=                  0.81707367997822533123d0
      iwe=iwe+1
      biasc( 18,  3)=                  0.87505502801880163943d0
      iwe=iwe+1
      weightc(  1, 19,  3)=                  0.08707451612633197724d0
      iwe=iwe+1
      weightc(  2, 19,  3)=                 -0.55192200519294432048d0
      iwe=iwe+1
      weightc(  3, 19,  3)=                 -0.16534775155113815015d0
      iwe=iwe+1
      weightc(  4, 19,  3)=                  0.00929732212239378630d0
      iwe=iwe+1
      weightc(  5, 19,  3)=                  0.02183084362552127622d0
      iwe=iwe+1
      weightc(  6, 19,  3)=                  0.22643519167559175709d0
      iwe=iwe+1
      weightc(  7, 19,  3)=                 -0.45496566580871200536d0
      iwe=iwe+1
      weightc(  8, 19,  3)=                  0.19973040959556340179d0
      iwe=iwe+1
      weightc(  9, 19,  3)=                  0.19685490329862756487d0
      iwe=iwe+1
      weightc( 10, 19,  3)=                  0.18125008735181263875d0
      iwe=iwe+1
      weightc( 11, 19,  3)=                 -0.01382451305736057991d0
      iwe=iwe+1
      weightc( 12, 19,  3)=                  0.07408900442338932357d0
      iwe=iwe+1
      weightc( 13, 19,  3)=                  0.33435830387845733025d0
      iwe=iwe+1
      weightc( 14, 19,  3)=                 -0.11228169435408544286d0
      iwe=iwe+1
      weightc( 15, 19,  3)=                  0.17324289147219140705d0
      iwe=iwe+1
      weightc( 16, 19,  3)=                  0.22991675255635643516d0
      iwe=iwe+1
      weightc( 17, 19,  3)=                  0.17242110281688399764d0
      iwe=iwe+1
      weightc( 18, 19,  3)=                  0.56605615530884645370d0
      iwe=iwe+1
      weightc( 19, 19,  3)=                 -0.10681517162386941489d0
      iwe=iwe+1
      weightc( 20, 19,  3)=                 -0.18946168298029841814d0
      iwe=iwe+1
      weightc( 21, 19,  3)=                 -0.52659482130738199945d0
      iwe=iwe+1
      weightc( 22, 19,  3)=                  0.20601396247552883345d0
      iwe=iwe+1
      weightc( 23, 19,  3)=                  0.30104410391677871583d0
      iwe=iwe+1
      weightc( 24, 19,  3)=                 -0.06126096789810705351d0
      iwe=iwe+1
      weightc( 25, 19,  3)=                 -0.12743470832481051946d0
      iwe=iwe+1
      weightc( 26, 19,  3)=                 -0.44752990465730047021d0
      iwe=iwe+1
      weightc( 27, 19,  3)=                  0.25670050111343434285d0
      iwe=iwe+1
      weightc( 28, 19,  3)=                  0.10497151940771451417d0
      iwe=iwe+1
      weightc( 29, 19,  3)=                  0.17178366898941324625d0
      iwe=iwe+1
      weightc( 30, 19,  3)=                  0.00898105238915074787d0
      iwe=iwe+1
      weightc( 31, 19,  3)=                 -0.31650895495266584412d0
      iwe=iwe+1
      weightc( 32, 19,  3)=                  0.15434012556508483471d0
      iwe=iwe+1
      weightc( 33, 19,  3)=                 -0.07801508621118730114d0
      iwe=iwe+1
      weightc( 34, 19,  3)=                 -0.06993919548318430768d0
      iwe=iwe+1
      weightc( 35, 19,  3)=                 -0.01081470376674673224d0
      iwe=iwe+1
      weightc( 36, 19,  3)=                 -0.25499790890856061099d0
      iwe=iwe+1
      weightc( 37, 19,  3)=                 -0.22777728512989248166d0
      iwe=iwe+1
      weightc( 38, 19,  3)=                  0.08815775966826415455d0
      iwe=iwe+1
      weightc( 39, 19,  3)=                 -0.17733742254192833010d0
      iwe=iwe+1
      weightc( 40, 19,  3)=                 -0.27579084737945253059d0
      iwe=iwe+1
      weightc( 41, 19,  3)=                 -0.25979956818225252713d0
      iwe=iwe+1
      weightc( 42, 19,  3)=                  0.00156166136822045998d0
      iwe=iwe+1
      weightc( 43, 19,  3)=                  0.27654031654705790721d0
      iwe=iwe+1
      weightc( 44, 19,  3)=                 -0.40020425588705782483d0
      iwe=iwe+1
      weightc( 45, 19,  3)=                  0.00137977037397079465d0
      iwe=iwe+1
      weightc( 46, 19,  3)=                 -0.53803191173240993983d0
      iwe=iwe+1
      weightc( 47, 19,  3)=                  0.35321982055087769448d0
      iwe=iwe+1
      weightc( 48, 19,  3)=                 -0.10026296991489365429d0
      iwe=iwe+1
      weightc( 49, 19,  3)=                  0.17429585306124484312d0
      iwe=iwe+1
      weightc( 50, 19,  3)=                 -0.15349875331394022271d0
      iwe=iwe+1
      biasc( 19,  3)=                 -1.00216937957606111453d0
      iwe=iwe+1
      weightc(  1, 20,  3)=                 -0.46391576671097511930d0
      iwe=iwe+1
      weightc(  2, 20,  3)=                 -1.23582520138805640464d0
      iwe=iwe+1
      weightc(  3, 20,  3)=                 -0.37081169836572486220d0
      iwe=iwe+1
      weightc(  4, 20,  3)=                  0.08152323173363423825d0
      iwe=iwe+1
      weightc(  5, 20,  3)=                 -0.44203768806572979466d0
      iwe=iwe+1
      weightc(  6, 20,  3)=                 -0.40765907694174047249d0
      iwe=iwe+1
      weightc(  7, 20,  3)=                 -0.28114871429308607720d0
      iwe=iwe+1
      weightc(  8, 20,  3)=                  0.21679529291987342798d0
      iwe=iwe+1
      weightc(  9, 20,  3)=                  0.30628709753191440956d0
      iwe=iwe+1
      weightc( 10, 20,  3)=                 -0.15138034330451566323d0
      iwe=iwe+1
      weightc( 11, 20,  3)=                 -0.27878142029567176685d0
      iwe=iwe+1
      weightc( 12, 20,  3)=                  0.58986849500265925439d0
      iwe=iwe+1
      weightc( 13, 20,  3)=                  0.09218212698165956231d0
      iwe=iwe+1
      weightc( 14, 20,  3)=                  0.21412890361351422097d0
      iwe=iwe+1
      weightc( 15, 20,  3)=                  0.46522778769897227269d0
      iwe=iwe+1
      weightc( 16, 20,  3)=                  0.05608115961217149253d0
      iwe=iwe+1
      weightc( 17, 20,  3)=                 -0.03730404946691043278d0
      iwe=iwe+1
      weightc( 18, 20,  3)=                 -0.55480865634336096193d0
      iwe=iwe+1
      weightc( 19, 20,  3)=                 -0.46075731842824690920d0
      iwe=iwe+1
      weightc( 20, 20,  3)=                 -0.04920648088182521390d0
      iwe=iwe+1
      weightc( 21, 20,  3)=                  0.26928986953289341111d0
      iwe=iwe+1
      weightc( 22, 20,  3)=                  0.49310802377027040944d0
      iwe=iwe+1
      weightc( 23, 20,  3)=                  1.00436874817564336659d0
      iwe=iwe+1
      weightc( 24, 20,  3)=                  1.00457760311679544785d0
      iwe=iwe+1
      weightc( 25, 20,  3)=                 -0.18601035522204995010d0
      iwe=iwe+1
      weightc( 26, 20,  3)=                  0.05930469667478625168d0
      iwe=iwe+1
      weightc( 27, 20,  3)=                  0.35841561653007614208d0
      iwe=iwe+1
      weightc( 28, 20,  3)=                  0.16242428270453843075d0
      iwe=iwe+1
      weightc( 29, 20,  3)=                  0.02892846028248234266d0
      iwe=iwe+1
      weightc( 30, 20,  3)=                  0.06059581712541314835d0
      iwe=iwe+1
      weightc( 31, 20,  3)=                  0.20760254141252026949d0
      iwe=iwe+1
      weightc( 32, 20,  3)=                 -0.63617697994680155738d0
      iwe=iwe+1
      weightc( 33, 20,  3)=                 -0.21013245376125588848d0
      iwe=iwe+1
      weightc( 34, 20,  3)=                 -0.59033211522754280853d0
      iwe=iwe+1
      weightc( 35, 20,  3)=                 -0.36653030252573298720d0
      iwe=iwe+1
      weightc( 36, 20,  3)=                 -0.76892382692907423891d0
      iwe=iwe+1
      weightc( 37, 20,  3)=                  0.46661345200934878363d0
      iwe=iwe+1
      weightc( 38, 20,  3)=                  0.08257243907912924230d0
      iwe=iwe+1
      weightc( 39, 20,  3)=                  0.47165306458356964781d0
      iwe=iwe+1
      weightc( 40, 20,  3)=                  0.22488084849182612968d0
      iwe=iwe+1
      weightc( 41, 20,  3)=                 -0.00648531677196345895d0
      iwe=iwe+1
      weightc( 42, 20,  3)=                 -0.34426270231869893212d0
      iwe=iwe+1
      weightc( 43, 20,  3)=                 -0.03872838457633439452d0
      iwe=iwe+1
      weightc( 44, 20,  3)=                  0.79994617822497149362d0
      iwe=iwe+1
      weightc( 45, 20,  3)=                 -0.34692011658780907979d0
      iwe=iwe+1
      weightc( 46, 20,  3)=                 -0.89015349483054473367d0
      iwe=iwe+1
      weightc( 47, 20,  3)=                 -0.03673943463574393109d0
      iwe=iwe+1
      weightc( 48, 20,  3)=                  0.41429209209715461837d0
      iwe=iwe+1
      weightc( 49, 20,  3)=                 -0.32979472338969134659d0
      iwe=iwe+1
      weightc( 50, 20,  3)=                  1.08664435696873007409d0
      iwe=iwe+1
      biasc( 20,  3)=                 -0.99711468582259432658d0
      iwe=iwe+1
      weightc(  1, 21,  3)=                  0.32506101086969274583d0
      iwe=iwe+1
      weightc(  2, 21,  3)=                 -0.79754373454900162610d0
      iwe=iwe+1
      weightc(  3, 21,  3)=                  0.60005837448903542874d0
      iwe=iwe+1
      weightc(  4, 21,  3)=                  0.29796132997848356894d0
      iwe=iwe+1
      weightc(  5, 21,  3)=                 -0.17833820320563500972d0
      iwe=iwe+1
      weightc(  6, 21,  3)=                 -0.14892789850835788656d0
      iwe=iwe+1
      weightc(  7, 21,  3)=                 -0.24809582896335166668d0
      iwe=iwe+1
      weightc(  8, 21,  3)=                 -0.48445049633067049921d0
      iwe=iwe+1
      weightc(  9, 21,  3)=                 -0.06180806766662956531d0
      iwe=iwe+1
      weightc( 10, 21,  3)=                  0.46175025706370598222d0
      iwe=iwe+1
      weightc( 11, 21,  3)=                 -0.64038906657723193572d0
      iwe=iwe+1
      weightc( 12, 21,  3)=                 -0.55020319370081405275d0
      iwe=iwe+1
      weightc( 13, 21,  3)=                  0.34068267109872890641d0
      iwe=iwe+1
      weightc( 14, 21,  3)=                  0.02085360280167199154d0
      iwe=iwe+1
      weightc( 15, 21,  3)=                  0.47885923463472834793d0
      iwe=iwe+1
      weightc( 16, 21,  3)=                  0.35094629506383812068d0
      iwe=iwe+1
      weightc( 17, 21,  3)=                 -0.03026494841983597486d0
      iwe=iwe+1
      weightc( 18, 21,  3)=                 -0.57962304384545648706d0
      iwe=iwe+1
      weightc( 19, 21,  3)=                 -0.01162779148238642438d0
      iwe=iwe+1
      weightc( 20, 21,  3)=                 -0.01301478157109356958d0
      iwe=iwe+1
      weightc( 21, 21,  3)=                 -0.02497419401665261496d0
      iwe=iwe+1
      weightc( 22, 21,  3)=                  0.76300117239935916214d0
      iwe=iwe+1
      weightc( 23, 21,  3)=                 -0.23950034090048979984d0
      iwe=iwe+1
      weightc( 24, 21,  3)=                  0.32571853699362257606d0
      iwe=iwe+1
      weightc( 25, 21,  3)=                 -0.03839608311274399916d0
      iwe=iwe+1
      weightc( 26, 21,  3)=                 -0.00224514205345303312d0
      iwe=iwe+1
      weightc( 27, 21,  3)=                 -0.26525234635647271242d0
      iwe=iwe+1
      weightc( 28, 21,  3)=                  0.38151811917470007662d0
      iwe=iwe+1
      weightc( 29, 21,  3)=                  0.31580301610121841449d0
      iwe=iwe+1
      weightc( 30, 21,  3)=                 -0.17359048289929593367d0
      iwe=iwe+1
      weightc( 31, 21,  3)=                  0.44780209173412144352d0
      iwe=iwe+1
      weightc( 32, 21,  3)=                  0.46746104658440124080d0
      iwe=iwe+1
      weightc( 33, 21,  3)=                 -0.10909315429966107147d0
      iwe=iwe+1
      weightc( 34, 21,  3)=                  0.39874750511860096447d0
      iwe=iwe+1
      weightc( 35, 21,  3)=                 -0.33880715633188296376d0
      iwe=iwe+1
      weightc( 36, 21,  3)=                 -0.10424111028040593252d0
      iwe=iwe+1
      weightc( 37, 21,  3)=                 -0.14623176048015593120d0
      iwe=iwe+1
      weightc( 38, 21,  3)=                  0.25317691909327649791d0
      iwe=iwe+1
      weightc( 39, 21,  3)=                  0.31253615582891935976d0
      iwe=iwe+1
      weightc( 40, 21,  3)=                 -0.11221611142217359502d0
      iwe=iwe+1
      weightc( 41, 21,  3)=                 -0.32618307203639623770d0
      iwe=iwe+1
      weightc( 42, 21,  3)=                 -0.22899666814498390033d0
      iwe=iwe+1
      weightc( 43, 21,  3)=                  0.04180282012788451990d0
      iwe=iwe+1
      weightc( 44, 21,  3)=                  0.26942400114796216659d0
      iwe=iwe+1
      weightc( 45, 21,  3)=                 -0.51584145587601315519d0
      iwe=iwe+1
      weightc( 46, 21,  3)=                 -0.20389204617823553090d0
      iwe=iwe+1
      weightc( 47, 21,  3)=                  0.19404364924289005390d0
      iwe=iwe+1
      weightc( 48, 21,  3)=                  0.73436248457818797952d0
      iwe=iwe+1
      weightc( 49, 21,  3)=                  0.27230117209033566361d0
      iwe=iwe+1
      weightc( 50, 21,  3)=                  0.49066412225376904166d0
      iwe=iwe+1
      biasc( 21,  3)=                 -0.67381946180603102814d0
      iwe=iwe+1
      weightc(  1, 22,  3)=                 -0.52902622407732602383d0
      iwe=iwe+1
      weightc(  2, 22,  3)=                 -0.47179539374041795652d0
      iwe=iwe+1
      weightc(  3, 22,  3)=                 -0.44543309897530192210d0
      iwe=iwe+1
      weightc(  4, 22,  3)=                  0.32572827752863714457d0
      iwe=iwe+1
      weightc(  5, 22,  3)=                 -0.00110792907672295927d0
      iwe=iwe+1
      weightc(  6, 22,  3)=                  0.15313256566116453805d0
      iwe=iwe+1
      weightc(  7, 22,  3)=                  0.61833594829408200511d0
      iwe=iwe+1
      weightc(  8, 22,  3)=                 -0.02599608942364113953d0
      iwe=iwe+1
      weightc(  9, 22,  3)=                 -0.24890761200318903268d0
      iwe=iwe+1
      weightc( 10, 22,  3)=                 -0.29543774535949307580d0
      iwe=iwe+1
      weightc( 11, 22,  3)=                  0.51963495986162577811d0
      iwe=iwe+1
      weightc( 12, 22,  3)=                 -0.35762103635069020235d0
      iwe=iwe+1
      weightc( 13, 22,  3)=                  0.20028656812637815610d0
      iwe=iwe+1
      weightc( 14, 22,  3)=                 -0.23501083505684153274d0
      iwe=iwe+1
      weightc( 15, 22,  3)=                 -0.10568087135392750797d0
      iwe=iwe+1
      weightc( 16, 22,  3)=                  0.17957543832582620325d0
      iwe=iwe+1
      weightc( 17, 22,  3)=                 -0.67768794861186332223d0
      iwe=iwe+1
      weightc( 18, 22,  3)=                 -0.18336576717744329512d0
      iwe=iwe+1
      weightc( 19, 22,  3)=                 -0.13617192105593339813d0
      iwe=iwe+1
      weightc( 20, 22,  3)=                  0.11408319210989151249d0
      iwe=iwe+1
      weightc( 21, 22,  3)=                 -0.18788703524390076849d0
      iwe=iwe+1
      weightc( 22, 22,  3)=                 -0.16801534761885758562d0
      iwe=iwe+1
      weightc( 23, 22,  3)=                  0.15013791648279165014d0
      iwe=iwe+1
      weightc( 24, 22,  3)=                 -0.09364523562057752715d0
      iwe=iwe+1
      weightc( 25, 22,  3)=                  0.35822181131214270167d0
      iwe=iwe+1
      weightc( 26, 22,  3)=                  0.29348566933315362038d0
      iwe=iwe+1
      weightc( 27, 22,  3)=                  0.04273939462083387736d0
      iwe=iwe+1
      weightc( 28, 22,  3)=                  0.03348299192624289156d0
      iwe=iwe+1
      weightc( 29, 22,  3)=                  0.14115689139887011017d0
      iwe=iwe+1
      weightc( 30, 22,  3)=                  0.57201019033865219132d0
      iwe=iwe+1
      weightc( 31, 22,  3)=                 -0.35788906356886313054d0
      iwe=iwe+1
      weightc( 32, 22,  3)=                  0.01978063490196789453d0
      iwe=iwe+1
      weightc( 33, 22,  3)=                 -0.00712083330159631392d0
      iwe=iwe+1
      weightc( 34, 22,  3)=                 -0.07467987426141117768d0
      iwe=iwe+1
      weightc( 35, 22,  3)=                 -0.32601641066435554928d0
      iwe=iwe+1
      weightc( 36, 22,  3)=                  0.31716817608350633684d0
      iwe=iwe+1
      weightc( 37, 22,  3)=                 -0.16247897559381729859d0
      iwe=iwe+1
      weightc( 38, 22,  3)=                 -0.10919688101053774687d0
      iwe=iwe+1
      weightc( 39, 22,  3)=                  0.40788454588869355044d0
      iwe=iwe+1
      weightc( 40, 22,  3)=                  0.16944336131506365639d0
      iwe=iwe+1
      weightc( 41, 22,  3)=                 -0.21831255001272725780d0
      iwe=iwe+1
      weightc( 42, 22,  3)=                 -0.02921092591569654853d0
      iwe=iwe+1
      weightc( 43, 22,  3)=                  0.42850589018808460384d0
      iwe=iwe+1
      weightc( 44, 22,  3)=                 -0.13456026558474717958d0
      iwe=iwe+1
      weightc( 45, 22,  3)=                  0.22452181880941590730d0
      iwe=iwe+1
      weightc( 46, 22,  3)=                  0.04210909401383428757d0
      iwe=iwe+1
      weightc( 47, 22,  3)=                 -0.15010938581816776760d0
      iwe=iwe+1
      weightc( 48, 22,  3)=                  0.08691720283506060296d0
      iwe=iwe+1
      weightc( 49, 22,  3)=                  0.24688921384622097843d0
      iwe=iwe+1
      weightc( 50, 22,  3)=                  0.07086683066894437777d0
      iwe=iwe+1
      biasc( 22,  3)=                  0.78472758485976734644d0
      iwe=iwe+1
      weightc(  1, 23,  3)=                 -0.00626416250328969051d0
      iwe=iwe+1
      weightc(  2, 23,  3)=                  0.24992608408026523170d0
      iwe=iwe+1
      weightc(  3, 23,  3)=                 -0.19593112883707100580d0
      iwe=iwe+1
      weightc(  4, 23,  3)=                 -0.30463960723894506488d0
      iwe=iwe+1
      weightc(  5, 23,  3)=                 -0.01576029488834478423d0
      iwe=iwe+1
      weightc(  6, 23,  3)=                 -0.20317399952724243817d0
      iwe=iwe+1
      weightc(  7, 23,  3)=                  0.30585961217346185892d0
      iwe=iwe+1
      weightc(  8, 23,  3)=                  0.43605693672984413567d0
      iwe=iwe+1
      weightc(  9, 23,  3)=                  0.33486777283661278704d0
      iwe=iwe+1
      weightc( 10, 23,  3)=                  0.24664801182168627491d0
      iwe=iwe+1
      weightc( 11, 23,  3)=                  0.26962726819620946861d0
      iwe=iwe+1
      weightc( 12, 23,  3)=                  0.02651697957904275427d0
      iwe=iwe+1
      weightc( 13, 23,  3)=                 -0.33753559023384910320d0
      iwe=iwe+1
      weightc( 14, 23,  3)=                 -0.11176592631634921227d0
      iwe=iwe+1
      weightc( 15, 23,  3)=                  0.33820248877811109889d0
      iwe=iwe+1
      weightc( 16, 23,  3)=                 -0.22309887996844146585d0
      iwe=iwe+1
      weightc( 17, 23,  3)=                  0.25062010200112994074d0
      iwe=iwe+1
      weightc( 18, 23,  3)=                  0.02132144036378483612d0
      iwe=iwe+1
      weightc( 19, 23,  3)=                 -0.18825952327062983604d0
      iwe=iwe+1
      weightc( 20, 23,  3)=                  0.31240779565930748563d0
      iwe=iwe+1
      weightc( 21, 23,  3)=                 -0.33719516522211900877d0
      iwe=iwe+1
      weightc( 22, 23,  3)=                  0.14309594584638865578d0
      iwe=iwe+1
      weightc( 23, 23,  3)=                  0.05045576373705550760d0
      iwe=iwe+1
      weightc( 24, 23,  3)=                  0.28935644909149693671d0
      iwe=iwe+1
      weightc( 25, 23,  3)=                 -0.08033965707724090299d0
      iwe=iwe+1
      weightc( 26, 23,  3)=                 -0.29750697424928229662d0
      iwe=iwe+1
      weightc( 27, 23,  3)=                  0.20229330568768816301d0
      iwe=iwe+1
      weightc( 28, 23,  3)=                  0.05308408906853942510d0
      iwe=iwe+1
      weightc( 29, 23,  3)=                 -0.26099993948967215029d0
      iwe=iwe+1
      weightc( 30, 23,  3)=                 -0.03165220845255300314d0
      iwe=iwe+1
      weightc( 31, 23,  3)=                 -0.25602947361891520428d0
      iwe=iwe+1
      weightc( 32, 23,  3)=                 -0.34293486459290478674d0
      iwe=iwe+1
      weightc( 33, 23,  3)=                  0.19367270467862701677d0
      iwe=iwe+1
      weightc( 34, 23,  3)=                  0.16738879880481968843d0
      iwe=iwe+1
      weightc( 35, 23,  3)=                 -0.05313945366398433595d0
      iwe=iwe+1
      weightc( 36, 23,  3)=                  0.09531092868304991139d0
      iwe=iwe+1
      weightc( 37, 23,  3)=                  0.18679630323402812708d0
      iwe=iwe+1
      weightc( 38, 23,  3)=                 -0.02154860772373825423d0
      iwe=iwe+1
      weightc( 39, 23,  3)=                  0.11785509058484237854d0
      iwe=iwe+1
      weightc( 40, 23,  3)=                  0.30492329719627442319d0
      iwe=iwe+1
      weightc( 41, 23,  3)=                  0.40853011232163699562d0
      iwe=iwe+1
      weightc( 42, 23,  3)=                  0.38887047822264980690d0
      iwe=iwe+1
      weightc( 43, 23,  3)=                  0.23567715980490105965d0
      iwe=iwe+1
      weightc( 44, 23,  3)=                  0.30514289848327486032d0
      iwe=iwe+1
      weightc( 45, 23,  3)=                 -0.16374213581677973806d0
      iwe=iwe+1
      weightc( 46, 23,  3)=                 -0.04396216952246200654d0
      iwe=iwe+1
      weightc( 47, 23,  3)=                  0.13115815915930401081d0
      iwe=iwe+1
      weightc( 48, 23,  3)=                  0.48132405144791939877d0
      iwe=iwe+1
      weightc( 49, 23,  3)=                  0.10146562035588389816d0
      iwe=iwe+1
      weightc( 50, 23,  3)=                  0.35844504756976852677d0
      iwe=iwe+1
      biasc( 23,  3)=                 -0.71450376310748076047d0
      iwe=iwe+1
      weightc(  1, 24,  3)=                 -0.91510774244921722076d0
      iwe=iwe+1
      weightc(  2, 24,  3)=                 -0.54288483326616121527d0
      iwe=iwe+1
      weightc(  3, 24,  3)=                  0.39556403333890505225d0
      iwe=iwe+1
      weightc(  4, 24,  3)=                  0.13543808492464828874d0
      iwe=iwe+1
      weightc(  5, 24,  3)=                 -0.05547359106639348364d0
      iwe=iwe+1
      weightc(  6, 24,  3)=                 -0.02612063806386366593d0
      iwe=iwe+1
      weightc(  7, 24,  3)=                  0.03882283657755594697d0
      iwe=iwe+1
      weightc(  8, 24,  3)=                  0.41106600782959007434d0
      iwe=iwe+1
      weightc(  9, 24,  3)=                 -0.03530369188986716422d0
      iwe=iwe+1
      weightc( 10, 24,  3)=                  0.25438473196410865684d0
      iwe=iwe+1
      weightc( 11, 24,  3)=                  0.37378666789147663163d0
      iwe=iwe+1
      weightc( 12, 24,  3)=                  1.01156079148511834909d0
      iwe=iwe+1
      weightc( 13, 24,  3)=                 -0.50830371929008211218d0
      iwe=iwe+1
      weightc( 14, 24,  3)=                 -0.29145419004816841557d0
      iwe=iwe+1
      weightc( 15, 24,  3)=                 -0.06871839765022622060d0
      iwe=iwe+1
      weightc( 16, 24,  3)=                  0.42688499502344223746d0
      iwe=iwe+1
      weightc( 17, 24,  3)=                 -0.34742871436637984273d0
      iwe=iwe+1
      weightc( 18, 24,  3)=                  0.31820461755512741142d0
      iwe=iwe+1
      weightc( 19, 24,  3)=                 -0.03579600474757903966d0
      iwe=iwe+1
      weightc( 20, 24,  3)=                 -0.58963697283577010122d0
      iwe=iwe+1
      weightc( 21, 24,  3)=                 -0.38981459078693786457d0
      iwe=iwe+1
      weightc( 22, 24,  3)=                 -0.97488042459601820244d0
      iwe=iwe+1
      weightc( 23, 24,  3)=                 -0.19717810150558029436d0
      iwe=iwe+1
      weightc( 24, 24,  3)=                  0.21131295145056158691d0
      iwe=iwe+1
      weightc( 25, 24,  3)=                  0.13312080231634002003d0
      iwe=iwe+1
      weightc( 26, 24,  3)=                  0.13087506130963980078d0
      iwe=iwe+1
      weightc( 27, 24,  3)=                  0.43440695827027075993d0
      iwe=iwe+1
      weightc( 28, 24,  3)=                  0.15247657543745218867d0
      iwe=iwe+1
      weightc( 29, 24,  3)=                 -0.08251684427111111164d0
      iwe=iwe+1
      weightc( 30, 24,  3)=                  0.10235525273800125112d0
      iwe=iwe+1
      weightc( 31, 24,  3)=                  0.02081460312942636642d0
      iwe=iwe+1
      weightc( 32, 24,  3)=                 -0.12068512548874123225d0
      iwe=iwe+1
      weightc( 33, 24,  3)=                 -0.21101438021658780464d0
      iwe=iwe+1
      weightc( 34, 24,  3)=                  0.03322044553948334117d0
      iwe=iwe+1
      weightc( 35, 24,  3)=                 -0.19604843656667519936d0
      iwe=iwe+1
      weightc( 36, 24,  3)=                  0.09008008910884411635d0
      iwe=iwe+1
      weightc( 37, 24,  3)=                 -0.15098784600378711840d0
      iwe=iwe+1
      weightc( 38, 24,  3)=                  0.30327538638599310650d0
      iwe=iwe+1
      weightc( 39, 24,  3)=                  0.04869327623102663594d0
      iwe=iwe+1
      weightc( 40, 24,  3)=                  0.04288397174105876286d0
      iwe=iwe+1
      weightc( 41, 24,  3)=                  0.58594933606823662586d0
      iwe=iwe+1
      weightc( 42, 24,  3)=                  0.53849513096899015441d0
      iwe=iwe+1
      weightc( 43, 24,  3)=                  0.34198902599755159892d0
      iwe=iwe+1
      weightc( 44, 24,  3)=                 -0.16492756086079637945d0
      iwe=iwe+1
      weightc( 45, 24,  3)=                  0.32550857432622132270d0
      iwe=iwe+1
      weightc( 46, 24,  3)=                 -0.35850014261116364134d0
      iwe=iwe+1
      weightc( 47, 24,  3)=                  0.36098866988316391513d0
      iwe=iwe+1
      weightc( 48, 24,  3)=                 -0.34521868159022622846d0
      iwe=iwe+1
      weightc( 49, 24,  3)=                  0.45093769466222100029d0
      iwe=iwe+1
      weightc( 50, 24,  3)=                 -0.01907205273475449936d0
      iwe=iwe+1
      biasc( 24,  3)=                  0.40859732248685914913d0
      iwe=iwe+1
      weightc(  1, 25,  3)=                 -0.55351807569878008763d0
      iwe=iwe+1
      weightc(  2, 25,  3)=                  0.47365396565609935164d0
      iwe=iwe+1
      weightc(  3, 25,  3)=                  0.34692928309395681952d0
      iwe=iwe+1
      weightc(  4, 25,  3)=                 -0.13853879952598049941d0
      iwe=iwe+1
      weightc(  5, 25,  3)=                 -0.03583142066936991638d0
      iwe=iwe+1
      weightc(  6, 25,  3)=                 -0.17677566155920548807d0
      iwe=iwe+1
      weightc(  7, 25,  3)=                  0.26985789032496160234d0
      iwe=iwe+1
      weightc(  8, 25,  3)=                 -0.49624799260266377887d0
      iwe=iwe+1
      weightc(  9, 25,  3)=                  0.10371674488059089148d0
      iwe=iwe+1
      weightc( 10, 25,  3)=                 -0.12934185479903628768d0
      iwe=iwe+1
      weightc( 11, 25,  3)=                 -0.36823462115518573734d0
      iwe=iwe+1
      weightc( 12, 25,  3)=                 -0.35196427802936691709d0
      iwe=iwe+1
      weightc( 13, 25,  3)=                  0.45054424129145492772d0
      iwe=iwe+1
      weightc( 14, 25,  3)=                  0.08384838689909074327d0
      iwe=iwe+1
      weightc( 15, 25,  3)=                  0.18714301812374481426d0
      iwe=iwe+1
      weightc( 16, 25,  3)=                  0.15401846849850484023d0
      iwe=iwe+1
      weightc( 17, 25,  3)=                  0.09204674193363215906d0
      iwe=iwe+1
      weightc( 18, 25,  3)=                  0.00216264493385739769d0
      iwe=iwe+1
      weightc( 19, 25,  3)=                  0.16190172247582451659d0
      iwe=iwe+1
      weightc( 20, 25,  3)=                 -0.01309217930744707194d0
      iwe=iwe+1
      weightc( 21, 25,  3)=                  0.67916422005406718032d0
      iwe=iwe+1
      weightc( 22, 25,  3)=                 -0.14532670218808951823d0
      iwe=iwe+1
      weightc( 23, 25,  3)=                 -0.07626565579531260908d0
      iwe=iwe+1
      weightc( 24, 25,  3)=                 -0.57328683796737189837d0
      iwe=iwe+1
      weightc( 25, 25,  3)=                  0.09906157462520191748d0
      iwe=iwe+1
      weightc( 26, 25,  3)=                 -0.09335883463415466099d0
      iwe=iwe+1
      weightc( 27, 25,  3)=                 -0.12072371877402991724d0
      iwe=iwe+1
      weightc( 28, 25,  3)=                 -0.10846581646224098816d0
      iwe=iwe+1
      weightc( 29, 25,  3)=                  0.21304031883541862946d0
      iwe=iwe+1
      weightc( 30, 25,  3)=                  0.26725998887974766749d0
      iwe=iwe+1
      weightc( 31, 25,  3)=                 -0.12656755242915437853d0
      iwe=iwe+1
      weightc( 32, 25,  3)=                  0.41512578064090976948d0
      iwe=iwe+1
      weightc( 33, 25,  3)=                 -0.12806382461116147531d0
      iwe=iwe+1
      weightc( 34, 25,  3)=                 -0.52142700557958521212d0
      iwe=iwe+1
      weightc( 35, 25,  3)=                  0.09630954731199893593d0
      iwe=iwe+1
      weightc( 36, 25,  3)=                 -0.04813743962691507949d0
      iwe=iwe+1
      weightc( 37, 25,  3)=                  0.37570307353178444831d0
      iwe=iwe+1
      weightc( 38, 25,  3)=                 -0.50536465080547476880d0
      iwe=iwe+1
      weightc( 39, 25,  3)=                 -0.25278915198176965529d0
      iwe=iwe+1
      weightc( 40, 25,  3)=                  0.11563294358896208935d0
      iwe=iwe+1
      weightc( 41, 25,  3)=                  0.23321089015670176670d0
      iwe=iwe+1
      weightc( 42, 25,  3)=                  0.06390522787601972399d0
      iwe=iwe+1
      weightc( 43, 25,  3)=                 -0.32653350768228528445d0
      iwe=iwe+1
      weightc( 44, 25,  3)=                 -0.22430711283066592787d0
      iwe=iwe+1
      weightc( 45, 25,  3)=                 -0.08152863477791694180d0
      iwe=iwe+1
      weightc( 46, 25,  3)=                  0.60270156661962748235d0
      iwe=iwe+1
      weightc( 47, 25,  3)=                 -0.26872724726289370922d0
      iwe=iwe+1
      weightc( 48, 25,  3)=                 -0.37613642372391176139d0
      iwe=iwe+1
      weightc( 49, 25,  3)=                 -0.61425884980716882744d0
      iwe=iwe+1
      weightc( 50, 25,  3)=                 -0.11068825259392679750d0
      iwe=iwe+1
      biasc( 25,  3)=                  0.47730196924336465436d0
      iwe=iwe+1
      weightc(  1, 26,  3)=                 -1.00146393008853240580d0
      iwe=iwe+1
      weightc(  2, 26,  3)=                 -0.51912573622615898472d0
      iwe=iwe+1
      weightc(  3, 26,  3)=                  0.18308526029487395825d0
      iwe=iwe+1
      weightc(  4, 26,  3)=                 -0.40916976858433157238d0
      iwe=iwe+1
      weightc(  5, 26,  3)=                  0.47311004713594240201d0
      iwe=iwe+1
      weightc(  6, 26,  3)=                 -0.22775133954073339959d0
      iwe=iwe+1
      weightc(  7, 26,  3)=                 -0.26372379073128415783d0
      iwe=iwe+1
      weightc(  8, 26,  3)=                  0.65435515826684775842d0
      iwe=iwe+1
      weightc(  9, 26,  3)=                 -0.30050506603298066111d0
      iwe=iwe+1
      weightc( 10, 26,  3)=                 -0.52223156179096941187d0
      iwe=iwe+1
      weightc( 11, 26,  3)=                  0.08019626072660701599d0
      iwe=iwe+1
      weightc( 12, 26,  3)=                  0.80928520226516154068d0
      iwe=iwe+1
      weightc( 13, 26,  3)=                 -0.25047590739239089519d0
      iwe=iwe+1
      weightc( 14, 26,  3)=                 -0.36674767338620711810d0
      iwe=iwe+1
      weightc( 15, 26,  3)=                  0.35730545290100973466d0
      iwe=iwe+1
      weightc( 16, 26,  3)=                 -0.15983996905248823439d0
      iwe=iwe+1
      weightc( 17, 26,  3)=                 -0.24079482090107431902d0
      iwe=iwe+1
      weightc( 18, 26,  3)=                  0.14153185411233204505d0
      iwe=iwe+1
      weightc( 19, 26,  3)=                 -0.14311425774870889516d0
      iwe=iwe+1
      weightc( 20, 26,  3)=                  0.18991835367209458640d0
      iwe=iwe+1
      weightc( 21, 26,  3)=                 -0.18152387027625241367d0
      iwe=iwe+1
      weightc( 22, 26,  3)=                 -0.45157076597149709007d0
      iwe=iwe+1
      weightc( 23, 26,  3)=                 -0.50229747152016412937d0
      iwe=iwe+1
      weightc( 24, 26,  3)=                  0.77311117117490302242d0
      iwe=iwe+1
      weightc( 25, 26,  3)=                  0.16181392719871148800d0
      iwe=iwe+1
      weightc( 26, 26,  3)=                 -0.16678652935522894629d0
      iwe=iwe+1
      weightc( 27, 26,  3)=                  0.63361411982779958230d0
      iwe=iwe+1
      weightc( 28, 26,  3)=                  0.20378671333615569483d0
      iwe=iwe+1
      weightc( 29, 26,  3)=                  0.25641018149518207681d0
      iwe=iwe+1
      weightc( 30, 26,  3)=                 -0.23843951907844879168d0
      iwe=iwe+1
      weightc( 31, 26,  3)=                  0.20285339289986253908d0
      iwe=iwe+1
      weightc( 32, 26,  3)=                 -0.02076662716675572312d0
      iwe=iwe+1
      weightc( 33, 26,  3)=                 -0.25018311129622983202d0
      iwe=iwe+1
      weightc( 34, 26,  3)=                 -0.18026738867619240825d0
      iwe=iwe+1
      weightc( 35, 26,  3)=                  0.00835403635483363341d0
      iwe=iwe+1
      weightc( 36, 26,  3)=                  0.15000336844136602510d0
      iwe=iwe+1
      weightc( 37, 26,  3)=                 -0.28540940509018009053d0
      iwe=iwe+1
      weightc( 38, 26,  3)=                 -0.21133804833264835388d0
      iwe=iwe+1
      weightc( 39, 26,  3)=                  0.12785843870589869153d0
      iwe=iwe+1
      weightc( 40, 26,  3)=                  0.70678407798649534044d0
      iwe=iwe+1
      weightc( 41, 26,  3)=                 -0.20195380885302852136d0
      iwe=iwe+1
      weightc( 42, 26,  3)=                 -0.02389740365442187542d0
      iwe=iwe+1
      weightc( 43, 26,  3)=                  0.06833959984562540391d0
      iwe=iwe+1
      weightc( 44, 26,  3)=                  0.13542883442081016243d0
      iwe=iwe+1
      weightc( 45, 26,  3)=                  0.11999795329743771777d0
      iwe=iwe+1
      weightc( 46, 26,  3)=                 -0.60020261705682831366d0
      iwe=iwe+1
      weightc( 47, 26,  3)=                 -0.55227137626407274418d0
      iwe=iwe+1
      weightc( 48, 26,  3)=                  0.02437368637339610428d0
      iwe=iwe+1
      weightc( 49, 26,  3)=                 -0.21699575210168217665d0
      iwe=iwe+1
      weightc( 50, 26,  3)=                  0.24176055148294559038d0
      iwe=iwe+1
      biasc( 26,  3)=                  0.55070442825881926741d0
      iwe=iwe+1
      weightc(  1, 27,  3)=                 -0.61336342253882658593d0
      iwe=iwe+1
      weightc(  2, 27,  3)=                  0.06365293666797665340d0
      iwe=iwe+1
      weightc(  3, 27,  3)=                 -0.43471861101917275150d0
      iwe=iwe+1
      weightc(  4, 27,  3)=                  0.40370954765496885885d0
      iwe=iwe+1
      weightc(  5, 27,  3)=                 -0.14930885161794554827d0
      iwe=iwe+1
      weightc(  6, 27,  3)=                  0.35200744157383129229d0
      iwe=iwe+1
      weightc(  7, 27,  3)=                  0.05147435514042063287d0
      iwe=iwe+1
      weightc(  8, 27,  3)=                  0.09826894612733991230d0
      iwe=iwe+1
      weightc(  9, 27,  3)=                 -0.36502981037627879601d0
      iwe=iwe+1
      weightc( 10, 27,  3)=                 -0.12508570133988222706d0
      iwe=iwe+1
      weightc( 11, 27,  3)=                 -0.12956779814243873927d0
      iwe=iwe+1
      weightc( 12, 27,  3)=                 -0.19492266127681626142d0
      iwe=iwe+1
      weightc( 13, 27,  3)=                  0.16622556368621949074d0
      iwe=iwe+1
      weightc( 14, 27,  3)=                 -0.13653923843085921663d0
      iwe=iwe+1
      weightc( 15, 27,  3)=                 -0.08996005663393948082d0
      iwe=iwe+1
      weightc( 16, 27,  3)=                 -0.22500771763117483060d0
      iwe=iwe+1
      weightc( 17, 27,  3)=                  0.01277382768556795285d0
      iwe=iwe+1
      weightc( 18, 27,  3)=                 -0.13743702473372956807d0
      iwe=iwe+1
      weightc( 19, 27,  3)=                 -0.00786204870295267519d0
      iwe=iwe+1
      weightc( 20, 27,  3)=                 -0.20722442414610892092d0
      iwe=iwe+1
      weightc( 21, 27,  3)=                 -0.28537230951119507694d0
      iwe=iwe+1
      weightc( 22, 27,  3)=                 -0.33501195477699458047d0
      iwe=iwe+1
      weightc( 23, 27,  3)=                  0.72088214126682381711d0
      iwe=iwe+1
      weightc( 24, 27,  3)=                 -0.45018413246340388545d0
      iwe=iwe+1
      weightc( 25, 27,  3)=                  0.44129227288835048970d0
      iwe=iwe+1
      weightc( 26, 27,  3)=                  0.02998285079344215759d0
      iwe=iwe+1
      weightc( 27, 27,  3)=                  0.41201538618159955218d0
      iwe=iwe+1
      weightc( 28, 27,  3)=                  0.34702609846553778006d0
      iwe=iwe+1
      weightc( 29, 27,  3)=                 -0.29588321866574002206d0
      iwe=iwe+1
      weightc( 30, 27,  3)=                 -0.45549027152723520206d0
      iwe=iwe+1
      weightc( 31, 27,  3)=                  0.54952565951085552420d0
      iwe=iwe+1
      weightc( 32, 27,  3)=                  0.56136461464688558465d0
      iwe=iwe+1
      weightc( 33, 27,  3)=                 -0.08996680848512358941d0
      iwe=iwe+1
      weightc( 34, 27,  3)=                 -0.10760246243619039919d0
      iwe=iwe+1
      weightc( 35, 27,  3)=                 -0.12587027359072225363d0
      iwe=iwe+1
      weightc( 36, 27,  3)=                  0.04784384114426087908d0
      iwe=iwe+1
      weightc( 37, 27,  3)=                 -0.42705811162012274895d0
      iwe=iwe+1
      weightc( 38, 27,  3)=                 -0.22472383549726057672d0
      iwe=iwe+1
      weightc( 39, 27,  3)=                 -0.06029080415238852186d0
      iwe=iwe+1
      weightc( 40, 27,  3)=                  0.11323464541365811653d0
      iwe=iwe+1
      weightc( 41, 27,  3)=                  0.19535515201918390860d0
      iwe=iwe+1
      weightc( 42, 27,  3)=                 -0.16759588298140609686d0
      iwe=iwe+1
      weightc( 43, 27,  3)=                  0.26098102729918781773d0
      iwe=iwe+1
      weightc( 44, 27,  3)=                 -0.44573115526044942980d0
      iwe=iwe+1
      weightc( 45, 27,  3)=                  0.18804538179639118667d0
      iwe=iwe+1
      weightc( 46, 27,  3)=                 -0.57763626167463133498d0
      iwe=iwe+1
      weightc( 47, 27,  3)=                  0.07475334211005862928d0
      iwe=iwe+1
      weightc( 48, 27,  3)=                  0.24518262832953269248d0
      iwe=iwe+1
      weightc( 49, 27,  3)=                  0.30160995289307912515d0
      iwe=iwe+1
      weightc( 50, 27,  3)=                  0.45252564030860670252d0
      iwe=iwe+1
      biasc( 27,  3)=                  0.61391058626391836750d0
      iwe=iwe+1
      weightc(  1, 28,  3)=                  0.17764739170805940449d0
      iwe=iwe+1
      weightc(  2, 28,  3)=                  0.04591312965836959192d0
      iwe=iwe+1
      weightc(  3, 28,  3)=                  0.30639359317475417521d0
      iwe=iwe+1
      weightc(  4, 28,  3)=                 -0.42183318204533282181d0
      iwe=iwe+1
      weightc(  5, 28,  3)=                  0.00206314251308214536d0
      iwe=iwe+1
      weightc(  6, 28,  3)=                 -0.16604512418476544133d0
      iwe=iwe+1
      weightc(  7, 28,  3)=                  0.02994034620413717554d0
      iwe=iwe+1
      weightc(  8, 28,  3)=                  0.09096373130844373489d0
      iwe=iwe+1
      weightc(  9, 28,  3)=                 -0.43684041742403700859d0
      iwe=iwe+1
      weightc( 10, 28,  3)=                  0.01941692708613717427d0
      iwe=iwe+1
      weightc( 11, 28,  3)=                  0.25901404615026774048d0
      iwe=iwe+1
      weightc( 12, 28,  3)=                  0.46998475981193277295d0
      iwe=iwe+1
      weightc( 13, 28,  3)=                 -0.20820039505989856865d0
      iwe=iwe+1
      weightc( 14, 28,  3)=                  0.52069270757436036945d0
      iwe=iwe+1
      weightc( 15, 28,  3)=                  0.00674650846872146791d0
      iwe=iwe+1
      weightc( 16, 28,  3)=                  0.31668157242709504828d0
      iwe=iwe+1
      weightc( 17, 28,  3)=                  0.27326862750190566986d0
      iwe=iwe+1
      weightc( 18, 28,  3)=                 -0.00539000879484209140d0
      iwe=iwe+1
      weightc( 19, 28,  3)=                  0.12959197909712658059d0
      iwe=iwe+1
      weightc( 20, 28,  3)=                 -0.30286007536455705758d0
      iwe=iwe+1
      weightc( 21, 28,  3)=                  0.38939070524787894323d0
      iwe=iwe+1
      weightc( 22, 28,  3)=                  0.02979070378361409546d0
      iwe=iwe+1
      weightc( 23, 28,  3)=                 -0.08751030115079287686d0
      iwe=iwe+1
      weightc( 24, 28,  3)=                 -0.19712191929246097866d0
      iwe=iwe+1
      weightc( 25, 28,  3)=                  0.31486560848544442592d0
      iwe=iwe+1
      weightc( 26, 28,  3)=                 -0.52115500633351874438d0
      iwe=iwe+1
      weightc( 27, 28,  3)=                 -0.37775649244497860879d0
      iwe=iwe+1
      weightc( 28, 28,  3)=                 -0.38080304310491480679d0
      iwe=iwe+1
      weightc( 29, 28,  3)=                 -0.16309339247053813993d0
      iwe=iwe+1
      weightc( 30, 28,  3)=                 -0.01331372993439330563d0
      iwe=iwe+1
      weightc( 31, 28,  3)=                  0.01164127869347467842d0
      iwe=iwe+1
      weightc( 32, 28,  3)=                  0.17516657516607389566d0
      iwe=iwe+1
      weightc( 33, 28,  3)=                  0.21575055456125569187d0
      iwe=iwe+1
      weightc( 34, 28,  3)=                 -0.08036546148537607182d0
      iwe=iwe+1
      weightc( 35, 28,  3)=                  0.31124490256798886811d0
      iwe=iwe+1
      weightc( 36, 28,  3)=                  0.34300234280865560255d0
      iwe=iwe+1
      weightc( 37, 28,  3)=                  0.45440130626379138246d0
      iwe=iwe+1
      weightc( 38, 28,  3)=                  0.03132385622175656859d0
      iwe=iwe+1
      weightc( 39, 28,  3)=                 -0.04197724946799805124d0
      iwe=iwe+1
      weightc( 40, 28,  3)=                 -0.14757153392721136798d0
      iwe=iwe+1
      weightc( 41, 28,  3)=                 -0.17631608890846683924d0
      iwe=iwe+1
      weightc( 42, 28,  3)=                  0.08465460625993813382d0
      iwe=iwe+1
      weightc( 43, 28,  3)=                  0.21736477927736838622d0
      iwe=iwe+1
      weightc( 44, 28,  3)=                 -0.00146815937924423857d0
      iwe=iwe+1
      weightc( 45, 28,  3)=                  0.40275266949295196461d0
      iwe=iwe+1
      weightc( 46, 28,  3)=                  0.20441482695702506422d0
      iwe=iwe+1
      weightc( 47, 28,  3)=                  0.17076304813313258890d0
      iwe=iwe+1
      weightc( 48, 28,  3)=                  0.07145817068313815856d0
      iwe=iwe+1
      weightc( 49, 28,  3)=                  0.13458622995516567045d0
      iwe=iwe+1
      weightc( 50, 28,  3)=                 -0.29176832980213518454d0
      iwe=iwe+1
      biasc( 28,  3)=                 -0.74231293188759595036d0
      iwe=iwe+1
      weightc(  1, 29,  3)=                 -0.01775605793907942750d0
      iwe=iwe+1
      weightc(  2, 29,  3)=                 -0.41943451598006331604d0
      iwe=iwe+1
      weightc(  3, 29,  3)=                  0.16615320265525368448d0
      iwe=iwe+1
      weightc(  4, 29,  3)=                 -0.16776735394999381379d0
      iwe=iwe+1
      weightc(  5, 29,  3)=                  0.29769564478051063761d0
      iwe=iwe+1
      weightc(  6, 29,  3)=                 -0.17006874700262630817d0
      iwe=iwe+1
      weightc(  7, 29,  3)=                  0.09451075602932182407d0
      iwe=iwe+1
      weightc(  8, 29,  3)=                  0.02911813383124062238d0
      iwe=iwe+1
      weightc(  9, 29,  3)=                 -0.00192701976240154714d0
      iwe=iwe+1
      weightc( 10, 29,  3)=                  0.53350423204010188893d0
      iwe=iwe+1
      weightc( 11, 29,  3)=                 -0.15468915438178584831d0
      iwe=iwe+1
      weightc( 12, 29,  3)=                  0.35527535982853952756d0
      iwe=iwe+1
      weightc( 13, 29,  3)=                 -0.00003917458012511234d0
      iwe=iwe+1
      weightc( 14, 29,  3)=                  0.33131025296682459214d0
      iwe=iwe+1
      weightc( 15, 29,  3)=                  0.04346629942749492131d0
      iwe=iwe+1
      weightc( 16, 29,  3)=                 -0.29043167895340227247d0
      iwe=iwe+1
      weightc( 17, 29,  3)=                 -0.42069386995004870444d0
      iwe=iwe+1
      weightc( 18, 29,  3)=                 -0.29626785717171028045d0
      iwe=iwe+1
      weightc( 19, 29,  3)=                 -0.66867520624547971408d0
      iwe=iwe+1
      weightc( 20, 29,  3)=                  0.00918957091534958019d0
      iwe=iwe+1
      weightc( 21, 29,  3)=                  0.45377065116221393382d0
      iwe=iwe+1
      weightc( 22, 29,  3)=                 -0.02348877960501998680d0
      iwe=iwe+1
      weightc( 23, 29,  3)=                  0.09303689525821180750d0
      iwe=iwe+1
      weightc( 24, 29,  3)=                 -0.35560458250482135378d0
      iwe=iwe+1
      weightc( 25, 29,  3)=                 -0.03224581493474562577d0
      iwe=iwe+1
      weightc( 26, 29,  3)=                 -0.15677629381107646700d0
      iwe=iwe+1
      weightc( 27, 29,  3)=                  0.15425043847811412134d0
      iwe=iwe+1
      weightc( 28, 29,  3)=                  0.22000152066227451897d0
      iwe=iwe+1
      weightc( 29, 29,  3)=                 -0.24960644421504313284d0
      iwe=iwe+1
      weightc( 30, 29,  3)=                 -0.39785408285245438265d0
      iwe=iwe+1
      weightc( 31, 29,  3)=                  0.11015736185999991381d0
      iwe=iwe+1
      weightc( 32, 29,  3)=                 -0.34627559499723731262d0
      iwe=iwe+1
      weightc( 33, 29,  3)=                 -0.20564844026658324339d0
      iwe=iwe+1
      weightc( 34, 29,  3)=                 -0.05089133439175174550d0
      iwe=iwe+1
      weightc( 35, 29,  3)=                 -0.10292993509234958649d0
      iwe=iwe+1
      weightc( 36, 29,  3)=                  0.28238239250253799328d0
      iwe=iwe+1
      weightc( 37, 29,  3)=                  0.00536913447152646047d0
      iwe=iwe+1
      weightc( 38, 29,  3)=                  0.16616371676643232336d0
      iwe=iwe+1
      weightc( 39, 29,  3)=                  0.10536966052618264300d0
      iwe=iwe+1
      weightc( 40, 29,  3)=                 -0.26584605332443189685d0
      iwe=iwe+1
      weightc( 41, 29,  3)=                  0.00924829859281862433d0
      iwe=iwe+1
      weightc( 42, 29,  3)=                  0.17435857547566668835d0
      iwe=iwe+1
      weightc( 43, 29,  3)=                 -0.31414632437025097333d0
      iwe=iwe+1
      weightc( 44, 29,  3)=                  0.09020137369795375171d0
      iwe=iwe+1
      weightc( 45, 29,  3)=                  0.15097121671867513859d0
      iwe=iwe+1
      weightc( 46, 29,  3)=                  0.05659506360617552051d0
      iwe=iwe+1
      weightc( 47, 29,  3)=                  0.59977899626971298286d0
      iwe=iwe+1
      weightc( 48, 29,  3)=                  0.15502230633899122259d0
      iwe=iwe+1
      weightc( 49, 29,  3)=                 -0.74283147962599693770d0
      iwe=iwe+1
      weightc( 50, 29,  3)=                  0.34287694216690434157d0
      iwe=iwe+1
      biasc( 29,  3)=                  0.33162929041920952145d0
      iwe=iwe+1
      weightc(  1, 30,  3)=                  0.52556836259434458469d0
      iwe=iwe+1
      weightc(  2, 30,  3)=                  1.23988583740914970477d0
      iwe=iwe+1
      weightc(  3, 30,  3)=                  0.39271463539164708223d0
      iwe=iwe+1
      weightc(  4, 30,  3)=                  0.19241723299482349496d0
      iwe=iwe+1
      weightc(  5, 30,  3)=                  0.11338533899446609499d0
      iwe=iwe+1
      weightc(  6, 30,  3)=                 -0.23040281588312755412d0
      iwe=iwe+1
      weightc(  7, 30,  3)=                 -0.20107676412563987856d0
      iwe=iwe+1
      weightc(  8, 30,  3)=                 -0.27757605538688834290d0
      iwe=iwe+1
      weightc(  9, 30,  3)=                 -0.15412991389669039588d0
      iwe=iwe+1
      weightc( 10, 30,  3)=                  0.49207597852846718389d0
      iwe=iwe+1
      weightc( 11, 30,  3)=                  0.10527069377416377327d0
      iwe=iwe+1
      weightc( 12, 30,  3)=                 -0.13771327384851314579d0
      iwe=iwe+1
      weightc( 13, 30,  3)=                  0.22929509299744876838d0
      iwe=iwe+1
      weightc( 14, 30,  3)=                  0.09802210142244976998d0
      iwe=iwe+1
      weightc( 15, 30,  3)=                 -0.21613500813544522794d0
      iwe=iwe+1
      weightc( 16, 30,  3)=                  0.09455909955448414672d0
      iwe=iwe+1
      weightc( 17, 30,  3)=                  0.04265713094344950745d0
      iwe=iwe+1
      weightc( 18, 30,  3)=                 -0.20520144715464541663d0
      iwe=iwe+1
      weightc( 19, 30,  3)=                  0.41763335118954908465d0
      iwe=iwe+1
      weightc( 20, 30,  3)=                  0.00692189908217429647d0
      iwe=iwe+1
      weightc( 21, 30,  3)=                  0.24898671287685308906d0
      iwe=iwe+1
      weightc( 22, 30,  3)=                  0.02602012312370252656d0
      iwe=iwe+1
      weightc( 23, 30,  3)=                 -0.39917711388997267896d0
      iwe=iwe+1
      weightc( 24, 30,  3)=                 -0.80842131410380568823d0
      iwe=iwe+1
      weightc( 25, 30,  3)=                 -0.08925531973560200949d0
      iwe=iwe+1
      weightc( 26, 30,  3)=                  0.39020764712836214505d0
      iwe=iwe+1
      weightc( 27, 30,  3)=                 -0.08275819903445445769d0
      iwe=iwe+1
      weightc( 28, 30,  3)=                 -0.47432155202275516626d0
      iwe=iwe+1
      weightc( 29, 30,  3)=                 -0.11114585840456758792d0
      iwe=iwe+1
      weightc( 30, 30,  3)=                 -0.18145243121246529272d0
      iwe=iwe+1
      weightc( 31, 30,  3)=                  0.09961492158839252431d0
      iwe=iwe+1
      weightc( 32, 30,  3)=                  0.61458070007193099649d0
      iwe=iwe+1
      weightc( 33, 30,  3)=                  0.28104131156242034839d0
      iwe=iwe+1
      weightc( 34, 30,  3)=                  0.41112823520434976787d0
      iwe=iwe+1
      weightc( 35, 30,  3)=                 -0.55748420218251104608d0
      iwe=iwe+1
      weightc( 36, 30,  3)=                  0.27123168521482288185d0
      iwe=iwe+1
      weightc( 37, 30,  3)=                  0.19356299685148764533d0
      iwe=iwe+1
      weightc( 38, 30,  3)=                  0.24630303200914113737d0
      iwe=iwe+1
      weightc( 39, 30,  3)=                  0.27839404734254619145d0
      iwe=iwe+1
      weightc( 40, 30,  3)=                 -0.13322272232806472991d0
      iwe=iwe+1
      weightc( 41, 30,  3)=                  0.32200085855366361587d0
      iwe=iwe+1
      weightc( 42, 30,  3)=                 -0.37461156708757065159d0
      iwe=iwe+1
      weightc( 43, 30,  3)=                 -0.15401865598670261281d0
      iwe=iwe+1
      weightc( 44, 30,  3)=                 -0.56471225320593720909d0
      iwe=iwe+1
      weightc( 45, 30,  3)=                  0.03714085706708267209d0
      iwe=iwe+1
      weightc( 46, 30,  3)=                  0.89912273556222754856d0
      iwe=iwe+1
      weightc( 47, 30,  3)=                 -0.13876738238103486500d0
      iwe=iwe+1
      weightc( 48, 30,  3)=                 -0.68605149783141494702d0
      iwe=iwe+1
      weightc( 49, 30,  3)=                 -0.21457249124763227988d0
      iwe=iwe+1
      weightc( 50, 30,  3)=                 -0.39505527105666771170d0
      iwe=iwe+1
      biasc( 30,  3)=                 -0.11117110018688257378d0
      iwe=iwe+1
      weightc(  1, 31,  3)=                 -0.07522802428400453267d0
      iwe=iwe+1
      weightc(  2, 31,  3)=                  0.12781209063705498141d0
      iwe=iwe+1
      weightc(  3, 31,  3)=                 -0.25343178795896259548d0
      iwe=iwe+1
      weightc(  4, 31,  3)=                  0.46828642087031779884d0
      iwe=iwe+1
      weightc(  5, 31,  3)=                 -0.38014025311925020434d0
      iwe=iwe+1
      weightc(  6, 31,  3)=                 -0.06294654723094761373d0
      iwe=iwe+1
      weightc(  7, 31,  3)=                  0.20305308899825097457d0
      iwe=iwe+1
      weightc(  8, 31,  3)=                  0.62301766826602789084d0
      iwe=iwe+1
      weightc(  9, 31,  3)=                  0.22762285735903065031d0
      iwe=iwe+1
      weightc( 10, 31,  3)=                 -0.20266512715899015484d0
      iwe=iwe+1
      weightc( 11, 31,  3)=                 -0.39055568744213109422d0
      iwe=iwe+1
      weightc( 12, 31,  3)=                  0.31337426251362143770d0
      iwe=iwe+1
      weightc( 13, 31,  3)=                  0.03587179300623864753d0
      iwe=iwe+1
      weightc( 14, 31,  3)=                 -0.11533779309017783143d0
      iwe=iwe+1
      weightc( 15, 31,  3)=                  0.13634065308587303700d0
      iwe=iwe+1
      weightc( 16, 31,  3)=                 -0.41396610300009195615d0
      iwe=iwe+1
      weightc( 17, 31,  3)=                 -0.02875043817091610734d0
      iwe=iwe+1
      weightc( 18, 31,  3)=                  0.28321394617487566370d0
      iwe=iwe+1
      weightc( 19, 31,  3)=                  0.03356765338891459782d0
      iwe=iwe+1
      weightc( 20, 31,  3)=                 -0.01369762733890176123d0
      iwe=iwe+1
      weightc( 21, 31,  3)=                  0.10648505897833873690d0
      iwe=iwe+1
      weightc( 22, 31,  3)=                  0.31106193098535722674d0
      iwe=iwe+1
      weightc( 23, 31,  3)=                  0.04790778132156520847d0
      iwe=iwe+1
      weightc( 24, 31,  3)=                 -0.35690970470776745005d0
      iwe=iwe+1
      weightc( 25, 31,  3)=                 -0.03902499777321954966d0
      iwe=iwe+1
      weightc( 26, 31,  3)=                  0.06233716754994479692d0
      iwe=iwe+1
      weightc( 27, 31,  3)=                 -0.16966300952207047370d0
      iwe=iwe+1
      weightc( 28, 31,  3)=                 -0.04687950224455125076d0
      iwe=iwe+1
      weightc( 29, 31,  3)=                  0.23718255340596466896d0
      iwe=iwe+1
      weightc( 30, 31,  3)=                 -0.01694214264547527771d0
      iwe=iwe+1
      weightc( 31, 31,  3)=                  0.28874817965044213830d0
      iwe=iwe+1
      weightc( 32, 31,  3)=                  0.67204965527452609209d0
      iwe=iwe+1
      weightc( 33, 31,  3)=                 -0.01080924094458347515d0
      iwe=iwe+1
      weightc( 34, 31,  3)=                 -0.18063848793331779841d0
      iwe=iwe+1
      weightc( 35, 31,  3)=                 -0.08576932084067663553d0
      iwe=iwe+1
      weightc( 36, 31,  3)=                 -0.32123587547409954146d0
      iwe=iwe+1
      weightc( 37, 31,  3)=                 -0.44435019916603757384d0
      iwe=iwe+1
      weightc( 38, 31,  3)=                  0.03323778673138056555d0
      iwe=iwe+1
      weightc( 39, 31,  3)=                 -0.12980698812630397931d0
      iwe=iwe+1
      weightc( 40, 31,  3)=                  0.09104467233616826694d0
      iwe=iwe+1
      weightc( 41, 31,  3)=                 -0.23809814847234808677d0
      iwe=iwe+1
      weightc( 42, 31,  3)=                 -0.53434556185355908120d0
      iwe=iwe+1
      weightc( 43, 31,  3)=                  0.26961266692076041318d0
      iwe=iwe+1
      weightc( 44, 31,  3)=                 -0.34938783880981633123d0
      iwe=iwe+1
      weightc( 45, 31,  3)=                  0.11781513859445344461d0
      iwe=iwe+1
      weightc( 46, 31,  3)=                 -0.22198132615403409762d0
      iwe=iwe+1
      weightc( 47, 31,  3)=                 -0.28786163715773860350d0
      iwe=iwe+1
      weightc( 48, 31,  3)=                 -0.17028266188358531785d0
      iwe=iwe+1
      weightc( 49, 31,  3)=                  0.70335413472121244283d0
      iwe=iwe+1
      weightc( 50, 31,  3)=                  0.47541132689729531657d0
      iwe=iwe+1
      biasc( 31,  3)=                  0.40395295736491820815d0
      iwe=iwe+1
      weightc(  1, 32,  3)=                  0.34964907093340680255d0
      iwe=iwe+1
      weightc(  2, 32,  3)=                 -0.11875900311884059202d0
      iwe=iwe+1
      weightc(  3, 32,  3)=                  0.35176285052108635654d0
      iwe=iwe+1
      weightc(  4, 32,  3)=                  0.20427403094994528443d0
      iwe=iwe+1
      weightc(  5, 32,  3)=                  0.28390785838596865887d0
      iwe=iwe+1
      weightc(  6, 32,  3)=                  0.13278321517851704447d0
      iwe=iwe+1
      weightc(  7, 32,  3)=                 -0.12824402322682201816d0
      iwe=iwe+1
      weightc(  8, 32,  3)=                 -0.46292111145301201303d0
      iwe=iwe+1
      weightc(  9, 32,  3)=                  0.33923665555371596003d0
      iwe=iwe+1
      weightc( 10, 32,  3)=                  0.17491782328466204399d0
      iwe=iwe+1
      weightc( 11, 32,  3)=                 -0.17928538633318993889d0
      iwe=iwe+1
      weightc( 12, 32,  3)=                  0.06819343720818694943d0
      iwe=iwe+1
      weightc( 13, 32,  3)=                 -0.23893613475037092653d0
      iwe=iwe+1
      weightc( 14, 32,  3)=                  0.25377911960767796096d0
      iwe=iwe+1
      weightc( 15, 32,  3)=                  0.30542052661333196628d0
      iwe=iwe+1
      weightc( 16, 32,  3)=                 -0.28171895121957740704d0
      iwe=iwe+1
      weightc( 17, 32,  3)=                 -0.21074159964216079843d0
      iwe=iwe+1
      weightc( 18, 32,  3)=                 -0.28273505098043399952d0
      iwe=iwe+1
      weightc( 19, 32,  3)=                  0.98928210566517083002d0
      iwe=iwe+1
      weightc( 20, 32,  3)=                  0.18390952189119022520d0
      iwe=iwe+1
      weightc( 21, 32,  3)=                  0.46518855270175002437d0
      iwe=iwe+1
      weightc( 22, 32,  3)=                 -0.15362518356046642176d0
      iwe=iwe+1
      weightc( 23, 32,  3)=                  0.19270738566965228689d0
      iwe=iwe+1
      weightc( 24, 32,  3)=                 -0.20043175822947939535d0
      iwe=iwe+1
      weightc( 25, 32,  3)=                 -0.10609163435695044553d0
      iwe=iwe+1
      weightc( 26, 32,  3)=                 -0.31920015990181238585d0
      iwe=iwe+1
      weightc( 27, 32,  3)=                  0.22436429046671735321d0
      iwe=iwe+1
      weightc( 28, 32,  3)=                 -0.85293891469440319408d0
      iwe=iwe+1
      weightc( 29, 32,  3)=                 -0.30743064506448930517d0
      iwe=iwe+1
      weightc( 30, 32,  3)=                  0.40868492242440129791d0
      iwe=iwe+1
      weightc( 31, 32,  3)=                  0.17770302354946815315d0
      iwe=iwe+1
      weightc( 32, 32,  3)=                 -0.52476892088726223573d0
      iwe=iwe+1
      weightc( 33, 32,  3)=                 -0.18823519798753776677d0
      iwe=iwe+1
      weightc( 34, 32,  3)=                  0.28519936952032987065d0
      iwe=iwe+1
      weightc( 35, 32,  3)=                  0.38842569067225080071d0
      iwe=iwe+1
      weightc( 36, 32,  3)=                 -0.28147952731902392554d0
      iwe=iwe+1
      weightc( 37, 32,  3)=                 -0.34530592973490675801d0
      iwe=iwe+1
      weightc( 38, 32,  3)=                  0.32862466671257206663d0
      iwe=iwe+1
      weightc( 39, 32,  3)=                  0.12830862043380036885d0
      iwe=iwe+1
      weightc( 40, 32,  3)=                  0.04265497401776174868d0
      iwe=iwe+1
      weightc( 41, 32,  3)=                 -0.30411359347750022142d0
      iwe=iwe+1
      weightc( 42, 32,  3)=                 -0.32288933609113151801d0
      iwe=iwe+1
      weightc( 43, 32,  3)=                  0.16025817759473240387d0
      iwe=iwe+1
      weightc( 44, 32,  3)=                  0.16327591023477433518d0
      iwe=iwe+1
      weightc( 45, 32,  3)=                 -0.05913201894149505700d0
      iwe=iwe+1
      weightc( 46, 32,  3)=                 -0.09879700719682911469d0
      iwe=iwe+1
      weightc( 47, 32,  3)=                 -0.40602697716059227284d0
      iwe=iwe+1
      weightc( 48, 32,  3)=                 -0.14710718731597371978d0
      iwe=iwe+1
      weightc( 49, 32,  3)=                 -0.13286998589033127693d0
      iwe=iwe+1
      weightc( 50, 32,  3)=                 -0.12418652601308385885d0
      iwe=iwe+1
      biasc( 32,  3)=                 -0.13820992633300704933d0
      iwe=iwe+1
      weightc(  1, 33,  3)=                  0.63963871260513549544d0
      iwe=iwe+1
      weightc(  2, 33,  3)=                 -0.51123302238816314969d0
      iwe=iwe+1
      weightc(  3, 33,  3)=                 -0.13132332664220713880d0
      iwe=iwe+1
      weightc(  4, 33,  3)=                 -0.18732652672645139225d0
      iwe=iwe+1
      weightc(  5, 33,  3)=                 -0.09541377562855749006d0
      iwe=iwe+1
      weightc(  6, 33,  3)=                  0.14907046839129595162d0
      iwe=iwe+1
      weightc(  7, 33,  3)=                 -0.56798750645616713495d0
      iwe=iwe+1
      weightc(  8, 33,  3)=                 -0.15491417797220563557d0
      iwe=iwe+1
      weightc(  9, 33,  3)=                  0.23501657134952050332d0
      iwe=iwe+1
      weightc( 10, 33,  3)=                  0.41292396439688094922d0
      iwe=iwe+1
      weightc( 11, 33,  3)=                  0.12852771894305131672d0
      iwe=iwe+1
      weightc( 12, 33,  3)=                 -0.07476369773480792680d0
      iwe=iwe+1
      weightc( 13, 33,  3)=                  0.07754338882151060042d0
      iwe=iwe+1
      weightc( 14, 33,  3)=                 -0.32880992684466958664d0
      iwe=iwe+1
      weightc( 15, 33,  3)=                 -0.31459574226893172177d0
      iwe=iwe+1
      weightc( 16, 33,  3)=                  0.21871438273096718841d0
      iwe=iwe+1
      weightc( 17, 33,  3)=                  0.01452022529594610908d0
      iwe=iwe+1
      weightc( 18, 33,  3)=                 -0.11139532061088991410d0
      iwe=iwe+1
      weightc( 19, 33,  3)=                 -0.09734059209809858837d0
      iwe=iwe+1
      weightc( 20, 33,  3)=                 -0.13372554858728444294d0
      iwe=iwe+1
      weightc( 21, 33,  3)=                  0.27114028085170460702d0
      iwe=iwe+1
      weightc( 22, 33,  3)=                  0.12311699597261779870d0
      iwe=iwe+1
      weightc( 23, 33,  3)=                  0.04600296746752231825d0
      iwe=iwe+1
      weightc( 24, 33,  3)=                  0.16951012701657261483d0
      iwe=iwe+1
      weightc( 25, 33,  3)=                 -0.05326688444638971037d0
      iwe=iwe+1
      weightc( 26, 33,  3)=                 -0.38711436514640473749d0
      iwe=iwe+1
      weightc( 27, 33,  3)=                  0.22961438090081323637d0
      iwe=iwe+1
      weightc( 28, 33,  3)=                 -0.04637572693183616979d0
      iwe=iwe+1
      weightc( 29, 33,  3)=                 -0.33761246105859826772d0
      iwe=iwe+1
      weightc( 30, 33,  3)=                 -0.09549088006966155451d0
      iwe=iwe+1
      weightc( 31, 33,  3)=                 -0.25891723218367362902d0
      iwe=iwe+1
      weightc( 32, 33,  3)=                 -0.12642103585958056056d0
      iwe=iwe+1
      weightc( 33, 33,  3)=                  0.15169962290133442995d0
      iwe=iwe+1
      weightc( 34, 33,  3)=                 -0.27710481319630325681d0
      iwe=iwe+1
      weightc( 35, 33,  3)=                  0.58019095571382139909d0
      iwe=iwe+1
      weightc( 36, 33,  3)=                  0.36560450301825869746d0
      iwe=iwe+1
      weightc( 37, 33,  3)=                 -0.19024558542285446849d0
      iwe=iwe+1
      weightc( 38, 33,  3)=                 -0.04125428902656737284d0
      iwe=iwe+1
      weightc( 39, 33,  3)=                 -0.41282721502311581219d0
      iwe=iwe+1
      weightc( 40, 33,  3)=                  0.02901850541828006683d0
      iwe=iwe+1
      weightc( 41, 33,  3)=                 -0.22204586805761117319d0
      iwe=iwe+1
      weightc( 42, 33,  3)=                  0.50713834844704230864d0
      iwe=iwe+1
      weightc( 43, 33,  3)=                  0.02018454234095380315d0
      iwe=iwe+1
      weightc( 44, 33,  3)=                  0.43055896939110438471d0
      iwe=iwe+1
      weightc( 45, 33,  3)=                  0.50024067836297070322d0
      iwe=iwe+1
      weightc( 46, 33,  3)=                  0.27256549715922662180d0
      iwe=iwe+1
      weightc( 47, 33,  3)=                  0.37461002416767053003d0
      iwe=iwe+1
      weightc( 48, 33,  3)=                 -0.34552354682008573628d0
      iwe=iwe+1
      weightc( 49, 33,  3)=                 -0.31800754198894232161d0
      iwe=iwe+1
      weightc( 50, 33,  3)=                 -0.79516469149390767157d0
      iwe=iwe+1
      biasc( 33,  3)=                 -0.38706810243163114471d0
      iwe=iwe+1
      weightc(  1, 34,  3)=                 -0.36600718868008530471d0
      iwe=iwe+1
      weightc(  2, 34,  3)=                 -0.04108322335583281665d0
      iwe=iwe+1
      weightc(  3, 34,  3)=                 -0.22131550767146332404d0
      iwe=iwe+1
      weightc(  4, 34,  3)=                 -0.02678390708740396170d0
      iwe=iwe+1
      weightc(  5, 34,  3)=                 -0.11570633468888315287d0
      iwe=iwe+1
      weightc(  6, 34,  3)=                  0.12810106319264336072d0
      iwe=iwe+1
      weightc(  7, 34,  3)=                 -0.28753604830285245386d0
      iwe=iwe+1
      weightc(  8, 34,  3)=                 -0.18401842124184639160d0
      iwe=iwe+1
      weightc(  9, 34,  3)=                 -0.17464474664843590568d0
      iwe=iwe+1
      weightc( 10, 34,  3)=                 -0.20268870189068521892d0
      iwe=iwe+1
      weightc( 11, 34,  3)=                  0.07157585722009084106d0
      iwe=iwe+1
      weightc( 12, 34,  3)=                 -0.03536188504730322646d0
      iwe=iwe+1
      weightc( 13, 34,  3)=                  0.39346460391171722559d0
      iwe=iwe+1
      weightc( 14, 34,  3)=                 -0.18317340690842912054d0
      iwe=iwe+1
      weightc( 15, 34,  3)=                  0.30834453965940744613d0
      iwe=iwe+1
      weightc( 16, 34,  3)=                 -0.09131061312636651328d0
      iwe=iwe+1
      weightc( 17, 34,  3)=                  0.23266621506985074586d0
      iwe=iwe+1
      weightc( 18, 34,  3)=                  0.95484610109384882026d0
      iwe=iwe+1
      weightc( 19, 34,  3)=                 -0.59284899852412964449d0
      iwe=iwe+1
      weightc( 20, 34,  3)=                  0.19361802870319083647d0
      iwe=iwe+1
      weightc( 21, 34,  3)=                 -0.59753523667397379082d0
      iwe=iwe+1
      weightc( 22, 34,  3)=                  0.18787193753956543674d0
      iwe=iwe+1
      weightc( 23, 34,  3)=                  0.00181834889920771611d0
      iwe=iwe+1
      weightc( 24, 34,  3)=                 -0.00374420977103554712d0
      iwe=iwe+1
      weightc( 25, 34,  3)=                 -0.20825695217263420767d0
      iwe=iwe+1
      weightc( 26, 34,  3)=                 -0.36537966471832100668d0
      iwe=iwe+1
      weightc( 27, 34,  3)=                  0.50320047697809056064d0
      iwe=iwe+1
      weightc( 28, 34,  3)=                 -0.09260660576022142210d0
      iwe=iwe+1
      weightc( 29, 34,  3)=                 -0.32874586889778018017d0
      iwe=iwe+1
      weightc( 30, 34,  3)=                 -0.38998289695816273914d0
      iwe=iwe+1
      weightc( 31, 34,  3)=                  0.21567566415765085375d0
      iwe=iwe+1
      weightc( 32, 34,  3)=                 -0.11113106901345451427d0
      iwe=iwe+1
      weightc( 33, 34,  3)=                  0.01373252093366105972d0
      iwe=iwe+1
      weightc( 34, 34,  3)=                  0.14081908074481261361d0
      iwe=iwe+1
      weightc( 35, 34,  3)=                  0.23492514721145685286d0
      iwe=iwe+1
      weightc( 36, 34,  3)=                 -0.14515260966410817312d0
      iwe=iwe+1
      weightc( 37, 34,  3)=                 -0.18725816802016451157d0
      iwe=iwe+1
      weightc( 38, 34,  3)=                 -0.22297051410748408573d0
      iwe=iwe+1
      weightc( 39, 34,  3)=                  0.19058715609236498434d0
      iwe=iwe+1
      weightc( 40, 34,  3)=                 -0.29330703144854231024d0
      iwe=iwe+1
      weightc( 41, 34,  3)=                 -0.35986240927144180768d0
      iwe=iwe+1
      weightc( 42, 34,  3)=                  0.14421744387359769490d0
      iwe=iwe+1
      weightc( 43, 34,  3)=                  0.07184348146986510586d0
      iwe=iwe+1
      weightc( 44, 34,  3)=                  0.10977062485585231677d0
      iwe=iwe+1
      weightc( 45, 34,  3)=                 -0.55381052485337345370d0
      iwe=iwe+1
      weightc( 46, 34,  3)=                  0.35745440858364779801d0
      iwe=iwe+1
      weightc( 47, 34,  3)=                 -0.04043027693751150703d0
      iwe=iwe+1
      weightc( 48, 34,  3)=                  0.09038891448002286944d0
      iwe=iwe+1
      weightc( 49, 34,  3)=                  0.00578990527058781575d0
      iwe=iwe+1
      weightc( 50, 34,  3)=                  0.51051032627434778099d0
      iwe=iwe+1
      biasc( 34,  3)=                  0.23913011324200797447d0
      iwe=iwe+1
      weightc(  1, 35,  3)=                 -0.01120870363411587134d0
      iwe=iwe+1
      weightc(  2, 35,  3)=                  0.04652478117023825521d0
      iwe=iwe+1
      weightc(  3, 35,  3)=                  0.28992286515347154285d0
      iwe=iwe+1
      weightc(  4, 35,  3)=                  0.21408403283871213496d0
      iwe=iwe+1
      weightc(  5, 35,  3)=                  0.45141625104479099484d0
      iwe=iwe+1
      weightc(  6, 35,  3)=                  0.10748075814690997987d0
      iwe=iwe+1
      weightc(  7, 35,  3)=                 -0.27718976632880881761d0
      iwe=iwe+1
      weightc(  8, 35,  3)=                  0.05449003670854293824d0
      iwe=iwe+1
      weightc(  9, 35,  3)=                 -0.08197697009547207092d0
      iwe=iwe+1
      weightc( 10, 35,  3)=                 -0.13526290821652553475d0
      iwe=iwe+1
      weightc( 11, 35,  3)=                 -0.19279955748928634396d0
      iwe=iwe+1
      weightc( 12, 35,  3)=                  0.06085553478295264301d0
      iwe=iwe+1
      weightc( 13, 35,  3)=                 -0.19596115315636256082d0
      iwe=iwe+1
      weightc( 14, 35,  3)=                  0.09688559363237067568d0
      iwe=iwe+1
      weightc( 15, 35,  3)=                 -0.18070782358103135157d0
      iwe=iwe+1
      weightc( 16, 35,  3)=                  0.00237943290179713600d0
      iwe=iwe+1
      weightc( 17, 35,  3)=                  0.44015392160346350492d0
      iwe=iwe+1
      weightc( 18, 35,  3)=                 -0.01002267683057487917d0
      iwe=iwe+1
      weightc( 19, 35,  3)=                  0.20438439276989373017d0
      iwe=iwe+1
      weightc( 20, 35,  3)=                 -0.08450451608618188282d0
      iwe=iwe+1
      weightc( 21, 35,  3)=                 -0.15227784370361677202d0
      iwe=iwe+1
      weightc( 22, 35,  3)=                  0.16013566596790132501d0
      iwe=iwe+1
      weightc( 23, 35,  3)=                  0.24413207815303353265d0
      iwe=iwe+1
      weightc( 24, 35,  3)=                 -0.11169038020127106114d0
      iwe=iwe+1
      weightc( 25, 35,  3)=                 -0.43649356345960382830d0
      iwe=iwe+1
      weightc( 26, 35,  3)=                  0.03212880378376870016d0
      iwe=iwe+1
      weightc( 27, 35,  3)=                 -0.37318396724862012981d0
      iwe=iwe+1
      weightc( 28, 35,  3)=                  0.45699051539485807671d0
      iwe=iwe+1
      weightc( 29, 35,  3)=                  0.15041473846193909036d0
      iwe=iwe+1
      weightc( 30, 35,  3)=                 -0.55945143644274042405d0
      iwe=iwe+1
      weightc( 31, 35,  3)=                 -0.35323868194322366465d0
      iwe=iwe+1
      weightc( 32, 35,  3)=                  0.21821885406005531172d0
      iwe=iwe+1
      weightc( 33, 35,  3)=                 -0.06466837102170538976d0
      iwe=iwe+1
      weightc( 34, 35,  3)=                  0.29113481121340195612d0
      iwe=iwe+1
      weightc( 35, 35,  3)=                 -0.26588242204720718975d0
      iwe=iwe+1
      weightc( 36, 35,  3)=                 -0.10389234683653265912d0
      iwe=iwe+1
      weightc( 37, 35,  3)=                  0.33321822365891079487d0
      iwe=iwe+1
      weightc( 38, 35,  3)=                 -0.02089378447205139308d0
      iwe=iwe+1
      weightc( 39, 35,  3)=                 -0.20779145218317693344d0
      iwe=iwe+1
      weightc( 40, 35,  3)=                  0.33133086915203496803d0
      iwe=iwe+1
      weightc( 41, 35,  3)=                  0.07366239301646661242d0
      iwe=iwe+1
      weightc( 42, 35,  3)=                  0.41658632564590059033d0
      iwe=iwe+1
      weightc( 43, 35,  3)=                  0.03596845723623656732d0
      iwe=iwe+1
      weightc( 44, 35,  3)=                  0.16123671529693101023d0
      iwe=iwe+1
      weightc( 45, 35,  3)=                 -0.17227711829823014189d0
      iwe=iwe+1
      weightc( 46, 35,  3)=                  0.01904281026680568201d0
      iwe=iwe+1
      weightc( 47, 35,  3)=                 -0.19364712713578477454d0
      iwe=iwe+1
      weightc( 48, 35,  3)=                  0.32501610184425683281d0
      iwe=iwe+1
      weightc( 49, 35,  3)=                  0.48317057968361942777d0
      iwe=iwe+1
      weightc( 50, 35,  3)=                  0.20060903295968651738d0
      iwe=iwe+1
      biasc( 35,  3)=                 -0.09135691813613006085d0
      iwe=iwe+1
      weightc(  1, 36,  3)=                  0.09308915767195816149d0
      iwe=iwe+1
      weightc(  2, 36,  3)=                  0.01648498157002458928d0
      iwe=iwe+1
      weightc(  3, 36,  3)=                 -0.00715145336537967649d0
      iwe=iwe+1
      weightc(  4, 36,  3)=                 -0.13872025096675008604d0
      iwe=iwe+1
      weightc(  5, 36,  3)=                 -0.02132773239283517613d0
      iwe=iwe+1
      weightc(  6, 36,  3)=                 -0.27593012369824809760d0
      iwe=iwe+1
      weightc(  7, 36,  3)=                 -0.32158936419978939592d0
      iwe=iwe+1
      weightc(  8, 36,  3)=                 -0.40066832519506984100d0
      iwe=iwe+1
      weightc(  9, 36,  3)=                  0.21738286054244151946d0
      iwe=iwe+1
      weightc( 10, 36,  3)=                 -0.40194305852084838415d0
      iwe=iwe+1
      weightc( 11, 36,  3)=                  0.21622244209079277688d0
      iwe=iwe+1
      weightc( 12, 36,  3)=                  0.17878267950987730694d0
      iwe=iwe+1
      weightc( 13, 36,  3)=                  0.06370479103650822372d0
      iwe=iwe+1
      weightc( 14, 36,  3)=                 -0.15683261493525202379d0
      iwe=iwe+1
      weightc( 15, 36,  3)=                 -0.20482381451831979668d0
      iwe=iwe+1
      weightc( 16, 36,  3)=                  0.44575218734014038224d0
      iwe=iwe+1
      weightc( 17, 36,  3)=                 -0.06845444383389640008d0
      iwe=iwe+1
      weightc( 18, 36,  3)=                 -0.37448870069070672173d0
      iwe=iwe+1
      weightc( 19, 36,  3)=                 -0.46057666343499942263d0
      iwe=iwe+1
      weightc( 20, 36,  3)=                 -0.11738218574955740225d0
      iwe=iwe+1
      weightc( 21, 36,  3)=                  0.28061883220406491635d0
      iwe=iwe+1
      weightc( 22, 36,  3)=                 -0.32939484183714162757d0
      iwe=iwe+1
      weightc( 23, 36,  3)=                 -0.57118591123172290924d0
      iwe=iwe+1
      weightc( 24, 36,  3)=                  0.14088767199076890346d0
      iwe=iwe+1
      weightc( 25, 36,  3)=                 -0.04927561112404950372d0
      iwe=iwe+1
      weightc( 26, 36,  3)=                 -0.19487219642867545377d0
      iwe=iwe+1
      weightc( 27, 36,  3)=                  0.38064072917206159818d0
      iwe=iwe+1
      weightc( 28, 36,  3)=                  0.00621259396902210277d0
      iwe=iwe+1
      weightc( 29, 36,  3)=                  0.31966018104421700663d0
      iwe=iwe+1
      weightc( 30, 36,  3)=                  0.04807855691817154720d0
      iwe=iwe+1
      weightc( 31, 36,  3)=                  0.42622524030476921508d0
      iwe=iwe+1
      weightc( 32, 36,  3)=                  0.58257817757354590782d0
      iwe=iwe+1
      weightc( 33, 36,  3)=                  0.15144108987456994520d0
      iwe=iwe+1
      weightc( 34, 36,  3)=                 -0.52981274525991906010d0
      iwe=iwe+1
      weightc( 35, 36,  3)=                  0.29519748004126195040d0
      iwe=iwe+1
      weightc( 36, 36,  3)=                 -0.40639838019030904981d0
      iwe=iwe+1
      weightc( 37, 36,  3)=                  0.40919878458991770787d0
      iwe=iwe+1
      weightc( 38, 36,  3)=                 -0.14918136327402478636d0
      iwe=iwe+1
      weightc( 39, 36,  3)=                 -0.10786752351116599136d0
      iwe=iwe+1
      weightc( 40, 36,  3)=                 -0.04968812920191639088d0
      iwe=iwe+1
      weightc( 41, 36,  3)=                  0.41114204625514017000d0
      iwe=iwe+1
      weightc( 42, 36,  3)=                 -0.08698306839404157387d0
      iwe=iwe+1
      weightc( 43, 36,  3)=                  0.09646866091366136653d0
      iwe=iwe+1
      weightc( 44, 36,  3)=                  0.41594682284338968525d0
      iwe=iwe+1
      weightc( 45, 36,  3)=                 -0.09959007486595067293d0
      iwe=iwe+1
      weightc( 46, 36,  3)=                  0.19983924953522091972d0
      iwe=iwe+1
      weightc( 47, 36,  3)=                  0.18667661981840047436d0
      iwe=iwe+1
      weightc( 48, 36,  3)=                 -0.11576660850404510428d0
      iwe=iwe+1
      weightc( 49, 36,  3)=                  0.23207268627567695374d0
      iwe=iwe+1
      weightc( 50, 36,  3)=                  0.33457252074990462276d0
      iwe=iwe+1
      biasc( 36,  3)=                 -0.11072563396287316007d0
      iwe=iwe+1
      weightc(  1, 37,  3)=                 -0.01500835200273547415d0
      iwe=iwe+1
      weightc(  2, 37,  3)=                 -0.06740903957772284572d0
      iwe=iwe+1
      weightc(  3, 37,  3)=                  0.01793352795419548423d0
      iwe=iwe+1
      weightc(  4, 37,  3)=                 -0.22634368378917985032d0
      iwe=iwe+1
      weightc(  5, 37,  3)=                 -0.16887143304014692879d0
      iwe=iwe+1
      weightc(  6, 37,  3)=                  0.27864195280975800895d0
      iwe=iwe+1
      weightc(  7, 37,  3)=                  0.04401706670230046831d0
      iwe=iwe+1
      weightc(  8, 37,  3)=                 -0.20917699113917662124d0
      iwe=iwe+1
      weightc(  9, 37,  3)=                 -0.38738384097341471701d0
      iwe=iwe+1
      weightc( 10, 37,  3)=                 -0.68921685939440535673d0
      iwe=iwe+1
      weightc( 11, 37,  3)=                 -0.97308043843105584969d0
      iwe=iwe+1
      weightc( 12, 37,  3)=                  0.21362326983607732300d0
      iwe=iwe+1
      weightc( 13, 37,  3)=                  0.30747557709108269686d0
      iwe=iwe+1
      weightc( 14, 37,  3)=                 -0.10366354055933488243d0
      iwe=iwe+1
      weightc( 15, 37,  3)=                  0.05199898308987087325d0
      iwe=iwe+1
      weightc( 16, 37,  3)=                 -0.01253249106182334309d0
      iwe=iwe+1
      weightc( 17, 37,  3)=                  0.04108681070379568284d0
      iwe=iwe+1
      weightc( 18, 37,  3)=                 -0.36460826933871082201d0
      iwe=iwe+1
      weightc( 19, 37,  3)=                 -0.02856229187737868713d0
      iwe=iwe+1
      weightc( 20, 37,  3)=                 -0.25939357772324672657d0
      iwe=iwe+1
      weightc( 21, 37,  3)=                 -0.07265624964905918748d0
      iwe=iwe+1
      weightc( 22, 37,  3)=                  0.21899273762620966033d0
      iwe=iwe+1
      weightc( 23, 37,  3)=                  0.63801650865930792378d0
      iwe=iwe+1
      weightc( 24, 37,  3)=                 -0.04220161123085046373d0
      iwe=iwe+1
      weightc( 25, 37,  3)=                 -0.38954195887179687841d0
      iwe=iwe+1
      weightc( 26, 37,  3)=                  0.25248884567211726804d0
      iwe=iwe+1
      weightc( 27, 37,  3)=                 -0.55848626323609140698d0
      iwe=iwe+1
      weightc( 28, 37,  3)=                  0.12818636320940554607d0
      iwe=iwe+1
      weightc( 29, 37,  3)=                 -0.01422099213645267209d0
      iwe=iwe+1
      weightc( 30, 37,  3)=                 -0.39764507311742364193d0
      iwe=iwe+1
      weightc( 31, 37,  3)=                 -0.05374858158240053418d0
      iwe=iwe+1
      weightc( 32, 37,  3)=                  0.16530259928987345308d0
      iwe=iwe+1
      weightc( 33, 37,  3)=                  0.17027089572102960258d0
      iwe=iwe+1
      weightc( 34, 37,  3)=                  0.53384633246937585049d0
      iwe=iwe+1
      weightc( 35, 37,  3)=                  0.14362411392394686116d0
      iwe=iwe+1
      weightc( 36, 37,  3)=                 -0.07530084848602178194d0
      iwe=iwe+1
      weightc( 37, 37,  3)=                  0.52843655875633976926d0
      iwe=iwe+1
      weightc( 38, 37,  3)=                  0.17022990491652159606d0
      iwe=iwe+1
      weightc( 39, 37,  3)=                  0.25450141690877736700d0
      iwe=iwe+1
      weightc( 40, 37,  3)=                  0.35977319267270430059d0
      iwe=iwe+1
      weightc( 41, 37,  3)=                 -0.20986180628261402736d0
      iwe=iwe+1
      weightc( 42, 37,  3)=                 -0.10015067169028024630d0
      iwe=iwe+1
      weightc( 43, 37,  3)=                 -0.30799181801520464363d0
      iwe=iwe+1
      weightc( 44, 37,  3)=                 -0.74178417035382071543d0
      iwe=iwe+1
      weightc( 45, 37,  3)=                 -0.07023549695259118097d0
      iwe=iwe+1
      weightc( 46, 37,  3)=                 -0.41292399652754885331d0
      iwe=iwe+1
      weightc( 47, 37,  3)=                 -0.30590270893646726025d0
      iwe=iwe+1
      weightc( 48, 37,  3)=                  0.19701219107749143311d0
      iwe=iwe+1
      weightc( 49, 37,  3)=                  0.14806996617962786544d0
      iwe=iwe+1
      weightc( 50, 37,  3)=                  0.21178678965059100081d0
      iwe=iwe+1
      biasc( 37,  3)=                  0.21452357877045233336d0
      iwe=iwe+1
      weightc(  1, 38,  3)=                  0.33861992785880118406d0
      iwe=iwe+1
      weightc(  2, 38,  3)=                  0.21075282126786468173d0
      iwe=iwe+1
      weightc(  3, 38,  3)=                  0.23290071923123159547d0
      iwe=iwe+1
      weightc(  4, 38,  3)=                  0.12678219178700292358d0
      iwe=iwe+1
      weightc(  5, 38,  3)=                  0.05241245727026779683d0
      iwe=iwe+1
      weightc(  6, 38,  3)=                 -0.00753727262305433146d0
      iwe=iwe+1
      weightc(  7, 38,  3)=                  0.13588210225548949528d0
      iwe=iwe+1
      weightc(  8, 38,  3)=                  0.21349368082007735836d0
      iwe=iwe+1
      weightc(  9, 38,  3)=                 -0.31825474869667258471d0
      iwe=iwe+1
      weightc( 10, 38,  3)=                  0.10675377980118744281d0
      iwe=iwe+1
      weightc( 11, 38,  3)=                  0.15743067358483397999d0
      iwe=iwe+1
      weightc( 12, 38,  3)=                 -0.21319768196377456015d0
      iwe=iwe+1
      weightc( 13, 38,  3)=                  0.43475782388741163187d0
      iwe=iwe+1
      weightc( 14, 38,  3)=                  0.06079843010419503507d0
      iwe=iwe+1
      weightc( 15, 38,  3)=                 -0.46369165491982938798d0
      iwe=iwe+1
      weightc( 16, 38,  3)=                  0.30686532240751890344d0
      iwe=iwe+1
      weightc( 17, 38,  3)=                 -0.26211411461970707260d0
      iwe=iwe+1
      weightc( 18, 38,  3)=                 -0.03629102298249480690d0
      iwe=iwe+1
      weightc( 19, 38,  3)=                  0.20212761660578318357d0
      iwe=iwe+1
      weightc( 20, 38,  3)=                  0.10415665418558951727d0
      iwe=iwe+1
      weightc( 21, 38,  3)=                  0.17620232106611230516d0
      iwe=iwe+1
      weightc( 22, 38,  3)=                 -0.17813244973834641005d0
      iwe=iwe+1
      weightc( 23, 38,  3)=                  0.15583630043837981560d0
      iwe=iwe+1
      weightc( 24, 38,  3)=                  0.30373865686393758390d0
      iwe=iwe+1
      weightc( 25, 38,  3)=                 -0.18690494901880339018d0
      iwe=iwe+1
      weightc( 26, 38,  3)=                  0.04063341403348547098d0
      iwe=iwe+1
      weightc( 27, 38,  3)=                 -0.11406622337504115916d0
      iwe=iwe+1
      weightc( 28, 38,  3)=                  0.31476829803898137561d0
      iwe=iwe+1
      weightc( 29, 38,  3)=                  0.40564896461976285291d0
      iwe=iwe+1
      weightc( 30, 38,  3)=                  0.06294668237932320165d0
      iwe=iwe+1
      weightc( 31, 38,  3)=                  0.10296655847429006525d0
      iwe=iwe+1
      weightc( 32, 38,  3)=                  0.44235672345452814458d0
      iwe=iwe+1
      weightc( 33, 38,  3)=                 -0.25947583954124170402d0
      iwe=iwe+1
      weightc( 34, 38,  3)=                  0.14231751798847430690d0
      iwe=iwe+1
      weightc( 35, 38,  3)=                 -0.19012103040311173485d0
      iwe=iwe+1
      weightc( 36, 38,  3)=                 -0.23204423723566555693d0
      iwe=iwe+1
      weightc( 37, 38,  3)=                  0.58605856348844687087d0
      iwe=iwe+1
      weightc( 38, 38,  3)=                 -0.10938091371857881773d0
      iwe=iwe+1
      weightc( 39, 38,  3)=                  0.12409187192456815063d0
      iwe=iwe+1
      weightc( 40, 38,  3)=                 -0.16536975139399273660d0
      iwe=iwe+1
      weightc( 41, 38,  3)=                  0.02507642102082185617d0
      iwe=iwe+1
      weightc( 42, 38,  3)=                  0.49836209932721819982d0
      iwe=iwe+1
      weightc( 43, 38,  3)=                 -0.13493934088535819438d0
      iwe=iwe+1
      weightc( 44, 38,  3)=                  0.34032494694029097326d0
      iwe=iwe+1
      weightc( 45, 38,  3)=                 -0.39580226176455074460d0
      iwe=iwe+1
      weightc( 46, 38,  3)=                 -0.19353887339021877412d0
      iwe=iwe+1
      weightc( 47, 38,  3)=                 -0.14697487308117862526d0
      iwe=iwe+1
      weightc( 48, 38,  3)=                  0.11064915542876274657d0
      iwe=iwe+1
      weightc( 49, 38,  3)=                 -0.08300612099431478597d0
      iwe=iwe+1
      weightc( 50, 38,  3)=                  0.08776594795139884553d0
      iwe=iwe+1
      biasc( 38,  3)=                 -0.15357271907636416142d0
      iwe=iwe+1
      weightc(  1, 39,  3)=                 -0.50032310526553613883d0
      iwe=iwe+1
      weightc(  2, 39,  3)=                 -0.00521782923493082414d0
      iwe=iwe+1
      weightc(  3, 39,  3)=                 -0.14456403036346510138d0
      iwe=iwe+1
      weightc(  4, 39,  3)=                  0.18041261264476643467d0
      iwe=iwe+1
      weightc(  5, 39,  3)=                  0.17243484684209844926d0
      iwe=iwe+1
      weightc(  6, 39,  3)=                 -0.18003773720162760674d0
      iwe=iwe+1
      weightc(  7, 39,  3)=                 -0.00310196920962824401d0
      iwe=iwe+1
      weightc(  8, 39,  3)=                 -0.05174195447092713035d0
      iwe=iwe+1
      weightc(  9, 39,  3)=                  0.36147878563059965273d0
      iwe=iwe+1
      weightc( 10, 39,  3)=                 -0.51430059554409424116d0
      iwe=iwe+1
      weightc( 11, 39,  3)=                  0.29560745201831722939d0
      iwe=iwe+1
      weightc( 12, 39,  3)=                  0.31675179729136532236d0
      iwe=iwe+1
      weightc( 13, 39,  3)=                 -0.45883871821484367715d0
      iwe=iwe+1
      weightc( 14, 39,  3)=                  0.02079623215964443439d0
      iwe=iwe+1
      weightc( 15, 39,  3)=                  0.01997218751284510208d0
      iwe=iwe+1
      weightc( 16, 39,  3)=                  0.05358944318176702554d0
      iwe=iwe+1
      weightc( 17, 39,  3)=                  0.53182612448533705951d0
      iwe=iwe+1
      weightc( 18, 39,  3)=                  0.21133192077508980433d0
      iwe=iwe+1
      weightc( 19, 39,  3)=                  0.35276229296460037688d0
      iwe=iwe+1
      weightc( 20, 39,  3)=                  0.01497893942016483709d0
      iwe=iwe+1
      weightc( 21, 39,  3)=                 -0.05527041162852194822d0
      iwe=iwe+1
      weightc( 22, 39,  3)=                  0.13254581662722234037d0
      iwe=iwe+1
      weightc( 23, 39,  3)=                  0.13023298135093103189d0
      iwe=iwe+1
      weightc( 24, 39,  3)=                  0.10316087298309639664d0
      iwe=iwe+1
      weightc( 25, 39,  3)=                 -0.26233648215663224468d0
      iwe=iwe+1
      weightc( 26, 39,  3)=                 -0.42097228504782147063d0
      iwe=iwe+1
      weightc( 27, 39,  3)=                  0.04099859216342060381d0
      iwe=iwe+1
      weightc( 28, 39,  3)=                  0.05346936232898857888d0
      iwe=iwe+1
      weightc( 29, 39,  3)=                 -0.00900989973635320240d0
      iwe=iwe+1
      weightc( 30, 39,  3)=                  0.07917219993656614274d0
      iwe=iwe+1
      weightc( 31, 39,  3)=                  0.01092852105139577659d0
      iwe=iwe+1
      weightc( 32, 39,  3)=                 -0.28583847227405162483d0
      iwe=iwe+1
      weightc( 33, 39,  3)=                 -0.20545328737189860746d0
      iwe=iwe+1
      weightc( 34, 39,  3)=                 -0.16267244907531827613d0
      iwe=iwe+1
      weightc( 35, 39,  3)=                 -0.25144514178563448503d0
      iwe=iwe+1
      weightc( 36, 39,  3)=                  0.22591549046546574586d0
      iwe=iwe+1
      weightc( 37, 39,  3)=                 -0.17318201249117420870d0
      iwe=iwe+1
      weightc( 38, 39,  3)=                 -0.24376081351796713426d0
      iwe=iwe+1
      weightc( 39, 39,  3)=                  0.01949729960690745056d0
      iwe=iwe+1
      weightc( 40, 39,  3)=                  0.04095753677299984741d0
      iwe=iwe+1
      weightc( 41, 39,  3)=                  0.33518863410142318848d0
      iwe=iwe+1
      weightc( 42, 39,  3)=                 -0.12708858512041890099d0
      iwe=iwe+1
      weightc( 43, 39,  3)=                 -0.15146076973986921654d0
      iwe=iwe+1
      weightc( 44, 39,  3)=                  0.32775557698321566846d0
      iwe=iwe+1
      weightc( 45, 39,  3)=                  0.10072037567198365016d0
      iwe=iwe+1
      weightc( 46, 39,  3)=                  0.27571113148230552703d0
      iwe=iwe+1
      weightc( 47, 39,  3)=                 -0.21170034948078672588d0
      iwe=iwe+1
      weightc( 48, 39,  3)=                 -0.11214092636314605678d0
      iwe=iwe+1
      weightc( 49, 39,  3)=                 -0.80075097939063610841d0
      iwe=iwe+1
      weightc( 50, 39,  3)=                  0.03097614277510747985d0
      iwe=iwe+1
      biasc( 39,  3)=                  0.09360740120184697644d0
      iwe=iwe+1
      weightc(  1, 40,  3)=                 -0.50604473019979034909d0
      iwe=iwe+1
      weightc(  2, 40,  3)=                  0.01455017324692485688d0
      iwe=iwe+1
      weightc(  3, 40,  3)=                  0.25328281242544908869d0
      iwe=iwe+1
      weightc(  4, 40,  3)=                 -0.09835849806691124297d0
      iwe=iwe+1
      weightc(  5, 40,  3)=                 -0.30355407459098360246d0
      iwe=iwe+1
      weightc(  6, 40,  3)=                  0.44652307078552061492d0
      iwe=iwe+1
      weightc(  7, 40,  3)=                  0.13349483659897834475d0
      iwe=iwe+1
      weightc(  8, 40,  3)=                 -0.20978498128927589028d0
      iwe=iwe+1
      weightc(  9, 40,  3)=                  0.25486860702307778670d0
      iwe=iwe+1
      weightc( 10, 40,  3)=                 -0.07414232299146174265d0
      iwe=iwe+1
      weightc( 11, 40,  3)=                  0.02206735628248939970d0
      iwe=iwe+1
      weightc( 12, 40,  3)=                 -0.26149343878776215577d0
      iwe=iwe+1
      weightc( 13, 40,  3)=                  0.17508841014027645699d0
      iwe=iwe+1
      weightc( 14, 40,  3)=                  0.25691698617300584573d0
      iwe=iwe+1
      weightc( 15, 40,  3)=                  0.17758550612113399580d0
      iwe=iwe+1
      weightc( 16, 40,  3)=                 -0.12657646552935211681d0
      iwe=iwe+1
      weightc( 17, 40,  3)=                 -0.07414574063769210910d0
      iwe=iwe+1
      weightc( 18, 40,  3)=                 -0.11965442428668421337d0
      iwe=iwe+1
      weightc( 19, 40,  3)=                  0.25497985264080713641d0
      iwe=iwe+1
      weightc( 20, 40,  3)=                 -0.57416690649444002137d0
      iwe=iwe+1
      weightc( 21, 40,  3)=                  0.22650088944751151088d0
      iwe=iwe+1
      weightc( 22, 40,  3)=                  0.21919923272999194963d0
      iwe=iwe+1
      weightc( 23, 40,  3)=                  0.10750415682735706135d0
      iwe=iwe+1
      weightc( 24, 40,  3)=                  0.02324355770013154104d0
      iwe=iwe+1
      weightc( 25, 40,  3)=                  0.45135050713112107035d0
      iwe=iwe+1
      weightc( 26, 40,  3)=                 -0.39625290326249090755d0
      iwe=iwe+1
      weightc( 27, 40,  3)=                 -0.20065991975581698448d0
      iwe=iwe+1
      weightc( 28, 40,  3)=                  0.42156719904772205210d0
      iwe=iwe+1
      weightc( 29, 40,  3)=                 -0.43447280958362294312d0
      iwe=iwe+1
      weightc( 30, 40,  3)=                  0.05957988114588699813d0
      iwe=iwe+1
      weightc( 31, 40,  3)=                  0.26260954433208566483d0
      iwe=iwe+1
      weightc( 32, 40,  3)=                  0.02005232743624266872d0
      iwe=iwe+1
      weightc( 33, 40,  3)=                  0.28124551046891360651d0
      iwe=iwe+1
      weightc( 34, 40,  3)=                 -0.49514393200560408159d0
      iwe=iwe+1
      weightc( 35, 40,  3)=                  0.23733634245299309318d0
      iwe=iwe+1
      weightc( 36, 40,  3)=                  0.20105002375142871918d0
      iwe=iwe+1
      weightc( 37, 40,  3)=                  0.29566275726834301274d0
      iwe=iwe+1
      weightc( 38, 40,  3)=                  0.36742853126543850717d0
      iwe=iwe+1
      weightc( 39, 40,  3)=                 -0.48237994116208759987d0
      iwe=iwe+1
      weightc( 40, 40,  3)=                  0.04597220817609062871d0
      iwe=iwe+1
      weightc( 41, 40,  3)=                 -0.18021007474745626142d0
      iwe=iwe+1
      weightc( 42, 40,  3)=                 -0.10245624864927392605d0
      iwe=iwe+1
      weightc( 43, 40,  3)=                  0.03681600315137284474d0
      iwe=iwe+1
      weightc( 44, 40,  3)=                 -0.23243194103174613652d0
      iwe=iwe+1
      weightc( 45, 40,  3)=                 -0.20699832042988189351d0
      iwe=iwe+1
      weightc( 46, 40,  3)=                  0.08978335630014976088d0
      iwe=iwe+1
      weightc( 47, 40,  3)=                 -0.10542152647802954801d0
      iwe=iwe+1
      weightc( 48, 40,  3)=                 -0.37362286953240025911d0
      iwe=iwe+1
      weightc( 49, 40,  3)=                  0.10672446728942303062d0
      iwe=iwe+1
      weightc( 50, 40,  3)=                 -0.29643457877083956298d0
      iwe=iwe+1
      biasc( 40,  3)=                  0.16251833437075244304d0
      iwe=iwe+1
      weightc(  1, 41,  3)=                  0.15771089050900277684d0
      iwe=iwe+1
      weightc(  2, 41,  3)=                 -0.11640651433729566622d0
      iwe=iwe+1
      weightc(  3, 41,  3)=                  0.07086921014521950501d0
      iwe=iwe+1
      weightc(  4, 41,  3)=                  0.06779388870007671541d0
      iwe=iwe+1
      weightc(  5, 41,  3)=                  0.23428979121176893297d0
      iwe=iwe+1
      weightc(  6, 41,  3)=                  0.22697154564022037349d0
      iwe=iwe+1
      weightc(  7, 41,  3)=                 -0.14535543501764397467d0
      iwe=iwe+1
      weightc(  8, 41,  3)=                 -0.25989352855125463782d0
      iwe=iwe+1
      weightc(  9, 41,  3)=                  0.30624170781322934687d0
      iwe=iwe+1
      weightc( 10, 41,  3)=                 -0.40134116775438766211d0
      iwe=iwe+1
      weightc( 11, 41,  3)=                  0.43466164095608939011d0
      iwe=iwe+1
      weightc( 12, 41,  3)=                 -0.30687715886140820576d0
      iwe=iwe+1
      weightc( 13, 41,  3)=                 -0.26714671730172440123d0
      iwe=iwe+1
      weightc( 14, 41,  3)=                  0.12709926092634288297d0
      iwe=iwe+1
      weightc( 15, 41,  3)=                 -0.61817960621004786059d0
      iwe=iwe+1
      weightc( 16, 41,  3)=                 -0.11584340409074669886d0
      iwe=iwe+1
      weightc( 17, 41,  3)=                 -0.13292300358981873343d0
      iwe=iwe+1
      weightc( 18, 41,  3)=                  0.03886904814168581912d0
      iwe=iwe+1
      weightc( 19, 41,  3)=                 -0.09409236171296381235d0
      iwe=iwe+1
      weightc( 20, 41,  3)=                  0.49917827965998518014d0
      iwe=iwe+1
      weightc( 21, 41,  3)=                  0.20412447670809064082d0
      iwe=iwe+1
      weightc( 22, 41,  3)=                  0.85948033176527216526d0
      iwe=iwe+1
      weightc( 23, 41,  3)=                  0.14692161896407895938d0
      iwe=iwe+1
      weightc( 24, 41,  3)=                  0.23967624465442927129d0
      iwe=iwe+1
      weightc( 25, 41,  3)=                 -0.03333253343075300024d0
      iwe=iwe+1
      weightc( 26, 41,  3)=                 -0.12196746271446362586d0
      iwe=iwe+1
      weightc( 27, 41,  3)=                 -0.27636826957980109576d0
      iwe=iwe+1
      weightc( 28, 41,  3)=                  0.21585752212091208202d0
      iwe=iwe+1
      weightc( 29, 41,  3)=                 -0.23712056343452472817d0
      iwe=iwe+1
      weightc( 30, 41,  3)=                  0.03585248345094550759d0
      iwe=iwe+1
      weightc( 31, 41,  3)=                 -0.17181221749853148317d0
      iwe=iwe+1
      weightc( 32, 41,  3)=                  0.22379520273765660110d0
      iwe=iwe+1
      weightc( 33, 41,  3)=                 -0.41055011101747618252d0
      iwe=iwe+1
      weightc( 34, 41,  3)=                  0.32189357679173158377d0
      iwe=iwe+1
      weightc( 35, 41,  3)=                  0.36300625606944680879d0
      iwe=iwe+1
      weightc( 36, 41,  3)=                 -0.27758526135784278299d0
      iwe=iwe+1
      weightc( 37, 41,  3)=                  0.24017646041365994791d0
      iwe=iwe+1
      weightc( 38, 41,  3)=                 -0.46096252582495572669d0
      iwe=iwe+1
      weightc( 39, 41,  3)=                  0.28565936004201453180d0
      iwe=iwe+1
      weightc( 40, 41,  3)=                  0.02269259194616921743d0
      iwe=iwe+1
      weightc( 41, 41,  3)=                  0.16232599988008888925d0
      iwe=iwe+1
      weightc( 42, 41,  3)=                  0.46882765045699503759d0
      iwe=iwe+1
      weightc( 43, 41,  3)=                 -0.13338971924422721171d0
      iwe=iwe+1
      weightc( 44, 41,  3)=                  0.06811486897479110403d0
      iwe=iwe+1
      weightc( 45, 41,  3)=                  0.20016195510099590860d0
      iwe=iwe+1
      weightc( 46, 41,  3)=                  0.24933732648146117450d0
      iwe=iwe+1
      weightc( 47, 41,  3)=                  0.02786590422877000331d0
      iwe=iwe+1
      weightc( 48, 41,  3)=                  0.39833746596123886796d0
      iwe=iwe+1
      weightc( 49, 41,  3)=                 -0.33929662563112050755d0
      iwe=iwe+1
      weightc( 50, 41,  3)=                 -0.04705412766980489325d0
      iwe=iwe+1
      biasc( 41,  3)=                 -0.07993885716354084958d0
      iwe=iwe+1
      weightc(  1, 42,  3)=                  0.29636056884697814517d0
      iwe=iwe+1
      weightc(  2, 42,  3)=                  0.29622193056087620100d0
      iwe=iwe+1
      weightc(  3, 42,  3)=                 -0.37245589740330359296d0
      iwe=iwe+1
      weightc(  4, 42,  3)=                 -0.18522166049548557942d0
      iwe=iwe+1
      weightc(  5, 42,  3)=                  0.15009512428058610634d0
      iwe=iwe+1
      weightc(  6, 42,  3)=                 -0.01741401096050245248d0
      iwe=iwe+1
      weightc(  7, 42,  3)=                  0.22055867148291574686d0
      iwe=iwe+1
      weightc(  8, 42,  3)=                  0.18851253612669324755d0
      iwe=iwe+1
      weightc(  9, 42,  3)=                  0.21972634505837743135d0
      iwe=iwe+1
      weightc( 10, 42,  3)=                 -0.22022917629166258169d0
      iwe=iwe+1
      weightc( 11, 42,  3)=                  0.01062182962613653775d0
      iwe=iwe+1
      weightc( 12, 42,  3)=                  0.10824389085712318725d0
      iwe=iwe+1
      weightc( 13, 42,  3)=                  0.30264863101186018080d0
      iwe=iwe+1
      weightc( 14, 42,  3)=                  0.33175992323939212936d0
      iwe=iwe+1
      weightc( 15, 42,  3)=                  0.41303662073167068947d0
      iwe=iwe+1
      weightc( 16, 42,  3)=                  0.43641468808134065149d0
      iwe=iwe+1
      weightc( 17, 42,  3)=                 -0.42684301956124998112d0
      iwe=iwe+1
      weightc( 18, 42,  3)=                 -0.03262280222833412874d0
      iwe=iwe+1
      weightc( 19, 42,  3)=                  0.17620987271637011951d0
      iwe=iwe+1
      weightc( 20, 42,  3)=                  0.13576176056262123648d0
      iwe=iwe+1
      weightc( 21, 42,  3)=                 -0.25273069625497929236d0
      iwe=iwe+1
      weightc( 22, 42,  3)=                 -0.20676572727595901591d0
      iwe=iwe+1
      weightc( 23, 42,  3)=                  0.48101237463749324519d0
      iwe=iwe+1
      weightc( 24, 42,  3)=                 -0.17550920935387459565d0
      iwe=iwe+1
      weightc( 25, 42,  3)=                 -0.23358792302216099812d0
      iwe=iwe+1
      weightc( 26, 42,  3)=                  0.32992959651909287144d0
      iwe=iwe+1
      weightc( 27, 42,  3)=                  0.05322210230499482136d0
      iwe=iwe+1
      weightc( 28, 42,  3)=                 -0.17902350540285585923d0
      iwe=iwe+1
      weightc( 29, 42,  3)=                  0.17760336557825304182d0
      iwe=iwe+1
      weightc( 30, 42,  3)=                  0.29059783537893796312d0
      iwe=iwe+1
      weightc( 31, 42,  3)=                 -0.24360325853498990267d0
      iwe=iwe+1
      weightc( 32, 42,  3)=                  0.04340625801628154173d0
      iwe=iwe+1
      weightc( 33, 42,  3)=                  0.31776043959307925801d0
      iwe=iwe+1
      weightc( 34, 42,  3)=                 -0.28474650842663928874d0
      iwe=iwe+1
      weightc( 35, 42,  3)=                  0.34207443875236659414d0
      iwe=iwe+1
      weightc( 36, 42,  3)=                  0.29442791787218730581d0
      iwe=iwe+1
      weightc( 37, 42,  3)=                  0.23197703595084098738d0
      iwe=iwe+1
      weightc( 38, 42,  3)=                 -0.43024047677493598707d0
      iwe=iwe+1
      weightc( 39, 42,  3)=                  0.02282281142734381499d0
      iwe=iwe+1
      weightc( 40, 42,  3)=                  0.06616380607922131563d0
      iwe=iwe+1
      weightc( 41, 42,  3)=                  0.26151081407991094707d0
      iwe=iwe+1
      weightc( 42, 42,  3)=                  0.34056017175578601197d0
      iwe=iwe+1
      weightc( 43, 42,  3)=                  0.23641278431085205325d0
      iwe=iwe+1
      weightc( 44, 42,  3)=                  0.06370965492649485751d0
      iwe=iwe+1
      weightc( 45, 42,  3)=                  0.23673748518774126448d0
      iwe=iwe+1
      weightc( 46, 42,  3)=                 -0.03094748942216645968d0
      iwe=iwe+1
      weightc( 47, 42,  3)=                 -0.28836221195299854836d0
      iwe=iwe+1
      weightc( 48, 42,  3)=                 -0.09824139151171840112d0
      iwe=iwe+1
      weightc( 49, 42,  3)=                  0.08816083852753570094d0
      iwe=iwe+1
      weightc( 50, 42,  3)=                 -0.35497375261169394900d0
      iwe=iwe+1
      biasc( 42,  3)=                 -0.00033263618280742369d0
      iwe=iwe+1
      weightc(  1, 43,  3)=                  0.19747980675984075360d0
      iwe=iwe+1
      weightc(  2, 43,  3)=                  0.10433984990170340479d0
      iwe=iwe+1
      weightc(  3, 43,  3)=                 -0.39482548495068081618d0
      iwe=iwe+1
      weightc(  4, 43,  3)=                  0.05628256379989559494d0
      iwe=iwe+1
      weightc(  5, 43,  3)=                 -0.12863492521559696802d0
      iwe=iwe+1
      weightc(  6, 43,  3)=                 -0.40867907131481046035d0
      iwe=iwe+1
      weightc(  7, 43,  3)=                 -0.08329219085335652639d0
      iwe=iwe+1
      weightc(  8, 43,  3)=                 -0.22968593207996215733d0
      iwe=iwe+1
      weightc(  9, 43,  3)=                  0.23179309817714494057d0
      iwe=iwe+1
      weightc( 10, 43,  3)=                  0.23346720515764388115d0
      iwe=iwe+1
      weightc( 11, 43,  3)=                 -0.49942723623550644430d0
      iwe=iwe+1
      weightc( 12, 43,  3)=                  0.26372576520848689530d0
      iwe=iwe+1
      weightc( 13, 43,  3)=                  0.02672635473663972569d0
      iwe=iwe+1
      weightc( 14, 43,  3)=                  0.10595580133788475019d0
      iwe=iwe+1
      weightc( 15, 43,  3)=                  0.16690816759832816096d0
      iwe=iwe+1
      weightc( 16, 43,  3)=                 -0.13493904235955164750d0
      iwe=iwe+1
      weightc( 17, 43,  3)=                 -0.15090732988354385591d0
      iwe=iwe+1
      weightc( 18, 43,  3)=                 -0.20809553336299380089d0
      iwe=iwe+1
      weightc( 19, 43,  3)=                 -0.09640487368394376477d0
      iwe=iwe+1
      weightc( 20, 43,  3)=                  0.19107610309544875715d0
      iwe=iwe+1
      weightc( 21, 43,  3)=                  0.35294071419741568363d0
      iwe=iwe+1
      weightc( 22, 43,  3)=                  0.06975473719937144712d0
      iwe=iwe+1
      weightc( 23, 43,  3)=                 -0.25422778939776863316d0
      iwe=iwe+1
      weightc( 24, 43,  3)=                 -0.21273840936597351869d0
      iwe=iwe+1
      weightc( 25, 43,  3)=                  0.11424297318041710947d0
      iwe=iwe+1
      weightc( 26, 43,  3)=                  0.36845930823905742590d0
      iwe=iwe+1
      weightc( 27, 43,  3)=                 -0.12494532111880603253d0
      iwe=iwe+1
      weightc( 28, 43,  3)=                 -0.19381216132620823767d0
      iwe=iwe+1
      weightc( 29, 43,  3)=                 -0.21220196583336636831d0
      iwe=iwe+1
      weightc( 30, 43,  3)=                 -0.07139416250348087911d0
      iwe=iwe+1
      weightc( 31, 43,  3)=                  0.33779405908420295779d0
      iwe=iwe+1
      weightc( 32, 43,  3)=                 -0.31306393617103689397d0
      iwe=iwe+1
      weightc( 33, 43,  3)=                  0.24475630797969119556d0
      iwe=iwe+1
      weightc( 34, 43,  3)=                 -0.52804851829769527960d0
      iwe=iwe+1
      weightc( 35, 43,  3)=                  0.15443866235770115081d0
      iwe=iwe+1
      weightc( 36, 43,  3)=                 -0.13325253419133031851d0
      iwe=iwe+1
      weightc( 37, 43,  3)=                 -0.36105420243772623490d0
      iwe=iwe+1
      weightc( 38, 43,  3)=                  0.18989100959155719162d0
      iwe=iwe+1
      weightc( 39, 43,  3)=                 -0.47969977763885163213d0
      iwe=iwe+1
      weightc( 40, 43,  3)=                  0.27063461991594184308d0
      iwe=iwe+1
      weightc( 41, 43,  3)=                  0.11546784695509676455d0
      iwe=iwe+1
      weightc( 42, 43,  3)=                 -0.05861904990028143914d0
      iwe=iwe+1
      weightc( 43, 43,  3)=                  0.33223121889950185670d0
      iwe=iwe+1
      weightc( 44, 43,  3)=                 -0.14540285817794182388d0
      iwe=iwe+1
      weightc( 45, 43,  3)=                  0.28994367055070774386d0
      iwe=iwe+1
      weightc( 46, 43,  3)=                 -0.11796845731125465973d0
      iwe=iwe+1
      weightc( 47, 43,  3)=                  0.01398882951232892358d0
      iwe=iwe+1
      weightc( 48, 43,  3)=                  0.04648264884633591248d0
      iwe=iwe+1
      weightc( 49, 43,  3)=                 -0.85582402316493799699d0
      iwe=iwe+1
      weightc( 50, 43,  3)=                 -0.15853242572433609570d0
      iwe=iwe+1
      biasc( 43,  3)=                 -0.03063284805155735285d0
      iwe=iwe+1
      weightc(  1, 44,  3)=                  0.45723495344144926555d0
      iwe=iwe+1
      weightc(  2, 44,  3)=                 -0.01219074816248369789d0
      iwe=iwe+1
      weightc(  3, 44,  3)=                 -0.12744182159122968701d0
      iwe=iwe+1
      weightc(  4, 44,  3)=                  0.10101419784423773529d0
      iwe=iwe+1
      weightc(  5, 44,  3)=                  0.30594070332996703421d0
      iwe=iwe+1
      weightc(  6, 44,  3)=                  0.30467378485376533925d0
      iwe=iwe+1
      weightc(  7, 44,  3)=                  0.30334069058474388836d0
      iwe=iwe+1
      weightc(  8, 44,  3)=                 -0.33091660309184267597d0
      iwe=iwe+1
      weightc(  9, 44,  3)=                 -0.43329112029808908302d0
      iwe=iwe+1
      weightc( 10, 44,  3)=                  0.26930613650963514116d0
      iwe=iwe+1
      weightc( 11, 44,  3)=                 -0.00978678236531791562d0
      iwe=iwe+1
      weightc( 12, 44,  3)=                  0.13486189257907443828d0
      iwe=iwe+1
      weightc( 13, 44,  3)=                  0.29561571932060015655d0
      iwe=iwe+1
      weightc( 14, 44,  3)=                  0.12262167316726900468d0
      iwe=iwe+1
      weightc( 15, 44,  3)=                 -0.36900424484727706309d0
      iwe=iwe+1
      weightc( 16, 44,  3)=                 -0.28881689960496553793d0
      iwe=iwe+1
      weightc( 17, 44,  3)=                  0.03750450223348339440d0
      iwe=iwe+1
      weightc( 18, 44,  3)=                  0.14312279821711815231d0
      iwe=iwe+1
      weightc( 19, 44,  3)=                 -0.15950333093812404939d0
      iwe=iwe+1
      weightc( 20, 44,  3)=                  0.40085238050999172366d0
      iwe=iwe+1
      weightc( 21, 44,  3)=                 -0.39412875221389548352d0
      iwe=iwe+1
      weightc( 22, 44,  3)=                  0.11660446979422470215d0
      iwe=iwe+1
      weightc( 23, 44,  3)=                 -0.37776726180811348588d0
      iwe=iwe+1
      weightc( 24, 44,  3)=                 -0.10828797382185587073d0
      iwe=iwe+1
      weightc( 25, 44,  3)=                  0.40804268718222680423d0
      iwe=iwe+1
      weightc( 26, 44,  3)=                  0.27787744173062006725d0
      iwe=iwe+1
      weightc( 27, 44,  3)=                  0.30951704928992501697d0
      iwe=iwe+1
      weightc( 28, 44,  3)=                  0.20452005070645237761d0
      iwe=iwe+1
      weightc( 29, 44,  3)=                 -0.36803699615052759553d0
      iwe=iwe+1
      weightc( 30, 44,  3)=                  0.21393477717399844718d0
      iwe=iwe+1
      weightc( 31, 44,  3)=                 -0.26236805800150841961d0
      iwe=iwe+1
      weightc( 32, 44,  3)=                  0.17223853721863235933d0
      iwe=iwe+1
      weightc( 33, 44,  3)=                  0.28953623915361342833d0
      iwe=iwe+1
      weightc( 34, 44,  3)=                 -0.42382264336275593530d0
      iwe=iwe+1
      weightc( 35, 44,  3)=                 -0.09773916742196084306d0
      iwe=iwe+1
      weightc( 36, 44,  3)=                 -0.32962522195742871567d0
      iwe=iwe+1
      weightc( 37, 44,  3)=                  0.25760342050660484103d0
      iwe=iwe+1
      weightc( 38, 44,  3)=                 -0.17821303056655524166d0
      iwe=iwe+1
      weightc( 39, 44,  3)=                  0.33863210929983084130d0
      iwe=iwe+1
      weightc( 40, 44,  3)=                 -0.09835481736435282285d0
      iwe=iwe+1
      weightc( 41, 44,  3)=                 -0.09628943042406422348d0
      iwe=iwe+1
      weightc( 42, 44,  3)=                 -0.01507284814442185969d0
      iwe=iwe+1
      weightc( 43, 44,  3)=                 -0.35337084186326306323d0
      iwe=iwe+1
      weightc( 44, 44,  3)=                 -0.09842286264940738882d0
      iwe=iwe+1
      weightc( 45, 44,  3)=                 -0.15582551514722356445d0
      iwe=iwe+1
      weightc( 46, 44,  3)=                 -0.00553316254584364491d0
      iwe=iwe+1
      weightc( 47, 44,  3)=                  0.11527833490041633491d0
      iwe=iwe+1
      weightc( 48, 44,  3)=                 -0.29234014095346000373d0
      iwe=iwe+1
      weightc( 49, 44,  3)=                  0.47823716367149249340d0
      iwe=iwe+1
      weightc( 50, 44,  3)=                  0.28902818934188378996d0
      iwe=iwe+1
      biasc( 44,  3)=                  0.19908784864635897804d0
      iwe=iwe+1
      weightc(  1, 45,  3)=                 -0.03410994839655524802d0
      iwe=iwe+1
      weightc(  2, 45,  3)=                  0.39140223780053712277d0
      iwe=iwe+1
      weightc(  3, 45,  3)=                 -0.20836378532021637700d0
      iwe=iwe+1
      weightc(  4, 45,  3)=                 -0.15569179371452068761d0
      iwe=iwe+1
      weightc(  5, 45,  3)=                 -0.24966741774196271608d0
      iwe=iwe+1
      weightc(  6, 45,  3)=                  0.07418380978173694240d0
      iwe=iwe+1
      weightc(  7, 45,  3)=                  0.30020951733426848307d0
      iwe=iwe+1
      weightc(  8, 45,  3)=                 -0.34023427606387152133d0
      iwe=iwe+1
      weightc(  9, 45,  3)=                 -0.64879162236096710181d0
      iwe=iwe+1
      weightc( 10, 45,  3)=                 -0.02066667233031162926d0
      iwe=iwe+1
      weightc( 11, 45,  3)=                  0.15195684669113015963d0
      iwe=iwe+1
      weightc( 12, 45,  3)=                  0.16512148758051384267d0
      iwe=iwe+1
      weightc( 13, 45,  3)=                  0.13411686412152737380d0
      iwe=iwe+1
      weightc( 14, 45,  3)=                 -0.33926138958586377070d0
      iwe=iwe+1
      weightc( 15, 45,  3)=                 -0.12964012473206437681d0
      iwe=iwe+1
      weightc( 16, 45,  3)=                 -0.18661133710735583469d0
      iwe=iwe+1
      weightc( 17, 45,  3)=                 -0.26840613741351421195d0
      iwe=iwe+1
      weightc( 18, 45,  3)=                  0.30391975471638171813d0
      iwe=iwe+1
      weightc( 19, 45,  3)=                 -0.18295407010888906085d0
      iwe=iwe+1
      weightc( 20, 45,  3)=                 -0.17579652404384532582d0
      iwe=iwe+1
      weightc( 21, 45,  3)=                  0.03749751320096079282d0
      iwe=iwe+1
      weightc( 22, 45,  3)=                 -0.06880909839497095781d0
      iwe=iwe+1
      weightc( 23, 45,  3)=                 -0.46983958705391681843d0
      iwe=iwe+1
      weightc( 24, 45,  3)=                 -0.12165366748215239445d0
      iwe=iwe+1
      weightc( 25, 45,  3)=                  0.30151242495520724773d0
      iwe=iwe+1
      weightc( 26, 45,  3)=                 -0.10042766246954339115d0
      iwe=iwe+1
      weightc( 27, 45,  3)=                 -0.07024050995045884316d0
      iwe=iwe+1
      weightc( 28, 45,  3)=                 -0.26339623436492048958d0
      iwe=iwe+1
      weightc( 29, 45,  3)=                  0.22301904627565868888d0
      iwe=iwe+1
      weightc( 30, 45,  3)=                  0.26549809426086040665d0
      iwe=iwe+1
      weightc( 31, 45,  3)=                 -0.22739817504623227595d0
      iwe=iwe+1
      weightc( 32, 45,  3)=                  0.13771001724602985328d0
      iwe=iwe+1
      weightc( 33, 45,  3)=                 -0.26646163375561898734d0
      iwe=iwe+1
      weightc( 34, 45,  3)=                  0.31271121561558962165d0
      iwe=iwe+1
      weightc( 35, 45,  3)=                 -0.05303470036606159482d0
      iwe=iwe+1
      weightc( 36, 45,  3)=                 -0.03979101990407321598d0
      iwe=iwe+1
      weightc( 37, 45,  3)=                 -0.02647788489634993192d0
      iwe=iwe+1
      weightc( 38, 45,  3)=                 -0.32960805201020215716d0
      iwe=iwe+1
      weightc( 39, 45,  3)=                 -0.08695822602829048065d0
      iwe=iwe+1
      weightc( 40, 45,  3)=                 -0.10019507441329526809d0
      iwe=iwe+1
      weightc( 41, 45,  3)=                  0.29826509601298106800d0
      iwe=iwe+1
      weightc( 42, 45,  3)=                 -0.06754286566291264893d0
      iwe=iwe+1
      weightc( 43, 45,  3)=                 -0.43598463003359738677d0
      iwe=iwe+1
      weightc( 44, 45,  3)=                 -0.36463779779109412038d0
      iwe=iwe+1
      weightc( 45, 45,  3)=                 -0.11044349160181203551d0
      iwe=iwe+1
      weightc( 46, 45,  3)=                 -0.06304212364294375925d0
      iwe=iwe+1
      weightc( 47, 45,  3)=                 -0.07523159185036998320d0
      iwe=iwe+1
      weightc( 48, 45,  3)=                  0.46413295889352462753d0
      iwe=iwe+1
      weightc( 49, 45,  3)=                  0.19871409808464138291d0
      iwe=iwe+1
      weightc( 50, 45,  3)=                  0.30115913866578292168d0
      iwe=iwe+1
      biasc( 45,  3)=                 -0.11428077657489776886d0
      iwe=iwe+1
      weightc(  1, 46,  3)=                 -0.03807166509620932282d0
      iwe=iwe+1
      weightc(  2, 46,  3)=                  0.23700928125239412170d0
      iwe=iwe+1
      weightc(  3, 46,  3)=                 -0.26699412784716453073d0
      iwe=iwe+1
      weightc(  4, 46,  3)=                  0.41394028564404083959d0
      iwe=iwe+1
      weightc(  5, 46,  3)=                 -0.26573044166942427768d0
      iwe=iwe+1
      weightc(  6, 46,  3)=                 -0.01648053548674215801d0
      iwe=iwe+1
      weightc(  7, 46,  3)=                 -0.14675780112940292610d0
      iwe=iwe+1
      weightc(  8, 46,  3)=                  0.26886186024110392268d0
      iwe=iwe+1
      weightc(  9, 46,  3)=                  0.26768940796717610731d0
      iwe=iwe+1
      weightc( 10, 46,  3)=                 -0.42994541311185990873d0
      iwe=iwe+1
      weightc( 11, 46,  3)=                  0.03068510900893043486d0
      iwe=iwe+1
      weightc( 12, 46,  3)=                  0.25127727408942596155d0
      iwe=iwe+1
      weightc( 13, 46,  3)=                 -0.40418523412408380313d0
      iwe=iwe+1
      weightc( 14, 46,  3)=                  0.21072764812528943512d0
      iwe=iwe+1
      weightc( 15, 46,  3)=                  0.48253207031853451170d0
      iwe=iwe+1
      weightc( 16, 46,  3)=                 -0.20418618527302268006d0
      iwe=iwe+1
      weightc( 17, 46,  3)=                 -0.33555781463711620294d0
      iwe=iwe+1
      weightc( 18, 46,  3)=                  0.65092682917128086295d0
      iwe=iwe+1
      weightc( 19, 46,  3)=                 -0.04228770240335892605d0
      iwe=iwe+1
      weightc( 20, 46,  3)=                  0.06118646388371231509d0
      iwe=iwe+1
      weightc( 21, 46,  3)=                  0.31652356782495466581d0
      iwe=iwe+1
      weightc( 22, 46,  3)=                 -0.26243581061633142193d0
      iwe=iwe+1
      weightc( 23, 46,  3)=                  0.27957697352610816344d0
      iwe=iwe+1
      weightc( 24, 46,  3)=                 -0.02093249705181057796d0
      iwe=iwe+1
      weightc( 25, 46,  3)=                 -0.34542001702340080493d0
      iwe=iwe+1
      weightc( 26, 46,  3)=                  0.23536515009062222714d0
      iwe=iwe+1
      weightc( 27, 46,  3)=                 -0.12506971433254376880d0
      iwe=iwe+1
      weightc( 28, 46,  3)=                  0.27865759344612156534d0
      iwe=iwe+1
      weightc( 29, 46,  3)=                 -0.46781444190432591723d0
      iwe=iwe+1
      weightc( 30, 46,  3)=                  0.34125130975591827509d0
      iwe=iwe+1
      weightc( 31, 46,  3)=                 -0.38536322681903378840d0
      iwe=iwe+1
      weightc( 32, 46,  3)=                 -0.22996136722323096135d0
      iwe=iwe+1
      weightc( 33, 46,  3)=                 -0.06287750335845510019d0
      iwe=iwe+1
      weightc( 34, 46,  3)=                  0.11821450807008673789d0
      iwe=iwe+1
      weightc( 35, 46,  3)=                  0.01578401585051051811d0
      iwe=iwe+1
      weightc( 36, 46,  3)=                  0.19162562109898376161d0
      iwe=iwe+1
      weightc( 37, 46,  3)=                  0.49753645493133225042d0
      iwe=iwe+1
      weightc( 38, 46,  3)=                 -0.30232053082224952245d0
      iwe=iwe+1
      weightc( 39, 46,  3)=                  0.01429879121188084440d0
      iwe=iwe+1
      weightc( 40, 46,  3)=                  0.49277370414192961379d0
      iwe=iwe+1
      weightc( 41, 46,  3)=                  0.14052605872369339224d0
      iwe=iwe+1
      weightc( 42, 46,  3)=                 -0.13402401226500421094d0
      iwe=iwe+1
      weightc( 43, 46,  3)=                 -0.36692523918246500170d0
      iwe=iwe+1
      weightc( 44, 46,  3)=                 -0.18900300294544900015d0
      iwe=iwe+1
      weightc( 45, 46,  3)=                 -0.27881021243821751954d0
      iwe=iwe+1
      weightc( 46, 46,  3)=                 -0.09060329018082451114d0
      iwe=iwe+1
      weightc( 47, 46,  3)=                 -0.08902414409459122324d0
      iwe=iwe+1
      weightc( 48, 46,  3)=                  0.02230324012028136668d0
      iwe=iwe+1
      weightc( 49, 46,  3)=                 -0.09139255164978549173d0
      iwe=iwe+1
      weightc( 50, 46,  3)=                  0.49562884633688891745d0
      iwe=iwe+1
      biasc( 46,  3)=                  0.21333365391166672631d0
      iwe=iwe+1
      weightc(  1, 47,  3)=                  0.12271249100602742155d0
      iwe=iwe+1
      weightc(  2, 47,  3)=                  0.92180602788414911508d0
      iwe=iwe+1
      weightc(  3, 47,  3)=                  0.44199254500347723296d0
      iwe=iwe+1
      weightc(  4, 47,  3)=                 -0.19157310967244528532d0
      iwe=iwe+1
      weightc(  5, 47,  3)=                  0.20398680804316948745d0
      iwe=iwe+1
      weightc(  6, 47,  3)=                  0.02147266451200755683d0
      iwe=iwe+1
      weightc(  7, 47,  3)=                  0.03079355185167435144d0
      iwe=iwe+1
      weightc(  8, 47,  3)=                 -0.36600149590213348905d0
      iwe=iwe+1
      weightc(  9, 47,  3)=                 -0.28996499675350440040d0
      iwe=iwe+1
      weightc( 10, 47,  3)=                 -0.16470091501291053704d0
      iwe=iwe+1
      weightc( 11, 47,  3)=                  0.44259703233450220505d0
      iwe=iwe+1
      weightc( 12, 47,  3)=                 -0.22538062488969826114d0
      iwe=iwe+1
      weightc( 13, 47,  3)=                 -0.28333786536529731448d0
      iwe=iwe+1
      weightc( 14, 47,  3)=                  0.20877932147923303208d0
      iwe=iwe+1
      weightc( 15, 47,  3)=                 -0.25678225237770152534d0
      iwe=iwe+1
      weightc( 16, 47,  3)=                  0.25995840261076602618d0
      iwe=iwe+1
      weightc( 17, 47,  3)=                  0.13314795586089051005d0
      iwe=iwe+1
      weightc( 18, 47,  3)=                  0.21551972315172054917d0
      iwe=iwe+1
      weightc( 19, 47,  3)=                  0.12029891939734121964d0
      iwe=iwe+1
      weightc( 20, 47,  3)=                 -0.09670211721597089805d0
      iwe=iwe+1
      weightc( 21, 47,  3)=                  0.58427484704908816404d0
      iwe=iwe+1
      weightc( 22, 47,  3)=                  0.23951846912187824135d0
      iwe=iwe+1
      weightc( 23, 47,  3)=                 -0.64981346569828923876d0
      iwe=iwe+1
      weightc( 24, 47,  3)=                 -0.06048522567714906956d0
      iwe=iwe+1
      weightc( 25, 47,  3)=                  0.26402581715395939677d0
      iwe=iwe+1
      weightc( 26, 47,  3)=                  0.33452657841475147427d0
      iwe=iwe+1
      weightc( 27, 47,  3)=                 -0.46387460579643124969d0
      iwe=iwe+1
      weightc( 28, 47,  3)=                 -0.44701783657842297792d0
      iwe=iwe+1
      weightc( 29, 47,  3)=                  0.28688876905474636203d0
      iwe=iwe+1
      weightc( 30, 47,  3)=                 -0.40703172899979528365d0
      iwe=iwe+1
      weightc( 31, 47,  3)=                 -0.62420224783743716301d0
      iwe=iwe+1
      weightc( 32, 47,  3)=                  0.27654625444242614263d0
      iwe=iwe+1
      weightc( 33, 47,  3)=                  0.05697139570434650580d0
      iwe=iwe+1
      weightc( 34, 47,  3)=                 -0.01991633097684807063d0
      iwe=iwe+1
      weightc( 35, 47,  3)=                 -0.27624411942718274382d0
      iwe=iwe+1
      weightc( 36, 47,  3)=                  0.49001111834813843027d0
      iwe=iwe+1
      weightc( 37, 47,  3)=                 -0.32575023614650344683d0
      iwe=iwe+1
      weightc( 38, 47,  3)=                 -0.22346425506816078310d0
      iwe=iwe+1
      weightc( 39, 47,  3)=                 -0.10335396668887809890d0
      iwe=iwe+1
      weightc( 40, 47,  3)=                 -0.02755721231732304738d0
      iwe=iwe+1
      weightc( 41, 47,  3)=                 -0.37729056881881545271d0
      iwe=iwe+1
      weightc( 42, 47,  3)=                  0.05775276643201517762d0
      iwe=iwe+1
      weightc( 43, 47,  3)=                  0.27363534461549932075d0
      iwe=iwe+1
      weightc( 44, 47,  3)=                 -0.07337141764023143164d0
      iwe=iwe+1
      weightc( 45, 47,  3)=                 -0.05618725069105878767d0
      iwe=iwe+1
      weightc( 46, 47,  3)=                 -0.10612549224332741560d0
      iwe=iwe+1
      weightc( 47, 47,  3)=                  0.44781589792579362674d0
      iwe=iwe+1
      weightc( 48, 47,  3)=                 -0.25568752830985286284d0
      iwe=iwe+1
      weightc( 49, 47,  3)=                 -0.29965509629386527513d0
      iwe=iwe+1
      weightc( 50, 47,  3)=                  0.09574500524794582468d0
      iwe=iwe+1
      biasc( 47,  3)=                  0.02727823341492438547d0
      iwe=iwe+1
      weightc(  1, 48,  3)=                  0.77112296210033104416d0
      iwe=iwe+1
      weightc(  2, 48,  3)=                  0.69574766608518112676d0
      iwe=iwe+1
      weightc(  3, 48,  3)=                  0.02985137778339742864d0
      iwe=iwe+1
      weightc(  4, 48,  3)=                  0.08193378987883748188d0
      iwe=iwe+1
      weightc(  5, 48,  3)=                  0.27110218807253133599d0
      iwe=iwe+1
      weightc(  6, 48,  3)=                  0.09413268166423209571d0
      iwe=iwe+1
      weightc(  7, 48,  3)=                 -0.27482998003638670070d0
      iwe=iwe+1
      weightc(  8, 48,  3)=                 -0.61729488794631359738d0
      iwe=iwe+1
      weightc(  9, 48,  3)=                 -0.36140454825470902378d0
      iwe=iwe+1
      weightc( 10, 48,  3)=                  0.16449851153868394471d0
      iwe=iwe+1
      weightc( 11, 48,  3)=                  0.52333068950701278066d0
      iwe=iwe+1
      weightc( 12, 48,  3)=                 -0.45882380784508747240d0
      iwe=iwe+1
      weightc( 13, 48,  3)=                 -0.02360278186409904555d0
      iwe=iwe+1
      weightc( 14, 48,  3)=                 -0.05325052127617605630d0
      iwe=iwe+1
      weightc( 15, 48,  3)=                 -0.06387874061366653755d0
      iwe=iwe+1
      weightc( 16, 48,  3)=                 -0.15023149900850701899d0
      iwe=iwe+1
      weightc( 17, 48,  3)=                 -0.05356215075002830617d0
      iwe=iwe+1
      weightc( 18, 48,  3)=                 -0.56643072799483584756d0
      iwe=iwe+1
      weightc( 19, 48,  3)=                 -0.02371369126218289200d0
      iwe=iwe+1
      weightc( 20, 48,  3)=                 -0.63756371372151510180d0
      iwe=iwe+1
      weightc( 21, 48,  3)=                  0.29220337623708625419d0
      iwe=iwe+1
      weightc( 22, 48,  3)=                 -0.45605594261365306474d0
      iwe=iwe+1
      weightc( 23, 48,  3)=                 -0.04772039065897024090d0
      iwe=iwe+1
      weightc( 24, 48,  3)=                  0.21155315722776524279d0
      iwe=iwe+1
      weightc( 25, 48,  3)=                  0.20721430063876661309d0
      iwe=iwe+1
      weightc( 26, 48,  3)=                  0.40844592967656284666d0
      iwe=iwe+1
      weightc( 27, 48,  3)=                 -0.35604407442430796582d0
      iwe=iwe+1
      weightc( 28, 48,  3)=                 -0.24175814809550874585d0
      iwe=iwe+1
      weightc( 29, 48,  3)=                 -0.45459585150454812075d0
      iwe=iwe+1
      weightc( 30, 48,  3)=                 -0.17674071043416489379d0
      iwe=iwe+1
      weightc( 31, 48,  3)=                  0.12542720241061208752d0
      iwe=iwe+1
      weightc( 32, 48,  3)=                  0.42607703763110671424d0
      iwe=iwe+1
      weightc( 33, 48,  3)=                  0.51587845005941868060d0
      iwe=iwe+1
      weightc( 34, 48,  3)=                  0.12005441992442507371d0
      iwe=iwe+1
      weightc( 35, 48,  3)=                  0.66687965423633310813d0
      iwe=iwe+1
      weightc( 36, 48,  3)=                  0.31634144077099113357d0
      iwe=iwe+1
      weightc( 37, 48,  3)=                 -0.04098101505269229061d0
      iwe=iwe+1
      weightc( 38, 48,  3)=                 -0.04531201461580176143d0
      iwe=iwe+1
      weightc( 39, 48,  3)=                  0.02435513345089988790d0
      iwe=iwe+1
      weightc( 40, 48,  3)=                 -0.15506253803455341544d0
      iwe=iwe+1
      weightc( 41, 48,  3)=                 -0.11003599691929882853d0
      iwe=iwe+1
      weightc( 42, 48,  3)=                 -0.53453160449375092256d0
      iwe=iwe+1
      weightc( 43, 48,  3)=                 -0.26656185303032592371d0
      iwe=iwe+1
      weightc( 44, 48,  3)=                  0.18743962965574170743d0
      iwe=iwe+1
      weightc( 45, 48,  3)=                 -0.25276679830250459169d0
      iwe=iwe+1
      weightc( 46, 48,  3)=                  0.41332158457779138994d0
      iwe=iwe+1
      weightc( 47, 48,  3)=                  0.17692797610800584107d0
      iwe=iwe+1
      weightc( 48, 48,  3)=                 -0.50968352998121302377d0
      iwe=iwe+1
      weightc( 49, 48,  3)=                  0.14346134113930114617d0
      iwe=iwe+1
      weightc( 50, 48,  3)=                 -0.05923739476999810571d0
      iwe=iwe+1
      biasc( 48,  3)=                  0.41027194440594644265d0
      iwe=iwe+1
      weightc(  1, 49,  3)=                 -0.10843617391531956695d0
      iwe=iwe+1
      weightc(  2, 49,  3)=                 -0.10097948656828102665d0
      iwe=iwe+1
      weightc(  3, 49,  3)=                  0.46038194468482862565d0
      iwe=iwe+1
      weightc(  4, 49,  3)=                  0.08002854072274522002d0
      iwe=iwe+1
      weightc(  5, 49,  3)=                  0.41497397039612349268d0
      iwe=iwe+1
      weightc(  6, 49,  3)=                 -0.21411661047965505067d0
      iwe=iwe+1
      weightc(  7, 49,  3)=                 -0.07532370868373648720d0
      iwe=iwe+1
      weightc(  8, 49,  3)=                 -0.20070566948445900390d0
      iwe=iwe+1
      weightc(  9, 49,  3)=                 -0.05484211421784832702d0
      iwe=iwe+1
      weightc( 10, 49,  3)=                  0.05789485847702346977d0
      iwe=iwe+1
      weightc( 11, 49,  3)=                 -0.16117264884634305289d0
      iwe=iwe+1
      weightc( 12, 49,  3)=                  0.44999972664053772275d0
      iwe=iwe+1
      weightc( 13, 49,  3)=                 -0.21844409341058843022d0
      iwe=iwe+1
      weightc( 14, 49,  3)=                  0.23585644868180960509d0
      iwe=iwe+1
      weightc( 15, 49,  3)=                 -0.18212572627949916160d0
      iwe=iwe+1
      weightc( 16, 49,  3)=                  0.09481858138059155727d0
      iwe=iwe+1
      weightc( 17, 49,  3)=                  0.46803074739951311400d0
      iwe=iwe+1
      weightc( 18, 49,  3)=                 -0.32390687788100913647d0
      iwe=iwe+1
      weightc( 19, 49,  3)=                 -0.61112880672437930318d0
      iwe=iwe+1
      weightc( 20, 49,  3)=                  0.18483424448530211270d0
      iwe=iwe+1
      weightc( 21, 49,  3)=                  0.48329561276001170578d0
      iwe=iwe+1
      weightc( 22, 49,  3)=                  0.48404753562889274443d0
      iwe=iwe+1
      weightc( 23, 49,  3)=                 -0.42122401098935163821d0
      iwe=iwe+1
      weightc( 24, 49,  3)=                 -0.07155388484932749538d0
      iwe=iwe+1
      weightc( 25, 49,  3)=                  0.02276674776523511523d0
      iwe=iwe+1
      weightc( 26, 49,  3)=                  0.02989800918913899583d0
      iwe=iwe+1
      weightc( 27, 49,  3)=                  0.33854177046266831219d0
      iwe=iwe+1
      weightc( 28, 49,  3)=                  0.00509228708358066672d0
      iwe=iwe+1
      weightc( 29, 49,  3)=                 -0.41521886691465043073d0
      iwe=iwe+1
      weightc( 30, 49,  3)=                 -0.05903555696912852341d0
      iwe=iwe+1
      weightc( 31, 49,  3)=                  0.48325397144286030837d0
      iwe=iwe+1
      weightc( 32, 49,  3)=                  0.81822024396169901195d0
      iwe=iwe+1
      weightc( 33, 49,  3)=                 -0.19373911042347502498d0
      iwe=iwe+1
      weightc( 34, 49,  3)=                  0.25280420715279633415d0
      iwe=iwe+1
      weightc( 35, 49,  3)=                  0.23676568652829593775d0
      iwe=iwe+1
      weightc( 36, 49,  3)=                  0.24188171048656201267d0
      iwe=iwe+1
      weightc( 37, 49,  3)=                  0.08472288437377527293d0
      iwe=iwe+1
      weightc( 38, 49,  3)=                 -0.15436936378318816265d0
      iwe=iwe+1
      weightc( 39, 49,  3)=                  0.10942885668609381167d0
      iwe=iwe+1
      weightc( 40, 49,  3)=                 -0.24181362316803228785d0
      iwe=iwe+1
      weightc( 41, 49,  3)=                  0.16618256049115037731d0
      iwe=iwe+1
      weightc( 42, 49,  3)=                  0.45024091399173538086d0
      iwe=iwe+1
      weightc( 43, 49,  3)=                 -0.07223872310023954357d0
      iwe=iwe+1
      weightc( 44, 49,  3)=                  0.23717281388978095347d0
      iwe=iwe+1
      weightc( 45, 49,  3)=                 -0.67204741582577898207d0
      iwe=iwe+1
      weightc( 46, 49,  3)=                  0.02504105494579308283d0
      iwe=iwe+1
      weightc( 47, 49,  3)=                 -0.08932017863900588994d0
      iwe=iwe+1
      weightc( 48, 49,  3)=                 -0.39245995336324468461d0
      iwe=iwe+1
      weightc( 49, 49,  3)=                  0.01713577901656765032d0
      iwe=iwe+1
      weightc( 50, 49,  3)=                 -0.57370697575209717023d0
      iwe=iwe+1
      biasc( 49,  3)=                  0.28122115183422807805d0
      iwe=iwe+1
      weightc(  1, 50,  3)=                 -0.00395073576063351920d0
      iwe=iwe+1
      weightc(  2, 50,  3)=                  0.41246116870867610693d0
      iwe=iwe+1
      weightc(  3, 50,  3)=                  0.12412953572946980318d0
      iwe=iwe+1
      weightc(  4, 50,  3)=                 -0.18569103594051183936d0
      iwe=iwe+1
      weightc(  5, 50,  3)=                  0.03596924650115111699d0
      iwe=iwe+1
      weightc(  6, 50,  3)=                 -0.47387815599660776389d0
      iwe=iwe+1
      weightc(  7, 50,  3)=                  0.00376754789646838563d0
      iwe=iwe+1
      weightc(  8, 50,  3)=                 -0.58498360830126361343d0
      iwe=iwe+1
      weightc(  9, 50,  3)=                 -0.01308957983480579790d0
      iwe=iwe+1
      weightc( 10, 50,  3)=                 -0.41918177868274181241d0
      iwe=iwe+1
      weightc( 11, 50,  3)=                 -0.10398364527514988853d0
      iwe=iwe+1
      weightc( 12, 50,  3)=                 -0.25367973087947881528d0
      iwe=iwe+1
      weightc( 13, 50,  3)=                  0.18821667016121867988d0
      iwe=iwe+1
      weightc( 14, 50,  3)=                  0.07612910484961979418d0
      iwe=iwe+1
      weightc( 15, 50,  3)=                 -0.77615473296722747865d0
      iwe=iwe+1
      weightc( 16, 50,  3)=                 -0.05986215119293290116d0
      iwe=iwe+1
      weightc( 17, 50,  3)=                 -0.25366906787440268722d0
      iwe=iwe+1
      weightc( 18, 50,  3)=                  0.60538932993762184509d0
      iwe=iwe+1
      weightc( 19, 50,  3)=                  0.22923313877797119043d0
      iwe=iwe+1
      weightc( 20, 50,  3)=                  0.29435381175034147638d0
      iwe=iwe+1
      weightc( 21, 50,  3)=                 -0.27506350359229303493d0
      iwe=iwe+1
      weightc( 22, 50,  3)=                  0.02527806616045464444d0
      iwe=iwe+1
      weightc( 23, 50,  3)=                 -0.36143858713943993743d0
      iwe=iwe+1
      weightc( 24, 50,  3)=                  0.04614426495946939710d0
      iwe=iwe+1
      weightc( 25, 50,  3)=                 -0.00820298106090700321d0
      iwe=iwe+1
      weightc( 26, 50,  3)=                 -0.27679894304634455882d0
      iwe=iwe+1
      weightc( 27, 50,  3)=                 -0.05390407926604369460d0
      iwe=iwe+1
      weightc( 28, 50,  3)=                 -0.62970804349497122576d0
      iwe=iwe+1
      weightc( 29, 50,  3)=                 -0.15403584062637590280d0
      iwe=iwe+1
      weightc( 30, 50,  3)=                 -0.07480378497292236584d0
      iwe=iwe+1
      weightc( 31, 50,  3)=                 -0.66794455517980111381d0
      iwe=iwe+1
      weightc( 32, 50,  3)=                  0.15151426416085606030d0
      iwe=iwe+1
      weightc( 33, 50,  3)=                 -0.09227427885425576459d0
      iwe=iwe+1
      weightc( 34, 50,  3)=                  0.05097121411097919885d0
      iwe=iwe+1
      weightc( 35, 50,  3)=                 -0.23422184729996309294d0
      iwe=iwe+1
      weightc( 36, 50,  3)=                  0.12486187884745870991d0
      iwe=iwe+1
      weightc( 37, 50,  3)=                 -0.31543050314391696265d0
      iwe=iwe+1
      weightc( 38, 50,  3)=                  0.00115086133864144517d0
      iwe=iwe+1
      weightc( 39, 50,  3)=                 -0.00314992153262261005d0
      iwe=iwe+1
      weightc( 40, 50,  3)=                 -0.00639786395591254112d0
      iwe=iwe+1
      weightc( 41, 50,  3)=                  0.13200030849341928829d0
      iwe=iwe+1
      weightc( 42, 50,  3)=                 -0.00132467502156964883d0
      iwe=iwe+1
      weightc( 43, 50,  3)=                  0.22764693584865003384d0
      iwe=iwe+1
      weightc( 44, 50,  3)=                 -0.47726142205941152197d0
      iwe=iwe+1
      weightc( 45, 50,  3)=                  0.08623639150298477440d0
      iwe=iwe+1
      weightc( 46, 50,  3)=                  0.42377399291109241197d0
      iwe=iwe+1
      weightc( 47, 50,  3)=                  0.09742541465400823830d0
      iwe=iwe+1
      weightc( 48, 50,  3)=                 -0.00742371889671220898d0
      iwe=iwe+1
      weightc( 49, 50,  3)=                 -0.47439591664997227127d0
      iwe=iwe+1
      weightc( 50, 50,  3)=                 -0.48321610663033087718d0
      iwe=iwe+1
      biasc( 50,  3)=                  0.28826622797143813814d0
      iwe=iwe+1
      weightc(  1, 51,  3)=                 -0.01614672694394352070d0
      iwe=iwe+1
      weightc(  2, 51,  3)=                 -0.37129673448489430854d0
      iwe=iwe+1
      weightc(  3, 51,  3)=                  0.03155623275476933387d0
      iwe=iwe+1
      weightc(  4, 51,  3)=                  0.08235420008869648312d0
      iwe=iwe+1
      weightc(  5, 51,  3)=                  0.00322516677489605684d0
      iwe=iwe+1
      weightc(  6, 51,  3)=                  0.03211893440841324249d0
      iwe=iwe+1
      weightc(  7, 51,  3)=                  0.17207139176916733114d0
      iwe=iwe+1
      weightc(  8, 51,  3)=                  0.66386645717306802528d0
      iwe=iwe+1
      weightc(  9, 51,  3)=                 -0.09345035384922938115d0
      iwe=iwe+1
      weightc( 10, 51,  3)=                 -0.31835395462413523804d0
      iwe=iwe+1
      weightc( 11, 51,  3)=                 -0.14758984988898371515d0
      iwe=iwe+1
      weightc( 12, 51,  3)=                  0.19463661415922314801d0
      iwe=iwe+1
      weightc( 13, 51,  3)=                  0.11431015711042225025d0
      iwe=iwe+1
      weightc( 14, 51,  3)=                 -0.28471150736434308604d0
      iwe=iwe+1
      weightc( 15, 51,  3)=                  0.27170306707653335554d0
      iwe=iwe+1
      weightc( 16, 51,  3)=                 -0.10420510805316716973d0
      iwe=iwe+1
      weightc( 17, 51,  3)=                 -0.32415218815194546398d0
      iwe=iwe+1
      weightc( 18, 51,  3)=                  0.22526779568750601723d0
      iwe=iwe+1
      weightc( 19, 51,  3)=                  0.38702481284975415177d0
      iwe=iwe+1
      weightc( 20, 51,  3)=                 -0.05191484558938383453d0
      iwe=iwe+1
      weightc( 21, 51,  3)=                 -0.03052891903028908532d0
      iwe=iwe+1
      weightc( 22, 51,  3)=                  0.28682230038448636167d0
      iwe=iwe+1
      weightc( 23, 51,  3)=                  0.22737050533015873421d0
      iwe=iwe+1
      weightc( 24, 51,  3)=                  0.72809063237399784807d0
      iwe=iwe+1
      weightc( 25, 51,  3)=                 -0.07399556203376680963d0
      iwe=iwe+1
      weightc( 26, 51,  3)=                  0.15958598684571503878d0
      iwe=iwe+1
      weightc( 27, 51,  3)=                 -0.65901711070062529707d0
      iwe=iwe+1
      weightc( 28, 51,  3)=                  0.31842231265635068116d0
      iwe=iwe+1
      weightc( 29, 51,  3)=                 -0.32358464988189977740d0
      iwe=iwe+1
      weightc( 30, 51,  3)=                 -0.28297182233581419375d0
      iwe=iwe+1
      weightc( 31, 51,  3)=                  0.07597328447845230759d0
      iwe=iwe+1
      weightc( 32, 51,  3)=                 -0.21029217512518058597d0
      iwe=iwe+1
      weightc( 33, 51,  3)=                 -0.24690907412869592119d0
      iwe=iwe+1
      weightc( 34, 51,  3)=                  0.10620003566352571867d0
      iwe=iwe+1
      weightc( 35, 51,  3)=                  0.23737939205104899298d0
      iwe=iwe+1
      weightc( 36, 51,  3)=                 -0.21641089596327559019d0
      iwe=iwe+1
      weightc( 37, 51,  3)=                 -0.20496981429952981779d0
      iwe=iwe+1
      weightc( 38, 51,  3)=                 -0.18751858799850032455d0
      iwe=iwe+1
      weightc( 39, 51,  3)=                  0.16393853923926485217d0
      iwe=iwe+1
      weightc( 40, 51,  3)=                  0.20853046233820349276d0
      iwe=iwe+1
      weightc( 41, 51,  3)=                  0.01927967682676551275d0
      iwe=iwe+1
      weightc( 42, 51,  3)=                 -0.08956330287985604655d0
      iwe=iwe+1
      weightc( 43, 51,  3)=                  0.04374508853389762197d0
      iwe=iwe+1
      weightc( 44, 51,  3)=                  0.63210219965282699039d0
      iwe=iwe+1
      weightc( 45, 51,  3)=                  0.11636523865943765310d0
      iwe=iwe+1
      weightc( 46, 51,  3)=                 -0.37362649811906051278d0
      iwe=iwe+1
      weightc( 47, 51,  3)=                  0.13410220065883196594d0
      iwe=iwe+1
      weightc( 48, 51,  3)=                  0.54707850877691932556d0
      iwe=iwe+1
      weightc( 49, 51,  3)=                  0.31605236206742315375d0
      iwe=iwe+1
      weightc( 50, 51,  3)=                 -0.30263716505531773615d0
      iwe=iwe+1
      biasc( 51,  3)=                 -0.49401690109634754933d0
      iwe=iwe+1
      weightc(  1, 52,  3)=                  0.59571976189832587245d0
      iwe=iwe+1
      weightc(  2, 52,  3)=                  0.07689448153551460552d0
      iwe=iwe+1
      weightc(  3, 52,  3)=                 -0.32955230679958563700d0
      iwe=iwe+1
      weightc(  4, 52,  3)=                 -0.29820409629675570518d0
      iwe=iwe+1
      weightc(  5, 52,  3)=                  0.37867074099692532574d0
      iwe=iwe+1
      weightc(  6, 52,  3)=                 -0.02209735797256624779d0
      iwe=iwe+1
      weightc(  7, 52,  3)=                 -0.23047055939364732846d0
      iwe=iwe+1
      weightc(  8, 52,  3)=                 -0.37112185175150202987d0
      iwe=iwe+1
      weightc(  9, 52,  3)=                  0.24847668219800439493d0
      iwe=iwe+1
      weightc( 10, 52,  3)=                  0.25787770089620348779d0
      iwe=iwe+1
      weightc( 11, 52,  3)=                  0.26426803113526231570d0
      iwe=iwe+1
      weightc( 12, 52,  3)=                  0.14954604757421630090d0
      iwe=iwe+1
      weightc( 13, 52,  3)=                 -0.03626326929014142553d0
      iwe=iwe+1
      weightc( 14, 52,  3)=                  0.19171676976606000231d0
      iwe=iwe+1
      weightc( 15, 52,  3)=                 -0.36967013559798123090d0
      iwe=iwe+1
      weightc( 16, 52,  3)=                 -0.12193798895605938160d0
      iwe=iwe+1
      weightc( 17, 52,  3)=                  0.22439844331330685567d0
      iwe=iwe+1
      weightc( 18, 52,  3)=                  0.13824723049465276192d0
      iwe=iwe+1
      weightc( 19, 52,  3)=                  0.16983604910954608336d0
      iwe=iwe+1
      weightc( 20, 52,  3)=                 -0.47426373345692796057d0
      iwe=iwe+1
      weightc( 21, 52,  3)=                 -0.09415452526198944683d0
      iwe=iwe+1
      weightc( 22, 52,  3)=                 -0.12505267135331282757d0
      iwe=iwe+1
      weightc( 23, 52,  3)=                 -0.03602803011791667204d0
      iwe=iwe+1
      weightc( 24, 52,  3)=                  0.10092308960311734134d0
      iwe=iwe+1
      weightc( 25, 52,  3)=                  0.20517487831112851682d0
      iwe=iwe+1
      weightc( 26, 52,  3)=                 -0.07142016168339071491d0
      iwe=iwe+1
      weightc( 27, 52,  3)=                 -0.23707852796631881387d0
      iwe=iwe+1
      weightc( 28, 52,  3)=                 -0.24527121849215882676d0
      iwe=iwe+1
      weightc( 29, 52,  3)=                 -0.07116173938978320734d0
      iwe=iwe+1
      weightc( 30, 52,  3)=                  0.01508970369433660849d0
      iwe=iwe+1
      weightc( 31, 52,  3)=                 -0.05442673032784069165d0
      iwe=iwe+1
      weightc( 32, 52,  3)=                 -0.12497737857543392281d0
      iwe=iwe+1
      weightc( 33, 52,  3)=                  0.16188564906198946169d0
      iwe=iwe+1
      weightc( 34, 52,  3)=                  0.26119697092213783884d0
      iwe=iwe+1
      weightc( 35, 52,  3)=                 -0.03182120770438721241d0
      iwe=iwe+1
      weightc( 36, 52,  3)=                 -0.19317494488544897924d0
      iwe=iwe+1
      weightc( 37, 52,  3)=                 -0.47572363353366448058d0
      iwe=iwe+1
      weightc( 38, 52,  3)=                 -0.09526412151187257926d0
      iwe=iwe+1
      weightc( 39, 52,  3)=                  0.11603568088073010212d0
      iwe=iwe+1
      weightc( 40, 52,  3)=                 -0.43691790767217536517d0
      iwe=iwe+1
      weightc( 41, 52,  3)=                 -0.09733677312303273821d0
      iwe=iwe+1
      weightc( 42, 52,  3)=                  0.04304014686497573822d0
      iwe=iwe+1
      weightc( 43, 52,  3)=                  0.24981825467142723673d0
      iwe=iwe+1
      weightc( 44, 52,  3)=                  0.30744395768836763061d0
      iwe=iwe+1
      weightc( 45, 52,  3)=                 -0.21822462060374084314d0
      iwe=iwe+1
      weightc( 46, 52,  3)=                 -0.25732839830686082827d0
      iwe=iwe+1
      weightc( 47, 52,  3)=                 -0.12978277560528686529d0
      iwe=iwe+1
      weightc( 48, 52,  3)=                 -0.05846412192986389506d0
      iwe=iwe+1
      weightc( 49, 52,  3)=                  0.04994313817213857920d0
      iwe=iwe+1
      weightc( 50, 52,  3)=                  0.17502466574290442836d0
      iwe=iwe+1
      biasc( 52,  3)=                 -0.61555816676847752156d0
      iwe=iwe+1
      weightc(  1, 53,  3)=                  0.03147206864666102222d0
      iwe=iwe+1
      weightc(  2, 53,  3)=                  0.42406476249631430697d0
      iwe=iwe+1
      weightc(  3, 53,  3)=                  0.16698639717361460355d0
      iwe=iwe+1
      weightc(  4, 53,  3)=                 -0.21658121453647399823d0
      iwe=iwe+1
      weightc(  5, 53,  3)=                 -0.16108929678880615222d0
      iwe=iwe+1
      weightc(  6, 53,  3)=                  0.00779742680311549131d0
      iwe=iwe+1
      weightc(  7, 53,  3)=                  0.19314859576302162436d0
      iwe=iwe+1
      weightc(  8, 53,  3)=                 -0.16056564586662558369d0
      iwe=iwe+1
      weightc(  9, 53,  3)=                 -0.62147350509887344661d0
      iwe=iwe+1
      weightc( 10, 53,  3)=                 -0.03443592140835566306d0
      iwe=iwe+1
      weightc( 11, 53,  3)=                  0.32891719705718730493d0
      iwe=iwe+1
      weightc( 12, 53,  3)=                  0.31170624638120719707d0
      iwe=iwe+1
      weightc( 13, 53,  3)=                 -0.71963329734186409770d0
      iwe=iwe+1
      weightc( 14, 53,  3)=                 -0.21399124594081006534d0
      iwe=iwe+1
      weightc( 15, 53,  3)=                 -0.43729297934313188234d0
      iwe=iwe+1
      weightc( 16, 53,  3)=                 -0.17274762172795068982d0
      iwe=iwe+1
      weightc( 17, 53,  3)=                 -0.42868756932777135615d0
      iwe=iwe+1
      weightc( 18, 53,  3)=                  0.00226561003940638694d0
      iwe=iwe+1
      weightc( 19, 53,  3)=                  0.22146871066787443549d0
      iwe=iwe+1
      weightc( 20, 53,  3)=                 -0.02030338375895889003d0
      iwe=iwe+1
      weightc( 21, 53,  3)=                  0.01286874338330631223d0
      iwe=iwe+1
      weightc( 22, 53,  3)=                 -0.75850928866852607158d0
      iwe=iwe+1
      weightc( 23, 53,  3)=                 -0.35203647448207275872d0
      iwe=iwe+1
      weightc( 24, 53,  3)=                  0.26016067651690089058d0
      iwe=iwe+1
      weightc( 25, 53,  3)=                 -0.10008198533393325436d0
      iwe=iwe+1
      weightc( 26, 53,  3)=                  0.56261914271792001774d0
      iwe=iwe+1
      weightc( 27, 53,  3)=                 -0.42621632992318397859d0
      iwe=iwe+1
      weightc( 28, 53,  3)=                 -0.03361884177691266962d0
      iwe=iwe+1
      weightc( 29, 53,  3)=                  0.06537800490125342256d0
      iwe=iwe+1
      weightc( 30, 53,  3)=                 -0.21813497446282811842d0
      iwe=iwe+1
      weightc( 31, 53,  3)=                 -0.15625481903109278425d0
      iwe=iwe+1
      weightc( 32, 53,  3)=                  0.33661620685090498650d0
      iwe=iwe+1
      weightc( 33, 53,  3)=                 -0.08021719618570773147d0
      iwe=iwe+1
      weightc( 34, 53,  3)=                  0.18282682094290914065d0
      iwe=iwe+1
      weightc( 35, 53,  3)=                 -0.48617604180605700215d0
      iwe=iwe+1
      weightc( 36, 53,  3)=                  0.15461035681932203123d0
      iwe=iwe+1
      weightc( 37, 53,  3)=                 -0.38847401507435896928d0
      iwe=iwe+1
      weightc( 38, 53,  3)=                 -0.23077779195233139031d0
      iwe=iwe+1
      weightc( 39, 53,  3)=                 -0.33929351391210638145d0
      iwe=iwe+1
      weightc( 40, 53,  3)=                  0.28073774186674643749d0
      iwe=iwe+1
      weightc( 41, 53,  3)=                  0.02624071585752531591d0
      iwe=iwe+1
      weightc( 42, 53,  3)=                  0.22520177194095866713d0
      iwe=iwe+1
      weightc( 43, 53,  3)=                  0.13736669772859130823d0
      iwe=iwe+1
      weightc( 44, 53,  3)=                 -0.04165699313830443368d0
      iwe=iwe+1
      weightc( 45, 53,  3)=                 -0.13897759774104931352d0
      iwe=iwe+1
      weightc( 46, 53,  3)=                 -0.05281700238442692263d0
      iwe=iwe+1
      weightc( 47, 53,  3)=                 -0.33381584876506170678d0
      iwe=iwe+1
      weightc( 48, 53,  3)=                  0.22166721848735362888d0
      iwe=iwe+1
      weightc( 49, 53,  3)=                  0.06907518819962583934d0
      iwe=iwe+1
      weightc( 50, 53,  3)=                  0.25979359473258500923d0
      iwe=iwe+1
      biasc( 53,  3)=                  0.51647028541274164759d0
      iwe=iwe+1
      weightc(  1, 54,  3)=                  0.14021354941515287718d0
      iwe=iwe+1
      weightc(  2, 54,  3)=                 -0.18158705217237428031d0
      iwe=iwe+1
      weightc(  3, 54,  3)=                 -0.14089991481624900005d0
      iwe=iwe+1
      weightc(  4, 54,  3)=                  0.20726724137968483008d0
      iwe=iwe+1
      weightc(  5, 54,  3)=                 -0.30942285121020501881d0
      iwe=iwe+1
      weightc(  6, 54,  3)=                 -0.35451662915750398186d0
      iwe=iwe+1
      weightc(  7, 54,  3)=                  0.66097878673693455376d0
      iwe=iwe+1
      weightc(  8, 54,  3)=                  0.12012930387858659909d0
      iwe=iwe+1
      weightc(  9, 54,  3)=                  0.07953815928284473091d0
      iwe=iwe+1
      weightc( 10, 54,  3)=                 -0.07822195304491234846d0
      iwe=iwe+1
      weightc( 11, 54,  3)=                 -0.45072358006394158680d0
      iwe=iwe+1
      weightc( 12, 54,  3)=                  0.23321199820399754477d0
      iwe=iwe+1
      weightc( 13, 54,  3)=                 -0.56147306585386480560d0
      iwe=iwe+1
      weightc( 14, 54,  3)=                  0.45212901229961632854d0
      iwe=iwe+1
      weightc( 15, 54,  3)=                  0.09410443899676110280d0
      iwe=iwe+1
      weightc( 16, 54,  3)=                 -0.02519274054687827696d0
      iwe=iwe+1
      weightc( 17, 54,  3)=                  0.19477764568863947803d0
      iwe=iwe+1
      weightc( 18, 54,  3)=                  0.29249630719101771259d0
      iwe=iwe+1
      weightc( 19, 54,  3)=                  0.62971256590135538111d0
      iwe=iwe+1
      weightc( 20, 54,  3)=                  0.20458937029464160928d0
      iwe=iwe+1
      weightc( 21, 54,  3)=                  0.00574903832039922683d0
      iwe=iwe+1
      weightc( 22, 54,  3)=                  0.05711219849487311762d0
      iwe=iwe+1
      weightc( 23, 54,  3)=                 -0.18858091376382848936d0
      iwe=iwe+1
      weightc( 24, 54,  3)=                 -0.45517064351417663159d0
      iwe=iwe+1
      weightc( 25, 54,  3)=                  0.14251471725104339350d0
      iwe=iwe+1
      weightc( 26, 54,  3)=                  0.40333537336103802984d0
      iwe=iwe+1
      weightc( 27, 54,  3)=                 -0.03136666339962652927d0
      iwe=iwe+1
      weightc( 28, 54,  3)=                 -0.37910937293924218405d0
      iwe=iwe+1
      weightc( 29, 54,  3)=                 -0.41684869302547977732d0
      iwe=iwe+1
      weightc( 30, 54,  3)=                 -0.40797961861636972136d0
      iwe=iwe+1
      weightc( 31, 54,  3)=                 -0.11237748132466832129d0
      iwe=iwe+1
      weightc( 32, 54,  3)=                 -0.22909353749797894961d0
      iwe=iwe+1
      weightc( 33, 54,  3)=                  0.07904651677630908368d0
      iwe=iwe+1
      weightc( 34, 54,  3)=                 -0.04981346752793205240d0
      iwe=iwe+1
      weightc( 35, 54,  3)=                 -0.07611832331743700886d0
      iwe=iwe+1
      weightc( 36, 54,  3)=                 -0.03038824862126732890d0
      iwe=iwe+1
      weightc( 37, 54,  3)=                 -0.58185497444554579172d0
      iwe=iwe+1
      weightc( 38, 54,  3)=                  0.10132482937182614446d0
      iwe=iwe+1
      weightc( 39, 54,  3)=                 -0.67563052410873181142d0
      iwe=iwe+1
      weightc( 40, 54,  3)=                 -0.18983604549877086676d0
      iwe=iwe+1
      weightc( 41, 54,  3)=                 -0.17623486607982793983d0
      iwe=iwe+1
      weightc( 42, 54,  3)=                  0.24551123201505539728d0
      iwe=iwe+1
      weightc( 43, 54,  3)=                 -0.17365448954315354513d0
      iwe=iwe+1
      weightc( 44, 54,  3)=                 -0.19735287164772319368d0
      iwe=iwe+1
      weightc( 45, 54,  3)=                  0.44782438912026301114d0
      iwe=iwe+1
      weightc( 46, 54,  3)=                 -0.46314951058694309172d0
      iwe=iwe+1
      weightc( 47, 54,  3)=                 -0.43525884521500235458d0
      iwe=iwe+1
      weightc( 48, 54,  3)=                  0.15623690631636433235d0
      iwe=iwe+1
      weightc( 49, 54,  3)=                  0.20366144984994566380d0
      iwe=iwe+1
      weightc( 50, 54,  3)=                  0.09038748862876402890d0
      iwe=iwe+1
      biasc( 54,  3)=                  0.62614247043223991707d0
      iwe=iwe+1
      weightc(  1, 55,  3)=                  0.56172124886394725340d0
      iwe=iwe+1
      weightc(  2, 55,  3)=                  0.58430337747517369085d0
      iwe=iwe+1
      weightc(  3, 55,  3)=                  0.23634575095173260273d0
      iwe=iwe+1
      weightc(  4, 55,  3)=                  0.31256545593447682130d0
      iwe=iwe+1
      weightc(  5, 55,  3)=                  0.13687337624802253799d0
      iwe=iwe+1
      weightc(  6, 55,  3)=                 -0.09383640889363842330d0
      iwe=iwe+1
      weightc(  7, 55,  3)=                 -0.12738334296159253833d0
      iwe=iwe+1
      weightc(  8, 55,  3)=                  0.34970636747209499218d0
      iwe=iwe+1
      weightc(  9, 55,  3)=                  0.27897049228766634954d0
      iwe=iwe+1
      weightc( 10, 55,  3)=                  0.39774686521009161577d0
      iwe=iwe+1
      weightc( 11, 55,  3)=                  0.40781801934811440224d0
      iwe=iwe+1
      weightc( 12, 55,  3)=                  0.36783547156839779824d0
      iwe=iwe+1
      weightc( 13, 55,  3)=                 -0.35810316925255525344d0
      iwe=iwe+1
      weightc( 14, 55,  3)=                 -0.11606452526781724233d0
      iwe=iwe+1
      weightc( 15, 55,  3)=                  0.13200723140487213847d0
      iwe=iwe+1
      weightc( 16, 55,  3)=                  0.07551750809385281149d0
      iwe=iwe+1
      weightc( 17, 55,  3)=                  0.43872373376256368349d0
      iwe=iwe+1
      weightc( 18, 55,  3)=                 -0.23028574413877653249d0
      iwe=iwe+1
      weightc( 19, 55,  3)=                 -0.09208621620301508937d0
      iwe=iwe+1
      weightc( 20, 55,  3)=                  0.44126141359906040362d0
      iwe=iwe+1
      weightc( 21, 55,  3)=                 -0.02403360391010880490d0
      iwe=iwe+1
      weightc( 22, 55,  3)=                  0.32755836090772794122d0
      iwe=iwe+1
      weightc( 23, 55,  3)=                  0.00760886167914171224d0
      iwe=iwe+1
      weightc( 24, 55,  3)=                 -0.11173396670874549685d0
      iwe=iwe+1
      weightc( 25, 55,  3)=                  0.30839924872644886022d0
      iwe=iwe+1
      weightc( 26, 55,  3)=                  0.03960970446537698253d0
      iwe=iwe+1
      weightc( 27, 55,  3)=                 -0.42224834682973849675d0
      iwe=iwe+1
      weightc( 28, 55,  3)=                  0.32356311692370376409d0
      iwe=iwe+1
      weightc( 29, 55,  3)=                 -0.45254786861167228817d0
      iwe=iwe+1
      weightc( 30, 55,  3)=                 -0.18589127177915898415d0
      iwe=iwe+1
      weightc( 31, 55,  3)=                 -0.08659975656609140982d0
      iwe=iwe+1
      weightc( 32, 55,  3)=                 -0.15683485653531076265d0
      iwe=iwe+1
      weightc( 33, 55,  3)=                 -0.19190247426900428063d0
      iwe=iwe+1
      weightc( 34, 55,  3)=                 -0.46072802109315791341d0
      iwe=iwe+1
      weightc( 35, 55,  3)=                  0.14235454488778981341d0
      iwe=iwe+1
      weightc( 36, 55,  3)=                  0.08895364867499143402d0
      iwe=iwe+1
      weightc( 37, 55,  3)=                 -0.06290749818438992613d0
      iwe=iwe+1
      weightc( 38, 55,  3)=                  0.55350164723293782121d0
      iwe=iwe+1
      weightc( 39, 55,  3)=                 -0.18818698864788388492d0
      iwe=iwe+1
      weightc( 40, 55,  3)=                 -0.15669170029362650132d0
      iwe=iwe+1
      weightc( 41, 55,  3)=                 -0.17868182433595036773d0
      iwe=iwe+1
      weightc( 42, 55,  3)=                  0.32868569550948351088d0
      iwe=iwe+1
      weightc( 43, 55,  3)=                  0.47388268952413697965d0
      iwe=iwe+1
      weightc( 44, 55,  3)=                  0.12280928433248509968d0
      iwe=iwe+1
      weightc( 45, 55,  3)=                 -0.24764090199658711500d0
      iwe=iwe+1
      weightc( 46, 55,  3)=                 -0.08365282066361967583d0
      iwe=iwe+1
      weightc( 47, 55,  3)=                  0.26666289927030090157d0
      iwe=iwe+1
      weightc( 48, 55,  3)=                 -0.28057989951525502681d0
      iwe=iwe+1
      weightc( 49, 55,  3)=                 -0.46438097286919716167d0
      iwe=iwe+1
      weightc( 50, 55,  3)=                 -0.37924856319134420124d0
      iwe=iwe+1
      biasc( 55,  3)=                  0.67327177098376034259d0
      iwe=iwe+1
      weightc(  1, 56,  3)=                 -0.32821183786185142983d0
      iwe=iwe+1
      weightc(  2, 56,  3)=                 -0.03115350065829983889d0
      iwe=iwe+1
      weightc(  3, 56,  3)=                  0.76385788298392542917d0
      iwe=iwe+1
      weightc(  4, 56,  3)=                  0.28152321470139390902d0
      iwe=iwe+1
      weightc(  5, 56,  3)=                  0.03311419896762719806d0
      iwe=iwe+1
      weightc(  6, 56,  3)=                 -0.05299352939680453123d0
      iwe=iwe+1
      weightc(  7, 56,  3)=                  0.31525255369961574514d0
      iwe=iwe+1
      weightc(  8, 56,  3)=                 -0.30261787783696558751d0
      iwe=iwe+1
      weightc(  9, 56,  3)=                 -0.22101887415348103749d0
      iwe=iwe+1
      weightc( 10, 56,  3)=                 -0.28574279781678524337d0
      iwe=iwe+1
      weightc( 11, 56,  3)=                 -0.13827832927272493135d0
      iwe=iwe+1
      weightc( 12, 56,  3)=                  0.20034821699095181624d0
      iwe=iwe+1
      weightc( 13, 56,  3)=                  0.14577657547965097717d0
      iwe=iwe+1
      weightc( 14, 56,  3)=                  0.45206341390375665013d0
      iwe=iwe+1
      weightc( 15, 56,  3)=                 -0.30616196088994968028d0
      iwe=iwe+1
      weightc( 16, 56,  3)=                  0.01025614830138212204d0
      iwe=iwe+1
      weightc( 17, 56,  3)=                 -0.30109365725569625649d0
      iwe=iwe+1
      weightc( 18, 56,  3)=                 -0.78497995217305338578d0
      iwe=iwe+1
      weightc( 19, 56,  3)=                  0.35127734409726496523d0
      iwe=iwe+1
      weightc( 20, 56,  3)=                 -0.10591954857745526641d0
      iwe=iwe+1
      weightc( 21, 56,  3)=                  1.12411182380076613008d0
      iwe=iwe+1
      weightc( 22, 56,  3)=                  0.12839023564028254065d0
      iwe=iwe+1
      weightc( 23, 56,  3)=                  0.23181865091854789163d0
      iwe=iwe+1
      weightc( 24, 56,  3)=                 -0.15144896033305363381d0
      iwe=iwe+1
      weightc( 25, 56,  3)=                  0.40737968641747485110d0
      iwe=iwe+1
      weightc( 26, 56,  3)=                 -0.03262772183618689592d0
      iwe=iwe+1
      weightc( 27, 56,  3)=                 -0.48002721848243445901d0
      iwe=iwe+1
      weightc( 28, 56,  3)=                  0.52571714629909827021d0
      iwe=iwe+1
      weightc( 29, 56,  3)=                 -0.43558467082725771391d0
      iwe=iwe+1
      weightc( 30, 56,  3)=                 -0.43137301432244201660d0
      iwe=iwe+1
      weightc( 31, 56,  3)=                 -0.08472542508361578795d0
      iwe=iwe+1
      weightc( 32, 56,  3)=                  0.27385202933638841394d0
      iwe=iwe+1
      weightc( 33, 56,  3)=                  0.41258778058354250717d0
      iwe=iwe+1
      weightc( 34, 56,  3)=                  0.32043817615025971257d0
      iwe=iwe+1
      weightc( 35, 56,  3)=                 -0.68429153242832407855d0
      iwe=iwe+1
      weightc( 36, 56,  3)=                 -0.10274651152670115362d0
      iwe=iwe+1
      weightc( 37, 56,  3)=                 -0.39944470194989539769d0
      iwe=iwe+1
      weightc( 38, 56,  3)=                 -0.16879851579307558751d0
      iwe=iwe+1
      weightc( 39, 56,  3)=                 -0.03952820151303045038d0
      iwe=iwe+1
      weightc( 40, 56,  3)=                 -0.23822421370871699198d0
      iwe=iwe+1
      weightc( 41, 56,  3)=                 -0.02417201629455221004d0
      iwe=iwe+1
      weightc( 42, 56,  3)=                  0.24764668766420028234d0
      iwe=iwe+1
      weightc( 43, 56,  3)=                  0.37584787366855298973d0
      iwe=iwe+1
      weightc( 44, 56,  3)=                 -0.35982546828147199403d0
      iwe=iwe+1
      weightc( 45, 56,  3)=                 -0.55540126069335704617d0
      iwe=iwe+1
      weightc( 46, 56,  3)=                 -0.23661509712510880865d0
      iwe=iwe+1
      weightc( 47, 56,  3)=                 -0.52801767644990393880d0
      iwe=iwe+1
      weightc( 48, 56,  3)=                  0.14891318652411536516d0
      iwe=iwe+1
      weightc( 49, 56,  3)=                 -0.24769846748870288922d0
      iwe=iwe+1
      weightc( 50, 56,  3)=                 -0.37819675632029225998d0
      iwe=iwe+1
      biasc( 56,  3)=                 -0.65871679358268608873d0
      iwe=iwe+1
      weightc(  1, 57,  3)=                  0.28186787452649442187d0
      iwe=iwe+1
      weightc(  2, 57,  3)=                  0.20260022827065485296d0
      iwe=iwe+1
      weightc(  3, 57,  3)=                 -0.25355439238082222442d0
      iwe=iwe+1
      weightc(  4, 57,  3)=                 -0.34599954634176827151d0
      iwe=iwe+1
      weightc(  5, 57,  3)=                  0.36863756538115427519d0
      iwe=iwe+1
      weightc(  6, 57,  3)=                 -0.02964955323685802835d0
      iwe=iwe+1
      weightc(  7, 57,  3)=                 -0.22502501145160064278d0
      iwe=iwe+1
      weightc(  8, 57,  3)=                  0.07777205998568820222d0
      iwe=iwe+1
      weightc(  9, 57,  3)=                 -0.51036463968232947952d0
      iwe=iwe+1
      weightc( 10, 57,  3)=                  0.28669855900237489754d0
      iwe=iwe+1
      weightc( 11, 57,  3)=                  0.14631036114078310728d0
      iwe=iwe+1
      weightc( 12, 57,  3)=                  0.38183521887941068718d0
      iwe=iwe+1
      weightc( 13, 57,  3)=                 -0.15853883612335897824d0
      iwe=iwe+1
      weightc( 14, 57,  3)=                  0.33913590182305253240d0
      iwe=iwe+1
      weightc( 15, 57,  3)=                  0.29439962547097608958d0
      iwe=iwe+1
      weightc( 16, 57,  3)=                  0.17687899144432123189d0
      iwe=iwe+1
      weightc( 17, 57,  3)=                  0.53477682975063089987d0
      iwe=iwe+1
      weightc( 18, 57,  3)=                  0.29118401208800620550d0
      iwe=iwe+1
      weightc( 19, 57,  3)=                 -0.17825058832370882511d0
      iwe=iwe+1
      weightc( 20, 57,  3)=                  0.22582150446925136622d0
      iwe=iwe+1
      weightc( 21, 57,  3)=                  0.01900036112879353173d0
      iwe=iwe+1
      weightc( 22, 57,  3)=                 -0.20360819721273623606d0
      iwe=iwe+1
      weightc( 23, 57,  3)=                 -0.05430049165430576169d0
      iwe=iwe+1
      weightc( 24, 57,  3)=                 -0.32201627440391988877d0
      iwe=iwe+1
      weightc( 25, 57,  3)=                  0.44468536539978537059d0
      iwe=iwe+1
      weightc( 26, 57,  3)=                  0.22515241167525193444d0
      iwe=iwe+1
      weightc( 27, 57,  3)=                  0.02052030348073767205d0
      iwe=iwe+1
      weightc( 28, 57,  3)=                  0.10427350340930158223d0
      iwe=iwe+1
      weightc( 29, 57,  3)=                 -0.31797430187316888528d0
      iwe=iwe+1
      weightc( 30, 57,  3)=                 -0.29143910035372888601d0
      iwe=iwe+1
      weightc( 31, 57,  3)=                 -0.16081445013242212649d0
      iwe=iwe+1
      weightc( 32, 57,  3)=                  0.28910712738991511950d0
      iwe=iwe+1
      weightc( 33, 57,  3)=                  0.17049730655628728138d0
      iwe=iwe+1
      weightc( 34, 57,  3)=                  0.27518498271193408966d0
      iwe=iwe+1
      weightc( 35, 57,  3)=                  0.03383899535874659165d0
      iwe=iwe+1
      weightc( 36, 57,  3)=                 -0.12954894967804839179d0
      iwe=iwe+1
      weightc( 37, 57,  3)=                  0.02272737926263086738d0
      iwe=iwe+1
      weightc( 38, 57,  3)=                  0.05666215569757883375d0
      iwe=iwe+1
      weightc( 39, 57,  3)=                  0.23081014544062380955d0
      iwe=iwe+1
      weightc( 40, 57,  3)=                  0.44588957192624639747d0
      iwe=iwe+1
      weightc( 41, 57,  3)=                 -0.38712534821674404739d0
      iwe=iwe+1
      weightc( 42, 57,  3)=                 -0.14043689498279199324d0
      iwe=iwe+1
      weightc( 43, 57,  3)=                  0.02242918746613711822d0
      iwe=iwe+1
      weightc( 44, 57,  3)=                  0.47810415252997445767d0
      iwe=iwe+1
      weightc( 45, 57,  3)=                  0.04803684050481221018d0
      iwe=iwe+1
      weightc( 46, 57,  3)=                 -0.16209193202863381167d0
      iwe=iwe+1
      weightc( 47, 57,  3)=                 -0.05613270798869659378d0
      iwe=iwe+1
      weightc( 48, 57,  3)=                 -0.17648757153390987051d0
      iwe=iwe+1
      weightc( 49, 57,  3)=                  0.00789620486974479917d0
      iwe=iwe+1
      weightc( 50, 57,  3)=                 -0.19989102418973800357d0
      iwe=iwe+1
      biasc( 57,  3)=                  0.71634588857101499926d0
      iwe=iwe+1
      weightc(  1, 58,  3)=                  0.29614143079137450476d0
      iwe=iwe+1
      weightc(  2, 58,  3)=                  0.00753711354470930350d0
      iwe=iwe+1
      weightc(  3, 58,  3)=                 -0.22455202559889278491d0
      iwe=iwe+1
      weightc(  4, 58,  3)=                  0.19565426679468117532d0
      iwe=iwe+1
      weightc(  5, 58,  3)=                  0.62118739011783097315d0
      iwe=iwe+1
      weightc(  6, 58,  3)=                  0.14614682998619227261d0
      iwe=iwe+1
      weightc(  7, 58,  3)=                  0.15305809253958208016d0
      iwe=iwe+1
      weightc(  8, 58,  3)=                  0.24995820488574399532d0
      iwe=iwe+1
      weightc(  9, 58,  3)=                 -0.58600232110613836856d0
      iwe=iwe+1
      weightc( 10, 58,  3)=                 -0.35921319855212963112d0
      iwe=iwe+1
      weightc( 11, 58,  3)=                 -0.14311209779963976474d0
      iwe=iwe+1
      weightc( 12, 58,  3)=                 -0.59160801790444528248d0
      iwe=iwe+1
      weightc( 13, 58,  3)=                 -0.48717231436842084458d0
      iwe=iwe+1
      weightc( 14, 58,  3)=                  0.28716655132758689417d0
      iwe=iwe+1
      weightc( 15, 58,  3)=                  0.77110310032014195425d0
      iwe=iwe+1
      weightc( 16, 58,  3)=                  0.21938188092372384874d0
      iwe=iwe+1
      weightc( 17, 58,  3)=                 -0.13995533646068469835d0
      iwe=iwe+1
      weightc( 18, 58,  3)=                 -0.09700292155741030431d0
      iwe=iwe+1
      weightc( 19, 58,  3)=                 -0.70614235566575822567d0
      iwe=iwe+1
      weightc( 20, 58,  3)=                 -0.10710527199486498395d0
      iwe=iwe+1
      weightc( 21, 58,  3)=                  0.51815736729121897319d0
      iwe=iwe+1
      weightc( 22, 58,  3)=                 -0.28585725705147069231d0
      iwe=iwe+1
      weightc( 23, 58,  3)=                  0.32084885235267612824d0
      iwe=iwe+1
      weightc( 24, 58,  3)=                  0.21484933594745209140d0
      iwe=iwe+1
      weightc( 25, 58,  3)=                  0.24082365560281102090d0
      iwe=iwe+1
      weightc( 26, 58,  3)=                 -0.46624447757570752771d0
      iwe=iwe+1
      weightc( 27, 58,  3)=                 -0.03786042244839345899d0
      iwe=iwe+1
      weightc( 28, 58,  3)=                 -0.24942335595379033775d0
      iwe=iwe+1
      weightc( 29, 58,  3)=                  0.05270262627170536202d0
      iwe=iwe+1
      weightc( 30, 58,  3)=                 -0.38614726729300041796d0
      iwe=iwe+1
      weightc( 31, 58,  3)=                  0.63291461450595254412d0
      iwe=iwe+1
      weightc( 32, 58,  3)=                 -0.11344300135977049282d0
      iwe=iwe+1
      weightc( 33, 58,  3)=                  0.26878570478012658862d0
      iwe=iwe+1
      weightc( 34, 58,  3)=                 -0.02143591339429186393d0
      iwe=iwe+1
      weightc( 35, 58,  3)=                 -0.31811991796937005850d0
      iwe=iwe+1
      weightc( 36, 58,  3)=                 -0.17705239595489027926d0
      iwe=iwe+1
      weightc( 37, 58,  3)=                  0.05065729222539093468d0
      iwe=iwe+1
      weightc( 38, 58,  3)=                  0.42122209607987071145d0
      iwe=iwe+1
      weightc( 39, 58,  3)=                  0.43135885257175526908d0
      iwe=iwe+1
      weightc( 40, 58,  3)=                 -0.42421641968606937922d0
      iwe=iwe+1
      weightc( 41, 58,  3)=                 -0.08592600372557497590d0
      iwe=iwe+1
      weightc( 42, 58,  3)=                 -0.18537204403421067567d0
      iwe=iwe+1
      weightc( 43, 58,  3)=                 -0.13456878682696576943d0
      iwe=iwe+1
      weightc( 44, 58,  3)=                  0.37119807597210074945d0
      iwe=iwe+1
      weightc( 45, 58,  3)=                 -0.11925456517050472827d0
      iwe=iwe+1
      weightc( 46, 58,  3)=                 -0.64538185443023765586d0
      iwe=iwe+1
      weightc( 47, 58,  3)=                  0.02032090514411265605d0
      iwe=iwe+1
      weightc( 48, 58,  3)=                 -0.26873841687037086645d0
      iwe=iwe+1
      weightc( 49, 58,  3)=                 -0.35095301312641324909d0
      iwe=iwe+1
      weightc( 50, 58,  3)=                 -0.34494619656135572239d0
      iwe=iwe+1
      biasc( 58,  3)=                 -0.59214974739394921066d0
      iwe=iwe+1
      weightc(  1, 59,  3)=                 -0.01421648678142608917d0
      iwe=iwe+1
      weightc(  2, 59,  3)=                  0.25387811791221248647d0
      iwe=iwe+1
      weightc(  3, 59,  3)=                  0.11384277856640329096d0
      iwe=iwe+1
      weightc(  4, 59,  3)=                  0.06962717309110014186d0
      iwe=iwe+1
      weightc(  5, 59,  3)=                  0.17631512274909169613d0
      iwe=iwe+1
      weightc(  6, 59,  3)=                 -0.03429551721390980412d0
      iwe=iwe+1
      weightc(  7, 59,  3)=                 -0.37271611218287808986d0
      iwe=iwe+1
      weightc(  8, 59,  3)=                  0.09546948480403143200d0
      iwe=iwe+1
      weightc(  9, 59,  3)=                 -0.09632967004494849550d0
      iwe=iwe+1
      weightc( 10, 59,  3)=                 -0.23878707576614438546d0
      iwe=iwe+1
      weightc( 11, 59,  3)=                  0.32362853283748133082d0
      iwe=iwe+1
      weightc( 12, 59,  3)=                 -0.30130344476770470896d0
      iwe=iwe+1
      weightc( 13, 59,  3)=                 -0.01270624699061229622d0
      iwe=iwe+1
      weightc( 14, 59,  3)=                  0.14979148085780283339d0
      iwe=iwe+1
      weightc( 15, 59,  3)=                 -0.04831030662849261637d0
      iwe=iwe+1
      weightc( 16, 59,  3)=                  0.21734239030603161313d0
      iwe=iwe+1
      weightc( 17, 59,  3)=                  0.43002700811127519964d0
      iwe=iwe+1
      weightc( 18, 59,  3)=                  0.07515190855157444227d0
      iwe=iwe+1
      weightc( 19, 59,  3)=                  0.79880854524208244616d0
      iwe=iwe+1
      weightc( 20, 59,  3)=                 -0.11717957427055734898d0
      iwe=iwe+1
      weightc( 21, 59,  3)=                 -0.26773750806094975818d0
      iwe=iwe+1
      weightc( 22, 59,  3)=                 -0.16651280570123061509d0
      iwe=iwe+1
      weightc( 23, 59,  3)=                  0.11797297029685510639d0
      iwe=iwe+1
      weightc( 24, 59,  3)=                 -0.03722340598873437323d0
      iwe=iwe+1
      weightc( 25, 59,  3)=                 -0.00552630472884899516d0
      iwe=iwe+1
      weightc( 26, 59,  3)=                  0.22469913237276681328d0
      iwe=iwe+1
      weightc( 27, 59,  3)=                 -0.74236161061216920931d0
      iwe=iwe+1
      weightc( 28, 59,  3)=                 -0.03181577476278742850d0
      iwe=iwe+1
      weightc( 29, 59,  3)=                  0.10395177914899872418d0
      iwe=iwe+1
      weightc( 30, 59,  3)=                  0.13109980540789470393d0
      iwe=iwe+1
      weightc( 31, 59,  3)=                 -0.06446891275261182330d0
      iwe=iwe+1
      weightc( 32, 59,  3)=                 -0.03787452446822132252d0
      iwe=iwe+1
      weightc( 33, 59,  3)=                 -0.24529261907984811764d0
      iwe=iwe+1
      weightc( 34, 59,  3)=                  0.05855524275249214539d0
      iwe=iwe+1
      weightc( 35, 59,  3)=                 -0.19261019482132082925d0
      iwe=iwe+1
      weightc( 36, 59,  3)=                 -0.12617275796401850041d0
      iwe=iwe+1
      weightc( 37, 59,  3)=                 -0.14586355782048665564d0
      iwe=iwe+1
      weightc( 38, 59,  3)=                  0.48604841350382149701d0
      iwe=iwe+1
      weightc( 39, 59,  3)=                 -0.42851402380332015429d0
      iwe=iwe+1
      weightc( 40, 59,  3)=                  0.15111550180669580667d0
      iwe=iwe+1
      weightc( 41, 59,  3)=                  0.02847635831982955890d0
      iwe=iwe+1
      weightc( 42, 59,  3)=                  0.16273325953279241252d0
      iwe=iwe+1
      weightc( 43, 59,  3)=                 -0.11635241509003801941d0
      iwe=iwe+1
      weightc( 44, 59,  3)=                 -0.02045324851458242901d0
      iwe=iwe+1
      weightc( 45, 59,  3)=                 -0.39485604639210403199d0
      iwe=iwe+1
      weightc( 46, 59,  3)=                  0.57098933650572214482d0
      iwe=iwe+1
      weightc( 47, 59,  3)=                 -0.09780618237449831276d0
      iwe=iwe+1
      weightc( 48, 59,  3)=                  0.15295709331491436078d0
      iwe=iwe+1
      weightc( 49, 59,  3)=                  0.02785012248972191379d0
      iwe=iwe+1
      weightc( 50, 59,  3)=                 -0.43550133604918594976d0
      iwe=iwe+1
      biasc( 59,  3)=                 -0.61597921273646205620d0
      iwe=iwe+1
      weightc(  1, 60,  3)=                 -0.20229329875243012848d0
      iwe=iwe+1
      weightc(  2, 60,  3)=                 -0.47286081807201962857d0
      iwe=iwe+1
      weightc(  3, 60,  3)=                 -0.68708318748996810577d0
      iwe=iwe+1
      weightc(  4, 60,  3)=                  0.30944334534059508846d0
      iwe=iwe+1
      weightc(  5, 60,  3)=                 -0.02675870805401756383d0
      iwe=iwe+1
      weightc(  6, 60,  3)=                  0.20613202412973943844d0
      iwe=iwe+1
      weightc(  7, 60,  3)=                  0.18668492592646276917d0
      iwe=iwe+1
      weightc(  8, 60,  3)=                  0.85635737138520950928d0
      iwe=iwe+1
      weightc(  9, 60,  3)=                  0.01121906579743357259d0
      iwe=iwe+1
      weightc( 10, 60,  3)=                  0.18448122661750754325d0
      iwe=iwe+1
      weightc( 11, 60,  3)=                 -0.15018963659061315696d0
      iwe=iwe+1
      weightc( 12, 60,  3)=                 -0.02784996748374679934d0
      iwe=iwe+1
      weightc( 13, 60,  3)=                 -0.12859203855628043023d0
      iwe=iwe+1
      weightc( 14, 60,  3)=                  0.24804508002744238282d0
      iwe=iwe+1
      weightc( 15, 60,  3)=                 -0.24174225095656848294d0
      iwe=iwe+1
      weightc( 16, 60,  3)=                  0.40291552770614780243d0
      iwe=iwe+1
      weightc( 17, 60,  3)=                 -0.02895471549636449357d0
      iwe=iwe+1
      weightc( 18, 60,  3)=                 -0.00068099357967116303d0
      iwe=iwe+1
      weightc( 19, 60,  3)=                 -0.00163618476550133913d0
      iwe=iwe+1
      weightc( 20, 60,  3)=                 -0.10055551075474350453d0
      iwe=iwe+1
      weightc( 21, 60,  3)=                  0.15074744724900238091d0
      iwe=iwe+1
      weightc( 22, 60,  3)=                 -0.64341096162603372832d0
      iwe=iwe+1
      weightc( 23, 60,  3)=                  0.15266833646840208272d0
      iwe=iwe+1
      weightc( 24, 60,  3)=                  0.59648986480003918231d0
      iwe=iwe+1
      weightc( 25, 60,  3)=                 -0.06112904041262470084d0
      iwe=iwe+1
      weightc( 26, 60,  3)=                 -0.07493892257248335742d0
      iwe=iwe+1
      weightc( 27, 60,  3)=                  0.12303380401587364623d0
      iwe=iwe+1
      weightc( 28, 60,  3)=                  0.04945027884553732100d0
      iwe=iwe+1
      weightc( 29, 60,  3)=                  0.22062412599129965773d0
      iwe=iwe+1
      weightc( 30, 60,  3)=                  0.10168425565040750680d0
      iwe=iwe+1
      weightc( 31, 60,  3)=                 -0.07234909363885379252d0
      iwe=iwe+1
      weightc( 32, 60,  3)=                 -0.57829953499222741531d0
      iwe=iwe+1
      weightc( 33, 60,  3)=                  0.25941315183723723248d0
      iwe=iwe+1
      weightc( 34, 60,  3)=                 -0.54956549296263501603d0
      iwe=iwe+1
      weightc( 35, 60,  3)=                 -0.05741298987776629476d0
      iwe=iwe+1
      weightc( 36, 60,  3)=                  0.47508837687742710987d0
      iwe=iwe+1
      weightc( 37, 60,  3)=                  0.18794205725677307073d0
      iwe=iwe+1
      weightc( 38, 60,  3)=                  0.22254211846445878797d0
      iwe=iwe+1
      weightc( 39, 60,  3)=                 -0.34924208518470767348d0
      iwe=iwe+1
      weightc( 40, 60,  3)=                 -0.18961678009194110617d0
      iwe=iwe+1
      weightc( 41, 60,  3)=                 -0.23403346903607152862d0
      iwe=iwe+1
      weightc( 42, 60,  3)=                  0.52278636816475354543d0
      iwe=iwe+1
      weightc( 43, 60,  3)=                 -0.36278243357320311135d0
      iwe=iwe+1
      weightc( 44, 60,  3)=                  0.40158798538324291805d0
      iwe=iwe+1
      weightc( 45, 60,  3)=                 -0.07845436898096981582d0
      iwe=iwe+1
      weightc( 46, 60,  3)=                 -0.79645998102867121560d0
      iwe=iwe+1
      weightc( 47, 60,  3)=                  0.42607977494481774627d0
      iwe=iwe+1
      weightc( 48, 60,  3)=                 -0.06418786215866190137d0
      iwe=iwe+1
      weightc( 49, 60,  3)=                 -0.15004937498122286610d0
      iwe=iwe+1
      weightc( 50, 60,  3)=                  0.57382186471504548209d0
      iwe=iwe+1
      biasc( 60,  3)=                 -0.64130291603927647159d0
      iwe=iwe+1
      weightc(  1, 61,  3)=                  0.63131412970162581466d0
      iwe=iwe+1
      weightc(  2, 61,  3)=                  0.34474588886503598761d0
      iwe=iwe+1
      weightc(  3, 61,  3)=                  0.46800215154875962620d0
      iwe=iwe+1
      weightc(  4, 61,  3)=                  0.25757075403820145487d0
      iwe=iwe+1
      weightc(  5, 61,  3)=                  0.33866778691785592859d0
      iwe=iwe+1
      weightc(  6, 61,  3)=                 -0.04614599210024556558d0
      iwe=iwe+1
      weightc(  7, 61,  3)=                 -0.07674711637514455842d0
      iwe=iwe+1
      weightc(  8, 61,  3)=                 -0.51828184066064786339d0
      iwe=iwe+1
      weightc(  9, 61,  3)=                 -0.20020886245637925516d0
      iwe=iwe+1
      weightc( 10, 61,  3)=                  0.35094225991575639378d0
      iwe=iwe+1
      weightc( 11, 61,  3)=                  0.13191836999633757554d0
      iwe=iwe+1
      weightc( 12, 61,  3)=                  0.10169307740651754857d0
      iwe=iwe+1
      weightc( 13, 61,  3)=                 -0.06602527187183830637d0
      iwe=iwe+1
      weightc( 14, 61,  3)=                  0.10991031911155284273d0
      iwe=iwe+1
      weightc( 15, 61,  3)=                 -0.09708825309160928896d0
      iwe=iwe+1
      weightc( 16, 61,  3)=                  0.17828871987792976883d0
      iwe=iwe+1
      weightc( 17, 61,  3)=                 -0.20225706300025114714d0
      iwe=iwe+1
      weightc( 18, 61,  3)=                  0.11701285831480694177d0
      iwe=iwe+1
      weightc( 19, 61,  3)=                  0.24004924278097172774d0
      iwe=iwe+1
      weightc( 20, 61,  3)=                  0.12772669441515774325d0
      iwe=iwe+1
      weightc( 21, 61,  3)=                  0.25239205870055880787d0
      iwe=iwe+1
      weightc( 22, 61,  3)=                  0.03101377636837221105d0
      iwe=iwe+1
      weightc( 23, 61,  3)=                 -0.30919653691870746526d0
      iwe=iwe+1
      weightc( 24, 61,  3)=                 -0.71644726041108153236d0
      iwe=iwe+1
      weightc( 25, 61,  3)=                  0.49365559105830481013d0
      iwe=iwe+1
      weightc( 26, 61,  3)=                  0.08573789049677152385d0
      iwe=iwe+1
      weightc( 27, 61,  3)=                  0.24875396099420069018d0
      iwe=iwe+1
      weightc( 28, 61,  3)=                 -0.22157077648499765021d0
      iwe=iwe+1
      weightc( 29, 61,  3)=                  0.24151072796591149805d0
      iwe=iwe+1
      weightc( 30, 61,  3)=                 -0.55475562782897791525d0
      iwe=iwe+1
      weightc( 31, 61,  3)=                 -0.15481793410945313139d0
      iwe=iwe+1
      weightc( 32, 61,  3)=                  0.40768485152019817708d0
      iwe=iwe+1
      weightc( 33, 61,  3)=                  0.23186347354270694932d0
      iwe=iwe+1
      weightc( 34, 61,  3)=                 -0.20194658886202127013d0
      iwe=iwe+1
      weightc( 35, 61,  3)=                  0.10962875891127112082d0
      iwe=iwe+1
      weightc( 36, 61,  3)=                  0.33403451958441915393d0
      iwe=iwe+1
      weightc( 37, 61,  3)=                  0.26606615830609475770d0
      iwe=iwe+1
      weightc( 38, 61,  3)=                 -0.00224676963192420873d0
      iwe=iwe+1
      weightc( 39, 61,  3)=                 -0.43097193892890200972d0
      iwe=iwe+1
      weightc( 40, 61,  3)=                 -0.03374324833701697335d0
      iwe=iwe+1
      weightc( 41, 61,  3)=                  0.04561767609810633145d0
      iwe=iwe+1
      weightc( 42, 61,  3)=                 -0.23141805061378620256d0
      iwe=iwe+1
      weightc( 43, 61,  3)=                 -0.01281847265142365376d0
      iwe=iwe+1
      weightc( 44, 61,  3)=                 -1.17713504740123098280d0
      iwe=iwe+1
      weightc( 45, 61,  3)=                  0.35393935973741474932d0
      iwe=iwe+1
      weightc( 46, 61,  3)=                  0.05266528706510997804d0
      iwe=iwe+1
      weightc( 47, 61,  3)=                 -0.07675497711762238606d0
      iwe=iwe+1
      weightc( 48, 61,  3)=                  0.27736571544458071825d0
      iwe=iwe+1
      weightc( 49, 61,  3)=                  0.22195973313980615904d0
      iwe=iwe+1
      weightc( 50, 61,  3)=                 -0.15262328250980775057d0
      iwe=iwe+1
      biasc( 61,  3)=                  0.88578769110041488677d0
      iwe=iwe+1
      weightc(  1, 62,  3)=                 -0.22155392990195188485d0
      iwe=iwe+1
      weightc(  2, 62,  3)=                  0.51740459456065746036d0
      iwe=iwe+1
      weightc(  3, 62,  3)=                  0.16726141028170571357d0
      iwe=iwe+1
      weightc(  4, 62,  3)=                 -0.15735764538836891080d0
      iwe=iwe+1
      weightc(  5, 62,  3)=                 -0.30218293563997017381d0
      iwe=iwe+1
      weightc(  6, 62,  3)=                  0.06503034416607554602d0
      iwe=iwe+1
      weightc(  7, 62,  3)=                  0.10257251834244530964d0
      iwe=iwe+1
      weightc(  8, 62,  3)=                  0.12833109365461034534d0
      iwe=iwe+1
      weightc(  9, 62,  3)=                  0.23355900587493724774d0
      iwe=iwe+1
      weightc( 10, 62,  3)=                 -0.02241536986465587217d0
      iwe=iwe+1
      weightc( 11, 62,  3)=                  0.42135431672756956667d0
      iwe=iwe+1
      weightc( 12, 62,  3)=                 -0.60419828035262246324d0
      iwe=iwe+1
      weightc( 13, 62,  3)=                 -0.02009733531546116156d0
      iwe=iwe+1
      weightc( 14, 62,  3)=                  0.24026967623867714896d0
      iwe=iwe+1
      weightc( 15, 62,  3)=                 -0.31026243245257817405d0
      iwe=iwe+1
      weightc( 16, 62,  3)=                  0.02769012254622370620d0
      iwe=iwe+1
      weightc( 17, 62,  3)=                 -0.32118151810841905069d0
      iwe=iwe+1
      weightc( 18, 62,  3)=                 -0.51484903498388789878d0
      iwe=iwe+1
      weightc( 19, 62,  3)=                  0.21184891753093371136d0
      iwe=iwe+1
      weightc( 20, 62,  3)=                  0.01674319876725884060d0
      iwe=iwe+1
      weightc( 21, 62,  3)=                  0.19512671699942255032d0
      iwe=iwe+1
      weightc( 22, 62,  3)=                 -0.10937468468207683925d0
      iwe=iwe+1
      weightc( 23, 62,  3)=                 -0.10701159675719493225d0
      iwe=iwe+1
      weightc( 24, 62,  3)=                  0.30019706961382053301d0
      iwe=iwe+1
      weightc( 25, 62,  3)=                 -0.01565209813895715452d0
      iwe=iwe+1
      weightc( 26, 62,  3)=                  0.16879033896528955472d0
      iwe=iwe+1
      weightc( 27, 62,  3)=                 -0.27718254339251535701d0
      iwe=iwe+1
      weightc( 28, 62,  3)=                 -0.04309350384258583966d0
      iwe=iwe+1
      weightc( 29, 62,  3)=                 -0.53327118496156056260d0
      iwe=iwe+1
      weightc( 30, 62,  3)=                 -0.15252084767808699040d0
      iwe=iwe+1
      weightc( 31, 62,  3)=                  0.04066329870421205722d0
      iwe=iwe+1
      weightc( 32, 62,  3)=                 -0.22017106832454191867d0
      iwe=iwe+1
      weightc( 33, 62,  3)=                 -0.20729031407755019178d0
      iwe=iwe+1
      weightc( 34, 62,  3)=                 -0.30738173403657204075d0
      iwe=iwe+1
      weightc( 35, 62,  3)=                 -0.06156105939710484337d0
      iwe=iwe+1
      weightc( 36, 62,  3)=                  1.06518407055316166598d0
      iwe=iwe+1
      weightc( 37, 62,  3)=                  0.45292139628804306550d0
      iwe=iwe+1
      weightc( 38, 62,  3)=                  0.27079499138027401939d0
      iwe=iwe+1
      weightc( 39, 62,  3)=                 -0.17533682802973038495d0
      iwe=iwe+1
      weightc( 40, 62,  3)=                  0.12443643262058380616d0
      iwe=iwe+1
      weightc( 41, 62,  3)=                 -0.33700708276377894235d0
      iwe=iwe+1
      weightc( 42, 62,  3)=                 -0.41010024721349791488d0
      iwe=iwe+1
      weightc( 43, 62,  3)=                 -0.03862636195978672027d0
      iwe=iwe+1
      weightc( 44, 62,  3)=                 -0.14830068070303056849d0
      iwe=iwe+1
      weightc( 45, 62,  3)=                  0.41145350298184840687d0
      iwe=iwe+1
      weightc( 46, 62,  3)=                 -0.28160104606302982511d0
      iwe=iwe+1
      weightc( 47, 62,  3)=                  0.30316221709659929573d0
      iwe=iwe+1
      weightc( 48, 62,  3)=                 -0.29449481511917191545d0
      iwe=iwe+1
      weightc( 49, 62,  3)=                 -0.64365598357928210937d0
      iwe=iwe+1
      weightc( 50, 62,  3)=                 -0.10662521312717393451d0
      iwe=iwe+1
      biasc( 62,  3)=                 -0.66568156649636744948d0
      iwe=iwe+1
      weightc(  1, 63,  3)=                  0.61784862339536561482d0
      iwe=iwe+1
      weightc(  2, 63,  3)=                 -0.19756920659130422502d0
      iwe=iwe+1
      weightc(  3, 63,  3)=                 -0.24872653979319375717d0
      iwe=iwe+1
      weightc(  4, 63,  3)=                  0.02295629077417664018d0
      iwe=iwe+1
      weightc(  5, 63,  3)=                  0.27182188200591206328d0
      iwe=iwe+1
      weightc(  6, 63,  3)=                  0.43242555566835483294d0
      iwe=iwe+1
      weightc(  7, 63,  3)=                 -0.41066864267376679276d0
      iwe=iwe+1
      weightc(  8, 63,  3)=                  0.35750371324709079301d0
      iwe=iwe+1
      weightc(  9, 63,  3)=                  0.56486191937781993211d0
      iwe=iwe+1
      weightc( 10, 63,  3)=                  0.27117560303927312759d0
      iwe=iwe+1
      weightc( 11, 63,  3)=                  0.05827778494418213440d0
      iwe=iwe+1
      weightc( 12, 63,  3)=                 -0.01022576012861311709d0
      iwe=iwe+1
      weightc( 13, 63,  3)=                  0.01235017566022271647d0
      iwe=iwe+1
      weightc( 14, 63,  3)=                  0.04748404185123986793d0
      iwe=iwe+1
      weightc( 15, 63,  3)=                 -0.05594383613166303837d0
      iwe=iwe+1
      weightc( 16, 63,  3)=                  0.06956642984237804139d0
      iwe=iwe+1
      weightc( 17, 63,  3)=                  0.07437024018347825061d0
      iwe=iwe+1
      weightc( 18, 63,  3)=                  0.02832140544208134811d0
      iwe=iwe+1
      weightc( 19, 63,  3)=                 -0.28792428343880449582d0
      iwe=iwe+1
      weightc( 20, 63,  3)=                  0.24470103322626393649d0
      iwe=iwe+1
      weightc( 21, 63,  3)=                 -0.19928594047623823804d0
      iwe=iwe+1
      weightc( 22, 63,  3)=                 -0.17976421938238135168d0
      iwe=iwe+1
      weightc( 23, 63,  3)=                 -0.13043405177964925712d0
      iwe=iwe+1
      weightc( 24, 63,  3)=                  0.44052454744621077909d0
      iwe=iwe+1
      weightc( 25, 63,  3)=                  0.28760076037022241913d0
      iwe=iwe+1
      weightc( 26, 63,  3)=                  0.26643212748107508725d0
      iwe=iwe+1
      weightc( 27, 63,  3)=                 -0.31831653473371801510d0
      iwe=iwe+1
      weightc( 28, 63,  3)=                  0.11861013258048648533d0
      iwe=iwe+1
      weightc( 29, 63,  3)=                 -0.18459634201130925568d0
      iwe=iwe+1
      weightc( 30, 63,  3)=                 -0.13275399314340477486d0
      iwe=iwe+1
      weightc( 31, 63,  3)=                 -0.38187540032671385415d0
      iwe=iwe+1
      weightc( 32, 63,  3)=                 -0.36342497714586796675d0
      iwe=iwe+1
      weightc( 33, 63,  3)=                 -0.31758600921393947969d0
      iwe=iwe+1
      weightc( 34, 63,  3)=                 -0.37107100177573049127d0
      iwe=iwe+1
      weightc( 35, 63,  3)=                  0.02387165870715566435d0
      iwe=iwe+1
      weightc( 36, 63,  3)=                 -0.37664903638342023262d0
      iwe=iwe+1
      weightc( 37, 63,  3)=                 -0.11770480848819331321d0
      iwe=iwe+1
      weightc( 38, 63,  3)=                  0.67330185877073045475d0
      iwe=iwe+1
      weightc( 39, 63,  3)=                 -0.00995696160221984199d0
      iwe=iwe+1
      weightc( 40, 63,  3)=                 -0.28053169408657935291d0
      iwe=iwe+1
      weightc( 41, 63,  3)=                 -0.04773686571946336721d0
      iwe=iwe+1
      weightc( 42, 63,  3)=                 -0.15470953669332329627d0
      iwe=iwe+1
      weightc( 43, 63,  3)=                  0.08651285862159392714d0
      iwe=iwe+1
      weightc( 44, 63,  3)=                  0.39991380344820581794d0
      iwe=iwe+1
      weightc( 45, 63,  3)=                  0.11995463506726192215d0
      iwe=iwe+1
      weightc( 46, 63,  3)=                  0.42723620117472393964d0
      iwe=iwe+1
      weightc( 47, 63,  3)=                  0.16213441314626605982d0
      iwe=iwe+1
      weightc( 48, 63,  3)=                  0.28614453180684534805d0
      iwe=iwe+1
      weightc( 49, 63,  3)=                  0.36093720524497191482d0
      iwe=iwe+1
      weightc( 50, 63,  3)=                  0.38796245642683957477d0
      iwe=iwe+1
      biasc( 63,  3)=                  1.07563454237125655233d0
      iwe=iwe+1
      weightc(  1, 64,  3)=                  0.40985678944684866831d0
      iwe=iwe+1
      weightc(  2, 64,  3)=                 -0.09514026079219636833d0
      iwe=iwe+1
      weightc(  3, 64,  3)=                  0.11499221168699376439d0
      iwe=iwe+1
      weightc(  4, 64,  3)=                  0.39309034934127351502d0
      iwe=iwe+1
      weightc(  5, 64,  3)=                  0.44310634096326950715d0
      iwe=iwe+1
      weightc(  6, 64,  3)=                 -0.38400024125555676235d0
      iwe=iwe+1
      weightc(  7, 64,  3)=                 -0.39365241288177083012d0
      iwe=iwe+1
      weightc(  8, 64,  3)=                 -0.17158951304832353868d0
      iwe=iwe+1
      weightc(  9, 64,  3)=                 -0.14277016739210005025d0
      iwe=iwe+1
      weightc( 10, 64,  3)=                  0.60552617758862192776d0
      iwe=iwe+1
      weightc( 11, 64,  3)=                 -0.01426409818426230963d0
      iwe=iwe+1
      weightc( 12, 64,  3)=                 -0.22749967513096666649d0
      iwe=iwe+1
      weightc( 13, 64,  3)=                  0.20040163984084136128d0
      iwe=iwe+1
      weightc( 14, 64,  3)=                 -0.28553953084191729950d0
      iwe=iwe+1
      weightc( 15, 64,  3)=                 -0.08228600848819747626d0
      iwe=iwe+1
      weightc( 16, 64,  3)=                  0.09114036669423619674d0
      iwe=iwe+1
      weightc( 17, 64,  3)=                  0.27788807838766033109d0
      iwe=iwe+1
      weightc( 18, 64,  3)=                 -0.47571513486805089288d0
      iwe=iwe+1
      weightc( 19, 64,  3)=                  0.08468820442013479111d0
      iwe=iwe+1
      weightc( 20, 64,  3)=                 -0.09080601385018262361d0
      iwe=iwe+1
      weightc( 21, 64,  3)=                  0.35985062863370304020d0
      iwe=iwe+1
      weightc( 22, 64,  3)=                  0.02825088505096650521d0
      iwe=iwe+1
      weightc( 23, 64,  3)=                  0.08333871298289942386d0
      iwe=iwe+1
      weightc( 24, 64,  3)=                  0.40096189210652205537d0
      iwe=iwe+1
      weightc( 25, 64,  3)=                 -0.17317331438171457147d0
      iwe=iwe+1
      weightc( 26, 64,  3)=                  0.20857754768750022545d0
      iwe=iwe+1
      weightc( 27, 64,  3)=                 -0.23452997753902288247d0
      iwe=iwe+1
      weightc( 28, 64,  3)=                 -0.23231339082351082359d0
      iwe=iwe+1
      weightc( 29, 64,  3)=                  0.27144925441584522030d0
      iwe=iwe+1
      weightc( 30, 64,  3)=                  0.37761194004572956606d0
      iwe=iwe+1
      weightc( 31, 64,  3)=                  0.01218935384968384758d0
      iwe=iwe+1
      weightc( 32, 64,  3)=                  0.12668066514372461340d0
      iwe=iwe+1
      weightc( 33, 64,  3)=                 -0.32634251551075571518d0
      iwe=iwe+1
      weightc( 34, 64,  3)=                  0.23186027251485671896d0
      iwe=iwe+1
      weightc( 35, 64,  3)=                  0.05182568233847749395d0
      iwe=iwe+1
      weightc( 36, 64,  3)=                  0.23930952970067465024d0
      iwe=iwe+1
      weightc( 37, 64,  3)=                  0.11486427013994993107d0
      iwe=iwe+1
      weightc( 38, 64,  3)=                  0.03758669993157223721d0
      iwe=iwe+1
      weightc( 39, 64,  3)=                  0.48985071754551240408d0
      iwe=iwe+1
      weightc( 40, 64,  3)=                  0.38877043434677754918d0
      iwe=iwe+1
      weightc( 41, 64,  3)=                  0.26176396425407771895d0
      iwe=iwe+1
      weightc( 42, 64,  3)=                  0.34160255126482397259d0
      iwe=iwe+1
      weightc( 43, 64,  3)=                 -0.21799072158072735350d0
      iwe=iwe+1
      weightc( 44, 64,  3)=                 -0.21212781577304448688d0
      iwe=iwe+1
      weightc( 45, 64,  3)=                  0.04975758519527456736d0
      iwe=iwe+1
      weightc( 46, 64,  3)=                 -0.03217650741135533871d0
      iwe=iwe+1
      weightc( 47, 64,  3)=                  0.01453120524083108267d0
      iwe=iwe+1
      weightc( 48, 64,  3)=                 -0.47545266486634757408d0
      iwe=iwe+1
      weightc( 49, 64,  3)=                  0.16729053656753961610d0
      iwe=iwe+1
      weightc( 50, 64,  3)=                 -0.79403873033959337935d0
      iwe=iwe+1
      biasc( 64,  3)=                  0.85918747584103682957d0
      iwe=iwe+1
      weightc(  1, 65,  3)=                  0.42159499320727272798d0
      iwe=iwe+1
      weightc(  2, 65,  3)=                 -0.13090659446635818930d0
      iwe=iwe+1
      weightc(  3, 65,  3)=                 -0.44679885593453438908d0
      iwe=iwe+1
      weightc(  4, 65,  3)=                 -0.26425410097836093959d0
      iwe=iwe+1
      weightc(  5, 65,  3)=                 -0.22399261085261848447d0
      iwe=iwe+1
      weightc(  6, 65,  3)=                 -0.08675669752926117029d0
      iwe=iwe+1
      weightc(  7, 65,  3)=                  0.49314734528009224190d0
      iwe=iwe+1
      weightc(  8, 65,  3)=                  0.07073386321014552003d0
      iwe=iwe+1
      weightc(  9, 65,  3)=                  0.27804193783446240484d0
      iwe=iwe+1
      weightc( 10, 65,  3)=                  0.01111289364229465192d0
      iwe=iwe+1
      weightc( 11, 65,  3)=                 -0.42461620716111520002d0
      iwe=iwe+1
      weightc( 12, 65,  3)=                 -0.10705500407651447059d0
      iwe=iwe+1
      weightc( 13, 65,  3)=                  0.25832079959641196520d0
      iwe=iwe+1
      weightc( 14, 65,  3)=                  0.28141732077724024297d0
      iwe=iwe+1
      weightc( 15, 65,  3)=                  0.03712216693546143559d0
      iwe=iwe+1
      weightc( 16, 65,  3)=                 -0.36123766044956612253d0
      iwe=iwe+1
      weightc( 17, 65,  3)=                 -0.20366140973903634759d0
      iwe=iwe+1
      weightc( 18, 65,  3)=                  0.14004552828716998469d0
      iwe=iwe+1
      weightc( 19, 65,  3)=                  0.25773614864127808444d0
      iwe=iwe+1
      weightc( 20, 65,  3)=                  0.33999442191966533500d0
      iwe=iwe+1
      weightc( 21, 65,  3)=                 -0.15300497577901239765d0
      iwe=iwe+1
      weightc( 22, 65,  3)=                 -0.01128048308924659363d0
      iwe=iwe+1
      weightc( 23, 65,  3)=                  0.11513052912763867275d0
      iwe=iwe+1
      weightc( 24, 65,  3)=                 -0.27455861566048156419d0
      iwe=iwe+1
      weightc( 25, 65,  3)=                 -0.10826699899068263633d0
      iwe=iwe+1
      weightc( 26, 65,  3)=                 -0.08608450161665315292d0
      iwe=iwe+1
      weightc( 27, 65,  3)=                  0.02399997707060555485d0
      iwe=iwe+1
      weightc( 28, 65,  3)=                  0.33772962918569793267d0
      iwe=iwe+1
      weightc( 29, 65,  3)=                 -0.40476884685073372117d0
      iwe=iwe+1
      weightc( 30, 65,  3)=                 -0.24648312469486055587d0
      iwe=iwe+1
      weightc( 31, 65,  3)=                  0.53400559818448489757d0
      iwe=iwe+1
      weightc( 32, 65,  3)=                 -0.31438195816993619314d0
      iwe=iwe+1
      weightc( 33, 65,  3)=                  0.21809031758968200343d0
      iwe=iwe+1
      weightc( 34, 65,  3)=                  0.03526737480002365560d0
      iwe=iwe+1
      weightc( 35, 65,  3)=                 -0.04595133165057982416d0
      iwe=iwe+1
      weightc( 36, 65,  3)=                 -0.32794696202687773079d0
      iwe=iwe+1
      weightc( 37, 65,  3)=                  0.38007736726839913555d0
      iwe=iwe+1
      weightc( 38, 65,  3)=                  0.10645585216783645666d0
      iwe=iwe+1
      weightc( 39, 65,  3)=                  0.24003487277771828889d0
      iwe=iwe+1
      weightc( 40, 65,  3)=                 -0.11207060259427523152d0
      iwe=iwe+1
      weightc( 41, 65,  3)=                  0.41555431529934527823d0
      iwe=iwe+1
      weightc( 42, 65,  3)=                  0.28774664131363653086d0
      iwe=iwe+1
      weightc( 43, 65,  3)=                 -0.17728967014928198598d0
      iwe=iwe+1
      weightc( 44, 65,  3)=                  0.00864052559069968494d0
      iwe=iwe+1
      weightc( 45, 65,  3)=                 -0.18484083702571385555d0
      iwe=iwe+1
      weightc( 46, 65,  3)=                 -0.24891167454069068610d0
      iwe=iwe+1
      weightc( 47, 65,  3)=                  0.06375334213852339171d0
      iwe=iwe+1
      weightc( 48, 65,  3)=                  0.19814889926250256469d0
      iwe=iwe+1
      weightc( 49, 65,  3)=                  0.51962930150224273529d0
      iwe=iwe+1
      weightc( 50, 65,  3)=                 -0.42601700530973229952d0
      iwe=iwe+1
      biasc( 65,  3)=                  0.83195773926612803795d0
      iwe=iwe+1
      weightc(  1, 66,  3)=                  0.24637862065002114065d0
      iwe=iwe+1
      weightc(  2, 66,  3)=                  0.05113707000259123947d0
      iwe=iwe+1
      weightc(  3, 66,  3)=                 -0.08556338610022835856d0
      iwe=iwe+1
      weightc(  4, 66,  3)=                 -0.25404772899410937859d0
      iwe=iwe+1
      weightc(  5, 66,  3)=                  0.20330683482248607108d0
      iwe=iwe+1
      weightc(  6, 66,  3)=                 -0.14609561840420340340d0
      iwe=iwe+1
      weightc(  7, 66,  3)=                  0.20743731301128529032d0
      iwe=iwe+1
      weightc(  8, 66,  3)=                 -0.59329876022428451599d0
      iwe=iwe+1
      weightc(  9, 66,  3)=                 -0.17699596638999676168d0
      iwe=iwe+1
      weightc( 10, 66,  3)=                 -0.29145100622561798120d0
      iwe=iwe+1
      weightc( 11, 66,  3)=                  0.14519861025257008169d0
      iwe=iwe+1
      weightc( 12, 66,  3)=                 -0.50583686880455658308d0
      iwe=iwe+1
      weightc( 13, 66,  3)=                  0.18225158616911721343d0
      iwe=iwe+1
      weightc( 14, 66,  3)=                 -0.12570491989642143538d0
      iwe=iwe+1
      weightc( 15, 66,  3)=                 -0.28854535024089433826d0
      iwe=iwe+1
      weightc( 16, 66,  3)=                  0.23726550432008228220d0
      iwe=iwe+1
      weightc( 17, 66,  3)=                  0.12972413122771586647d0
      iwe=iwe+1
      weightc( 18, 66,  3)=                 -0.05977674602080065153d0
      iwe=iwe+1
      weightc( 19, 66,  3)=                  0.12836579652160101661d0
      iwe=iwe+1
      weightc( 20, 66,  3)=                 -0.05077471402795529637d0
      iwe=iwe+1
      weightc( 21, 66,  3)=                 -0.19830659885719217894d0
      iwe=iwe+1
      weightc( 22, 66,  3)=                  0.27722674701603883252d0
      iwe=iwe+1
      weightc( 23, 66,  3)=                 -0.06296663618602925394d0
      iwe=iwe+1
      weightc( 24, 66,  3)=                 -0.13827172055006164975d0
      iwe=iwe+1
      weightc( 25, 66,  3)=                  0.18890051995424791964d0
      iwe=iwe+1
      weightc( 26, 66,  3)=                 -0.23239207612359633059d0
      iwe=iwe+1
      weightc( 27, 66,  3)=                  0.12995711747819474469d0
      iwe=iwe+1
      weightc( 28, 66,  3)=                  0.23453488070050801384d0
      iwe=iwe+1
      weightc( 29, 66,  3)=                 -0.05292849881458690925d0
      iwe=iwe+1
      weightc( 30, 66,  3)=                 -0.23491404862363118866d0
      iwe=iwe+1
      weightc( 31, 66,  3)=                  0.54424391430889440535d0
      iwe=iwe+1
      weightc( 32, 66,  3)=                  0.43801786182317792306d0
      iwe=iwe+1
      weightc( 33, 66,  3)=                 -0.25645578622256337553d0
      iwe=iwe+1
      weightc( 34, 66,  3)=                 -0.05673352476481832718d0
      iwe=iwe+1
      weightc( 35, 66,  3)=                  0.21905024539392239924d0
      iwe=iwe+1
      weightc( 36, 66,  3)=                  0.31451732037572194267d0
      iwe=iwe+1
      weightc( 37, 66,  3)=                 -0.47483693148218975022d0
      iwe=iwe+1
      weightc( 38, 66,  3)=                 -0.18009966619886658146d0
      iwe=iwe+1
      weightc( 39, 66,  3)=                  0.13784115192057075361d0
      iwe=iwe+1
      weightc( 40, 66,  3)=                 -0.22109258685128166388d0
      iwe=iwe+1
      weightc( 41, 66,  3)=                  0.03878486107586814891d0
      iwe=iwe+1
      weightc( 42, 66,  3)=                  0.26766209247231531609d0
      iwe=iwe+1
      weightc( 43, 66,  3)=                  0.21949288157885449291d0
      iwe=iwe+1
      weightc( 44, 66,  3)=                 -0.07530974794892870972d0
      iwe=iwe+1
      weightc( 45, 66,  3)=                  0.25825429592363974285d0
      iwe=iwe+1
      weightc( 46, 66,  3)=                  0.27600277432616798778d0
      iwe=iwe+1
      weightc( 47, 66,  3)=                 -0.38117678207338057117d0
      iwe=iwe+1
      weightc( 48, 66,  3)=                  0.10909292246641383306d0
      iwe=iwe+1
      weightc( 49, 66,  3)=                 -0.34952974505135137040d0
      iwe=iwe+1
      weightc( 50, 66,  3)=                 -0.14303446470026859316d0
      iwe=iwe+1
      biasc( 66,  3)=                  0.94357007729954256448d0
      iwe=iwe+1
      weightc(  1, 67,  3)=                  0.15292696052802298712d0
      iwe=iwe+1
      weightc(  2, 67,  3)=                 -0.73983622113619607052d0
      iwe=iwe+1
      weightc(  3, 67,  3)=                 -0.12632277814130224436d0
      iwe=iwe+1
      weightc(  4, 67,  3)=                  0.11030192683946814236d0
      iwe=iwe+1
      weightc(  5, 67,  3)=                 -0.34094340521343807771d0
      iwe=iwe+1
      weightc(  6, 67,  3)=                  0.11394145585300836931d0
      iwe=iwe+1
      weightc(  7, 67,  3)=                 -0.03270204169255008786d0
      iwe=iwe+1
      weightc(  8, 67,  3)=                  0.82342732998970424863d0
      iwe=iwe+1
      weightc(  9, 67,  3)=                 -0.17538994303338417691d0
      iwe=iwe+1
      weightc( 10, 67,  3)=                  0.26335489941663681179d0
      iwe=iwe+1
      weightc( 11, 67,  3)=                  0.35210076737180767692d0
      iwe=iwe+1
      weightc( 12, 67,  3)=                 -0.16650917542871065957d0
      iwe=iwe+1
      weightc( 13, 67,  3)=                 -0.08163618636471374479d0
      iwe=iwe+1
      weightc( 14, 67,  3)=                 -0.06152381905665352951d0
      iwe=iwe+1
      weightc( 15, 67,  3)=                 -0.30819806897267409962d0
      iwe=iwe+1
      weightc( 16, 67,  3)=                  0.32258989750424699183d0
      iwe=iwe+1
      weightc( 17, 67,  3)=                  0.09827920086652869314d0
      iwe=iwe+1
      weightc( 18, 67,  3)=                  0.11993125525470155202d0
      iwe=iwe+1
      weightc( 19, 67,  3)=                  0.02150192042026552453d0
      iwe=iwe+1
      weightc( 20, 67,  3)=                 -0.02691554383245365473d0
      iwe=iwe+1
      weightc( 21, 67,  3)=                  0.15767731556871772414d0
      iwe=iwe+1
      weightc( 22, 67,  3)=                  0.07540984514421950058d0
      iwe=iwe+1
      weightc( 23, 67,  3)=                  0.78378395405721867917d0
      iwe=iwe+1
      weightc( 24, 67,  3)=                  0.58593681859240598353d0
      iwe=iwe+1
      weightc( 25, 67,  3)=                  0.20591619386498016819d0
      iwe=iwe+1
      weightc( 26, 67,  3)=                 -0.08411390758114545285d0
      iwe=iwe+1
      weightc( 27, 67,  3)=                  0.28231448539352566041d0
      iwe=iwe+1
      weightc( 28, 67,  3)=                  0.37572034811102039686d0
      iwe=iwe+1
      weightc( 29, 67,  3)=                  0.32414419645647740698d0
      iwe=iwe+1
      weightc( 30, 67,  3)=                 -0.26626660135578045230d0
      iwe=iwe+1
      weightc( 31, 67,  3)=                  0.25462788637637062683d0
      iwe=iwe+1
      weightc( 32, 67,  3)=                  0.13277823488784151751d0
      iwe=iwe+1
      weightc( 33, 67,  3)=                  0.20666279210835147850d0
      iwe=iwe+1
      weightc( 34, 67,  3)=                 -0.61706130970375272504d0
      iwe=iwe+1
      weightc( 35, 67,  3)=                 -0.04941798666642653604d0
      iwe=iwe+1
      weightc( 36, 67,  3)=                 -0.30114254178654703553d0
      iwe=iwe+1
      weightc( 37, 67,  3)=                 -0.07807588899030078189d0
      iwe=iwe+1
      weightc( 38, 67,  3)=                 -0.20005012949218992091d0
      iwe=iwe+1
      weightc( 39, 67,  3)=                 -0.04039049086573185537d0
      iwe=iwe+1
      weightc( 40, 67,  3)=                  0.04861091397862606078d0
      iwe=iwe+1
      weightc( 41, 67,  3)=                 -0.28943542910710573501d0
      iwe=iwe+1
      weightc( 42, 67,  3)=                 -0.20872014305673960988d0
      iwe=iwe+1
      weightc( 43, 67,  3)=                  0.02301931587476074154d0
      iwe=iwe+1
      weightc( 44, 67,  3)=                  0.47282262625707355275d0
      iwe=iwe+1
      weightc( 45, 67,  3)=                  0.28540283197329902043d0
      iwe=iwe+1
      weightc( 46, 67,  3)=                 -0.12430771664643064378d0
      iwe=iwe+1
      weightc( 47, 67,  3)=                  0.12509380554820792586d0
      iwe=iwe+1
      weightc( 48, 67,  3)=                  0.26355686654804699742d0
      iwe=iwe+1
      weightc( 49, 67,  3)=                  1.02087829731148871382d0
      iwe=iwe+1
      weightc( 50, 67,  3)=                  0.39458325009826727969d0
      iwe=iwe+1
      biasc( 67,  3)=                 -0.86015939603862667795d0
      iwe=iwe+1
      weightc(  1, 68,  3)=                 -0.37069603547142904176d0
      iwe=iwe+1
      weightc(  2, 68,  3)=                  0.22970594518866235823d0
      iwe=iwe+1
      weightc(  3, 68,  3)=                 -0.11139390010906508044d0
      iwe=iwe+1
      weightc(  4, 68,  3)=                 -0.12143485518103058762d0
      iwe=iwe+1
      weightc(  5, 68,  3)=                 -0.47498186893855220969d0
      iwe=iwe+1
      weightc(  6, 68,  3)=                 -0.12931021712812401647d0
      iwe=iwe+1
      weightc(  7, 68,  3)=                 -0.36248885749031017900d0
      iwe=iwe+1
      weightc(  8, 68,  3)=                 -0.21913805023318597143d0
      iwe=iwe+1
      weightc(  9, 68,  3)=                  0.15577461218824609213d0
      iwe=iwe+1
      weightc( 10, 68,  3)=                 -0.22429965265499038352d0
      iwe=iwe+1
      weightc( 11, 68,  3)=                 -0.68167979250106547351d0
      iwe=iwe+1
      weightc( 12, 68,  3)=                 -0.29153264802004830170d0
      iwe=iwe+1
      weightc( 13, 68,  3)=                 -0.31158752880241114003d0
      iwe=iwe+1
      weightc( 14, 68,  3)=                 -0.37255926013468138036d0
      iwe=iwe+1
      weightc( 15, 68,  3)=                  0.18402591597000059198d0
      iwe=iwe+1
      weightc( 16, 68,  3)=                  0.25043397475298073696d0
      iwe=iwe+1
      weightc( 17, 68,  3)=                 -0.39665218212358027694d0
      iwe=iwe+1
      weightc( 18, 68,  3)=                 -0.00278527078531019649d0
      iwe=iwe+1
      weightc( 19, 68,  3)=                 -0.18558695938932862068d0
      iwe=iwe+1
      weightc( 20, 68,  3)=                 -0.29514294104921984241d0
      iwe=iwe+1
      weightc( 21, 68,  3)=                 -0.22476665199464324063d0
      iwe=iwe+1
      weightc( 22, 68,  3)=                 -0.21474240553557533140d0
      iwe=iwe+1
      weightc( 23, 68,  3)=                 -0.03213984301206892352d0
      iwe=iwe+1
      weightc( 24, 68,  3)=                  0.04990245660995837329d0
      iwe=iwe+1
      weightc( 25, 68,  3)=                 -0.18254881521486782114d0
      iwe=iwe+1
      weightc( 26, 68,  3)=                  0.06984174221911051972d0
      iwe=iwe+1
      weightc( 27, 68,  3)=                 -0.55653234757559799650d0
      iwe=iwe+1
      weightc( 28, 68,  3)=                  0.11874469678892879410d0
      iwe=iwe+1
      weightc( 29, 68,  3)=                  0.41088015633916308289d0
      iwe=iwe+1
      weightc( 30, 68,  3)=                 -0.11413357066521666316d0
      iwe=iwe+1
      weightc( 31, 68,  3)=                 -0.68057203263913568225d0
      iwe=iwe+1
      weightc( 32, 68,  3)=                  0.16952412833044608331d0
      iwe=iwe+1
      weightc( 33, 68,  3)=                 -0.20770071060140563035d0
      iwe=iwe+1
      weightc( 34, 68,  3)=                 -0.17751044961932102573d0
      iwe=iwe+1
      weightc( 35, 68,  3)=                  0.48633404677062674892d0
      iwe=iwe+1
      weightc( 36, 68,  3)=                 -0.04677640743577190369d0
      iwe=iwe+1
      weightc( 37, 68,  3)=                 -0.13842954077632541043d0
      iwe=iwe+1
      weightc( 38, 68,  3)=                  0.25988449976176786205d0
      iwe=iwe+1
      weightc( 39, 68,  3)=                 -0.33147316679540300699d0
      iwe=iwe+1
      weightc( 40, 68,  3)=                 -0.10503429622244613018d0
      iwe=iwe+1
      weightc( 41, 68,  3)=                 -0.13184112561008420883d0
      iwe=iwe+1
      weightc( 42, 68,  3)=                  0.37426671497586827542d0
      iwe=iwe+1
      weightc( 43, 68,  3)=                  0.26825328013461935406d0
      iwe=iwe+1
      weightc( 44, 68,  3)=                 -0.13230762156456854495d0
      iwe=iwe+1
      weightc( 45, 68,  3)=                  0.03362325478533916695d0
      iwe=iwe+1
      weightc( 46, 68,  3)=                 -0.23122049815124751104d0
      iwe=iwe+1
      weightc( 47, 68,  3)=                  0.29097903860493229411d0
      iwe=iwe+1
      weightc( 48, 68,  3)=                  0.21825214086834718308d0
      iwe=iwe+1
      weightc( 49, 68,  3)=                  0.15304407020105859072d0
      iwe=iwe+1
      weightc( 50, 68,  3)=                  0.21814787695839890636d0
      iwe=iwe+1
      biasc( 68,  3)=                  1.05026697141448455142d0
      iwe=iwe+1
      weightc(  1, 69,  3)=                  0.74080532853506653179d0
      iwe=iwe+1
      weightc(  2, 69,  3)=                  0.41272793954397352101d0
      iwe=iwe+1
      weightc(  3, 69,  3)=                  0.16005529748459809691d0
      iwe=iwe+1
      weightc(  4, 69,  3)=                 -0.18290102565036614468d0
      iwe=iwe+1
      weightc(  5, 69,  3)=                  0.20246556253781747281d0
      iwe=iwe+1
      weightc(  6, 69,  3)=                 -0.13638770807941691388d0
      iwe=iwe+1
      weightc(  7, 69,  3)=                  0.37805861929937339960d0
      iwe=iwe+1
      weightc(  8, 69,  3)=                 -0.30875841578155877043d0
      iwe=iwe+1
      weightc(  9, 69,  3)=                  0.09210768174040391554d0
      iwe=iwe+1
      weightc( 10, 69,  3)=                  0.02947084951850185985d0
      iwe=iwe+1
      weightc( 11, 69,  3)=                 -0.15169489429090543542d0
      iwe=iwe+1
      weightc( 12, 69,  3)=                 -0.35037694977057809442d0
      iwe=iwe+1
      weightc( 13, 69,  3)=                 -0.03884355767550605465d0
      iwe=iwe+1
      weightc( 14, 69,  3)=                 -0.09125737352442403472d0
      iwe=iwe+1
      weightc( 15, 69,  3)=                  0.26242028102558379032d0
      iwe=iwe+1
      weightc( 16, 69,  3)=                 -0.01097930121915600965d0
      iwe=iwe+1
      weightc( 17, 69,  3)=                  0.24261893245928906060d0
      iwe=iwe+1
      weightc( 18, 69,  3)=                 -0.58314505185505460805d0
      iwe=iwe+1
      weightc( 19, 69,  3)=                 -0.08435259645521096805d0
      iwe=iwe+1
      weightc( 20, 69,  3)=                 -0.33263483766477236481d0
      iwe=iwe+1
      weightc( 21, 69,  3)=                  0.09035354514395470271d0
      iwe=iwe+1
      weightc( 22, 69,  3)=                  0.19471334021368696954d0
      iwe=iwe+1
      weightc( 23, 69,  3)=                 -0.03143781644519551277d0
      iwe=iwe+1
      weightc( 24, 69,  3)=                  0.31701964814994493258d0
      iwe=iwe+1
      weightc( 25, 69,  3)=                  0.17310570060971411377d0
      iwe=iwe+1
      weightc( 26, 69,  3)=                  0.38731279003880841882d0
      iwe=iwe+1
      weightc( 27, 69,  3)=                 -0.49558669605365862632d0
      iwe=iwe+1
      weightc( 28, 69,  3)=                  0.35125515854641270463d0
      iwe=iwe+1
      weightc( 29, 69,  3)=                 -0.16045147135297502250d0
      iwe=iwe+1
      weightc( 30, 69,  3)=                  0.32991007668346894466d0
      iwe=iwe+1
      weightc( 31, 69,  3)=                 -0.40188495913801058901d0
      iwe=iwe+1
      weightc( 32, 69,  3)=                 -0.46161254857361005977d0
      iwe=iwe+1
      weightc( 33, 69,  3)=                 -0.22074696897929210748d0
      iwe=iwe+1
      weightc( 34, 69,  3)=                 -0.32751122889857020581d0
      iwe=iwe+1
      weightc( 35, 69,  3)=                  0.05307553036729763946d0
      iwe=iwe+1
      weightc( 36, 69,  3)=                  0.41220280938384223912d0
      iwe=iwe+1
      weightc( 37, 69,  3)=                  0.07867250719905266587d0
      iwe=iwe+1
      weightc( 38, 69,  3)=                 -0.18989609710697666345d0
      iwe=iwe+1
      weightc( 39, 69,  3)=                 -0.29599463477522219845d0
      iwe=iwe+1
      weightc( 40, 69,  3)=                 -0.29643314026015155083d0
      iwe=iwe+1
      weightc( 41, 69,  3)=                  0.08679242715880515491d0
      iwe=iwe+1
      weightc( 42, 69,  3)=                  0.14262309257013991437d0
      iwe=iwe+1
      weightc( 43, 69,  3)=                  0.21757391234484430020d0
      iwe=iwe+1
      weightc( 44, 69,  3)=                  0.48692917857100082024d0
      iwe=iwe+1
      weightc( 45, 69,  3)=                 -0.03555688090937290935d0
      iwe=iwe+1
      weightc( 46, 69,  3)=                 -0.20204812325006518692d0
      iwe=iwe+1
      weightc( 47, 69,  3)=                 -0.45326553581085859967d0
      iwe=iwe+1
      weightc( 48, 69,  3)=                  0.02505032513469981903d0
      iwe=iwe+1
      weightc( 49, 69,  3)=                 -0.29049222039407307516d0
      iwe=iwe+1
      weightc( 50, 69,  3)=                 -0.49815173979613130983d0
      iwe=iwe+1
      biasc( 69,  3)=                  1.22715415277297412722d0
      iwe=iwe+1
      weightc(  1, 70,  3)=                  0.20030857140538960159d0
      iwe=iwe+1
      weightc(  2, 70,  3)=                  0.09522527193517460464d0
      iwe=iwe+1
      weightc(  3, 70,  3)=                  0.06641595727761631651d0
      iwe=iwe+1
      weightc(  4, 70,  3)=                  0.22335581605713031306d0
      iwe=iwe+1
      weightc(  5, 70,  3)=                  0.17853519319972024904d0
      iwe=iwe+1
      weightc(  6, 70,  3)=                  0.34843989503951711129d0
      iwe=iwe+1
      weightc(  7, 70,  3)=                 -0.03869344582504732899d0
      iwe=iwe+1
      weightc(  8, 70,  3)=                 -0.05397104486821551611d0
      iwe=iwe+1
      weightc(  9, 70,  3)=                 -0.09465307457305072170d0
      iwe=iwe+1
      weightc( 10, 70,  3)=                  0.26482736874322365672d0
      iwe=iwe+1
      weightc( 11, 70,  3)=                  0.37746564653130515454d0
      iwe=iwe+1
      weightc( 12, 70,  3)=                 -0.16148242853275188158d0
      iwe=iwe+1
      weightc( 13, 70,  3)=                 -0.23408610859779693802d0
      iwe=iwe+1
      weightc( 14, 70,  3)=                 -0.10741809811064149949d0
      iwe=iwe+1
      weightc( 15, 70,  3)=                 -0.06614166084926562106d0
      iwe=iwe+1
      weightc( 16, 70,  3)=                  0.33149399690519204542d0
      iwe=iwe+1
      weightc( 17, 70,  3)=                 -0.24705018975886575139d0
      iwe=iwe+1
      weightc( 18, 70,  3)=                 -0.20551987833957022223d0
      iwe=iwe+1
      weightc( 19, 70,  3)=                  0.36930631393332563617d0
      iwe=iwe+1
      weightc( 20, 70,  3)=                 -0.29945978762746994217d0
      iwe=iwe+1
      weightc( 21, 70,  3)=                 -0.09971193502699136901d0
      iwe=iwe+1
      weightc( 22, 70,  3)=                 -0.31498649235362574661d0
      iwe=iwe+1
      weightc( 23, 70,  3)=                  0.25271945768375475572d0
      iwe=iwe+1
      weightc( 24, 70,  3)=                 -0.16097184375091228015d0
      iwe=iwe+1
      weightc( 25, 70,  3)=                 -0.06816071317330375801d0
      iwe=iwe+1
      weightc( 26, 70,  3)=                  0.18138855670658854402d0
      iwe=iwe+1
      weightc( 27, 70,  3)=                 -0.01668037070483097128d0
      iwe=iwe+1
      weightc( 28, 70,  3)=                  0.17527479191075548415d0
      iwe=iwe+1
      weightc( 29, 70,  3)=                 -0.00492727845526757212d0
      iwe=iwe+1
      weightc( 30, 70,  3)=                 -0.12304349231850499058d0
      iwe=iwe+1
      weightc( 31, 70,  3)=                  0.01787024955563967440d0
      iwe=iwe+1
      weightc( 32, 70,  3)=                  0.13448667947984976889d0
      iwe=iwe+1
      weightc( 33, 70,  3)=                 -0.40191297748563747927d0
      iwe=iwe+1
      weightc( 34, 70,  3)=                 -0.34889621802977149878d0
      iwe=iwe+1
      weightc( 35, 70,  3)=                  0.13180523568230256837d0
      iwe=iwe+1
      weightc( 36, 70,  3)=                  0.05480273464245580956d0
      iwe=iwe+1
      weightc( 37, 70,  3)=                  0.27668149966037736132d0
      iwe=iwe+1
      weightc( 38, 70,  3)=                  0.08095070224863670783d0
      iwe=iwe+1
      weightc( 39, 70,  3)=                  0.14061380008486595861d0
      iwe=iwe+1
      weightc( 40, 70,  3)=                  0.34014907812922939856d0
      iwe=iwe+1
      weightc( 41, 70,  3)=                  0.28069532212722536624d0
      iwe=iwe+1
      weightc( 42, 70,  3)=                 -0.09986994585854812312d0
      iwe=iwe+1
      weightc( 43, 70,  3)=                  0.32312337101654226013d0
      iwe=iwe+1
      weightc( 44, 70,  3)=                  0.20514088403797561821d0
      iwe=iwe+1
      weightc( 45, 70,  3)=                  0.14927252447240951794d0
      iwe=iwe+1
      weightc( 46, 70,  3)=                  0.02841053599445072034d0
      iwe=iwe+1
      weightc( 47, 70,  3)=                 -0.11779751440076635660d0
      iwe=iwe+1
      weightc( 48, 70,  3)=                  0.28363164392317635754d0
      iwe=iwe+1
      weightc( 49, 70,  3)=                 -0.36359586953095446304d0
      iwe=iwe+1
      weightc( 50, 70,  3)=                 -0.24053439352168515253d0
      iwe=iwe+1
      biasc( 70,  3)=                  1.15381748621035451485d0
      iwe=iwe+1
      weightc(  1, 71,  3)=                 -0.29288577810248278555d0
      iwe=iwe+1
      weightc(  2, 71,  3)=                 -0.09801359475175457081d0
      iwe=iwe+1
      weightc(  3, 71,  3)=                 -0.19835657507443565928d0
      iwe=iwe+1
      weightc(  4, 71,  3)=                  0.19032153607175744670d0
      iwe=iwe+1
      weightc(  5, 71,  3)=                  0.14753657418691029646d0
      iwe=iwe+1
      weightc(  6, 71,  3)=                 -0.16973057345120537431d0
      iwe=iwe+1
      weightc(  7, 71,  3)=                  0.26035571060147633116d0
      iwe=iwe+1
      weightc(  8, 71,  3)=                 -0.25426333354490321392d0
      iwe=iwe+1
      weightc(  9, 71,  3)=                  0.33594006333543280363d0
      iwe=iwe+1
      weightc( 10, 71,  3)=                  0.05300215734691580277d0
      iwe=iwe+1
      weightc( 11, 71,  3)=                 -0.14501090521653800525d0
      iwe=iwe+1
      weightc( 12, 71,  3)=                  0.19916539494429147394d0
      iwe=iwe+1
      weightc( 13, 71,  3)=                 -0.30071091738288358020d0
      iwe=iwe+1
      weightc( 14, 71,  3)=                  0.35511184268884654625d0
      iwe=iwe+1
      weightc( 15, 71,  3)=                 -0.41241177521189242849d0
      iwe=iwe+1
      weightc( 16, 71,  3)=                  0.46385398527315757633d0
      iwe=iwe+1
      weightc( 17, 71,  3)=                  0.69174899633978748081d0
      iwe=iwe+1
      weightc( 18, 71,  3)=                 -0.11669547398764743007d0
      iwe=iwe+1
      weightc( 19, 71,  3)=                  0.20856724880036708880d0
      iwe=iwe+1
      weightc( 20, 71,  3)=                 -0.17384083731612973156d0
      iwe=iwe+1
      weightc( 21, 71,  3)=                  0.26090558225423932104d0
      iwe=iwe+1
      weightc( 22, 71,  3)=                 -0.25148033865062513481d0
      iwe=iwe+1
      weightc( 23, 71,  3)=                 -0.31908183681277529908d0
      iwe=iwe+1
      weightc( 24, 71,  3)=                 -0.29567187071415718114d0
      iwe=iwe+1
      weightc( 25, 71,  3)=                 -0.29987291334991061920d0
      iwe=iwe+1
      weightc( 26, 71,  3)=                 -0.12598731281877736943d0
      iwe=iwe+1
      weightc( 27, 71,  3)=                 -0.10987942991085532241d0
      iwe=iwe+1
      weightc( 28, 71,  3)=                 -0.13915385083290826573d0
      iwe=iwe+1
      weightc( 29, 71,  3)=                 -0.10766436456071978855d0
      iwe=iwe+1
      weightc( 30, 71,  3)=                 -0.04217542298943950663d0
      iwe=iwe+1
      weightc( 31, 71,  3)=                 -0.12636484307771006508d0
      iwe=iwe+1
      weightc( 32, 71,  3)=                  0.73489956173058146316d0
      iwe=iwe+1
      weightc( 33, 71,  3)=                  0.12558085782506617223d0
      iwe=iwe+1
      weightc( 34, 71,  3)=                 -0.30405945867650152614d0
      iwe=iwe+1
      weightc( 35, 71,  3)=                 -0.37377949464716397898d0
      iwe=iwe+1
      weightc( 36, 71,  3)=                 -0.39138833155485414084d0
      iwe=iwe+1
      weightc( 37, 71,  3)=                 -0.31671280836558235450d0
      iwe=iwe+1
      weightc( 38, 71,  3)=                 -0.03756362434308247594d0
      iwe=iwe+1
      weightc( 39, 71,  3)=                 -0.04828336152996474256d0
      iwe=iwe+1
      weightc( 40, 71,  3)=                  0.25522820201310914001d0
      iwe=iwe+1
      weightc( 41, 71,  3)=                  0.05701202699234633742d0
      iwe=iwe+1
      weightc( 42, 71,  3)=                 -0.52548424274412675050d0
      iwe=iwe+1
      weightc( 43, 71,  3)=                 -0.18781200903989114792d0
      iwe=iwe+1
      weightc( 44, 71,  3)=                 -0.05432119119623282644d0
      iwe=iwe+1
      weightc( 45, 71,  3)=                  0.24660751252169157977d0
      iwe=iwe+1
      weightc( 46, 71,  3)=                  0.04710332900332467321d0
      iwe=iwe+1
      weightc( 47, 71,  3)=                  0.21260790505034252162d0
      iwe=iwe+1
      weightc( 48, 71,  3)=                  0.33171439485490755716d0
      iwe=iwe+1
      weightc( 49, 71,  3)=                 -0.17073798326580319484d0
      iwe=iwe+1
      weightc( 50, 71,  3)=                  0.53420054337721656346d0
      iwe=iwe+1
      biasc( 71,  3)=                 -1.16877908387719076089d0
      iwe=iwe+1
      weightc(  1, 72,  3)=                 -0.01792274848528181350d0
      iwe=iwe+1
      weightc(  2, 72,  3)=                  0.04627388994089385449d0
      iwe=iwe+1
      weightc(  3, 72,  3)=                 -0.18901077200180921301d0
      iwe=iwe+1
      weightc(  4, 72,  3)=                 -0.11631262462742504582d0
      iwe=iwe+1
      weightc(  5, 72,  3)=                 -0.07641220044852679860d0
      iwe=iwe+1
      weightc(  6, 72,  3)=                  0.06685274983368180712d0
      iwe=iwe+1
      weightc(  7, 72,  3)=                  0.01190826872142395493d0
      iwe=iwe+1
      weightc(  8, 72,  3)=                 -0.19982792483676775630d0
      iwe=iwe+1
      weightc(  9, 72,  3)=                 -0.37129700391365760836d0
      iwe=iwe+1
      weightc( 10, 72,  3)=                  0.12105958241184999746d0
      iwe=iwe+1
      weightc( 11, 72,  3)=                  0.01248667642349245502d0
      iwe=iwe+1
      weightc( 12, 72,  3)=                  0.12177220493057562545d0
      iwe=iwe+1
      weightc( 13, 72,  3)=                  0.36005196569153224972d0
      iwe=iwe+1
      weightc( 14, 72,  3)=                  0.07894017139449291398d0
      iwe=iwe+1
      weightc( 15, 72,  3)=                 -0.03826560192254567505d0
      iwe=iwe+1
      weightc( 16, 72,  3)=                  0.12069906182652009874d0
      iwe=iwe+1
      weightc( 17, 72,  3)=                 -0.00427607972348611164d0
      iwe=iwe+1
      weightc( 18, 72,  3)=                 -0.11145308450383105414d0
      iwe=iwe+1
      weightc( 19, 72,  3)=                  0.04728821378079841459d0
      iwe=iwe+1
      weightc( 20, 72,  3)=                  0.10224937406494727377d0
      iwe=iwe+1
      weightc( 21, 72,  3)=                  0.34928816134154966333d0
      iwe=iwe+1
      weightc( 22, 72,  3)=                  0.14815726186620811755d0
      iwe=iwe+1
      weightc( 23, 72,  3)=                  0.11956981692290816199d0
      iwe=iwe+1
      weightc( 24, 72,  3)=                  0.06214735866384906576d0
      iwe=iwe+1
      weightc( 25, 72,  3)=                  0.41920717185245748304d0
      iwe=iwe+1
      weightc( 26, 72,  3)=                  0.00381977981347424904d0
      iwe=iwe+1
      weightc( 27, 72,  3)=                 -0.07989333306630624909d0
      iwe=iwe+1
      weightc( 28, 72,  3)=                  0.13908736437449858991d0
      iwe=iwe+1
      weightc( 29, 72,  3)=                  0.16346263036534056101d0
      iwe=iwe+1
      weightc( 30, 72,  3)=                 -0.12442176748382785534d0
      iwe=iwe+1
      weightc( 31, 72,  3)=                 -0.26290208507617079947d0
      iwe=iwe+1
      weightc( 32, 72,  3)=                  0.36114939981125554480d0
      iwe=iwe+1
      weightc( 33, 72,  3)=                 -0.30205474405096277568d0
      iwe=iwe+1
      weightc( 34, 72,  3)=                 -0.23315338886317968359d0
      iwe=iwe+1
      weightc( 35, 72,  3)=                 -0.26183242093575215259d0
      iwe=iwe+1
      weightc( 36, 72,  3)=                 -0.08330497054405724966d0
      iwe=iwe+1
      weightc( 37, 72,  3)=                  0.23264842229273419161d0
      iwe=iwe+1
      weightc( 38, 72,  3)=                 -0.21356750137660032718d0
      iwe=iwe+1
      weightc( 39, 72,  3)=                 -0.15307141684156630457d0
      iwe=iwe+1
      weightc( 40, 72,  3)=                  0.05272245893540804251d0
      iwe=iwe+1
      weightc( 41, 72,  3)=                 -0.14007809050363978498d0
      iwe=iwe+1
      weightc( 42, 72,  3)=                 -0.25486932502388071065d0
      iwe=iwe+1
      weightc( 43, 72,  3)=                  0.11313978727403635471d0
      iwe=iwe+1
      weightc( 44, 72,  3)=                  0.14741165935700437095d0
      iwe=iwe+1
      weightc( 45, 72,  3)=                 -0.47299139777913756788d0
      iwe=iwe+1
      weightc( 46, 72,  3)=                 -0.22386330065706697146d0
      iwe=iwe+1
      weightc( 47, 72,  3)=                  0.23505151660441547801d0
      iwe=iwe+1
      weightc( 48, 72,  3)=                  0.42771687250740803021d0
      iwe=iwe+1
      weightc( 49, 72,  3)=                 -0.27290935217893547149d0
      iwe=iwe+1
      weightc( 50, 72,  3)=                 -0.44799724466171414461d0
      iwe=iwe+1
      biasc( 72,  3)=                 -1.33675691366042626029d0
      iwe=iwe+1
      weightc(  1, 73,  3)=                 -0.21565158563588310292d0
      iwe=iwe+1
      weightc(  2, 73,  3)=                  0.38659872087703961441d0
      iwe=iwe+1
      weightc(  3, 73,  3)=                  0.12203331706929733402d0
      iwe=iwe+1
      weightc(  4, 73,  3)=                  0.02466241181811152164d0
      iwe=iwe+1
      weightc(  5, 73,  3)=                 -0.33989266490784059149d0
      iwe=iwe+1
      weightc(  6, 73,  3)=                 -0.19176280776473011991d0
      iwe=iwe+1
      weightc(  7, 73,  3)=                  0.05092417064403852861d0
      iwe=iwe+1
      weightc(  8, 73,  3)=                 -0.41902137909305248176d0
      iwe=iwe+1
      weightc(  9, 73,  3)=                  0.06760698512014576278d0
      iwe=iwe+1
      weightc( 10, 73,  3)=                 -0.38362831264996588576d0
      iwe=iwe+1
      weightc( 11, 73,  3)=                 -0.14629921079894056546d0
      iwe=iwe+1
      weightc( 12, 73,  3)=                 -0.21131515794227864746d0
      iwe=iwe+1
      weightc( 13, 73,  3)=                  0.00035254391940960268d0
      iwe=iwe+1
      weightc( 14, 73,  3)=                 -0.07667406140594072717d0
      iwe=iwe+1
      weightc( 15, 73,  3)=                 -1.05845527352614121597d0
      iwe=iwe+1
      weightc( 16, 73,  3)=                  0.18570453772144027149d0
      iwe=iwe+1
      weightc( 17, 73,  3)=                 -0.12778392514352537868d0
      iwe=iwe+1
      weightc( 18, 73,  3)=                  0.02349652427962686113d0
      iwe=iwe+1
      weightc( 19, 73,  3)=                 -0.37946612965563908393d0
      iwe=iwe+1
      weightc( 20, 73,  3)=                  0.01184708929066983184d0
      iwe=iwe+1
      weightc( 21, 73,  3)=                  0.20613387355936127476d0
      iwe=iwe+1
      weightc( 22, 73,  3)=                  0.42748257203539580251d0
      iwe=iwe+1
      weightc( 23, 73,  3)=                 -0.21782124244705239335d0
      iwe=iwe+1
      weightc( 24, 73,  3)=                 -0.23414713564917807864d0
      iwe=iwe+1
      weightc( 25, 73,  3)=                  0.19568952519270410573d0
      iwe=iwe+1
      weightc( 26, 73,  3)=                  0.29286440192004159488d0
      iwe=iwe+1
      weightc( 27, 73,  3)=                 -0.85471336409753984054d0
      iwe=iwe+1
      weightc( 28, 73,  3)=                  0.12878685881141893610d0
      iwe=iwe+1
      weightc( 29, 73,  3)=                  0.26004215374586386877d0
      iwe=iwe+1
      weightc( 30, 73,  3)=                 -0.31419848365125252476d0
      iwe=iwe+1
      weightc( 31, 73,  3)=                 -0.61298091098762208517d0
      iwe=iwe+1
      weightc( 32, 73,  3)=                  0.18184778000816001486d0
      iwe=iwe+1
      weightc( 33, 73,  3)=                 -0.02129047147177952695d0
      iwe=iwe+1
      weightc( 34, 73,  3)=                 -0.00889807327595220493d0
      iwe=iwe+1
      weightc( 35, 73,  3)=                  0.07305214217999680959d0
      iwe=iwe+1
      weightc( 36, 73,  3)=                 -0.16071039959726254875d0
      iwe=iwe+1
      weightc( 37, 73,  3)=                 -0.42202976729894020602d0
      iwe=iwe+1
      weightc( 38, 73,  3)=                 -0.23475323036809547794d0
      iwe=iwe+1
      weightc( 39, 73,  3)=                 -0.28015233969805225511d0
      iwe=iwe+1
      weightc( 40, 73,  3)=                  0.52812436821184149949d0
      iwe=iwe+1
      weightc( 41, 73,  3)=                 -0.27847480655048501008d0
      iwe=iwe+1
      weightc( 42, 73,  3)=                  0.11368421826234159644d0
      iwe=iwe+1
      weightc( 43, 73,  3)=                  0.13870510088347304256d0
      iwe=iwe+1
      weightc( 44, 73,  3)=                 -0.08093256506911078452d0
      iwe=iwe+1
      weightc( 45, 73,  3)=                  0.21376718322021112662d0
      iwe=iwe+1
      weightc( 46, 73,  3)=                  0.23731713310266516759d0
      iwe=iwe+1
      weightc( 47, 73,  3)=                  0.15743016106245760755d0
      iwe=iwe+1
      weightc( 48, 73,  3)=                  0.28619052371232350795d0
      iwe=iwe+1
      weightc( 49, 73,  3)=                  0.42728602356444361776d0
      iwe=iwe+1
      weightc( 50, 73,  3)=                 -0.22579241121022214367d0
      iwe=iwe+1
      biasc( 73,  3)=                 -1.34332601525288342081d0
      iwe=iwe+1
      weightc(  1, 74,  3)=                  0.19651247471587232618d0
      iwe=iwe+1
      weightc(  2, 74,  3)=                  0.05432077583340001736d0
      iwe=iwe+1
      weightc(  3, 74,  3)=                 -0.07336818973103526043d0
      iwe=iwe+1
      weightc(  4, 74,  3)=                 -0.15798408492301685424d0
      iwe=iwe+1
      weightc(  5, 74,  3)=                  0.24861787478321240030d0
      iwe=iwe+1
      weightc(  6, 74,  3)=                 -0.18011687103873758042d0
      iwe=iwe+1
      weightc(  7, 74,  3)=                  0.19664997896658736876d0
      iwe=iwe+1
      weightc(  8, 74,  3)=                  0.12933646358133848997d0
      iwe=iwe+1
      weightc(  9, 74,  3)=                  0.38032248303054749794d0
      iwe=iwe+1
      weightc( 10, 74,  3)=                 -0.38055093457655564393d0
      iwe=iwe+1
      weightc( 11, 74,  3)=                  0.75950528436533049081d0
      iwe=iwe+1
      weightc( 12, 74,  3)=                 -0.35849048320629145481d0
      iwe=iwe+1
      weightc( 13, 74,  3)=                 -0.11750466877574455848d0
      iwe=iwe+1
      weightc( 14, 74,  3)=                  0.23024446738672557644d0
      iwe=iwe+1
      weightc( 15, 74,  3)=                  0.35007954719263789656d0
      iwe=iwe+1
      weightc( 16, 74,  3)=                 -0.02971037888034629149d0
      iwe=iwe+1
      weightc( 17, 74,  3)=                  0.41456700992413325624d0
      iwe=iwe+1
      weightc( 18, 74,  3)=                 -0.47612035331498231416d0
      iwe=iwe+1
      weightc( 19, 74,  3)=                 -0.64689396793072084790d0
      iwe=iwe+1
      weightc( 20, 74,  3)=                  0.43005460175445942017d0
      iwe=iwe+1
      weightc( 21, 74,  3)=                  0.25078381320563619683d0
      iwe=iwe+1
      weightc( 22, 74,  3)=                 -0.13725035270076146876d0
      iwe=iwe+1
      weightc( 23, 74,  3)=                  0.08582942456960983291d0
      iwe=iwe+1
      weightc( 24, 74,  3)=                 -0.28641372408314169640d0
      iwe=iwe+1
      weightc( 25, 74,  3)=                  0.50649773169993694832d0
      iwe=iwe+1
      weightc( 26, 74,  3)=                  0.04879637680176752285d0
      iwe=iwe+1
      weightc( 27, 74,  3)=                 -0.27798506588483357094d0
      iwe=iwe+1
      weightc( 28, 74,  3)=                 -0.43471071541247974235d0
      iwe=iwe+1
      weightc( 29, 74,  3)=                  0.13989974474889055323d0
      iwe=iwe+1
      weightc( 30, 74,  3)=                 -0.05303648522532402459d0
      iwe=iwe+1
      weightc( 31, 74,  3)=                 -0.31782158430729012810d0
      iwe=iwe+1
      weightc( 32, 74,  3)=                 -0.28392787782554462783d0
      iwe=iwe+1
      weightc( 33, 74,  3)=                  0.06857264224044991308d0
      iwe=iwe+1
      weightc( 34, 74,  3)=                  0.02865794453581037987d0
      iwe=iwe+1
      weightc( 35, 74,  3)=                 -0.26850428114727931117d0
      iwe=iwe+1
      weightc( 36, 74,  3)=                 -0.18517516720662779983d0
      iwe=iwe+1
      weightc( 37, 74,  3)=                  0.13566731031394813067d0
      iwe=iwe+1
      weightc( 38, 74,  3)=                  0.39398589535283090601d0
      iwe=iwe+1
      weightc( 39, 74,  3)=                 -0.03340752312394653506d0
      iwe=iwe+1
      weightc( 40, 74,  3)=                 -0.15684195881783533078d0
      iwe=iwe+1
      weightc( 41, 74,  3)=                 -0.23221940667860643814d0
      iwe=iwe+1
      weightc( 42, 74,  3)=                  0.20138102939788743440d0
      iwe=iwe+1
      weightc( 43, 74,  3)=                 -0.00601171655947957233d0
      iwe=iwe+1
      weightc( 44, 74,  3)=                 -0.02679010938949540066d0
      iwe=iwe+1
      weightc( 45, 74,  3)=                  0.19750994823466411221d0
      iwe=iwe+1
      weightc( 46, 74,  3)=                  0.19902242647500675843d0
      iwe=iwe+1
      weightc( 47, 74,  3)=                 -0.02013011931173624633d0
      iwe=iwe+1
      weightc( 48, 74,  3)=                 -0.07871811451489683920d0
      iwe=iwe+1
      weightc( 49, 74,  3)=                  0.11413225016338107709d0
      iwe=iwe+1
      weightc( 50, 74,  3)=                 -0.44504691800015760972d0
      iwe=iwe+1
      biasc( 74,  3)=                 -1.38747110919962124420d0
      iwe=iwe+1
      weightc(  1, 75,  3)=                  0.03424917469380925339d0
      iwe=iwe+1
      weightc(  2, 75,  3)=                  0.28338965455006887018d0
      iwe=iwe+1
      weightc(  3, 75,  3)=                  0.30173274985893749900d0
      iwe=iwe+1
      weightc(  4, 75,  3)=                 -0.30596993397490224176d0
      iwe=iwe+1
      weightc(  5, 75,  3)=                  0.26594197079371417747d0
      iwe=iwe+1
      weightc(  6, 75,  3)=                 -0.45387055724827585212d0
      iwe=iwe+1
      weightc(  7, 75,  3)=                 -0.23929545798289650338d0
      iwe=iwe+1
      weightc(  8, 75,  3)=                 -0.12633813140695041022d0
      iwe=iwe+1
      weightc(  9, 75,  3)=                  0.19417714837649124870d0
      iwe=iwe+1
      weightc( 10, 75,  3)=                  0.33446482230134089164d0
      iwe=iwe+1
      weightc( 11, 75,  3)=                  0.35966383777731675275d0
      iwe=iwe+1
      weightc( 12, 75,  3)=                 -0.04324470980475059873d0
      iwe=iwe+1
      weightc( 13, 75,  3)=                 -0.09587174591803103441d0
      iwe=iwe+1
      weightc( 14, 75,  3)=                  0.44011567984366373185d0
      iwe=iwe+1
      weightc( 15, 75,  3)=                 -0.06212827528494878349d0
      iwe=iwe+1
      weightc( 16, 75,  3)=                  0.06918127225239824318d0
      iwe=iwe+1
      weightc( 17, 75,  3)=                 -0.00572356729719096947d0
      iwe=iwe+1
      weightc( 18, 75,  3)=                  0.01128745879899241411d0
      iwe=iwe+1
      weightc( 19, 75,  3)=                  0.12182235973275175323d0
      iwe=iwe+1
      weightc( 20, 75,  3)=                  0.10954543859614439272d0
      iwe=iwe+1
      weightc( 21, 75,  3)=                  0.22277730009124296906d0
      iwe=iwe+1
      weightc( 22, 75,  3)=                  0.18146478622210671094d0
      iwe=iwe+1
      weightc( 23, 75,  3)=                 -0.05202021583495632789d0
      iwe=iwe+1
      weightc( 24, 75,  3)=                  0.63863151896186154399d0
      iwe=iwe+1
      weightc( 25, 75,  3)=                  0.57893106798614990538d0
      iwe=iwe+1
      weightc( 26, 75,  3)=                  0.09186889520653329644d0
      iwe=iwe+1
      weightc( 27, 75,  3)=                  0.04995156491820643141d0
      iwe=iwe+1
      weightc( 28, 75,  3)=                 -0.04232386548017409017d0
      iwe=iwe+1
      weightc( 29, 75,  3)=                 -0.59928512174465475848d0
      iwe=iwe+1
      weightc( 30, 75,  3)=                  0.38788470890084031373d0
      iwe=iwe+1
      weightc( 31, 75,  3)=                 -0.13843795268502190332d0
      iwe=iwe+1
      weightc( 32, 75,  3)=                 -0.24352624728566560353d0
      iwe=iwe+1
      weightc( 33, 75,  3)=                  0.14653113124534014600d0
      iwe=iwe+1
      weightc( 34, 75,  3)=                 -0.01419885487370538615d0
      iwe=iwe+1
      weightc( 35, 75,  3)=                 -0.53330329513849350498d0
      iwe=iwe+1
      weightc( 36, 75,  3)=                  0.02304414814772039188d0
      iwe=iwe+1
      weightc( 37, 75,  3)=                 -0.10592798800895557310d0
      iwe=iwe+1
      weightc( 38, 75,  3)=                 -0.15635720613948070334d0
      iwe=iwe+1
      weightc( 39, 75,  3)=                 -0.21033254551762894935d0
      iwe=iwe+1
      weightc( 40, 75,  3)=                  0.19858943562918798809d0
      iwe=iwe+1
      weightc( 41, 75,  3)=                  0.07519244050332826723d0
      iwe=iwe+1
      weightc( 42, 75,  3)=                 -0.29622282646613018464d0
      iwe=iwe+1
      weightc( 43, 75,  3)=                 -0.15415201157331503978d0
      iwe=iwe+1
      weightc( 44, 75,  3)=                 -0.14598977175846045151d0
      iwe=iwe+1
      weightc( 45, 75,  3)=                  0.35314267691011863581d0
      iwe=iwe+1
      weightc( 46, 75,  3)=                  0.11577628172648629645d0
      iwe=iwe+1
      weightc( 47, 75,  3)=                 -0.07157204231485510271d0
      iwe=iwe+1
      weightc( 48, 75,  3)=                  0.49593578183390496505d0
      iwe=iwe+1
      weightc( 49, 75,  3)=                 -0.15898844096085415489d0
      iwe=iwe+1
      weightc( 50, 75,  3)=                 -0.39590902842052411170d0
      iwe=iwe+1
      biasc( 75,  3)=                 -1.43313739630046699247d0
      iwe=iwe+1
      weightc(  1, 76,  3)=                 -0.21349648699355316950d0
      iwe=iwe+1
      weightc(  2, 76,  3)=                 -0.44915939849797326122d0
      iwe=iwe+1
      weightc(  3, 76,  3)=                 -0.36635037692833055667d0
      iwe=iwe+1
      weightc(  4, 76,  3)=                 -0.03489411879206051614d0
      iwe=iwe+1
      weightc(  5, 76,  3)=                 -0.13066284017745866119d0
      iwe=iwe+1
      weightc(  6, 76,  3)=                 -0.14045871175911181505d0
      iwe=iwe+1
      weightc(  7, 76,  3)=                 -0.25175582853571815134d0
      iwe=iwe+1
      weightc(  8, 76,  3)=                 -0.03820797034094850636d0
      iwe=iwe+1
      weightc(  9, 76,  3)=                 -0.50562500687758027418d0
      iwe=iwe+1
      weightc( 10, 76,  3)=                  0.50535397870115827956d0
      iwe=iwe+1
      weightc( 11, 76,  3)=                 -0.68031659439831715375d0
      iwe=iwe+1
      weightc( 12, 76,  3)=                 -0.24798469427851724256d0
      iwe=iwe+1
      weightc( 13, 76,  3)=                  0.09389877740893598501d0
      iwe=iwe+1
      weightc( 14, 76,  3)=                 -0.35461507642258988104d0
      iwe=iwe+1
      weightc( 15, 76,  3)=                 -0.18883739397752116740d0
      iwe=iwe+1
      weightc( 16, 76,  3)=                  0.14966120096885138224d0
      iwe=iwe+1
      weightc( 17, 76,  3)=                  0.01867395286276105765d0
      iwe=iwe+1
      weightc( 18, 76,  3)=                  0.21702276281717050588d0
      iwe=iwe+1
      weightc( 19, 76,  3)=                  0.14700342521846546107d0
      iwe=iwe+1
      weightc( 20, 76,  3)=                  0.02267867324958253161d0
      iwe=iwe+1
      weightc( 21, 76,  3)=                  0.48434747966132934982d0
      iwe=iwe+1
      weightc( 22, 76,  3)=                 -0.03541427474580677998d0
      iwe=iwe+1
      weightc( 23, 76,  3)=                 -0.32122498047636022234d0
      iwe=iwe+1
      weightc( 24, 76,  3)=                  0.47888776013214573446d0
      iwe=iwe+1
      weightc( 25, 76,  3)=                  0.70149331670090198099d0
      iwe=iwe+1
      weightc( 26, 76,  3)=                  0.09340135537236096686d0
      iwe=iwe+1
      weightc( 27, 76,  3)=                  0.63674052192168251185d0
      iwe=iwe+1
      weightc( 28, 76,  3)=                 -0.67024201300811991899d0
      iwe=iwe+1
      weightc( 29, 76,  3)=                 -0.01749402280016793682d0
      iwe=iwe+1
      weightc( 30, 76,  3)=                  0.15885774169365343700d0
      iwe=iwe+1
      weightc( 31, 76,  3)=                 -0.33110920095400664387d0
      iwe=iwe+1
      weightc( 32, 76,  3)=                 -0.09527394314667689268d0
      iwe=iwe+1
      weightc( 33, 76,  3)=                  0.19301719695852309622d0
      iwe=iwe+1
      weightc( 34, 76,  3)=                  0.33704580943222650635d0
      iwe=iwe+1
      weightc( 35, 76,  3)=                 -0.27824439083065732881d0
      iwe=iwe+1
      weightc( 36, 76,  3)=                  0.05631392464417478427d0
      iwe=iwe+1
      weightc( 37, 76,  3)=                  0.01455600979541091591d0
      iwe=iwe+1
      weightc( 38, 76,  3)=                  0.18138943190210549128d0
      iwe=iwe+1
      weightc( 39, 76,  3)=                 -0.22144682845219015865d0
      iwe=iwe+1
      weightc( 40, 76,  3)=                 -0.02240387456465785937d0
      iwe=iwe+1
      weightc( 41, 76,  3)=                 -0.02587884327624388400d0
      iwe=iwe+1
      weightc( 42, 76,  3)=                 -0.20576164021663792547d0
      iwe=iwe+1
      weightc( 43, 76,  3)=                 -0.23761919608743115040d0
      iwe=iwe+1
      weightc( 44, 76,  3)=                 -0.07384462638074550112d0
      iwe=iwe+1
      weightc( 45, 76,  3)=                  0.41287501561608019873d0
      iwe=iwe+1
      weightc( 46, 76,  3)=                 -0.08382381988416784391d0
      iwe=iwe+1
      weightc( 47, 76,  3)=                  0.37765199585471675991d0
      iwe=iwe+1
      weightc( 48, 76,  3)=                  0.71869951592685166197d0
      iwe=iwe+1
      weightc( 49, 76,  3)=                  0.47124265719627822513d0
      iwe=iwe+1
      weightc( 50, 76,  3)=                  0.03467102828616933086d0
      iwe=iwe+1
      biasc( 76,  3)=                  1.28317900209839264036d0
      iwe=iwe+1
      weightc(  1, 77,  3)=                 -0.44838871722831341593d0
      iwe=iwe+1
      weightc(  2, 77,  3)=                  0.23987476589767595114d0
      iwe=iwe+1
      weightc(  3, 77,  3)=                  0.16370522110593371812d0
      iwe=iwe+1
      weightc(  4, 77,  3)=                  0.03530357164830294492d0
      iwe=iwe+1
      weightc(  5, 77,  3)=                 -0.00079219932616806103d0
      iwe=iwe+1
      weightc(  6, 77,  3)=                 -0.35998556644377621705d0
      iwe=iwe+1
      weightc(  7, 77,  3)=                  0.29305217201582955955d0
      iwe=iwe+1
      weightc(  8, 77,  3)=                  0.55199883777238156757d0
      iwe=iwe+1
      weightc(  9, 77,  3)=                 -0.03789152586144892837d0
      iwe=iwe+1
      weightc( 10, 77,  3)=                 -0.22600645485682757663d0
      iwe=iwe+1
      weightc( 11, 77,  3)=                  0.48316710328308526412d0
      iwe=iwe+1
      weightc( 12, 77,  3)=                  0.23861725323366425600d0
      iwe=iwe+1
      weightc( 13, 77,  3)=                  0.46650368363095690016d0
      iwe=iwe+1
      weightc( 14, 77,  3)=                 -0.11396964763611579230d0
      iwe=iwe+1
      weightc( 15, 77,  3)=                  0.54542753912741104294d0
      iwe=iwe+1
      weightc( 16, 77,  3)=                  0.11193632117870670750d0
      iwe=iwe+1
      weightc( 17, 77,  3)=                 -0.27648123963866133579d0
      iwe=iwe+1
      weightc( 18, 77,  3)=                  0.35579616928237395301d0
      iwe=iwe+1
      weightc( 19, 77,  3)=                 -0.72062787825887253401d0
      iwe=iwe+1
      weightc( 20, 77,  3)=                 -0.57944958004393942730d0
      iwe=iwe+1
      weightc( 21, 77,  3)=                  0.35878462486548656774d0
      iwe=iwe+1
      weightc( 22, 77,  3)=                 -0.45345820444415319006d0
      iwe=iwe+1
      weightc( 23, 77,  3)=                  0.51657156275913129750d0
      iwe=iwe+1
      weightc( 24, 77,  3)=                 -0.08771301475245474322d0
      iwe=iwe+1
      weightc( 25, 77,  3)=                  0.41301836663363217239d0
      iwe=iwe+1
      weightc( 26, 77,  3)=                 -0.19793593342667195611d0
      iwe=iwe+1
      weightc( 27, 77,  3)=                 -0.03740920669789678243d0
      iwe=iwe+1
      weightc( 28, 77,  3)=                  0.03652885521193134644d0
      iwe=iwe+1
      weightc( 29, 77,  3)=                 -0.35429570447262298538d0
      iwe=iwe+1
      weightc( 30, 77,  3)=                  0.35346871248886529981d0
      iwe=iwe+1
      weightc( 31, 77,  3)=                 -0.07146881520362058371d0
      iwe=iwe+1
      weightc( 32, 77,  3)=                 -0.65417964749936841073d0
      iwe=iwe+1
      weightc( 33, 77,  3)=                 -0.41620151745854822023d0
      iwe=iwe+1
      weightc( 34, 77,  3)=                  0.03641446236221079075d0
      iwe=iwe+1
      weightc( 35, 77,  3)=                  0.21582477811709527282d0
      iwe=iwe+1
      weightc( 36, 77,  3)=                  0.06137697970002490427d0
      iwe=iwe+1
      weightc( 37, 77,  3)=                  0.33676820144565505766d0
      iwe=iwe+1
      weightc( 38, 77,  3)=                  0.07441746794641290741d0
      iwe=iwe+1
      weightc( 39, 77,  3)=                  0.25834638234678825031d0
      iwe=iwe+1
      weightc( 40, 77,  3)=                 -0.22144356156498459787d0
      iwe=iwe+1
      weightc( 41, 77,  3)=                  0.06814717523411355227d0
      iwe=iwe+1
      weightc( 42, 77,  3)=                 -0.17194794332631463396d0
      iwe=iwe+1
      weightc( 43, 77,  3)=                  0.10409843259857348707d0
      iwe=iwe+1
      weightc( 44, 77,  3)=                 -0.48304886548835690441d0
      iwe=iwe+1
      weightc( 45, 77,  3)=                  0.13328653582672000955d0
      iwe=iwe+1
      weightc( 46, 77,  3)=                  0.28851936443359565976d0
      iwe=iwe+1
      weightc( 47, 77,  3)=                 -0.30568917776738235847d0
      iwe=iwe+1
      weightc( 48, 77,  3)=                 -0.08426337726191446276d0
      iwe=iwe+1
      weightc( 49, 77,  3)=                  0.55867878462205344814d0
      iwe=iwe+1
      weightc( 50, 77,  3)=                  0.03209241901451272833d0
      iwe=iwe+1
      biasc( 77,  3)=                  1.31206218027615961752d0
      iwe=iwe+1
      weightc(  1, 78,  3)=                  0.07111394387740101186d0
      iwe=iwe+1
      weightc(  2, 78,  3)=                  0.38213261266019915574d0
      iwe=iwe+1
      weightc(  3, 78,  3)=                 -0.20800705160774729530d0
      iwe=iwe+1
      weightc(  4, 78,  3)=                  0.22595539687859567124d0
      iwe=iwe+1
      weightc(  5, 78,  3)=                 -0.35900813864671254905d0
      iwe=iwe+1
      weightc(  6, 78,  3)=                 -0.32638051825202296641d0
      iwe=iwe+1
      weightc(  7, 78,  3)=                  0.07736588975276140201d0
      iwe=iwe+1
      weightc(  8, 78,  3)=                  0.31913670580808944921d0
      iwe=iwe+1
      weightc(  9, 78,  3)=                  0.20706342345585732057d0
      iwe=iwe+1
      weightc( 10, 78,  3)=                 -0.05833901785772986626d0
      iwe=iwe+1
      weightc( 11, 78,  3)=                  0.26926022147021416719d0
      iwe=iwe+1
      weightc( 12, 78,  3)=                  0.17162356527519231908d0
      iwe=iwe+1
      weightc( 13, 78,  3)=                  0.31713547256261481744d0
      iwe=iwe+1
      weightc( 14, 78,  3)=                 -0.26582685935465699689d0
      iwe=iwe+1
      weightc( 15, 78,  3)=                 -0.21855606875529581812d0
      iwe=iwe+1
      weightc( 16, 78,  3)=                 -0.29438835288192349848d0
      iwe=iwe+1
      weightc( 17, 78,  3)=                  0.45098558190077264740d0
      iwe=iwe+1
      weightc( 18, 78,  3)=                  0.07978727972711638361d0
      iwe=iwe+1
      weightc( 19, 78,  3)=                 -0.17851197593058973356d0
      iwe=iwe+1
      weightc( 20, 78,  3)=                  0.26932500727216357461d0
      iwe=iwe+1
      weightc( 21, 78,  3)=                  0.02995420159539528490d0
      iwe=iwe+1
      weightc( 22, 78,  3)=                  0.18183270395567052713d0
      iwe=iwe+1
      weightc( 23, 78,  3)=                  0.00326600849097580768d0
      iwe=iwe+1
      weightc( 24, 78,  3)=                  0.19163528134226773258d0
      iwe=iwe+1
      weightc( 25, 78,  3)=                  0.04764476304593499856d0
      iwe=iwe+1
      weightc( 26, 78,  3)=                  0.12451951199160363193d0
      iwe=iwe+1
      weightc( 27, 78,  3)=                  0.43981559601735792375d0
      iwe=iwe+1
      weightc( 28, 78,  3)=                 -0.38314985183766536725d0
      iwe=iwe+1
      weightc( 29, 78,  3)=                  0.28690466869614439371d0
      iwe=iwe+1
      weightc( 30, 78,  3)=                 -0.37907161674270906104d0
      iwe=iwe+1
      weightc( 31, 78,  3)=                 -0.19249745637787776809d0
      iwe=iwe+1
      weightc( 32, 78,  3)=                 -0.34894208918245039897d0
      iwe=iwe+1
      weightc( 33, 78,  3)=                  0.31375272260713615857d0
      iwe=iwe+1
      weightc( 34, 78,  3)=                  0.08401131473618486667d0
      iwe=iwe+1
      weightc( 35, 78,  3)=                 -0.18298513355107673406d0
      iwe=iwe+1
      weightc( 36, 78,  3)=                 -0.05608162036231610637d0
      iwe=iwe+1
      weightc( 37, 78,  3)=                 -0.43829165034070954876d0
      iwe=iwe+1
      weightc( 38, 78,  3)=                  0.27874459562849712713d0
      iwe=iwe+1
      weightc( 39, 78,  3)=                 -0.23093179242827419073d0
      iwe=iwe+1
      weightc( 40, 78,  3)=                 -0.27694746980538714753d0
      iwe=iwe+1
      weightc( 41, 78,  3)=                  0.19278619041697336867d0
      iwe=iwe+1
      weightc( 42, 78,  3)=                  0.25912923899166889763d0
      iwe=iwe+1
      weightc( 43, 78,  3)=                  0.03392352801570349546d0
      iwe=iwe+1
      weightc( 44, 78,  3)=                  0.58726040824394565298d0
      iwe=iwe+1
      weightc( 45, 78,  3)=                  0.02518647096792472201d0
      iwe=iwe+1
      weightc( 46, 78,  3)=                  0.02034925501246473076d0
      iwe=iwe+1
      weightc( 47, 78,  3)=                  0.36463250415312770114d0
      iwe=iwe+1
      weightc( 48, 78,  3)=                  0.22444605989791210909d0
      iwe=iwe+1
      weightc( 49, 78,  3)=                  0.01536220928119066617d0
      iwe=iwe+1
      weightc( 50, 78,  3)=                  0.40477981052066103196d0
      iwe=iwe+1
      biasc( 78,  3)=                 -1.45501141531404809548d0
      iwe=iwe+1
      weightc(  1, 79,  3)=                  0.11779371572823645054d0
      iwe=iwe+1
      weightc(  2, 79,  3)=                 -0.43059290817919204652d0
      iwe=iwe+1
      weightc(  3, 79,  3)=                  0.23785540116460543447d0
      iwe=iwe+1
      weightc(  4, 79,  3)=                  0.23914319754602400558d0
      iwe=iwe+1
      weightc(  5, 79,  3)=                 -0.12776804550203607613d0
      iwe=iwe+1
      weightc(  6, 79,  3)=                  0.09119288314944569429d0
      iwe=iwe+1
      weightc(  7, 79,  3)=                 -0.02372039496224026198d0
      iwe=iwe+1
      weightc(  8, 79,  3)=                 -0.12519633939374841258d0
      iwe=iwe+1
      weightc(  9, 79,  3)=                  0.29931284195592644526d0
      iwe=iwe+1
      weightc( 10, 79,  3)=                  0.08320603679454159629d0
      iwe=iwe+1
      weightc( 11, 79,  3)=                  0.07739341048563230796d0
      iwe=iwe+1
      weightc( 12, 79,  3)=                 -0.02337956084279591354d0
      iwe=iwe+1
      weightc( 13, 79,  3)=                 -0.21271493881643077639d0
      iwe=iwe+1
      weightc( 14, 79,  3)=                  0.14259366480826829449d0
      iwe=iwe+1
      weightc( 15, 79,  3)=                  0.02006237906847428698d0
      iwe=iwe+1
      weightc( 16, 79,  3)=                  0.18041527413972544003d0
      iwe=iwe+1
      weightc( 17, 79,  3)=                 -0.07026443695618768415d0
      iwe=iwe+1
      weightc( 18, 79,  3)=                  0.18267309873925161035d0
      iwe=iwe+1
      weightc( 19, 79,  3)=                  0.34188358690892783898d0
      iwe=iwe+1
      weightc( 20, 79,  3)=                 -0.40650612115745704545d0
      iwe=iwe+1
      weightc( 21, 79,  3)=                  0.15042244672263549443d0
      iwe=iwe+1
      weightc( 22, 79,  3)=                  0.30849623060899972193d0
      iwe=iwe+1
      weightc( 23, 79,  3)=                  0.45286485174897028738d0
      iwe=iwe+1
      weightc( 24, 79,  3)=                 -0.07372965379827924048d0
      iwe=iwe+1
      weightc( 25, 79,  3)=                  0.27728252676832693124d0
      iwe=iwe+1
      weightc( 26, 79,  3)=                 -0.26262383098926422864d0
      iwe=iwe+1
      weightc( 27, 79,  3)=                 -0.25054584251817479945d0
      iwe=iwe+1
      weightc( 28, 79,  3)=                  0.12806930189938339759d0
      iwe=iwe+1
      weightc( 29, 79,  3)=                 -0.26271764806945957504d0
      iwe=iwe+1
      weightc( 30, 79,  3)=                  0.24017189751945211551d0
      iwe=iwe+1
      weightc( 31, 79,  3)=                 -0.35732463558368804390d0
      iwe=iwe+1
      weightc( 32, 79,  3)=                 -0.23059902061116555050d0
      iwe=iwe+1
      weightc( 33, 79,  3)=                  0.11170653690873770525d0
      iwe=iwe+1
      weightc( 34, 79,  3)=                 -0.27017045685975377145d0
      iwe=iwe+1
      weightc( 35, 79,  3)=                  0.19577370958125614453d0
      iwe=iwe+1
      weightc( 36, 79,  3)=                  0.04004079554124562179d0
      iwe=iwe+1
      weightc( 37, 79,  3)=                 -0.08011389960472584115d0
      iwe=iwe+1
      weightc( 38, 79,  3)=                  0.29812012839964463495d0
      iwe=iwe+1
      weightc( 39, 79,  3)=                  0.29208045454079184511d0
      iwe=iwe+1
      weightc( 40, 79,  3)=                  0.24653425841229811843d0
      iwe=iwe+1
      weightc( 41, 79,  3)=                 -0.03862169799509088119d0
      iwe=iwe+1
      weightc( 42, 79,  3)=                 -0.20493637869867650791d0
      iwe=iwe+1
      weightc( 43, 79,  3)=                  0.26594424217109524644d0
      iwe=iwe+1
      weightc( 44, 79,  3)=                  0.34554315078432829011d0
      iwe=iwe+1
      weightc( 45, 79,  3)=                 -0.02388497518317327095d0
      iwe=iwe+1
      weightc( 46, 79,  3)=                 -0.08885162823256818887d0
      iwe=iwe+1
      weightc( 47, 79,  3)=                 -0.11169317655119588573d0
      iwe=iwe+1
      weightc( 48, 79,  3)=                  0.35701383781660500638d0
      iwe=iwe+1
      weightc( 49, 79,  3)=                 -0.25116792538434318249d0
      iwe=iwe+1
      weightc( 50, 79,  3)=                  0.02797961834502281711d0
      iwe=iwe+1
      biasc( 79,  3)=                  1.41984321764634957574d0
      iwe=iwe+1
      weightc(  1, 80,  3)=                  0.13441521900812350432d0
      iwe=iwe+1
      weightc(  2, 80,  3)=                  0.28729123674791917642d0
      iwe=iwe+1
      weightc(  3, 80,  3)=                  0.51715098303440543148d0
      iwe=iwe+1
      weightc(  4, 80,  3)=                 -0.06914868821663339160d0
      iwe=iwe+1
      weightc(  5, 80,  3)=                 -0.01762877919402384974d0
      iwe=iwe+1
      weightc(  6, 80,  3)=                 -0.40768344042790433113d0
      iwe=iwe+1
      weightc(  7, 80,  3)=                 -0.21152666268408501504d0
      iwe=iwe+1
      weightc(  8, 80,  3)=                 -0.20244546624260650880d0
      iwe=iwe+1
      weightc(  9, 80,  3)=                 -0.18075340697500688614d0
      iwe=iwe+1
      weightc( 10, 80,  3)=                 -0.07038095601311927796d0
      iwe=iwe+1
      weightc( 11, 80,  3)=                 -0.48177170672589197942d0
      iwe=iwe+1
      weightc( 12, 80,  3)=                  0.13812639994320397019d0
      iwe=iwe+1
      weightc( 13, 80,  3)=                 -0.39306464563276488633d0
      iwe=iwe+1
      weightc( 14, 80,  3)=                 -0.06105151154629685772d0
      iwe=iwe+1
      weightc( 15, 80,  3)=                  0.14566034597104648984d0
      iwe=iwe+1
      weightc( 16, 80,  3)=                  0.41369914894543424744d0
      iwe=iwe+1
      weightc( 17, 80,  3)=                  0.30718268201260223726d0
      iwe=iwe+1
      weightc( 18, 80,  3)=                  0.16719927436088163897d0
      iwe=iwe+1
      weightc( 19, 80,  3)=                  0.01055311017332236090d0
      iwe=iwe+1
      weightc( 20, 80,  3)=                 -0.08534915612847772393d0
      iwe=iwe+1
      weightc( 21, 80,  3)=                 -0.57708483647346164869d0
      iwe=iwe+1
      weightc( 22, 80,  3)=                 -0.35667831390084470122d0
      iwe=iwe+1
      weightc( 23, 80,  3)=                  0.25438701787501799556d0
      iwe=iwe+1
      weightc( 24, 80,  3)=                 -0.11110264214071351174d0
      iwe=iwe+1
      weightc( 25, 80,  3)=                 -0.10372166247791536620d0
      iwe=iwe+1
      weightc( 26, 80,  3)=                  0.14254662493196479378d0
      iwe=iwe+1
      weightc( 27, 80,  3)=                  0.16435673384991933421d0
      iwe=iwe+1
      weightc( 28, 80,  3)=                  0.15261239500004972203d0
      iwe=iwe+1
      weightc( 29, 80,  3)=                 -0.37900867442129371199d0
      iwe=iwe+1
      weightc( 30, 80,  3)=                 -0.22123201848690177140d0
      iwe=iwe+1
      weightc( 31, 80,  3)=                  0.10279520338757963671d0
      iwe=iwe+1
      weightc( 32, 80,  3)=                  0.28085881412482760489d0
      iwe=iwe+1
      weightc( 33, 80,  3)=                  0.43982430269523398181d0
      iwe=iwe+1
      weightc( 34, 80,  3)=                 -0.19101443499303577545d0
      iwe=iwe+1
      weightc( 35, 80,  3)=                 -0.28692784808767846094d0
      iwe=iwe+1
      weightc( 36, 80,  3)=                 -0.07938354062574845549d0
      iwe=iwe+1
      weightc( 37, 80,  3)=                  0.06708604798137052239d0
      iwe=iwe+1
      weightc( 38, 80,  3)=                 -0.01709885741002947421d0
      iwe=iwe+1
      weightc( 39, 80,  3)=                 -0.39250799583253687119d0
      iwe=iwe+1
      weightc( 40, 80,  3)=                  0.34146421688520972593d0
      iwe=iwe+1
      weightc( 41, 80,  3)=                 -0.08829034832924161080d0
      iwe=iwe+1
      weightc( 42, 80,  3)=                 -0.06346526472172739353d0
      iwe=iwe+1
      weightc( 43, 80,  3)=                  0.35080952882589910846d0
      iwe=iwe+1
      weightc( 44, 80,  3)=                 -0.39111625964523699661d0
      iwe=iwe+1
      weightc( 45, 80,  3)=                  0.16179461269600026174d0
      iwe=iwe+1
      weightc( 46, 80,  3)=                 -0.27808869214282466720d0
      iwe=iwe+1
      weightc( 47, 80,  3)=                 -0.06856792352362676979d0
      iwe=iwe+1
      weightc( 48, 80,  3)=                 -0.07532016606031380346d0
      iwe=iwe+1
      weightc( 49, 80,  3)=                  0.46872743824225127085d0
      iwe=iwe+1
      weightc( 50, 80,  3)=                  0.05146151322462173133d0
      iwe=iwe+1
      biasc( 80,  3)=                  1.50842401238802814589d0
      iwe=iwe+1
      weightc(  1,  1,  4)=                 -0.01449713772443666886d0
      iwe=iwe+1
      weightc(  2,  1,  4)=                  0.68246013026824647874d0
      iwe=iwe+1
      weightc(  3,  1,  4)=                  1.42604091858485904076d0
      iwe=iwe+1
      weightc(  4,  1,  4)=                 -1.01959773003000009339d0
      iwe=iwe+1
      weightc(  5,  1,  4)=                  1.13054909877317655287d0
      iwe=iwe+1
      weightc(  6,  1,  4)=                  0.86504849596458444072d0
      iwe=iwe+1
      weightc(  7,  1,  4)=                 -0.97090490858821443254d0
      iwe=iwe+1
      weightc(  8,  1,  4)=                 -0.98556618855658906231d0
      iwe=iwe+1
      weightc(  9,  1,  4)=                  0.57174322903054231038d0
      iwe=iwe+1
      weightc( 10,  1,  4)=                  1.02821546094558491369d0
      iwe=iwe+1
      weightc( 11,  1,  4)=                 -1.04123243206120252857d0
      iwe=iwe+1
      weightc( 12,  1,  4)=                  0.64770316156933893659d0
      iwe=iwe+1
      weightc( 13,  1,  4)=                 -0.65632833888242136933d0
      iwe=iwe+1
      weightc( 14,  1,  4)=                 -0.71583617667977217369d0
      iwe=iwe+1
      weightc( 15,  1,  4)=                 -0.18133223212049648376d0
      iwe=iwe+1
      weightc( 16,  1,  4)=                  0.30677837428219445481d0
      iwe=iwe+1
      weightc( 17,  1,  4)=                  1.01437472666760486462d0
      iwe=iwe+1
      weightc( 18,  1,  4)=                  1.30659843943131614985d0
      iwe=iwe+1
      weightc( 19,  1,  4)=                 -1.03916522768893160311d0
      iwe=iwe+1
      weightc( 20,  1,  4)=                 -1.24233237737205981510d0
      iwe=iwe+1
      weightc( 21,  1,  4)=                  1.26831020621400836212d0
      iwe=iwe+1
      weightc( 22,  1,  4)=                 -0.59741271966820075345d0
      iwe=iwe+1
      weightc( 23,  1,  4)=                  0.62122607192706935653d0
      iwe=iwe+1
      weightc( 24,  1,  4)=                  0.78482892639461865336d0
      iwe=iwe+1
      weightc( 25,  1,  4)=                 -0.45885343266933104056d0
      iwe=iwe+1
      weightc( 26,  1,  4)=                 -1.25889728321497296193d0
      iwe=iwe+1
      weightc( 27,  1,  4)=                  0.40112056973616233568d0
      iwe=iwe+1
      weightc( 28,  1,  4)=                 -0.63414159178491813496d0
      iwe=iwe+1
      weightc( 29,  1,  4)=                  1.33945945628730211929d0
      iwe=iwe+1
      weightc( 30,  1,  4)=                  1.31083385695120080428d0
      iwe=iwe+1
      weightc( 31,  1,  4)=                  1.22978249629432601076d0
      iwe=iwe+1
      weightc( 32,  1,  4)=                  1.18613830336248238240d0
      iwe=iwe+1
      weightc( 33,  1,  4)=                  0.64653327809526583980d0
      iwe=iwe+1
      weightc( 34,  1,  4)=                 -0.61704678213034047651d0
      iwe=iwe+1
      weightc( 35,  1,  4)=                 -0.35995425425202071112d0
      iwe=iwe+1
      weightc( 36,  1,  4)=                  0.84985673879154655097d0
      iwe=iwe+1
      weightc( 37,  1,  4)=                  1.25259446216181635769d0
      iwe=iwe+1
      weightc( 38,  1,  4)=                 -0.65831372056719894559d0
      iwe=iwe+1
      weightc( 39,  1,  4)=                  1.01621032759437435189d0
      iwe=iwe+1
      weightc( 40,  1,  4)=                  0.57319077480127389457d0
      iwe=iwe+1
      weightc( 41,  1,  4)=                 -1.01185976579249170548d0
      iwe=iwe+1
      weightc( 42,  1,  4)=                 -0.49199655009017628782d0
      iwe=iwe+1
      weightc( 43,  1,  4)=                 -1.15345426698204622795d0
      iwe=iwe+1
      weightc( 44,  1,  4)=                  0.74245259797578411209d0
      iwe=iwe+1
      weightc( 45,  1,  4)=                  0.72138124443475659664d0
      iwe=iwe+1
      weightc( 46,  1,  4)=                 -0.67415288854544808128d0
      iwe=iwe+1
      weightc( 47,  1,  4)=                  1.22215189728609430198d0
      iwe=iwe+1
      weightc( 48,  1,  4)=                 -1.65133177580874290769d0
      iwe=iwe+1
      weightc( 49,  1,  4)=                 -0.56491705473059505849d0
      iwe=iwe+1
      weightc( 50,  1,  4)=                  1.43699279395094126066d0
      iwe=iwe+1
      weightc( 51,  1,  4)=                 -0.81035123220992066884d0
      iwe=iwe+1
      weightc( 52,  1,  4)=                 -0.65532049329429609141d0
      iwe=iwe+1
      weightc( 53,  1,  4)=                 -1.12368675175907917207d0
      iwe=iwe+1
      weightc( 54,  1,  4)=                  1.08843636199482252103d0
      iwe=iwe+1
      weightc( 55,  1,  4)=                  0.99092830405428811158d0
      iwe=iwe+1
      weightc( 56,  1,  4)=                 -0.30970053641065076189d0
      iwe=iwe+1
      weightc( 57,  1,  4)=                  0.63164084683238741480d0
      iwe=iwe+1
      weightc( 58,  1,  4)=                  1.03440618236647141615d0
      iwe=iwe+1
      weightc( 59,  1,  4)=                  0.78576280530646591682d0
      iwe=iwe+1
      weightc( 60,  1,  4)=                  1.31718186486491473097d0
      iwe=iwe+1
      weightc( 61,  1,  4)=                 -0.91817579654727821126d0
      iwe=iwe+1
      weightc( 62,  1,  4)=                 -0.93161927757659102056d0
      iwe=iwe+1
      weightc( 63,  1,  4)=                  1.08091327194997277594d0
      iwe=iwe+1
      weightc( 64,  1,  4)=                  0.85209544125021885463d0
      iwe=iwe+1
      weightc( 65,  1,  4)=                  1.08249805064773552132d0
      iwe=iwe+1
      weightc( 66,  1,  4)=                 -0.79564684725301193513d0
      iwe=iwe+1
      weightc( 67,  1,  4)=                  1.86570348231570815045d0
      iwe=iwe+1
      weightc( 68,  1,  4)=                  1.37501707418509955261d0
      iwe=iwe+1
      weightc( 69,  1,  4)=                  1.01470595496444859762d0
      iwe=iwe+1
      weightc( 70,  1,  4)=                 -0.05935946110020732386d0
      iwe=iwe+1
      weightc( 71,  1,  4)=                  1.01826845459606518673d0
      iwe=iwe+1
      weightc( 72,  1,  4)=                 -0.45801299494309011262d0
      iwe=iwe+1
      weightc( 73,  1,  4)=                 -0.95323175533196469189d0
      iwe=iwe+1
      weightc( 74,  1,  4)=                 -1.37236757060484837467d0
      iwe=iwe+1
      weightc( 75,  1,  4)=                 -0.43246141642637853097d0
      iwe=iwe+1
      weightc( 76,  1,  4)=                  0.48848757772073475580d0
      iwe=iwe+1
      weightc( 77,  1,  4)=                 -0.93340519315738268435d0
      iwe=iwe+1
      weightc( 78,  1,  4)=                 -1.33404712573571559986d0
      iwe=iwe+1
      weightc( 79,  1,  4)=                 -0.42220136865424112704d0
      iwe=iwe+1
      weightc( 80,  1,  4)=                  0.57757149088433423767d0
      iwe=iwe+1
      biasc(  1,  4)=                  0.96900308575181981485d0
      iwe=iwe+1
      iwe= 5061
      if (iwe.ne.nwe) then
      write(*,*)'provided number of parameters ',nwe
      write(*,*)'actual number of parameters ',iwe
      write(*,*)'nwe not equal to iwe, check inputfiles or code'
      stop
      endif
        return

        end subroutine pes_init

        subroutine getpota(x,vpot)
        use nnparam
        implicit none
        integer i,inode1,inode2,ilay1,ilay2
        real*8 x(ninput),y(nodemax,nlayer),vpot
        real*8, external :: tranfun
!-->....set up the normalized input layer
        do i=1,ninput
          y(i,1)=(x(i)-pavga(i))/pdela(i)
        enddo

!-->....evaluate the hidden layer
        do ilay1=2,nlayer-1
        ilay2=ilay1-1
        do inode1=1,nodes(ilay1)
        y(inode1,ilay1)=biasa(inode1,ilay1)
        do inode2=1,nodes(ilay2)
        y(inode1,ilay1)=y(inode1,ilay1)+y(inode2,ilay2)&
     &*weighta(inode2,inode1,ilay1)
        enddo
        y(inode1,ilay1)=tranfun(y(inode1,ilay1),ifunc)
        enddo
        enddo

!-->....now evaluate the output
        ilay1=nlayer
        ilay2=ilay1-1
        do inode1=1,nodes(ilay1)
        y(inode1,ilay1)=biasa(inode1,ilay1)
        do inode2=1,nodes(ilay2)
        y(inode1,ilay1)=y(inode1,ilay1)+y(inode2,ilay2)&
     &*weighta(inode2,inode1,ilay1)
        enddo
!-->....the transfer function is linear y=x for output layer
!-->....so no operation is needed here
        enddo

!-->....the value of output layer is the fitted potntial 
        vpot=y(nodes(nlayer),nlayer)*pdela(nscale)+pavga(nscale)
        return
        end subroutine getpota

        subroutine getpotb(x,vpot)
        use nnparam
        implicit none
        integer i,inode1,inode2,ilay1,ilay2
        real*8 x(ninput),y(nodemax,nlayer),vpot
        real*8, external :: tranfun
!-->....set up the normalized input layer
        do i=1,ninput
          y(i,1)=(x(i)-pavgb(i))/pdelb(i)
        enddo

!-->....evaluate the hidden layer
        do ilay1=2,nlayer-1
        ilay2=ilay1-1
        do inode1=1,nodes(ilay1)
        y(inode1,ilay1)=biasb(inode1,ilay1)
        do inode2=1,nodes(ilay2)
        y(inode1,ilay1)=y(inode1,ilay1)+y(inode2,ilay2)&
     &*weightb(inode2,inode1,ilay1)
        enddo
        y(inode1,ilay1)=tranfun(y(inode1,ilay1),ifunc)
        enddo
        enddo

!-->....now evaluate the output
        ilay1=nlayer
        ilay2=ilay1-1
        do inode1=1,nodes(ilay1)
        y(inode1,ilay1)=biasb(inode1,ilay1)
        do inode2=1,nodes(ilay2)
        y(inode1,ilay1)=y(inode1,ilay1)+y(inode2,ilay2)&
     &*weightb(inode2,inode1,ilay1)
        enddo
!-->....the transfer function is linear y=x for output layer
!-->....so no operation is needed here
        enddo

!-->....the value of output layer is the fitted potntial 
        vpot=y(nodes(nlayer),nlayer)*pdelb(nscale)+pavgb(nscale)
        return
        end subroutine getpotb

        subroutine getpotc(x,vpot)
        use nnparam
        implicit none
        integer i,inode1,inode2,ilay1,ilay2
        real*8 x(ninput),y(nodemax,nlayer),vpot
        real*8, external :: tranfun
!-->....set up the normalized input layer
        do i=1,ninput
          y(i,1)=(x(i)-pavgc(i))/pdelc(i)
        enddo

!-->....evaluate the hidden layer
        do ilay1=2,nlayer-1
        ilay2=ilay1-1
        do inode1=1,nodes(ilay1)
        y(inode1,ilay1)=biasc(inode1,ilay1)
        do inode2=1,nodes(ilay2)
        y(inode1,ilay1)=y(inode1,ilay1)+y(inode2,ilay2)&
     &*weightc(inode2,inode1,ilay1)
        enddo
        y(inode1,ilay1)=tranfun(y(inode1,ilay1),ifunc)
        enddo
        enddo

!-->....now evaluate the output
        ilay1=nlayer
        ilay2=ilay1-1
        do inode1=1,nodes(ilay1)
        y(inode1,ilay1)=biasc(inode1,ilay1)
        do inode2=1,nodes(ilay2)
        y(inode1,ilay1)=y(inode1,ilay1)+y(inode2,ilay2)&
     &*weightc(inode2,inode1,ilay1)
        enddo
!-->....the transfer function is linear y=x for output layer
!-->....so no operation is needed here
        enddo

!-->....the value of output layer is the fitted potntial 
        vpot=y(nodes(nlayer),nlayer)*pdelc(nscale)+pavgc(nscale)
        return
        end subroutine getpotc

        function tranfun(x,ifunc)
        implicit none
        integer ifunc
        real*8 tranfun,x
        if (ifunc.eq.1) then
        tranfun=dtanh(x)
        else if (ifunc.eq.2) then
        tranfun=1d0/(1d0+exp(-x))
        else if (ifunc.eq.3) then
        tranfun=x
        endif
        return
        end

      function emsav(x,c) result(v)
      implicit none
      real*8,dimension(1:6)::x
      real*8,dimension(0:17)::c
      real*8::v
      ! ::::::::::::::::::::
      real*8,dimension(0:17)::p
      call bemsav(x,p)
      v = dot_product(p,c)
      return
      end function emsav
 
      subroutine bemsav(x,p)
      implicit none
      real*8,dimension(1:6),intent(in)::x
      real*8,dimension(0:17),intent(out)::p
      ! ::::::::::::::::::::
      real*8,dimension(0:10)::m
      call evmono(x,m)
      call evpoly(m,p)
      return
      end subroutine bemsav
 
      subroutine evmono(x,m)
      implicit none
      real*8,dimension(1:6),intent(in)::x
      real*8,dimension(0:10),intent(out)::m
 
      m(0)=1.D0
      m(1)=x(6)
      m(2)=x(5)
      m(3)=x(3)
      m(4)=x(4)
      m(5)=x(2)
      m(6)=x(1)
      m(7)=m(2)*m(3)
      m(8)=m(3)*m(4)
      m(9)=m(2)*m(5)
      m(10)=m(4)*m(5)
 
      return
      end subroutine evmono
 
      subroutine evpoly(m,p)
      implicit none
      real*8,dimension(0:10),intent(in)::m
      real*8,dimension(0:17),intent(out)::p
 
      p(0)=m(0)
      p(1)=m(1)
      p(2)=m(2)+m(3)
      p(3)=m(4)+m(5)
      p(4)=m(6)
      p(5)=p(1)*p(2)
      p(6)=m(7)
      p(7)=p(1)*p(3)
      p(8)=m(8)+m(9)
      p(9)=m(10)
      p(10)=p(2)*p(3)-p(8)
      p(11)=p(1)*p(4)
      p(12)=p(4)*p(2)
      p(13)=p(4)*p(3)
      p(14)=p(1)*p(1)
      p(15)=p(2)*p(2)-p(6)-p(6)
      p(16)=p(3)*p(3)-p(9)-p(9)
      p(17)=p(4)*p(4)
 
      return
      end subroutine evpoly

!++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      subroutine HOHCl_pes_interface(xc,vpes)
      use nnparam,only: vpescut
      implicit none
      integer lxc,i,j
      real*8 xc(3,4),rbond(6),xct(3,4),xvec(3,6),xct2(3,4)
      real*8 dpthcl,dptho,r13,r23,rhpo,rhcl,vfit,vdp
      real*8 vt1,vcorr,vpes,tmp1,ybond(6),va,vb,vc

      real*8 xcom1(3),xcom2(3),rcom,mass(4),skey

      mass(1)=1.00794d0
      mass(2)=mass(1)
      mass(3)=35.453d0   !HHClO standard weight
      mass(4)=15.9994d0
      
      vt1=0.0d0
      vcorr=0.0d0
      xct=xc

      xvec(:,2)=xct(:,3)-xct(:,1) !  Cl-H1
      xvec(:,4)=xct(:,3)-xct(:,2) !  H2-Cl
      r13=dsqrt(dot_product(xvec(:,2),xvec(:,2)))
      r23=dsqrt(dot_product(xvec(:,4),xvec(:,4)))

! check the linked atom order: make sure that
! 1st H linked or near Cl 

      if(r13.gt.r23)then
       xct2(:,1)=xct(:,2) 
       xct2(:,2)=xct(:,1) 
       xct2(:,3)=xct(:,3) 
       xct2(:,4)=xct(:,4)
      else
       xct2=xct
      endif

      call before_vpes(xct2,lxc)  !xct in order for H1-Cl  and H2-O, if possible

      if(lxc.eq.-1)then
        vpes=vpescut
        return
      endif

      lxc=0
      if(lxc.eq.2)then
        call HO_HCl_correction(xct2,vpes)        
        vpes=min(vpes,vpescut)
        return
      endif

      if(lxc.eq.0)then
        call clh2oNN(xct2,vpes,va,vb,vc)
        vpes=min(vpes,vpescut)
        return
      endif

      if(lxc.eq.1)then
! check the linked atom order: make sure that
! 1st H linked or near Cl 

        xcom1(:)=xct2(:,1)+(mass(3)/(mass(1)+mass(3)))*&
     & (xct2(:,3)-xct2(:,1))
        xcom2(:)=xct2(:,2)+(mass(4)/(mass(2)+mass(4)))*&
     & (xct2(:,4)-xct2(:,2))
        rcom=dsqrt(dot_product(xcom1-xcom2,xcom1-xcom2))
        skey=(1.0d0-dtanh(0.8d0*(rcom-10.0d0)))/2.0d0 
        call clh2oNN(xct2,vfit,va,vb,vc)
        call HO_HCl_correction(xct2,vdp)
        vpes=skey*vfit+(1.0d0-skey)*vdp 
        vpes=min(vpes,vpescut)
        return
      endif

      return
      end subroutine HOHCl_pes_interface 

!++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!make sure that 1st H linked or near to Cl
      subroutine HO_HCl_correction(xc,vdp)
      use nnparam
      implicit none 
      real*8 xc(3,4),xct2(3,4),vdp,vcorr,rbond(6),vt1
      real*8 xvec(3,6),rhpo,rhcl,dpthcl,dptho
      real*8 angB,angA,angAB,vecHCl(3),vecHO(3),vecHH(3)
      real*8 pointA(3),pointB(3),vecACl(3),vecBO(3),vecAB(3)
      real*8 rACl,rBO,rAB

      xct2=xc
      vt1=0.0d0
      vcorr=0.d0
      
      xvec(:,1)=xct2(:,2)-xct2(:,1) !  H2->H1
      xvec(:,2)=xct2(:,3)-xct2(:,1) !  Cl->H1
      xvec(:,3)=xct2(:,4)-xct2(:,1) !  O->H1
      xvec(:,4)=xct2(:,3)-xct2(:,2) !  H2->Cl
      xvec(:,5)=xct2(:,4)-xct2(:,2) !  H2->O
      xvec(:,6)=xct2(:,4)-xct2(:,3) !  Cl-O 
     
      rbond(1)=dsqrt(dot_product(xvec(:,1),xvec(:,1)))
      rbond(2)=dsqrt(dot_product(xvec(:,2),xvec(:,2)))
      rbond(3)=dsqrt(dot_product(xvec(:,3),xvec(:,3)))
      rbond(4)=dsqrt(dot_product(xvec(:,4),xvec(:,4)))
      rbond(5)=dsqrt(dot_product(xvec(:,5),xvec(:,5)))
      rbond(6)=dsqrt(dot_product(xvec(:,6),xvec(:,6))) 

      rhcl=rbond(2)
      rhpo=rbond(5)

!     Cl /\                       /\ O     
!          \                     /
!           \ thetaA            /thetaB
!         A  \-----------------/-----/
!             \               / B
!              \             /
!               \           / H
!             H  \

             
      call HO_HCl_pes_spline(rhcl,rhpo,vt1) 

      rhcl=rhcl/0.5291772d0
      rhpo=rhpo/0.52917720d0

      call hcl_dipole(rhcl,dpthcl)
      call ho_dipole(rhpo,dptho)

!      dipole should be for the middle point of HCl and HO 

      vecHCl(:)=xvec(:,2)
      vecHO(:)=xvec(:,5)
         
      pointA(:)=xct2(:,1)+vecHCl(:)/2.0d0
      pointB(:)=xct2(:,2)+vecHO(:)/2.0d0

      vecACl(:)=xct2(:,3)-pointA(:)
      vecBO(:)=xct2(:,4)-pointB(:)
      vecAB(:)=pointB(:)-pointA(:)

      rACl=dsqrt(dot_product(vecACl(:),vecACl(:)))
      rBO=dsqrt(dot_product(vecBO(:),vecBO(:)))
      rAB=dsqrt(dot_product(vecAB(:),vecAB(:)))

      angA=dot_product(vecACl,vecAB)/(rACl*rAB)
      angA=dacos(max(-1.0d0,min(1.0d0,angA)))

      angB=dot_product(vecBO,vecAB)/(rBO*rAB)
      angB=dacos(max(-1.0d0,min(1.0d0,angB)))

      angAB=dot_product(vecACl,vecBO)/(rACl*rBO)
      angAB=dacos(max(-1.0d0,min(1.0d0,angAB)))

      vcorr=dpthcl*dptho/((rAB/0.5291772d0)**3)*&
     &      (dcos(angAB)-3.0d0*dcos(angB)*dcos(angA))

      vdp=((vt1+vcorr)-vpesmin)*627.509d0 - 0.15d0
      vdp=vdp/23.0605d0

      return

      end subroutine HO_HCl_correction
      
!++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
! determine if need to call correction from dipole interaction of HO and HCl
! or, switch HHFO in the order of H1-Cl3, H2-O4 if possible
      subroutine before_vpes(xct,lxc)
      implicit none
      real*8 xct(3,4),bt(6),xvec(3,6),xct2(3,4)
      real*8 xcom1(3),xcom2(3),rcom,mass(4)
      real*8 r12,r13,r14,r23,r24,r34
      integer lxc,i,lbc,lcd,lde

      mass(1)=1.00794d0
      mass(2)=mass(1)
      mass(3)=35.453d0   !HHClO standard weight
      mass(4)=15.9994d0
      
! lxc=-1, unphysical point
! lxc=0,  normal
! lxc=1,  HO+HCl, using switch function
! lxc=2,  HO+HCl, using dipole interaction correction

      lxc=0
      lbc=0
      lcd=0
      lde=0
     
      xct2=xct
      
      xvec(:,1)=xct2(:,2)-xct2(:,1) !  H2-H1
      xvec(:,2)=xct2(:,3)-xct2(:,1) !  Cl-H1
      xvec(:,3)=xct2(:,4)-xct2(:,1) !  O-H1
      xvec(:,4)=xct2(:,3)-xct2(:,2) !  H2-Cl
      xvec(:,5)=xct2(:,4)-xct2(:,2) !  H2-O
      xvec(:,6)=xct2(:,4)-xct2(:,3) !  Cl-O 
     
      r12=dsqrt(dot_product(xvec(:,1),xvec(:,1)))
      r13=dsqrt(dot_product(xvec(:,2),xvec(:,2)))
      r14=dsqrt(dot_product(xvec(:,3),xvec(:,3)))
      r23=dsqrt(dot_product(xvec(:,4),xvec(:,4)))
      r24=dsqrt(dot_product(xvec(:,5),xvec(:,5)))
      r34=dsqrt(dot_product(xvec(:,6),xvec(:,6))) 

      bt(:)=(/r12,r13,r14,r23,r24,r34/)

! remove some unphysical points      
      
      do i=1,6
       if(bt(i).le.0.60d0)then
         lxc=-1 
         return
       endif
      enddo

!--> ClO distance, do not consider  H2 + ClO channel      
!--> ClO equilibrium distance,1.596gstrom, x 130% = 2.07 angstrom
      if(r34.le.1.30d0.or.r12.le.0.60d0) then 
       lxc=-1
       return
      endif

      if(minval(bt).ge.2.00d0)then  ! 
        lxc=-1
        return
      endif

      if(r13.le.0.75d0.or.r23.le.0.75d0)then
        lxc=-1
        return
      endif

! H+O+HCl or HO + H +Cl or H+H+Cl+O      
      if(r14.lt.r24.and.r24.gt.2.0d0) then
        if(r14.ge.2.0d0.or.r23.ge.2.0d0)then   
          lxc=-1
          return
        endif
      endif

      if(r24.lt.r14.and.r14.gt.2.0d0) then
        if(r24.ge.2.0d0.or.r13.ge.2.0d0)then  
          lxc=-1
          return
        endif
      endif
! OH1 and OH2 are both large
      if(r14.ge.2.0d0.and.r24.ge.2.0d0)then
        lxc=-1
        return
      endif
     
! ClH1 and ClH2 are both small
      if(r13.le.1.1d0.and.r23.le.1.1d0)then
        lxc=-1
        return
      endif
     
!     if(r23.lt.r13.and.r13.gt.1.9d0.and.r24.gt.1.8d0) then
!       if(r14.ge.1.8d0.or.r23.ge.1.9d0)then   
!         lxc=-1
!         return
!       endif
!     endif

!     if(r13.lt.r23.and.r23.gt.1.9d0.and.r14.gt.1.8d0) then
!       if(r13.ge.1.8d0.or.r24.ge.1.9d0)then  
!         lxc=-1
!         return
!       endif
!     endif
     
!check if HO and HCl were produced

!     if(r12.ge.3.5d0)then
!       
!       xcom1(:)=xct2(:,1)+(mass(3)/(mass(1)+mass(3)))*
!    $ (xct2(:,3)-xct2(:,1))
!       xcom2(:)=xct2(:,2)+(mass(4)/(mass(2)+mass(4)))*
!    $ (xct2(:,4)-xct2(:,2))
!    
!       rcom=dsqrt(dot_product(xcom1-xcom2,xcom1-xcom2))
!     
!       if(rcom.ge.5.0d0.and.rcom.le.16.0d0)then
!         lxc=1
!         return
!       else if(rcom.gt.16.0d0)then
!         lxc=2
!         return
!       else
!         lxc=0
!         return
!       endif

!     endif 
      lxc=0

      return

      end subroutine before_vpes
      
!++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      subroutine ho_dipole(rt,dpt)
      use nnparam
      IMPLICIT none
      integer,parameter::nn=100
      real*8,parameter::dy1=1.0d30,dyn=1.0d30
      real*8 y2(nn),rt,dpt

      y2=DP0ho2
      if (rt.lt.R0ho(1))  rt=R0ho(1)
      if (rt.gt.R0ho(n0ho))rt=R0ho(n0ho)
      call splint(R0ho,DP0ho,y2,n0ho,rt,dpt)

      return
        
      end  subroutine ho_dipole
     
!++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      subroutine hcl_dipole(rt,dpt)
      use nnparam
      IMPLICIT none
      integer,parameter::nn=100
      real*8,parameter::dy1=1.0d30,dyn=1.0d30
      real*8 y2(nn),rt,dpt

      y2=DP0hcl2
      if (rt.lt.R0hcl(1))  rt=R0hcl(1)
      if (rt.gt.R0hcl(n0hcl))rt=R0hcl(n0hcl)
      call splint(R0hcl,DP0hcl,y2,n0hcl,rt,dpt)

      return
        
      end  subroutine hcl_dipole
  
!++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      subroutine HO_HCl_pes_spline(r1,r2,vpes)
      use nnparam
      implicit none
      integer,parameter::nn=100 
      real*8 ytmp(nn),y2tmp(nn),y2a(nxhcl,nxho),yytmp(nn)
      real*8 x1a(nxhcl),x2a(nxho),ya(nxhcl,nxho)
      integer i,j,k,m,n
      real*8 r1,r2,x1,x2,y,vpes
      
      x1=r1
      x2=r2
      
      x1a=Rxhcl
      x2a=Rxho
      ya=Exhohcl

      m=nxhcl
      n=nxho

      y2a=Exhohcl2 
      
      do j=1,m
       do k=1,n
        ytmp(k)=ya(j,k)
        y2tmp(k)=y2a(j,k)
       enddo

       call splint(x2a,ytmp,y2tmp,n,x2,yytmp(j))

      enddo

      call spline(x1a,yytmp,m,1.0d30,1.0d30,y2tmp)
      call splint(x1a,yytmp,y2tmp,m,x1,y)

      vpes=y
      
      return

      end subroutine  HO_HCl_pes_spline
      
!++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE splint(xa,ya,y2a,n,x,y)
      implicit double precision  (a-h,o-z)
      DIMENSION xa(n),y2a(n),ya(n)
      klo=1
      khi=n
 1    if (khi-klo.gt.1) then
        k=(khi+klo)/2
        if(xa(k).gt.x)then
          khi=k
        else
          klo=k
        endif
      goto 1
      endif
      h=xa(khi)-xa(klo)
      if (h.eq.0.0d0) write(6,*) 'bad xa input in splint'
      a=(xa(khi)-x)/h
      b=(x-xa(klo))/h
      y=a*ya(klo)+b*ya(khi)+((a**3-a)*y2a(klo)+(b**3-b)*y2a(khi))*(h**2)/6.0d0
      return
      END

      SUBROUTINE spline(x,y,n,yp1,ypn,y2)
      implicit double precision  (a-h,o-z)
      DIMENSION x(n),y(n),y2(n)
      PARAMETER (NMAX=100)
      DIMENSION u(NMAX)
      if (yp1.gt..99d30) then
        y2(1)=0.0d0
        u(1)=0.0d0
      else
        y2(1)=-0.5d0
        u(1)=(3.0d0/(x(2)-x(1)))*((y(2)-y(1))/(x(2)-x(1))-yp1)
      endif
      do 11 i=2,n-1
        sig=(x(i)-x(i-1))/(x(i+1)-x(i-1))
        p=sig*y2(i-1)+2.0d0
        y2(i)=(sig-1.0d0)/p
        u(i)=(6.0d0*((y(i+1)-y(i))/(x(i+&
     &1)-x(i))-(y(i)-y(i-1))/(x(i)-x(i-1)))/(x(i+1)-x(i-1))-sig*&
     &u(i-1))/p
11    continue
      if (ypn.gt..99d30) then
        qn=0.0d0
        un=0.0d0
      else
        qn=0.5d0
        un=(3.0d0/(x(n)-x(n-1)))*(ypn-(y(n)-y(n-1))/(x(n)-x(n-1)))
      endif
      y2(n)=(un-qn*u(n-1))/(qn*y2(n-1)+1.0d0)
      do 12 k=n-1,1,-1
        y2(k)=y2(k)*y2(k+1)+u(k)
12    continue
      return
      END

!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->
